(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   3071769,      88401]
NotebookOptionsPosition[   2942818,      84379]
NotebookOutlinePosition[   2944305,      84434]
CellTagsIndexPosition[   2944199,      84428]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["AVF ",
  FontSlant->"Italic"],
 "Doc"
}], "Title",
 FontColor->RGBColor[1, 0, 0]],

Cell["Exterior calculus with algebra valued forms", "Subtitle",
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 StyleBox["Hugo D. Wahlquist \[Copyright] 2003-2012",
  FontSize->18],
 "\n\n",
 StyleBox["Now mantained by Frank B. Estabrook and Jos\[EAcute] M. Mart\
\[IAcute]n-Garc\[IAcute]a after Hugo passed away in 2008.",
  FontSize->14]
}], "Subsubtitle"],

Cell[TextData[{
 StyleBox["AVF",
  FontSlant->"Italic"],
 " is a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package for\n\t- exterior calculus with indexed (or algebra-valued) sets \
of basis forms,\n\t- Cartan moving frame theory in n-dimensional Riemannian \
geometry with arbitrary signature,\n\t- the exterior differential systems of \
Cartan-K\[ADoubleDot]hler theory and calculation of Cartan characters, and\n\t\
- embedding of Riemannian manifolds.\nThere are specific programs for \
generation and use of Clifford algebra valued forms with moving frames, and \
generalizations.  This package is a small modification of a suite of programs \
written by Hugo D. Wahlquist in 2003.\n\nFrank Estabrook, long-time \
collaborator of Hugo Wahlquist and first user of ",
 StyleBox["AVF, ",
  FontSlant->"Italic"],
 "has kindly authorized these programs to be included in the ",
 StyleBox["xAct",
  FontSlant->"Italic"],
 " suite of tensor computer algebra packages for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". The original programs, as Hugo wrote them for him, can be downloaded from\
\n\n\t",
 ButtonBox["http://www.emis.de/journals/SIGMA/2008/063/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.emis.de/journals/SIGMA/2008/063/"], None},
  ButtonNote->"http://www.emis.de/journals/SIGMA/2008/063/"],
 "\n\nThe original programs were not structured as a single ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package. There were actually two main codes, AVF (Algebra Valued Forms) \
and CAV (Clifford Algebra Valued forms), plus additional smaller utility \
programs. They have been merged and documented as a single ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package, called ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 ", and adapted to the ",
 StyleBox["xAct",
  FontSlant->"Italic"],
 " hierarchy.\n\nThe ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package is independent of the rest of the ",
 StyleBox["xAct",
  FontSlant->"Italic"],
 " packages except for ",
 StyleBox["xCore",
  FontSlant->"Italic"],
 ", needed to access directory information. ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " is included in the ",
 StyleBox["xAct",
  FontSlant->"Italic"],
 " framework because it covers a complementary area. It does not yet talk to \
the other mathematical packages as it uses a different, mostly index-free, \
approach."
}], "Text"],

Cell[TextData[{
 "\nThis is the doc file AVFDoc.nb of version 1.0 of the ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package. Last update on 17 December 2011.\n\nThis AVFDoc.nb file has been \
built by joining and editing nine different documentation files that Hugo \
wrote. At the beginning of each section we indicate the respective file used. \
It is divided in four parts:\n\t- Introduction: a general discussion of the \
capabilities of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 ", with no executable code.\n\t- Basic computations\n\t- Examples: not so \
basic computations\n\t- Advanced computations"
}], "Text"],

Cell[TextData[{
 "Two relevant references:\n\nF. B. Estabrook and H. D. Wahlquist, \
\[OpenCurlyDoubleQuote]",
 StyleBox["Classical Geometries Defined by Exterior Differential Systems on \
Higher Frame Bundles",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote], Classical and Quantum Gravity, 6, 263-74 (1989) \
(for Clifford-algebra-valued forms, Cartan-K\[ADoubleDot]hler theory and \
Cartan characters)\n\nH.D. Wahlquist \[OpenCurlyDoubleQuote]",
 StyleBox["Monte Carlo calculation of Cartan characters",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote], in Proc. International Conference on Aspects of \
General Relativity  and Mathematical Physics, ed. N. Breton, R. Capovilla and \
T. Matos, Mexico City, CINVESTAV, 1993."
}], "Text"],

Cell[CellGroupData[{

Cell["I. Introduction", "Section",
 FontColor->RGBColor[0, 0, 1]],

Cell["This is taken from the file AVF_Introduction.nb.", "Text"],

Cell[CellGroupData[{

Cell["I.a. General comments", "Subsection"],

Cell[TextData[{
 "This section contains a general description of the structure and \
capabilities of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 ". It covers the basic information and operations needed to understand the \
package, but will not serve as a detailed manual. All the operations \
described here, and many additional ones, are introduced, explained and used \
in the demonstration sections below.\n  \nSection I.g contains a summary of \
the complete set of variable and function names together with a brief \
description for each entry."
}], "Text",
 PageBreakBelow->Automatic,
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["I.b. Basic structures", "Subsection"],

Cell["\<\
An  algebra-valued-form (AVF) is a multinomial, each term of which is a \
product of three types of factors:

\t( scalar coefficient ) ( exterior product of basis forms ) ( a single \
algebra element )\
\>", "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 TextJustification->0,
 FontWeight->"Plain"],

Cell["For example,", "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"sampleterm", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", 
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Theta]", "2"]}], ")"}], 
   RowBox[{"(", 
    SubscriptBox["e", "3"], ")"}], "         ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"parentheses", " ", "optional"}], ")"}], "                  ", 
    "[", "1", "]"}]}]}]], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["\<\
Any of these factors may be omitted in any term of an AVF expression.\
\>", "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["I.b.1. Fundamental lists", "Subsubsection"],

Cell[TextData[{
 "The algebraic categories of the variables involved are established by their \
membership in one of three fundamental lists of arbitrarily chosen symbols \
with the reserved names: ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "After calling up the ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package with  ",
 StyleBox["<<xAct`AVF`", "Input",
  FontWeight->"Plain"],
 " and before starting a calculation, these lists may be defined (and can be \
changed at any later time) by the commands :\t"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", 
    RowBox[{"list", " ", "of", " ", "scalar", " ", "symbols"}], "}"}], "]"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"makeforms", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"list", " ", "of", " ", "1"}], "-", 
      RowBox[{"form", " ", "symbols"}]}], "}"}], "]"}], 
   "                                                          ", "[", "2", 
   "]"}], "\n"}], "\n", 
 RowBox[{"makeelements", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"list", " ", "of", " ", "algebra"}], "-", 
    RowBox[{"element", " ", "symbols"}]}], "}"}], "]"}]}], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "For instance, the following start-up commands (which can be executed in any \
order) would establish the properties of the symbols in the ",
 StyleBox["sampleterm", "Input",
  FontWeight->"Plain"],
 " used in [1] :"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{"makeforms", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], ",", 
    SubscriptBox["\[Theta]", "2"], ",", 
    SubscriptBox["\[Theta]", "3"], ",", 
    SubscriptBox["\[Theta]", "4"]}], "}"}], "]"}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], ",", 
     SubscriptBox["\[Theta]", "2"], ",", 
     SubscriptBox["\[Theta]", "3"], ",", 
     SubscriptBox["\[Theta]", "4"]}], "}"}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], 
  "                                                                           \
             ", "[", "3", "]"}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], "\n"}], "\n", 
 RowBox[{"makeelements", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["e", "0"], ",", 
    SubscriptBox["e", "1"], ",", 
    SubscriptBox["e", "2"], ",", 
    SubscriptBox["e", "3"]}], "}"}], "]"}], "\n", 
 StyleBox[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["e", "0"], ",", 
    SubscriptBox["e", "1"], ",", 
    SubscriptBox["e", "2"], ",", 
    SubscriptBox["e", "3"]}], "}"}],
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Outline"->False,
  "Shadow"->False,
  "Underline"->False}]}], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "Since their names are protected, the lists cannot be defined by simple \
assignments; such as for example, ",
 StyleBox["scalars={x, y, z}", "Input",
  FontWeight->"Plain"],
 ", although their values may always be viewed by typing their names.\n  \t\t\
\nIf the ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " commands are not executed, the lists will have the default values: ",
 StyleBox["scalars={}", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["forms={}", "Input",
  FontWeight->"Plain"],
 ", and ",
 StyleBox["elements={identity}", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "The ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " commands are needed to perform  several essential chores in addition to \
defining the values of the respective lists. For instance, the ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " commands for ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " (0-forms) and  ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " (1-forms) automatically  generate lists of symbols for their exterior \
derivatives with reserved names, ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 "; e.g.,"
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{"dscalars", "\n", 
 StyleBox[
  RowBox[{"{", 
   RowBox[{"dx", ",", "dy", ",", "dz"}], "}"}],
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Outline"->False,
  "Shadow"->False,
  "Underline"->False}], "\n", 
 RowBox[{"                                                                    \
                                                                     ", 
  RowBox[{"[", "4", "]"}]}], "\n", "dforms", "\n", 
 RowBox[{
  StyleBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["d\[Theta]", "1"], ",", 
     SubscriptBox["d\[Theta]", "2"], ",", 
     SubscriptBox["d\[Theta]", "3"], ",", 
     SubscriptBox["d\[Theta]", "4"]}], "}"}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], "\t\t\t\t\t\t\t\t     \t  \t"}]}], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "Furthermore, the ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " list is automatically joined to the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list,"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{"forms", 
  "                                                                           \
                                                   ", "[", "5", "]"}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], ",", 
     SubscriptBox["\[Theta]", "2"], ",", 
     SubscriptBox["\[Theta]", "3"], ",", 
     SubscriptBox["\[Theta]", "4"], ",", "dx", ",", "dy", ",", "dz"}], "}"}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  "                                                                      \
"}]}], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "and all members of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " are treated as independent 1-forms generating the Grassmann algebra based \
on them.\n\nThe algebra elements are assumed to be constant.\n  \t\t\nA ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " command creates a new list each time it is used; it does not extend the \
existing list. So, for example, ",
 StyleBox["makescalars[{}]", "Input",
  FontWeight->"Plain"],
 "  deletes all scalars, and ",
 StyleBox["makeforms[{}]", "Input",
  FontWeight->"Plain"],
 " deletes all 1-forms, except for the members of ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " (if any), which can be removed only by deleting the scalars.\n  \t\t \n\
Extending a list can be accomplished by; e.g., :"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"Join", "[", 
    RowBox[{"scalars", ",", 
     RowBox[{"{", 
      RowBox[{"list", " ", "of", " ", "additional", " ", "scalars"}], "}"}]}],
     "]"}], "]"}], "               ", "[", "6", "]"}]], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "Many other lists (described below) are also generated automatically by \
these commands, or else created by their own ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " commands."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["I.b.2. Symbols", "Subsubsection"],

Cell[TextData[{
 "There is nothing special about the particular symbols used for the members \
of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", and ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 "  in the examples displayed here. The symbols in these lists may be any \
variable names acceptable to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", and may include multiple subscripts, overscripts, underscripts, etc., but \
not superscripts, which are always interpreted as exponents.\t"
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "These symbols are the \"atoms\" out of which expressions will be built. \
They themselves must be elementary objects --simple names--, neither \
expressions nor functions, and must never have assigned values. For example, \
neither ",
 StyleBox["-x", "Input",
  FontWeight->"Plain"],
 "  nor ",
 StyleBox["f[x]", "Input",
  FontWeight->"Plain"],
 " is an acceptable candidate for membership in ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ", and ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"y", " ", "dz"}], " ", "-", " ", 
    RowBox[{"z", " ", "dy"}]}], ")"}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " is not a valid member of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". "
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "Any relations between the independent members of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " such as ",
 StyleBox["y\[Rule]y[x]", "Input",
  FontWeight->"Plain"],
 " or ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "1"], "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"y", " ", "dz"}], " ", "-", " ", 
     RowBox[{"z", " ", "dy"}]}], ")"}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 "can (",
 StyleBox["and must",
  FontVariations->{"Underline"->True}],
 ") be handled by using replacement rules, not by assignments. Of course, \
nothing forbits defining a 1-form ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], "=", 
   RowBox[{
    RowBox[{"y", " ", "dz"}], "-", 
    RowBox[{"z", " ", "dy"}]}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " by assignment; it simply becomes an AVF. But ",
 Cell[BoxData[
  SubscriptBox["\[Sigma]", "1"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " is not then an independent generator, or \[OpenCurlyDoubleQuote]basis-form\
\[CloseCurlyDoubleQuote], and so is not eligible for membership in the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list."
}], "Text"],

Cell[TextData[{
 "The ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " functions perform a screening test of their argument lists. The test will  \
cause an Interrupt if it finds a problem and indicate where it is, but it \
will not detect all possible errors. Most often, errors occur because a name \
has had a prior assignment. The Interrupt can be handled by selecting ",
 StyleBox["Abort", "Input",
  FontWeight->"Plain"],
 " in the window, modifying the input argument (e.g., clearing any assigned \
values), and re-executing the ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " command. Sometimes the easiest fix may be to ",
 StyleBox["Quit", "Input",
  FontWeight->"Plain"],
 " and re-start the Kernel.\t"
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "The different lists must have no members in common except for the automatic \
inclusion of ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " in ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". Any simple variable in an ",
 StyleBox["AVF",
  FontWeight->"Plain"],
 " expression which is not a member of any of these lists will be treated as \
a constant scalar parameter."
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["I.b.3. Algebras", "Subsubsection"],

Cell[TextData[{
 "The algebras of scalars and differential forms are fixed, but the algebra \
of elements must be specified in a multiplication table defining the desired \
algebra. This is accomplished by inputting a matrix with the appropriate \
products. For example, for an algebra with four generators (say, ",
 Cell[BoxData[
  RowBox[{"elements", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["e", "0"], ",", 
     SubscriptBox["e", "1"], ",", 
     SubscriptBox["e", "2"], ",", 
     SubscriptBox["e", "3"]}], "}"}]}]],
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 "), the matrix (here called producttable), would have the following \
structure:"
}], "Text"],

Cell[BoxData[
 RowBox[{"producttable", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "0"], 
       SubscriptBox["e", "0"]}], ",", 
      RowBox[{
       SubscriptBox["e", "0"], 
       SubscriptBox["e", "1"]}], ",", 
      RowBox[{
       SubscriptBox["e", "0"], 
       SubscriptBox["e", "2"]}], ",", 
      RowBox[{
       SubscriptBox["e", "0"], 
       SubscriptBox["e", "3"]}]}], "}"}], ",", "\n", "\t\t                ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "1"], 
       SubscriptBox["e", "0"]}], ",", 
      RowBox[{
       SubscriptBox["e", "1"], 
       SubscriptBox["e", "1"]}], ",", 
      RowBox[{
       SubscriptBox["e", "1"], 
       SubscriptBox["e", "2"]}], ",", 
      RowBox[{
       SubscriptBox["e", "1"], 
       SubscriptBox["e", "3"]}]}], "}"}], ",", 
    "                                                ", 
    RowBox[{
     RowBox[{"[", "7", "]"}], "\n", "\t\t                ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "2"], 
        SubscriptBox["e", "0"]}], ",", 
       RowBox[{
        SubscriptBox["e", "2"], 
        SubscriptBox["e", "1"]}], ",", 
       RowBox[{
        SubscriptBox["e", "2"], 
        SubscriptBox["e", "2"]}], ",", 
       RowBox[{
        SubscriptBox["e", "2"], 
        SubscriptBox["e", "3"]}]}], "}"}]}], ",", "\n", 
    "\t\t                ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "3"], 
       SubscriptBox["e", "0"]}], ",", 
      RowBox[{
       SubscriptBox["e", "3"], 
       SubscriptBox["e", "1"]}], ",", 
      RowBox[{
       SubscriptBox["e", "3"], 
       SubscriptBox["e", "2"]}], ",", 
      RowBox[{
       SubscriptBox["e", "3"], 
       SubscriptBox["e", "3"]}]}], "}"}]}], "}"}]}]], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "where the indicated products are to be replaced by their linear values for \
a specific algebra. Note that the first member of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " is always taken as the identity element of the algebra regardless of the \
symbol used for it. So in the above example, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["e", "0"], 
    SubscriptBox["e", "i"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["e", "i"], 
     SubscriptBox["e", "0"]}], " ", "=", " ", 
    SubscriptBox["e", "i"], " "}]}]],
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 ", and the top row and left column of the matrix will equal ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 "."
}], "Text"],

Cell["The algebra is then established by the command", "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makealgebra", "[", "producttable", "]"}], 
  "                                                                           \
       ", "[", "8", "]"}]], "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "which sets the reserved variable ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " to ",
 StyleBox["producttable", "Input",
  FontWeight->"Plain"],
 ". The variable ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " constitutes the actual look-up table for products of elements during \
calculations. It can be displayed in MatrixForm by typing the the command : \
",
 StyleBox["mtx[]", "Input",
  FontWeight->"Plain"],
 ". The ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " can be changed at any time by executing [8] with a different argument."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "The ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package requires an \"identity\" element, acting as a unital operator to \
serve as a  placeholder in many calculations. If the algebra defined by ",
 StyleBox["producttable", "Input",
  FontWeight->"Plain"],
 " does not include an identity element, one must be supplied by executing \
the command ",
 StyleBox["makealgebra[]", "Input",
  FontWeight->"Plain"],
 " with two arguments, ",
 StyleBox["makealgebra[producttable, symbol]", "Input",
  FontWeight->"Plain"],
 ", where the second (optional) argument, ",
 StyleBox["symbol", "Input",
  FontWeight->"Plain"],
 ", will be used as a new first member of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 ", to function as the essential placeholder. This will have no effect on the \
products defined by ",
 StyleBox["producttable", "Input",
  FontWeight->"Plain"],
 ", nor on calculations with AVFs not involving the spurious ",
 StyleBox["identity", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "Note that the initial values: ",
 StyleBox["elements={identity}", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["algebra={{identity}}", "Input",
  FontWeight->"Plain"],
 " are set when the package AVF.m is  called. These values are appropriate \
for doing ordinary differential form analysis, and so for this purpose it is \
not necessary to input any algebra table."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "The particular case of Clifford algebras is implemented through special \
routines collectively referred to as \[OpenCurlyDoubleQuote]the ",
 StyleBox["CAV",
  FontSlant->"Italic"],
 " program\[CloseCurlyDoubleQuote], described below. Using ",
 StyleBox["CAV",
  FontSlant->"Italic"],
 ", setting up a Clifford algebra can be easily accomplished by defining a \
list containing the signature of the metric in an ",
 StyleBox["orthonormal",
  FontVariations->{"Underline"->True}],
 " basis. Many problems in metric spaces, for example, can be conveniently \
treated with the CAV orthonormal frame form ",
 Cell[BoxData[
  OverscriptBox["\[Theta]", "^"]],
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 " and associated CAV connection form ",
 Cell[BoxData[
  OverscriptBox["\[Omega]", "^"]],
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 ", which are constructed by the ",
 StyleBox["CAV",
  FontSlant->"Italic"],
 " program."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["I.c. AVF expressions", "Subsection"],

Cell["\<\
An AVF expression is just a sum of terms similar to the sample term in [1]; \
e.g., \
\>", "Text",
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"avf", "=", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y", " ", 
     SubscriptBox["e", "2"]}], "+", 
    RowBox[{"\[Lambda]", " ", "z", " ", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "\[Wedge]", "dx"}], " ", 
     SubscriptBox["e", "0"]}], "-", " ", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"-", "3"}]], 
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "2"]}], " ", 
     SubscriptBox["e", "1"]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["d\[Theta]", "2"]}]}]}], 
  "                                          "}], "\n", 
 RowBox[{"                                                                    \
                                                                              \
 ", 
  RowBox[{"[", "9", "]"}]}], "\n", 
 StyleBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y", " ", 
    SubscriptBox["e", "2"]}], "+", 
   RowBox[{"z", " ", "\[Lambda]", " ", 
    SubscriptBox["e", "0"], " ", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", "dx"}]}], "+", 
   RowBox[{
    SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
    SubscriptBox["d\[Theta]", "2"]}], "-", 
   FractionBox[
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "2"]}]}], 
    SuperscriptBox["y", "3"]]}],
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Outline"->False,
  "Shadow"->False,
  "Underline"->False}]}], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "Any symbol in a wedge product must be a member of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " (which automatically includes ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 "), or of ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " (which is also automatically constructed). Improper inputs would include \
e.g., ",
 StyleBox[Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["\[Theta]", "1"],
     TraditionalForm], "\[Wedge]", 
    RowBox[{"(", 
     RowBox[{"-", 
      SubscriptBox["\[Theta]", "4"]}]}]}], TraditionalForm]], "Code",
  FontWeight->"Plain"], "Code"],
 StyleBox[") , (z ", "Code",
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[Theta]", "2"],
      TraditionalForm], ")"}], "\[Wedge]", " ", "dx"}], TraditionalForm]], 
  "Code",
  FontWeight->"Plain"], "Code"],
 StyleBox[" , ", "Code",
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "3"], TraditionalForm]], "Code",
  FontWeight->"Plain"], "Code"],
 StyleBox["\[Wedge] d ", "Code",
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "2"], TraditionalForm]], "Code",
  FontWeight->"Plain"], "Code"],
 StyleBox[" , y ", "Code",
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     FormBox[
      SubscriptBox["e", "2"],
      TraditionalForm], 
     RowBox[{
      SubscriptBox["e", "3"], "."}]}],
    FontSize->14], TraditionalForm]], "Code",
  FontWeight->"Plain"], "Code"],
 " Note that AVF expressions can be of inhomogeneous degree as differential \
forms.\n\nSince the symbol \[Lambda] is not a member of any list, it would be \
treated as a constant scalar. The missing algebra-element of the last input \
term defaults to the identity element of the algebra (the first member of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 "). Thus, the algebra-element could also have been omitted in the second \
term. If the algebra-element were omitted from all terms, ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " would become an ordinary differential form expression."
}], "Text"],

Cell[CellGroupData[{

Cell["I.c.1. Input", "Subsubsection"],

Cell[TextData[{
 "The expression ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " could be typed in from the keyboard just as it appears in [9]. For longer \
expressions, or more complicated symbols, this can become sufficiently \
tedious that defining a symbol palette my be useful, although the BasicInput \
palette is usually sufficient. In the case of expressions with uniform \
structure, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox["Sum", "Input",
  FontWeight->"Plain"],
 " function can be used, either with indexed symbols or with part \
specifications in the lists of variables; e.g.,"
}], "Text"],

Cell[BoxData[{
 RowBox[{"avf1", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "i"], 
     SubscriptBox["e", "i"]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "\n", 
 StyleBox[
  RowBox[{
   RowBox[{
    SubscriptBox["e", "1"], " ", 
    SubscriptBox["\[Theta]", "1"]}], "+", 
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Theta]", "2"]}], "+", 
   RowBox[{
    SubscriptBox["e", "3"], " ", 
    SubscriptBox["\[Theta]", "3"]}]}],
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Outline"->False,
  "Shadow"->False,
  "Underline"->False}], "\n", 
 RowBox[{"                                                                    \
                                                                              \
 ", 
  RowBox[{"[", "10", "]"}]}], "\n", 
 RowBox[{"avf1", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"forms", "[", 
      RowBox[{"[", "i", "]"}], "]"}], " ", 
     RowBox[{"elements", "[", 
      RowBox[{"[", 
       RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    SubscriptBox["e", "1"], " ", 
    SubscriptBox["\[Theta]", "1"]}], "+", 
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Theta]", "2"]}], "+", 
   RowBox[{
    SubscriptBox["e", "3"], " ", 
    SubscriptBox["\[Theta]", "3"]}]}],
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Outline"->False,
  "Shadow"->False,
  "Underline"->False}]}], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "Whenever an AVF expression is used as an argument in an ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " function (such a multiplication), it is converted to an equivalent List \
expression adapted to the simplified structure of AVFs. The purpose is to \
allow writing efficient ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " procedures and to accomplish certain operations that are quite difficult \
to implement with the standard commands provided by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".\n\nThese conversions happen \[OpenCurlyDoubleQuote]behind the scenes\
\[CloseCurlyDoubleQuote] and are generally invisible. The function ",
 StyleBox["in[avf]", "Input",
  FontWeight->"Plain"],
 " creates the equivalent List expression for the argument ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " whenever it is required in a calculation. The List expression can be \
displayed by executing that command with any AVF argument. Caution: only a \
properly input ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " will be converted correctly."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["I.c.2. Output", "Subsubsection"],

Cell[TextData[{
 "Upon completion of an ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " procedure, the final List expression is converted back to standard \
algebraic format by the function ",
 StyleBox["out[final]", "Input",
  FontWeight->"Plain"],
 ", essentially the inverse of ",
 StyleBox["in", "Input",
  FontWeight->"Plain"],
 ", except that all monomial wedge products are re-arranged into canonical ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " order and the identity element of the algebra is suppressed. Any of the \
usual ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands can then be used on the output expression."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["I.d. Algebraic operations", "Subsection"],

Cell["\<\
There are three special algebraic functions on AVFs implemented in the \
program; multiplication, factoring out a basis form, and contraction with \
vectors.\
\>", "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["I.d.1. Multiplication", "Subsubsection"],

Cell[TextData[{
 "The function, ",
 StyleBox["mult[avf1, avf2]", "Input",
  FontWeight->"Plain"],
 ", gives the expanded product of two AVFs. For each term in the result, it \
simultaneously performs the usual product of the scalar coefficients, the \
exterior product of the basis forms, and the algebraic product of the \
elements as determined by the ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " table.\n  \t\t\nThe same product results from using the ",
 StyleBox["NonCommutativeMultiply", "Input",
  FontWeight->"Plain"],
 " infix operator, ** . In this form, any number of AVFs can be multiplied \
together at once; e.g.,"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"avf1", "**", "avf2", "**", "avf3", "**", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"etc", "."}], ")"}], 
   "                                                                       ", 
   "[", "11", "]"}]}]], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["\<\
If the algebra table defines a non-associative algebra, it may be necessary \
to use the appropriate parentheses to define the order of multiplications. \
Without parentheses, multiplication proceeds from right to left, as for \
composite functions.\
\>", "Text"],

Cell[TextData[{
 "The infix wedge symbol \[Wedge] appearing  between basis forms in input and \
output expressions has the usual significance of exterior product. It is \
important to note, however, that it is neither recognized nor used by the \
program as an operator. It is used purely symbolically to denote products of \
basis forms, and also serves to prevent ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " from incorrectly permuting the order of such products."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "Any wedge symbol in a properly input ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " can be replaced by the ** operator. This has little effect when the wedge \
is between basis forms, but in the case of non-basis-form factors (which must \
themselves be properly input AVFs in  parentheses), it will cause the product \
to be expanded out."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "The AVF function, ",
 StyleBox["expand[avf]", "Input",
  FontWeight->"Plain"],
 ", is included for just this purpose. It substitutes ** for all wedge \
symbols in the argument ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 ", and returns the expanded result. Its primary use is to facilitate \
replacements within wedge products."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["I.d.2. Factoring", "Subsubsection"],

Cell[TextData[{
 "The function ",
 StyleBox["factor[basisform, avf]", "Input",
  FontWeight->"Plain"],
 " returns the factor of ",
 StyleBox["basisform", "Input",
  FontWeight->"Plain"],
 " in ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 ", where ",
 StyleBox["basisform", "Input",
  FontWeight->"Plain"],
 " is any member of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 ", and ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " is an AVF expression. The ",
 StyleBox["factor", "Input",
  FontWeight->"Plain"],
 " function does not require ",
 StyleBox["basisform", "Input",
  FontWeight->"Plain"],
 " to factor all of ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 "; it treats the terms separately and returns the factor of ",
 StyleBox["basisform", "Input",
  FontWeight->"Plain"],
 " in whatever subset of terms  contains it. For the sample ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " given in [9], for instance, "
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"factor", "[", 
   RowBox[{
    SubscriptBox["\[Theta]", "2"], ",", "avf"}], "]"}], 
  "                                                                           \
               ", "[", "12", "]"}]], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["returns ", "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   StyleBox[
    RowBox[{"dx", " ", "z", " ", "\[Lambda]"}],
    FontWeight->"Plain"], 
   StyleBox["-",
    FontWeight->"Plain"], 
   RowBox[{
    StyleBox[
     FractionBox[
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       RowBox[{
        SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
        SubscriptBox["\[Theta]", "4"]}]}], 
      SuperscriptBox["y", "3"]],
     FontWeight->"Plain"], 
    StyleBox[
     "                                                                        \
                 ",
     FontWeight->"Plain"], 
    StyleBox["[",
     FontWeight->"Bold"], 
    StyleBox["13",
     FontWeight->"Bold"], 
    StyleBox["]",
     FontWeight->"Bold"]}]}],
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Outline"->False,
  "Shadow"->False,
  "Underline"->False}]], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "where in standard AVF output the element ",
 Cell[BoxData[
  SubscriptBox["e", "0"]]],
 " has been suppressed. (The basisform is always factored to the left of ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 "). While this function may not be used very often, it is provided because \
it is not easily accomplished using standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " operations on wedge products."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["I.d.3. Vector contraction", "Subsubsection"],

Cell[TextData[{
 "In ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " a vector is a list of components, each component representing its \
contraction on the corresponding member of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " (which includes ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 "). In effect, the vector is expressed in the dual basis to ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". For convenience, the procedure ",
 StyleBox["makevectors[]", "Input",
  FontWeight->"Plain"],
 " (no arguments) will generate four such vectors, ",
 StyleBox["{vec1, vec2, vec3, vec4}", "Input",
  FontWeight->"Plain"],
 ". Each of these is a list of the same length as ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", having indexed components, ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["v1", "i"], ",", 
    SubscriptBox["v2", "i"], ",", 
    SubscriptBox["v3", "i"], ",", 
    SubscriptBox["v4", "i"]}], "}"}]]],
 ", to represent its contraction on the  ith  member of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". If needed  more vectors are easily constructed."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "Neither the names of the vectors nor the component symbols are reserved, so \
they can be given any variable names at will. A vector component should be \
defined for each member of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", however, unless care is taken to avoid potential errors. Whenever ",
 StyleBox["makeforms", "Input",
  FontWeight->"Plain"],
 " is executed, it calls the ",
 StyleBox["makevectors", "Input",
  FontWeight->"Plain"],
 " routine automatically to create four new vectors agreeing in length and \
order with the new ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "Additional structures are necessary to implement the contraction of vectors \
on the 2-forms included in ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 ". This is accomplished by defining a list of replacements named ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " to express ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " in terms of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". The reserved variable ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " can be established in the standard way by ",
 StyleBox["makedrules[replacement_list]", "Input",
  FontWeight->"Plain"],
 ". For instance, a typical set of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " might be:"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{"makedrules", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["d\[Theta]", "1"], "->", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "3"]}]}], ",", 
    RowBox[{
     SubscriptBox["d\[Theta]", "2"], "->", 
     RowBox[{
      SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "1"]}]}], ",", 
    RowBox[{
     SubscriptBox["d\[Theta]", "3"], "->", 
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "2"]}]}]}], "}"}], "]"}], "\n", 
 RowBox[{"                                                                    \
                                                                       ", 
  RowBox[{"[", "14", "]"}]}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
       SubscriptBox["\[Theta]", "3"]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
       SubscriptBox["\[Theta]", "1"]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "3"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Theta]", "2"]}]}]}], "}"}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], "       "}]}], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "The initial default value for ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " is ",
 StyleBox["natural", "Input",
  FontWeight->"Plain"],
 ", {",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["d\[Theta]", "1"], "->", "0"}]]],
 ", etc}, i.e. specifying that all members of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " are closed. The ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are invoked automatically for contractions where they are essential, but \
only then. The ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are an extremely important and useful feature of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " for many other purposes in addition to contraction. How the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are applied is illustrated in detail further down."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "Note that the vector components, ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["v1", "i"], ",", 
    SubscriptBox["v2", "i"], ",", 
    SubscriptBox["v3", "i"], ",", 
    SubscriptBox["v4", "i"]}], ")"}]]],
 ", are not automatically introduced into the ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " list, and so will not be differentiated. They can be added in by e.g.,"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"makescalars", "[", 
    RowBox[{"Join", "[", 
     RowBox[{"scalars", ",", "vec1"}], "]"}], "]"}], 
   "                                                                  ", "[", 
   "15", "]"}]}]], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "so that the ",
 Cell[BoxData[
  SubscriptBox["v1", "i"]],
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " become independent scalars with their own exterior derivatives ",
 Cell[BoxData[
  SubscriptBox["dv1", "i"]],
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 ". Alternatively, the components could be given assigned values either as \
explicit, or unspecified, functions of the existing scalars. This should not \
be done, if they have been introduced as independent scalars by the ",
 StyleBox["makescalars", "Input",
  FontWeight->"Plain"],
 " command."
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "The function ",
 StyleBox["contract[vector,expression]", "Input",
  FontWeight->"Plain"],
 " returns the contraction of ",
 StyleBox["vector", "Input",
  FontWeight->"Plain"],
 " on ",
 StyleBox["expression", "Input",
  FontWeight->"Plain"],
 ", where ",
 StyleBox["expression", "Input",
  FontWeight->"Plain"],
 " can be either a single AVF or a list of AVFs. This operation also has an \
infix form using the \[OpenCurlyDoubleQuote]small-circle\" symbol, which is \
input by typing the sequence esc-sc-esc. And in this form multiple \
contractions can be performed; e.g.,"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"vec1", "\[SmallCircle]", "vec2", "\[SmallCircle]", "vec3", 
  "\[SmallCircle]", 
  RowBox[{
  "avf1", "                                                                   \
                          ", "[", "16", "]"}]}]], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["or for a list of AVFs,", "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"vec4", "\[SmallCircle]", "vec1", "\[SmallCircle]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"avf1", ",", "avf2", ",", "avf3"}], "}"}], 
   "                                                                          \
 ", "[", "17", "]"}]}]], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["I.e. Exterior differentiation and Lie derivation", "Subsection"],

Cell[TextData[{
 "The operator ",
 StyleBox["d[expr]", "Input",
  FontWeight->"Plain"],
 " returns the exterior derivative of ",
 StyleBox["expr", "Input",
  FontWeight->"Plain"],
 " which may be either a single AVF, or a list of AVFs. The symbols used for \
the derivatives of all the fundamental variables are in ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 ". Their ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " commands also establish two additional replacement lists, ",
 StyleBox["sderiv", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["fderiv", "Input",
  FontWeight->"Plain"],
 ", to accomplish the derivations.\n\nA very simple example, for an ordinary \
1-form ",
 StyleBox["f", "Input",
  FontWeight->"Plain"],
 " is shown here:"
}], "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{"f", "=", 
  RowBox[{
   RowBox[{"x", " ", 
    SubscriptBox["\[Theta]", "1"]}], "+", 
   RowBox[{"y", " ", 
    SubscriptBox["\[Theta]", "2"]}], "+", 
   RowBox[{"z", " ", 
    SubscriptBox["\[Theta]", "3"]}]}]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"x", " ", 
    SubscriptBox["\[Theta]", "1"]}], "+", 
   RowBox[{"y", " ", 
    SubscriptBox["\[Theta]", "2"]}], "+", 
   RowBox[{"z", " ", 
    SubscriptBox["\[Theta]", "3"]}]}],
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Outline"->False,
  "Shadow"->False,
  "Underline"->False}], "\[IndentingNewLine]", 
 RowBox[{"                                                                    \
                                                          ", 
  RowBox[{"[", "18", "]"}]}], "\n", 
 RowBox[{"d", "[", "f", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{"x", " ", 
    SubscriptBox["d\[Theta]", "1"]}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox["+",
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox[
   RowBox[{"y", " ", 
    SubscriptBox["d\[Theta]", "2"]}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox["+",
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox[
   RowBox[{"z", " ", 
    SubscriptBox["d\[Theta]", "3"]}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox["+",
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox[
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Theta]", "1"]}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox["+",
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], 
  StyleBox[
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Theta]", "2"]}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}], "+", " ", 
  StyleBox[
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Theta]", "3"]}],
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontTracking->"Plain",
   FontVariations->{"Outline"->False,
   "Shadow"->False,
   "Underline"->False}]}]}], "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["The Lie derivative of AVFs is defined by the expansion:", "Text",
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lie", "[", 
   RowBox[{"vec", ",", "avf"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"vec", "\[SmallCircle]", 
    RowBox[{"d", "[", "avf", "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"vec", "\[SmallCircle]", "avf"}], "]"}], 
    "                                        ", "[", "19", "]"}]}]}]], "Input",\

 Evaluatable->False,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "and since both ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 " and \[SmallCircle] work with AVF lists, the ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " argument here can be a list of AVFs. As explained in section I.d.3 on \
contractions, to execute this function on general objects, a set of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " must be defined, and in order to be differentiated, the vector components \
must either be members of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " themselves, or expressed in terms of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageBreakBelow->Automatic,
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["I.f. Clifford algebras", "Subsection"],

Cell[TextData[{
 "We now describe how to set up Clifford-Algebra-Valued forms within ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 ". This is done by executing the command ",
 StyleBox["makeclifford[{signature_list}]", "Input",
  FontWeight->"Plain"],
 ". The argument specifies the signatures of the diagonal metric, ",
 Cell[BoxData[
  SubscriptBox["g", "ij"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontWeight->"Plain"],
 ", for a Clifford algebra defined with respect to an orthonormal basis, ",
 Cell[BoxData[
  SubscriptBox["\[Gamma]", "i"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontWeight->"Plain"],
 "; i.e.,"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "i"], 
    SubscriptBox["\[Gamma]", "j"]}], "+", 
   RowBox[{
    SubscriptBox["\[Gamma]", "j"], 
    SubscriptBox["\[Gamma]", "i"]}]}], "=", 
  RowBox[{"2", " ", 
   SubscriptBox["g", "ij"], 
   SubscriptBox["\[Gamma]", "0"], "        ", 
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["g", "ij"], "=", 
      RowBox[{"0", " ", 
       RowBox[{"{", 
        RowBox[{"i", "\[NotEqual]", "j"}], "}"}]}]}], ",", 
     RowBox[{
      SubscriptBox["g", "ii"], "=", 
      RowBox[{"\[PlusMinus]", "1"}]}]}], ")"}], "      ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "\[LessEqual]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "\[LessEqual]", "cadim"}], ")"}], 
    "         ", "[", "20", "]"}]}]}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  SubscriptBox["\[Gamma]", "0"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 " is the identity element and ",
 StyleBox["cadim", "Input",
  FontWeight->"Plain"],
 " is the number of generators. For example, a 4-dim Clifford algebra with \
Lorentzian metric would be obtained by:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeclifford", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}], "]"}], 
  "                                                              ", "[", "21",
   "]"}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["Another option would be:", "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeclifford", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}], 
  "                                                         ", "[", "22", 
  "]"}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["\<\
but the two options actually give different Clifford algebras. The input\
\>", "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeclifford", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], "]"}], 
  "                                                                       ", 
  "[", "23", "]"}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["\<\
gives a Clifford algebra which is isomorphic to the algebra of quaternions.\
\>", "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["I.f.1. Fundamental lists", "Subsubsection"],

Cell[TextData[{
 "The ",
 StyleBox["makeclifford[]", "Input",
  FontWeight->"Plain"],
 " command defines all the fundamental ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " lists for the chosen Clifford algebra, with the exception of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " which remains the null list ",
 StyleBox["{}", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "The program first checks the variable ",
 StyleBox["clifflist", "Input",
  FontWeight->"Plain"],
 " to see if this algebra has been encountered previously; if so, it will \
input the appropriate data file from the \
\[OpenCurlyDoubleQuote]CliffordAlgebras\[CloseCurlyDoubleQuote] folder. If \
not, it will proceed to construct the necessary quantities, save them in a \
file in that folder, and add the respective filename to ",
 StyleBox["clifflist", "Input",
  FontWeight->"Plain"],
 ", so it won't be necessary to repeat the calculation. Since the ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " matrix contains ",
 StyleBox["2^(2 cadim)", "Input",
  FontWeight->"Plain"],
 " entries, it is expensive in both time and memory to calculate for ",
 StyleBox["cadim > 6", "Input",
  FontWeight->"Plain"],
 " although the program is capable of ",
 StyleBox["cadim <= 11", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "If the command in [21] or [22] above were executed, the ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " list for either one would appear as :"
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Gamma]", "0"], ",", 
    SubscriptBox["\[Gamma]", "1"], ",", 
    SubscriptBox["\[Gamma]", "2"], ",", 
    SubscriptBox["\[Gamma]", "3"], ",", 
    SubscriptBox["\[Gamma]", "4"], ",", 
    SubscriptBox["\[Gamma]", "12"], ",", 
    SubscriptBox["\[Gamma]", "13"], ",", 
    SubscriptBox["\[Gamma]", "14"], ",", 
    SubscriptBox["\[Gamma]", "23"], ",", 
    SubscriptBox["\[Gamma]", "24"], ",", 
    SubscriptBox["\[Gamma]", "34"], ",", 
    SubscriptBox["\[Gamma]", "15"], ",", 
    SubscriptBox["\[Gamma]", "25"], ",", 
    SubscriptBox["\[Gamma]", "35"], ",", 
    SubscriptBox["\[Gamma]", "45"], ",", 
    SubscriptBox["\[Gamma]", "5"]}], "}"}], "            ", "[", "24", 
  "]"}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "although the algebra tables would differ. Multiple indices indicate the \
corresponding products; e.g. ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], "=", 
   RowBox[{
    SubscriptBox["\[Gamma]", "2"], 
    SubscriptBox["\[Gamma]", "3"]}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 ". The element ",
 Cell[BoxData[
  SubscriptBox["\[Gamma]", 
   RowBox[{"1", " ", "+", " ", "cadim"}]]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 " is always used to represent the complete product element; in this case ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Gamma]", "5"], "=", 
   RowBox[{
    SubscriptBox["\[Gamma]", "1"], 
    SubscriptBox["\[Gamma]", "2"], 
    SubscriptBox["\[Gamma]", "3"], 
    SubscriptBox["\[Gamma]", "4"]}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 ". And in order to minimize the amount of indices, a \
\[OpenCurlyDoubleQuote]dual\[CloseCurlyDoubleQuote] representation for higher \
products is employed; i.e., ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Gamma]", "15"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "1"], 
     SubscriptBox["\[Gamma]", "5"]}], "=", 
    RowBox[{
     RowBox[{"sig", "[", "1", "]"}], 
     SubscriptBox["\[Gamma]", "234"]}]}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 ", etc."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["I.f.2. Variables and algebra-valued-forms", "Subsubsection"],

Cell[TextData[{
 "Two lists of graded symbols are generated by ",
 StyleBox["makeclifford[]", "Input",
  FontWeight->"Plain"],
 ": ",
 StyleBox["omegas", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["thetas", "Input",
  FontWeight->"Plain"],
 ". Both are established as basis 1-forms by ",
 StyleBox["makeforms", "Input",
  FontWeight->"Plain"],
 "; e.g., (in the ",
 StyleBox["cadim==4", "Input",
  FontWeight->"Plain"],
 " case)"
}], "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"forms", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      OverscriptBox["\[Theta]", "0"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], ",", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], ",", 
      OverscriptBox["\[Theta]", "4"], ",", "\n", "\t           ", 
      OverscriptBox["\[Omega]", "0"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"], ",", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"], ",", 
      OverscriptBox["\[Omega]", "4"]}], "  ", "}"}], "      ", "[", "25", 
    "]"}]}]}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "where the grades of the basis 1-forms are indicated by overscripts. These \
are used to create two graded CAV 1-forms, ",
 Cell[BoxData[
  OverscriptBox["\[Theta]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " and ",
 Cell[BoxData[
  OverscriptBox["\[Omega]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    OverscriptBox["\[Theta]", "^"], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Theta]", "0"], " ", 
      SubscriptBox["\[Gamma]", "0"]}], "+", "\n", "\t       ", 
     RowBox[{
      SubscriptBox["\[Gamma]", "1"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "3"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "4"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"]}], "+", "\n", "\t       ", 
     RowBox[{
      SubscriptBox["\[Gamma]", "12"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "13"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "14"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "23"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "24"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "34"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"]}], "+", 
     "                                         ", 
     RowBox[{"[", "26", "]"}]}]}], "\n", "\t       ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "15"], " ", 
     SubscriptBox[
      OverscriptBox["\[Theta]", "3"], "1"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "25"], " ", 
     SubscriptBox[
      OverscriptBox["\[Theta]", "3"], "2"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "35"], " ", 
     SubscriptBox[
      OverscriptBox["\[Theta]", "3"], "3"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "45"], " ", 
     SubscriptBox[
      OverscriptBox["\[Theta]", "3"], "4"]}], "+", "\n", "\t       ", 
    RowBox[{
     OverscriptBox["\[Theta]", "4"], " ", 
     SubscriptBox["\[Gamma]", "5"]}]}], "\n", "\n", 
   RowBox[{
    OverscriptBox["\[Omega]", "^"], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Omega]", "0"], " ", 
      SubscriptBox["\[Gamma]", "0"]}], "+", "\n", "\t      ", 
     RowBox[{
      SubscriptBox["\[Gamma]", "1"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "3"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "4"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", "\n", "\t      ", 
     RowBox[{
      SubscriptBox["\[Gamma]", "12"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "13"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "14"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "23"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "24"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "34"], " ", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     "                                         ", 
     RowBox[{"[", "27", "]"}]}]}], "\n", "\t      ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "15"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "25"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "35"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "45"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "3"], "4"]}], " ", "+", "\n", 
    "                ", 
    RowBox[{
     OverscriptBox["\[Omega]", "4"], " ", 
     SubscriptBox["\[Gamma]", 
      RowBox[{"5", "\t\t\t"}]]}]}]}]}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["\<\
where the grades have been put on separate lines for clarity. Other CAV \
expressions with higher degree p-forms (not necessarily homogeneous) can also \
be defined. Examples are the homogeneous torsion and curvature 2-forms \
discussed next.\
\>", "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "In the particular case of metric geometry, the grade[1] part of ",
 Cell[BoxData[
  OverscriptBox["\[Theta]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " could represent an orthonormal co-frame with signature given by the \
Clifford algebra, and the grade[2] part of ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[Omega]", "^"], " "}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 "would represent Cartan\[CloseCurlyQuote]s skew-symmetric connection matrix. \
The commands ",
 Cell[BoxData[
  RowBox[{"grade", "[", 
   RowBox[{"1", ",", 
    OverscriptBox["\[Theta]", "^"]}], "]"}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " and ",
 Cell[BoxData[
  RowBox[{"and", " ", 
   RowBox[{"grade", "[", 
    RowBox[{"2", ",", 
     OverscriptBox["\[Omega]", "^"]}], "]"}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " will pick out these parts:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   OverscriptBox["\[Theta]", "^"], "=", " ", 
   RowBox[{
    RowBox[{"grade", "[", 
     RowBox[{"1", ",", 
      OverscriptBox["\[Theta]", "^"]}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Gamma]", "1"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "3"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "4"], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"]}]}]}]}], "  "}], "\n", 
 RowBox[{"\t\t\t\t\t\t                                                        \
                                             ", 
  RowBox[{"[", "28", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  OverscriptBox["\[Omega]", "^"], "=", " ", 
  RowBox[{
   RowBox[{"grade", "[", 
    RowBox[{"2", ",", 
     OverscriptBox["\[Omega]", "^"]}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "12"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "13"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "14"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "23"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "24"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
    RowBox[{
     SubscriptBox["\[Gamma]", "34"], " ", 
     SubscriptBox[
      OverscriptBox["\[Omega]", "2"], "34"], 
     "       \t                    "}]}]}]}]}], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["\<\
In this geometric situation, the components of the torsion 2-form, \
\[CapitalTheta], and the curvature 2-form, \[CapitalOmega], are defined by \
the Cartan structure equations:\
\>", "Text",
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["\[CapitalTheta]", "i"], "=", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["d\[Theta]", "1"], "i"], "+", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "cadim"], 
    RowBox[{
     SubscriptBox["g", "kk"], 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "ik"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "k"]}]}]}]}]}], "\[IndentingNewLine]", 

 RowBox[{"\t\t\t\t\t\t\t\t\t\t\t                                    \t\t", 
  RowBox[{"[", "29", "]"}]}], "\n", 
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "ij"], "=", " ", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["d\[Omega]", "2"], "ij"], "+", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "cadim"], 
    RowBox[{
     SubscriptBox["g", "kk"], 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "ik"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "kj"]}]}]}]}]}]}], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "These can be combined into the CAV torsion 2-form",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    RowBox[{" ", "\[CapitalTheta]"}], "^"], " ", "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", "i", "cadim"], 
    RowBox[{
     SubscriptBox["\[CapitalTheta]", "i"], 
     SubscriptBox["\[Gamma]", "i"]}]}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 ", and the CAV curvature 2-form ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[CapitalOmega]", "^"], " ", "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", ",", 
      RowBox[{"j", ">", "i"}]}], "cadim"], " ", 
    RowBox[{
     SubscriptBox["\[CapitalOmega]", "ij"], 
     SubscriptBox["\[Gamma]", "ij"]}]}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],
 ", which are then given by the AVF expressions"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  OverscriptBox["\[CapitalTheta]", "^"], " ", "=", " ", 
  RowBox[{
   RowBox[{"d", "[", 
    OverscriptBox["\[Theta]", "^"], "]"}], "+", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       OverscriptBox["\[Omega]", "^"], "**", 
       OverscriptBox["\[Theta]", "^"]}], "+", 
      RowBox[{
       OverscriptBox["\[Theta]", "^"], "**", 
       OverscriptBox["\[Omega]", "^"]}]}], ")"}]}]}]}], "\n", 
 RowBox[{"\t\t\t\t\t\t\t\t\t                          \t\t\t\t\t", 
  RowBox[{"[", "30", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  OverscriptBox["\[CapitalOmega]", "^"], " ", "=", " ", 
  RowBox[{
   RowBox[{"d", "[", 
    OverscriptBox["\[Omega]", "^"], "]"}], "+", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      OverscriptBox["\[Omega]", "^"], "**", 
      OverscriptBox["\[Omega]", "^"]}], ")"}]}]}]}]}], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell[TextData[{
 "and these CAVs comprise all the Cartan structure equations for the manifold \
--which would be Riemannian for vanishing torsion, ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[CapitalTheta]", "^"], "=", "0"}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 ". The ",
 StyleBox["CAV",
  FontSlant->"Italic"],
 " commands ",
 StyleBox["maketorsion[]", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["makecurvature[]", "Input",
  FontWeight->"Plain"],
 StyleBox[" will use these definitions to evaluate them explicitly for any \
assigned ",
  FontWeight->"Plain"],
 Cell[BoxData[
  OverscriptBox["\[Theta]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " and ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[Omega]", "^"], " "}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 "."
}], "Text"],

Cell[TextData[{
 "The definitions [30] can also be used in the general case when ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[Theta]", "^"], " "}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 "and ",
 Cell[BoxData[
  OverscriptBox["\[Omega]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " incorporate all possible grades for the algebra. In this situation ",
 Cell[BoxData[
  OverscriptBox["\[Omega]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " can be interpreted as a non-Abelian CAV gauge potential and ",
 Cell[BoxData[
  OverscriptBox["\[CapitalOmega]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " as the corresponding CAV field 2-form. Note that the field ",
 Cell[BoxData[
  OverscriptBox["\[CapitalOmega]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 " will contain a mixture of the different grades of the CAV gauge potential ",
 Cell[BoxData[
  OverscriptBox["\[Omega]", "^"]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 ". In the ",
 StyleBox["cadim=4", "Input",
  FontWeight->"Plain"],
 " case, for instance, interactions are generated among the"
}], "Text"],

Cell["\<\
grade[1] : ( vector - valued),
grade[2] : ( tensor - valued),
grade[3] : ( pseudovector - valued), and   
grade[4] : ( pseudoscalar - valued) parts.

The exception is the grade[0] : (scalar-valued, or Abelian) part, which never \
mixes.\
\>", "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell["\<\
Both the torsion and curvature 2-forms satisfy differential identities by \
virtue of their definitions,\
\>", "Text",
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"torsionidentity", "[", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", 
      OverscriptBox["\[CapitalTheta]", "^"], "]"}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[Omega]", "^"], "**", 
         OverscriptBox["\[CapitalTheta]", "^"]}], "-", 
        RowBox[{
         OverscriptBox["\[CapitalTheta]", "^"], "**", 
         OverscriptBox["\[Omega]", "^"]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[Theta]", "^"], "**", 
         OverscriptBox["\[CapitalOmega]", "^"]}], "-", 
        RowBox[{
         OverscriptBox["\[CapitalOmega]", "^"], "**", 
         OverscriptBox["\[Theta]", "^"]}]}], ")"}]}]}], ")"}], "==", 
   "0"}]}], "\[IndentingNewLine]", 
 RowBox[{"\t\t\t\t\t\t\t\t\t\t\t\t\t\t       \t\t", 
  RowBox[{"[", "31", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"curvatureidentity", "[", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", 
      OverscriptBox["\[CapitalOmega]", "^"], "]"}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[Omega]", "^"], "**", 
         OverscriptBox["\[CapitalOmega]", "^"]}], "-", 
        RowBox[{
         OverscriptBox["\[CapitalOmega]", "^"], "**", 
         OverscriptBox["\[Omega]", "^"]}]}], ")"}]}]}], ")"}], "==", 
   "0"}]}]}], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]],

Cell["\<\
and are known to the program by these names. They can be verified by explicit \
calculation, although in the completely general case with arbitrary basis \
forms and all grades included, it requires some time for a 4-dim, or higher, \
algebra.\
\>", "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->Automatic,
 FontWeight->"Plain"],

Cell[TextData[{
 "In the 4-dim Riemannian case with ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[CapitalTheta]", "^"], "=", "0"}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 ", only the last commutator in ",
 StyleBox["torsionidentity", "Input",
  FontWeight->"Plain"],
 " survives. It is a grade[1] 3-form which expresses the usual cyclic \
identity for the curvature components. The corresponding anticommutator, ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["G", "^"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       OverscriptBox["\[Theta]", "^"], "**", 
       OverscriptBox["\[CapitalOmega]", "^"]}], "+", 
      RowBox[{
       OverscriptBox["\[CapitalOmega]", "^"], "**", 
       OverscriptBox["\[Theta]", "^"]}]}], ")"}], "/", "2", " "}]}]],
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],
 "is a grade[3] 3-form which incorporates all four Ricci 3-forms expressing \
the Ricci, or actually Einstein, curvature tensor. It satisfais a contracted \
identity with the general form"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"contractedidentity", "[", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", 
      OverscriptBox["G", "^"], "]"}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[Omega]", "^"], "**", 
         OverscriptBox["G", "^"]}], "+", 
        RowBox[{
         OverscriptBox["G", "^"], "**", 
         OverscriptBox["\[Omega]", "^"]}]}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[CapitalTheta]", "^"], "**", 
         OverscriptBox["\[CapitalOmega]", "^"]}], "+", 
        RowBox[{
         OverscriptBox["\[CapitalOmega]", "^"], "**", 
         OverscriptBox["\[CapitalTheta]", "^"]}]}], ")"}]}]}], ")"}], "==", 
   RowBox[{"0", "            ", "[", "32", "]"}]}]}]], "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 Background->GrayLevel[0.900008]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["I.g. AVF names of variables and functions", "Subsection"],

Cell[TextData[{
 "All ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " names are lower case to distinguish them from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " names. Most of the names on these lists are protected and so will refuse \
assignment. A large number of unlisted temporary variables and subroutines \
have names beginning with ",
 StyleBox["av$", "Input",
  FontWeight->"Plain"],
 ".  To avoid interference, this pattern should not be used when defining new \
names or symbols."
}], "Text"],

Cell[CellGroupData[{

Cell["I.g.1.Variables", "Subsubsection"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{
    RowBox[{"1.", "  ", "adjlist"}], " ", "-", " ", 
    RowBox[{
    "arbitrary", " ", "permutation", " ", "of", " ", "the", " ", "list", " ", 
     "in", " ", "\"\<elements\>\""}]}], "  ", "\n", "  ", 
   RowBox[{
    RowBox[{"2.", "  ", "algebra"}], " ", "-", " ", 
    RowBox[{
    "multiplication", " ", "table", " ", "for", " ", "the", " ", 
     "\"\<elements\>\"", " ", "of", " ", "an", "  ", "algebra"}]}], "\n", 
   "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"3.", "  ", "brackets"}], " ", "-", " ", 
     RowBox[{"Lie", " ", "brackets"}]}], ",", 
    RowBox[{"[", " ", 
     RowBox[{
      SubscriptBox["V", 
       RowBox[{"forms", "[", 
        RowBox[{"[", "i", "]"}], "]"}]], ",", 
      SubscriptBox["V", 
       RowBox[{"forms", "[", 
        RowBox[{"[", "j", "]"}], "]"}]]}], " ", "]"}], ",", 
    RowBox[{
     RowBox[{"for", " ", "non"}], "-", 
     RowBox[{"exact", " ", "dual", " ", "vectors"}]}]}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"4.", "  ", "cadim"}], " ", "-", " ", 
     RowBox[{"number", " ", "of", " ", "generators", 
      RowBox[{"(", " ", 
       SubscriptBox["\[Gamma]", "i"], ")"}]}]}], ",", 
    RowBox[{
    "in", " ", "the", " ", "orthonormal", " ", "basis", " ", "of", " ", "a", 
     " ", "Clifford", " ", "algebra"}]}], "\n", "  ", 
   RowBox[{
    RowBox[{"5.", "  ", "clifflist"}], " ", "-", 
    RowBox[{
    "list", " ", "of", " ", "the", " ", "filenames", " ", "in", " ", "the", 
     "\"\<CliffordAlgebras\>\"", " ", "folder"}]}], "\n", "  ", 
   RowBox[{
    RowBox[{"6.", "  ", "coords"}], "-", " ", 
    RowBox[{
    "list", " ", "of", " ", "scalars", " ", "designated", " ", "as", " ", 
     "independent", " ", "variables"}]}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"7.", "  ", "coordsdim"}], " ", "-", " ", 
      RowBox[{"number", " ", "of", " ", "independent", " ", "variables"}]}], 
     ";"}], " ", "=", " ", 
    RowBox[{"Length", "[", "coords", "]"}]}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"8.", "  ", "cosub"}], " ", "-", " ", 
     RowBox[{"the", " ", "list", " ", "of", " ", "basis", " ", "1"}], "-", 
     RowBox[{
     "forms", " ", "to", " ", "be", " ", "annulled", " ", "in", " ", "a", " ",
       "subspace"}]}], ";", "\"\<subspace[cosub]\>\""}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"9.", "  ", "depend"}], " ", "-", " ", 
     RowBox[{"\"\<coords\>\"", " ", "as", " ", "a", " ", "Sequence"}]}], ";", 
    " ", 
    RowBox[{"used", " ", "for", " ", "function", " ", "arguments"}]}], "\n", 
   RowBox[{
    RowBox[{"10.", "  ", "dforms"}], " ", "-", 
    RowBox[{
    "list", " ", "of", " ", "symbols", " ", "for", " ", "the", " ", 
     "exterior", " ", "derivatives", " ", "of", " ", "the", " ", "members", 
     " ", "of", " ", "\"\<forms\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"11.", " ", "drules"}], " ", "-", " ", 
    RowBox[{
    "list", " ", "of", " ", "replacement", " ", "rules", " ", "for", " ", 
     "the", " ", "exterior", " ", "derivatives", " ", "of", " ", 
     "\"\<forms\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"12.", " ", "dscalars"}], " ", "-", " ", 
    RowBox[{
    "list", " ", "of", " ", "symbols", " ", "for", " ", "the", " ", 
     "exterior", " ", "derivatives", " ", "of", " ", "\"\<scalars\>\""}]}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"13.", " ", "eldim"}], " ", "-", " ", 
      RowBox[{"number", " ", "of", " ", "algebra", " ", "elements"}]}], ";"}],
     " ", "=", " ", 
    RowBox[{"Length", "[", "elements", "]"}]}], "\n", 
   RowBox[{
    RowBox[{"14.", " ", "elements"}], " ", "-", " ", 
    RowBox[{
    "list", " ", "of", " ", "generators", " ", "of", " ", "the", " ", 
     "algebra", " ", "specified", " ", "by", " ", "\"\<algebra\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"15.", " ", "fderiv"}], " ", "-", " ", 
    RowBox[{
    "basic", " ", "rules", " ", "to", " ", "give", " ", "exterior", " ", 
     "derivatives", " ", "of", " ", "\"\<forms\>\"", " ", "and", " ", 
     "\"\<dforms\>\""}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"16.", " ", "fmdim"}], " ", "-", " ", 
      RowBox[{
      "number", " ", "of", " ", "independent", " ", "basis", " ", "1"}], "-", 
      "forms"}], ";"}], " ", "=", " ", 
    RowBox[{"Length", "[", "forms", "]"}]}], "\n", 
   RowBox[{
    RowBox[{"17.", " ", "forms"}], " ", "-", " ", 
    RowBox[{"list", " ", "of", " ", "basis", " ", "1"}], "-", 
    RowBox[{
    "forms", " ", "generating", " ", "the", " ", "exterior", " ", "algebra"}],
     " ", "-", 
    RowBox[{"includes", " ", "\"\<dscalars\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"18.", " ", "frame"}], " ", "-", " ", 
    RowBox[{
    "list", " ", "of", " ", "orthonormal", " ", "basis", " ", "forms"}]}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"19.", " ", "frdim"}], " ", "-", " ", 
      RowBox[{
      "number", " ", "of", " ", "orthonormal", " ", "basis", " ", "1"}], "-", 
      "forms"}], ";"}], " ", "=", " ", 
    RowBox[{"Length", "[", "frame", "]"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"20.", " ", "gammas"}], " ", "-", 
     RowBox[{"all", "  ", "Clifford", " ", "\"\<elements\>\""}]}], ",", 
    RowBox[{
    "retrieved", " ", "from", " ", "a", " ", "file", " ", "in", "  ", 
     "\"\<CliffordAlgebras\>\""}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"21.", " ", "identity"}], " ", "-", " ", "elements"}], "=", 
    RowBox[{
     RowBox[{"{", "identity", "}"}], " ", "is", " ", "the", " ", "initial", 
     " ", "default", " ", "assignment", " ", "for", " ", 
     "\"\<elements\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"22.", " ", "names"}], " ", "-", " ", 
    RowBox[{
    "list", " ", "of", " ", "all", " ", "AVF", " ", "and", " ", "CAV", " ", 
     "variables", " ", "and", " ", "functions"}]}], "\n", 
   RowBox[{
    RowBox[{"23.", " ", "natural"}], " ", "-", " ", 
    RowBox[{
    "the", "\"\<drules\>\"", "specifying", " ", "\"\<closed\>\"", "  ", 
     "basis", " ", "1"}], "-", 
    RowBox[{"forms", 
     RowBox[{"(", " ", 
      RowBox[{"default", " ", "value"}], ")"}]}]}], " ", "\n", 
   RowBox[{
    RowBox[{"24.", " ", "omegas"}], " ", "-", " ", 
    RowBox[{
    "first", " ", "list", " ", "of", " ", "graded", " ", "symbols", " ", 
     "for", " ", "a", " ", "complete", " ", "set", " ", "of", " ", "CAV", "  ",
      "1"}], "-", "forms"}], "\n", 
   RowBox[{
    RowBox[{"25.", " ", "scalars"}], " ", "-", " ", 
    RowBox[{"list", " ", "of", " ", "0"}], "-", 
    RowBox[{
    "forms", " ", "which", " ", "will", " ", "have", " ", "exterior", " ", 
     "derivatives", " ", "given", " ", "by", " ", "\"\<dscalars\>\""}]}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"26.", " ", "scdim"}], " ", "-", " ", 
      RowBox[{"number", " ", "of", " ", "scalars"}]}], ";"}], " ", "=", 
    RowBox[{"Length", "[", "scalars", "]"}]}], "\n", 
   RowBox[{
    RowBox[{"27.", " ", "sderiv"}], " ", "-", "  ", 
    RowBox[{
    "basic", " ", "rules", " ", "to", "  ", "give", " ", "exterior", " ", 
     "derivatives", " ", "of", " ", "\"\<scalars\>\""}]}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"28.", " ", 
       RowBox[{"sig", "[", "i", "]"}]}], " ", "-", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SubscriptBox["\[Gamma]", "i"], ")"}], "2"]}], "=", 
     RowBox[{"\[PlusMinus]", "1"}]}], ",", 
    RowBox[{"the", " ", "ith", " ", "eigenvalue"}], ",", 
    SubscriptBox["g", "ii"], ",", 
    RowBox[{
    "of", " ", "the", " ", "diagonal", " ", "Clifford", " ", "metric"}]}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"29.", " ", "signature"}], " ", "-", 
     RowBox[{"list", " ", "of", " ", "all", " ", 
      RowBox[{"sig", "[", "i", "]"}]}]}], ";", " ", 
    RowBox[{
    "the", " ", "argument", " ", "for", "  ", 
     "\"\<makeclifford[signature]\>\""}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"30.", " ", "skew"}], " ", "-", " ", 
     RowBox[{"list", " ", "of", " ", "skew"}], "-", 
     RowBox[{"symmetric", " ", "structure", " ", 
      RowBox[{"constants", ":", "  ", 
       RowBox[{
        SubscriptBox["sk", 
         RowBox[{"i", ",", "j", ",", "k"}]], "+", 
        SubscriptBox["sk", 
         RowBox[{"i", ",", "k", ",", "j"}]]}]}]}]}], "=", "0"}], "\t", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"31.", " ", "sub"}], " ", "-", " ", 
      RowBox[{"list", " ", "of", " ", "basis", " ", "1"}], "-", 
      RowBox[{"forms", " ", "spanning", " ", "a", " ", "subspace"}]}], ";"}], 
    " ", "=", " ", 
    RowBox[{"Complement", "[", 
     RowBox[{"forms", ",", "cosub"}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"32.", " ", "symm"}], " ", "-", " ", 
     RowBox[{"list", " ", "of", " ", "symmetric", " ", "structure", " ", 
      RowBox[{"constants", ":", "  ", 
       RowBox[{
        SubscriptBox["sy", 
         RowBox[{"i", ",", "j", ",", "k"}]], "-", 
        SubscriptBox["sy", 
         RowBox[{"i", ",", "k", ",", "j"}]]}]}]}]}], "=", "0"}], "\t", "\n", 
   RowBox[{
    RowBox[{"33.", " ", "thetas"}], " ", "-", " ", 
    RowBox[{
    "second", " ", "list", " ", "of", " ", "graded", " ", "symbols", " ", 
     "for", " ", "a", " ", "complete", " ", "set", " ", "of", " ", "CAV", "  ",
      "1"}], "-", "forms"}], "\n", 
   RowBox[{
    RowBox[{"34.", " ", "topartials"}], " ", "-", " ", 
    RowBox[{
    "replacements", " ", "to", " ", "express", " ", "exterior", " ", 
     "derivatives", " ", "by", "  ", "partials", 
     RowBox[{"(", "subscripts", ")"}]}]}], "\n", 
   RowBox[{
    RowBox[{"35.", " ", "tosub"}], " ", "-", " ", 
    RowBox[{
    "replacements", " ", "to", " ", "annul", " ", "\"\<cosub\>\"", " ", "and",
      "  ", 
     RowBox[{"d", "[", "cosub", "]"}], " ", "in", " ", "a", " ", 
     "subspace"}]}], "\n", 
   RowBox[{
    RowBox[{"36.", " ", "trivial"}], " ", "-", " ", 
    RowBox[{
    "the", " ", "initial", " ", "default", " ", "value", " ", "of", " ", 
     "\"\<algebra\>\"", "  ", "having", " ", "\"\<identity\>\"", " ", "in", 
     " ", "most", " ", "positions"}]}], "\n", 
   RowBox[{
    RowBox[{"37.", " ", "vec1"}], ",", "vec2", ",", "vec3", ",", 
    RowBox[{"vec4", " ", "-", " ", 
     RowBox[{
     "four", " ", "independent", " ", "vectors", " ", "created", " ", "by", 
      " ", "\"\<makevectors\>\""}]}]}], "\n", 
   RowBox[{
    RowBox[{"38.", " ", 
     SubscriptBox["v1", "i"]}], ",", 
    SubscriptBox["v2", "i"], ",", 
    SubscriptBox["v3", "i"], ",", 
    RowBox[{
     SubscriptBox["v4", "i"], " ", "-", " ", 
     RowBox[{
     "the", " ", "components", " ", "of", " ", "the", " ", "above", " ", 
      "vectors", " ", "in", " ", "the", " ", "dual", " ", "basis", " ", "to", 
      " ", "\"\<forms\>\""}]}]}]}]}]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["I.g.2. Functions", "Subsubsection"],

Cell[TextData[{
 "The  argument ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " means a single  algebra-valued-form; ",
 StyleBox["avf or {avfs}", "Input",
  FontWeight->"Plain"],
 " means either a single avf, or a list of them. Functions with CAV arguments \
are defined only for those expressions. Empty brackets mean no arguments."
}], "Text"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1.", " ", 
      RowBox[{"adjmat", "[", 
       RowBox[{"list_of", "_elements"}], "]"}]}], " ", "-", " ", 
     RowBox[{"returns", " ", 
      RowBox[{"matrix", ":", 
       RowBox[{"adjmat", ".", "adjlist"}]}]}]}], " ", "=", " ", 
    "argument_list"}], "\n", "  ", 
   RowBox[{
    RowBox[{"2.", 
     RowBox[{"adL", "[", 
      RowBox[{"element", ",", 
       RowBox[{"list_of", "_elements"}]}], "]"}]}], " ", "-", " ", 
    RowBox[{"returns", " ", 
     RowBox[{
      RowBox[{"(", "element", ")"}], "**", 
      RowBox[{"{", 
       RowBox[{"any", " ", "list", " ", "of", " ", "the", " ", "elements"}], 
       "}"}]}]}]}], "\n", "  ", 
   RowBox[{
    RowBox[{"3.", " ", 
     RowBox[{"adR", "[", 
      RowBox[{
       RowBox[{"list_of", "_elements"}], ",", "element"}], "]"}]}], " ", "-", 
    " ", 
    RowBox[{"returns", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"any", " ", "list", " ", "of", " ", "the", " ", "elements"}], 
       "}"}], "**", 
      RowBox[{"(", "element", ")"}]}]}]}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"4.", " ", 
       RowBox[{"applydrules", "[", 
        RowBox[{"avf", " ", "or", " ", 
         RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", " ", 
      RowBox[{"implements", " ", "\"\<drules\>\""}]}], ";"}], "=", " ", 
    RowBox[{"expand", "[", 
     RowBox[{
      RowBox[{"{", "avfs", "}"}], "/.", "drules"}], "]"}]}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"5.", " ", 
      RowBox[{"associators", "[", "n", "]"}]}], " ", "-", " ", 
     RowBox[{
     "returns", " ", "up", " ", "to", " ", "\"\<n\>\"", "  ", "associators", 
      " ", "for", " ", "\"\<algebra\>\""}]}], ";", 
    RowBox[{"prints", " ", "number", " ", "found"}]}], "\n", "  ", 
   RowBox[{
    RowBox[{"6.", " ", 
     RowBox[{"coeffs", "[", "avf", "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "a", " ", "list", " ", "of", " ", "the", " ", "non"}], 
    "-", 
    RowBox[{
    "zero", " ", "coefficients", " ", "of", " ", "\"\<elements\>\"", " ", 
     "in", " ", "\"\<avf\>\""}]}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"7.", " ", 
      RowBox[{"collect", "[", 
       RowBox[{"avf", " ", "or", " ", 
        RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", " ", 
     RowBox[{
     "collects", " ", "the", " ", "factors", " ", "of", " ", 
      "\"\<elements\>\""}]}], ";", 
    RowBox[{"displays", "\"\<identity\>\""}]}], "\n", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"8.", " ", 
        RowBox[{"contract", "[", 
         RowBox[{"vector", ",", 
          RowBox[{"avf", " ", "or", " ", 
           RowBox[{"{", "avfs", "}"}]}]}], "]"}]}], " ", "-", " ", 
       RowBox[{"contracts", " ", "\"\<vector\>\"", " ", "on", " ", 
        RowBox[{"{", "avfs", "}"}]}]}], ";"}], "\[SmallCircle]", " ", "is"}], 
    " ", "the", " ", "infix", " ", "form"}], "\n", "  ", 
   RowBox[{
    RowBox[{"9.", " ", 
     RowBox[{"contractedidentity", "[", "]"}]}], " ", "-", " ", 
    RowBox[{
    "differential", " ", "identity", " ", "for", " ", "the", " ", "Einstein", 
     " ", "3"}], "-", 
    RowBox[{"form", "  ", 
     OverscriptBox[
      OverscriptBox["G", "^"], " "]}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"10.", " ", 
      RowBox[{"curvatureidentity", "[", "]"}]}], " ", "-", " ", 
     RowBox[{"aka", " ", "Bianchi", " ", "identity"}]}], ";", 
    RowBox[{
    "general", " ", "identity", " ", "for", " ", "CAV", " ", "field", "  ", 
     OverscriptBox["\[CapitalOmega]", "^"]}]}], "\n", 
   RowBox[{
    RowBox[{"11.", " ", 
     RowBox[{"d", "[", 
      RowBox[{"avf", " ", "or", " ", 
       RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "exterior", " ", "derivatives", " ", "of", " ", 
     "arguments"}]}], "\n", 
   RowBox[{
    RowBox[{"12.", " ", 
     RowBox[{"da", "[", 
      RowBox[{"avf", " ", "or", " ", 
       RowBox[{"{", "avfs", "}"}]}], "]"}]}], "-", " ", 
    RowBox[{"shortcut", " ", 
     RowBox[{"for", ":", "   ", 
      RowBox[{"applydrules", "[", 
       RowBox[{"d", "[", "arguments", "]"}], "]"}]}]}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"13.", " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"avf", " ", "or", " ", 
        RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", 
     RowBox[{
     "coderivative", " ", "for", " ", "arguments", " ", "expressed", " ", 
      "in", " ", "\"\<frame\>\""}]}], "=", 
    RowBox[{"hs", "[", 
     RowBox[{"da", "[", 
      RowBox[{"hs", "[", "arg", "]"}], "]"}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"14.", " ", 
     RowBox[{
      SubscriptBox["D", "sub"], "[", 
      RowBox[{"avf", " ", "or", " ", 
       RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "coordinate", " ", "derivative", " ", "defined", " ", "by", " ", 
     "\"\<makecoords[]\>\"", " ", "command"}]}], "\n", 
   RowBox[{
    RowBox[{"15.", " ", 
     RowBox[{"dot", "[", 
      RowBox[{
       RowBox[{"p", "-", "form1"}], ",", 
       RowBox[{"p", "-", "form2"}]}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "scalar", " ", "product", " ", "of", " ", "arguments", " ", "expressed", 
     " ", "in", " ", "\"\<frame\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"16.", " ", 
     RowBox[{"expand", "[", 
      RowBox[{"avf", " ", "or", " ", 
       RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", " ", 
    RowBox[{"substitutes", " ", "infix", "  ", "multiplication", " ", 
     RowBox[{
      RowBox[{"operator", " ", "**", " ", "for"}], " ", "\[Wedge]", " ", "\n",
       "17."}], " ", 
     RowBox[{"factor", "[", 
      RowBox[{"basisform", ",", "avf"}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "the", " ", "righthand", " ", "factor", " ", "of", " ", 
     "\"\<basisform\>\"", " ", "in", " ", "\"\<avf\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"18.", " ", 
     RowBox[{"generic", "[", "]"}]}], " ", "-", 
    RowBox[{
    "constructs", " ", "a", " ", "general", " ", "\"\<algebra\>\"", " ", 
     "for", " ", "\"\<elements\>\"", "using", " ", "\"\<skew\>\"", " ", "and",
      "  ", "\"\<symm\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"19.", " ", 
     RowBox[{"grade", "[", 
      RowBox[{"integer", ",", "CAV"}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "the", " ", "specified", " ", "grade", " ", "of", " ", 
     "a", " ", "CAV", " ", "form"}]}], "\n", 
   RowBox[{
    RowBox[{"20.", " ", 
     RowBox[{"grades", "[", "CAV", "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "a", " ", "list", " ", "of", " ", "all", " ", "grades", 
     " ", "of", " ", "a", " ", "CAV", " ", "form"}]}], "\n", 
   RowBox[{
    RowBox[{"21.", " ", 
     RowBox[{"hs", "[", 
      RowBox[{"avf", " ", "or", " ", 
       RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "the", " ", "Hodge", " ", "dual", " ", "for", " ", 
     "arguments", " ", "expressed", " ", "in", " ", "\"\<frame\>\""}]}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"22.", " ", 
     RowBox[{"in", "[", "avf", "]"}]}], " ", "-", " ", 
    RowBox[{
    "converts", " ", "\"\<avf\>\"", " ", "to", " ", "equivalent", " ", "List",
      " ", "expression", " ", "for", " ", "AVF", " ", "operations"}]}], "\n", 
   
   RowBox[{
    RowBox[{"23.", " ", 
     RowBox[{"involute", "[", "CAV", "]"}]}], " ", "-", " ", 
    RowBox[{
    "changes", " ", "sign", " ", "of", " ", "all", " ", "odd", " ", "grades", 
     " ", "in", " ", "CAV"}]}], "\n", 
   RowBox[{
    RowBox[{"24.", " ", 
     RowBox[{"lie", "[", 
      RowBox[{"vector", ",", 
       RowBox[{"avf", " ", "or", " ", 
        RowBox[{"{", "avfs", "}"}]}]}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", "  ", "Lie", " ", "derivatives", " ", "of", " ", 
     "\"\<avfs\>\"", "  ", "wrt", " ", "\"\<vector\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"25.", " ", 
     RowBox[{"liealgebra", "[", "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "the", " ", "Lie", " ", "brackets", " ", "of", " ", "the",
      " ", "dual", " ", "vectors", " ", "to", " ", "non"}], "-", " ", 
    RowBox[{"exact", " ", "forms"}]}], "\n", 
   RowBox[{
    RowBox[{"26.", " ", 
     RowBox[{"makealgebra", "[", "product_matrix", "]"}]}], "-", " ", 
    RowBox[{
    "establishes", " ", "the", " ", "multiplication", " ", "table", " ", 
     "for", " ", "\"\<elements\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"27.", " ", 
     RowBox[{"makeall", "[", "]"}]}], " ", "-", " ", 
    RowBox[{"in", " ", "CAV", " ", "does", 
     RowBox[{"(", 
      RowBox[{
      "makethetahat", ";", "makeomegahat", ";", "maketorsion", ";", 
       "makecurvature"}], ")"}]}]}], "\n", 
   RowBox[{
    RowBox[{"28.", " ", 
     RowBox[{"makeclifford", "[", 
      RowBox[{"signature", "-", "list"}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "makes", " ", "Clifford", " ", "algebra", " ", "with", " ", "specified", 
     " ", "signature"}]}], "\n", 
   RowBox[{
    RowBox[{"29.", " ", 
     RowBox[{"makecoords", "[", "symbol_list", "]"}]}], " ", "-", " ", 
    RowBox[{
    "defines", " ", "a", " ", "set", " ", "of", " ", "independent", " ", 
     "scalars", " ", "and", " ", "\"\<partials\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"30.", " ", 
     RowBox[{"makecurvature", "[", "]"}]}], "-", " ", 
    RowBox[{"calculates", " ", "the", " ", "CAV", "  ", "2"}], "-", 
    RowBox[{"form", "  ", 
     OverscriptBox["\[CapitalOmega]", "^"], "  ", "from", " ", "the", " ", 
     "connection", "  ", "1"}], "-", 
    RowBox[{"form", "  ", 
     OverscriptBox["\[Omega]", "^"]}]}], "\n", 
   RowBox[{
    RowBox[{"31.", " ", 
     RowBox[{"makedrules", "[", "replacement_list", "]"}]}], "-", " ", 
    RowBox[{
    "establishes", " ", "\"\<drules\>\"", " ", "for", " ", "\"\<dforms\>\"", 
     " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"+", " ", "optional"}], " ", "Rules"}], ")"}]}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"32.", " ", 
      RowBox[{"makeeinstein", "[", "]"}]}], " ", "-", " ", 
     RowBox[{"makes", " ", "a", " ", "CAV", "  ", "3"}], "-", 
     RowBox[{"form", "  ", 
      OverscriptBox["G", "^"]}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[Theta]", "^"], " ", "**", 
         OverscriptBox["\[CapitalOmega]", "^"]}], "+", 
        RowBox[{
         OverscriptBox["\[CapitalOmega]", "^"], "**", 
         OverscriptBox["\[Theta]", "^"]}]}], " ", ")"}], "/", "2"}], "  ", 
     RowBox[{"(", 
      RowBox[{"4", "dim", " ", "Einstein", " ", "tensor"}], ")"}]}]}], "\n", 
   RowBox[{
    RowBox[{"33.", " ", 
     RowBox[{"makeelements", "[", "symbol_list", "]"}]}], " ", "-", " ", 
    RowBox[{
    "establishes", " ", "the", " ", "list", " ", "of", " ", "generators", " ",
      "for", " ", "an", " ", "algebra"}]}], "\n", 
   RowBox[{
    RowBox[{"34.", " ", 
     RowBox[{"makeforms", "[", "symbol_list", "]"}]}], " ", "-", " ", 
    RowBox[{
    "establishes", " ", "the", " ", "list", " ", "of", " ", "fundamental", 
     " ", "non"}], "-", 
    RowBox[{"exact", " ", "1"}], "-", "forms"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"35.", " ", 
      RowBox[{"makeframe", "[", "symbol_list", "]"}]}], " ", "-", " ", 
     RowBox[{
     "defines", " ", "a", " ", "set", " ", "of", " ", "orthonormal", " ", 
      "basis", " ", "forms"}]}], " ", "=", " ", "\"\<frame\>\""}], " ", "\n", 
   
   RowBox[{
    RowBox[{"36.", " ", 
     RowBox[{"makematrices", "[", "]"}]}], " ", "-", " ", 
    RowBox[{
    "constructs", " ", "a", " ", "matrix", " ", "representation", " ", "of", 
     " ", "the", " ", "chosen", "  ", "Clifford", " ", "algebra"}]}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"37.", " ", 
      RowBox[{"makeomegahat", "[", "]"}]}], " ", "-", " ", 
     RowBox[{
     "makes", " ", "the", " ", "generalized", " ", "CAV", " ", "connection", "  ",
       "1"}], "-", " ", "form"}], ",", " ", 
    OverscriptBox[
     OverscriptBox["\[Omega]", "^"], " "]}], "\n", 
   RowBox[{
    RowBox[{"38.", " ", 
     RowBox[{"makescalars", "[", "symbol_list", "]"}]}], " ", "-", " ", 
    RowBox[{
    "establishes", " ", "the", " ", "list", " ", "of", " ", "fundamental", 
     " ", "scalars", 
     RowBox[{"(", 
      RowBox[{"0", "-", "forms"}], ")"}]}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"39.", " ", 
      RowBox[{"makethetahat", "[", "]"}]}], " ", "-", " ", 
     RowBox[{
     "makes", " ", "the", " ", "generalized", " ", "CAV", " ", 
      "\"\<co-frame\>\"", " ", "1"}], "-", "form"}], ",", " ", 
    OverscriptBox["\[Theta]", "^"]}], "\n", 
   RowBox[{
    RowBox[{"40.", " ", 
     RowBox[{"maketorsion", "[", "]"}]}], " ", "-", "  ", 
    RowBox[{"calculates", " ", "the", " ", "CAV", "  ", "2"}], "-", 
    RowBox[{"form", "  ", 
     OverscriptBox["\[CapitalTheta]", "^"], "  ", "from", " ", "the", " ", 
     "CAV", "  ", "1"}], "-", 
    RowBox[{"forms", "  ", 
     OverscriptBox["\[Theta]", "^"], "  ", "and", "  ", 
     OverscriptBox["\[Omega]", "^"]}]}], "\n", 
   RowBox[{
    RowBox[{"41.", " ", 
     RowBox[{"makevectors", "[", "]"}]}], " ", "-", " ", 
    RowBox[{
    "makes", " ", "a", " ", "set", " ", "of", " ", "four", " ", "lists", " ", 
     
     RowBox[{"named", ":", 
      RowBox[{"(", 
       RowBox[{"vec1", ",", "vec2", ",", "vec3", ",", "vec4"}], ")"}]}]}]}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"42.", " ", 
       RowBox[{"matmult", "[", 
        RowBox[{"m1", ",", "m2"}], "]"}]}], " ", "-", "  ", 
      RowBox[{"multiplication", " ", "of", " ", "AVF", "  ", "matrices"}]}], 
     ";", 
     RowBox[{"infix", " ", "operator"}]}], ",", " ", 
    RowBox[{"m1", "\[CircleTimes]", " ", "m2"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"43.", " ", 
      RowBox[{"mtx", "[", 
       RowBox[{"avf_", " ", "array"}], "]"}]}], " ", "-", " ", 
     RowBox[{
     "outputs", " ", "the", " ", "argument", " ", "in", " ", "MatrixForm"}]}],
     ";", 
    RowBox[{"\"\<algebra\>\"", " ", "is", " ", "default", " ", "argument"}]}],
    "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"44.", " ", 
      RowBox[{"mult", "[", 
       RowBox[{"avf1", ",", "avf2"}], "]"}]}], " ", "-", " ", 
     RowBox[{"returns", " ", "the", " ", "product"}]}], ",", " ", 
    RowBox[{"avf1", "**", "avf2"}], ",", " ", 
    RowBox[{
     RowBox[{"where", " ", "**", " ", "is"}], " ", "the", " ", "infix", " ", 
     "form"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"45.", " ", 
       RowBox[{"out", "[", 
        RowBox[{"List_form", "_of", "_avf"}], "]"}]}], " ", "-", " ", 
      RowBox[{"left", " ", "inverse", " ", "of", " ", 
       RowBox[{"in", "[", "avf", "]"}]}]}], ";", 
     RowBox[{"i", ".", "e", "."}]}], ",", 
    RowBox[{"avf", "==", 
     RowBox[{"out", "[", 
      RowBox[{"in", "[", "avf", "]"}], "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{"46.", " ", 
     RowBox[{"prune", "[", 
      RowBox[{"list", ",", "exp"}], "]"}]}], " ", "-", " ", 
    RowBox[{
    "keeps", " ", "only", " ", "those", " ", "members", " ", "of", " ", 
     "\"\<list\>\"", "that", "  ", "appear", " ", "in", " ", 
     "\"\<exp\>\""}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"47.", " ", 
       RowBox[{"pullback", "[", 
        RowBox[{"avf", " ", "or", " ", 
         RowBox[{"{", "avfs", "}"}]}], "]"}]}], " ", "-", " ", 
      RowBox[{"pulls", " ", "back", " ", 
       RowBox[{"{", "avfs", "}"}], " ", "into", " ", "subspace", 
       "\"\<sub\>\""}]}], ";"}], "=", 
    RowBox[{
     RowBox[{"{", "avfs", "}"}], "/.", "tosub"}]}], "\n", 
   RowBox[{
    RowBox[{"48.", " ", 
     RowBox[{"reset", "[", "]"}]}], "-", " ", 
    RowBox[{"set", " ", "\"\<timer\>\"", " ", "to", " ", "zero"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"49.", " ", 
      RowBox[{"reverse", "[", "CAV", "]"}]}], " ", "-", " ", 
     RowBox[{
     "returns", " ", "the", " ", "\"\<reversion\>\"", " ", "of", " ", 
      "CAV"}]}], ";", " ", 
    RowBox[{
     RowBox[{"equiv", ".", "to"}], " ", "reversing", " ", "all", " ", 
     SubscriptBox["\[Gamma]", "i"], " ", "products"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"50.", " ", 
       RowBox[{"setzero", "[", 
        RowBox[{"list_of", "_expressions"}], "]"}]}], " ", "-", " ", 
      RowBox[{
      "turns", " ", "the", "  ", "arg", " ", "list", " ", "into", " ", "a", 
       " ", "list", " ", "of", " ", "equations"}]}], ";"}], "==", "0"}], "\n", 
   RowBox[{
    RowBox[{"51.", " ", 
     RowBox[{"subspace", "[", 
      RowBox[{
       RowBox[{"list_of", "_basis", "_", "1"}], "-", "forms"}], "]"}]}], " ", 
    "-", " ", 
    RowBox[{
    "make", " ", "replacement", " ", "list", " ", "\"\<tosub\>\"", " ", "for",
      " ", "\"\<pullback\>\""}]}], "\n", 
   RowBox[{
    RowBox[{"52.", " ", 
     RowBox[{"timer", "[", "]"}]}], " ", "-", " ", 
    RowBox[{
    "returns", " ", "elapsed", " ", "time", " ", "from", " ", "most", " ", 
     "recent", " ", "\"\<reset\>\""}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"53.", " ", 
      RowBox[{"torsionidentity", "[", "]"}]}], " ", "-", "  ", 
     RowBox[{
     "general", " ", "identity", " ", "for", " ", "CAV", " ", "field"}]}], 
    ",", 
    RowBox[{
     OverscriptBox["\[CapitalTheta]", "^"], " ", ";", 
     RowBox[{"aka", " ", "Cartan", " ", "identity"}]}]}], "  ", "\n", 
   RowBox[{
    RowBox[{"54.", 
     RowBox[{"zerocurvature", "[", "]"}]}], " ", "-", " ", 
    RowBox[{
    "constructs", " ", "a", " ", "list", " ", "of", " ", "\"\<drules\>\"", 
     " ", "giving", " ", "vanishing", " ", "CAV", " ", "curvature", "  ", 
     OverscriptBox["\[CapitalOmega]", "^"]}]}], "\n", 
   RowBox[{
    RowBox[{"55.", 
     RowBox[{"zerotorsion", "[", "]"}]}], " ", "-", " ", 
    RowBox[{
    "constructs", " ", "a", " ", "list", " ", "of", " ", "\"\<drules\>\"", 
     " ", "giving", " ", "vanishing", " ", "CAV", " ", "torsion", "  ", 
     OverscriptBox[
      OverscriptBox["\[CapitalTheta]", "^"], " "]}]}]}]}]], "Text",
 PageBreakAbove->False,
 PageBreakWithin->False,
 PageBreakBelow->Automatic,
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["I.g.3. Jose: Additional comments on the choice of names", \
"Subsubsection"],

Cell[TextData[{
 "We have kept the original choices by Hugo Wahlquist on the naming \
conventions, though they are not standard in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". It is hence important to be aware of them:\n\n\t1. Commands of the \
package start with lowercase letters\n\t2. The many global variables of the \
package also have names starting with lowercase, instead of the standard \
capitalized names starting with $.\n\t3. The ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package already uses some frequent 1-character symbols, namely ",
 StyleBox["d", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["\[Delta]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["\[Omega]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["\[CapitalOmega]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["\[Theta]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["\[CapitalTheta]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["\[CapitalGamma]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["L", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["V", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["R", "Input",
  FontWeight->"Plain"],
 ". Also some 2- or 3- characters symbols: ",
 StyleBox["da", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["hs", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["dot", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["in", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["out", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["lie", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["mtx", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["sig", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["sk", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["sy", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["v1", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["v2", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["v3", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["v4", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["d\[Omega]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["d\[Theta]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["d\[CapitalOmega]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["d\[CapitalTheta]", "Input",
  FontWeight->"Plain"],
 ". Those symbols can be used for computations, but only as long as values \
are not assigned to them."
}], "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["II. Basic computations", "Section",
 FontColor->RGBColor[0, 0, 1]],

Cell["\<\
Sections II.a,b,c are taken from the file AVF_Demo.nb. Section II.d is taken \
from the file LieDerivative_Demo.nb.\
\>", "Text"],

Cell[TextData[{
 "Load the ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "xAct`AVF`"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print"],

Cell[BoxData["\<\"Package xAct`AVF`  version 1.0, {2011, 12, 18}\"\>"], \
"Print"],

Cell[BoxData["\<\"CopyRight (C) 2003-2012, Hugo D. Wahlquist, under the \
General Public License.\"\>"], "Print"],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print"],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print"],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["II.a. First examples", "Subsection"],

Cell[CellGroupData[{

Cell["II.a.1. Introducing the fundamental lists of variables", "Subsubsection"],

Cell["1) Declare a list of symbols to be scalars:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell["The information is stored in global variables:", "Text"],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["scdim"], "Input"],

Cell[BoxData["3"], "Output"]
}, Open  ]],

Cell["\<\
The differentials of those scalars are automatically created:\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "These exact 1-forms are also included in ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ":"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "2) To add in some non-exact basis 1-forms with derivative symbols in ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " we can use ",
 StyleBox["makeforms", "Input",
  FontWeight->"Plain"],
 ". The non-exact forms always appear before the exact forms:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeforms", "[", 
  RowBox[{"{", 
   RowBox[{"\[Xi]", ",", "\[Eta]", ",", "\[Zeta]"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[Xi]", ",", "\[Eta]", ",", "\[Zeta]", ",", "dx", ",", "dy", ",", "dz"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The global variable ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " contains respective exact 2-forms which can be given additional properties \
using ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ". The sub-section on ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " appears below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData["dforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"d\[Xi]", ",", "d\[Eta]", ",", "d\[Zeta]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Xi]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Eta]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Zeta]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "3) ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " initializes the ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " list and the ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " matrix as follows:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", "identity", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["algebra"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "identity", "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
so it is ready to accomplish ordinary differential form analysis without \
further input. Since that case is treated simply as a special (trivial) \
algebra, all the commands for it are identical to the more general case with \
a non-trivial algebra to be used here.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeelements", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["m", "0"], ",", 
    SubscriptBox["m", "1"], ",", 
    SubscriptBox["m", "2"], ",", 
    SubscriptBox["m", "3"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["m", "0"], ",", 
   SubscriptBox["m", "1"], ",", 
   SubscriptBox["m", "2"], ",", 
   SubscriptBox["m", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["m", "0"], ",", 
   SubscriptBox["m", "1"], ",", 
   SubscriptBox["m", "2"], ",", 
   SubscriptBox["m", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["eldim"], "Input"],

Cell[BoxData["4"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The three lists ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " may be introduced in any order and be changed at any time by executing new \
",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " commands. Note that ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " needs to be told that something is a variable (not constant) by being \
included in ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", but not what it depends on. In fact, the members of these fundamental \
lists are always treated as independent variables, and can neither be \
functions nor have assigned values. Interdependence among them may be imposed \
by using replacement rules, however. See below."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["II.a.2. Establishing the Algebra Table", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell["\<\
The next statement defines the multiplication table of a 2-dimensional \
Clifford algebra which is isomorphic to the algebra of real 2\[Times]2 \
orthogonal matrices. Flipping a few of the signs would turn it into the \
quaternion algebra H.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["M", "2"], "[", "R", "]"}], "=", 
  RowBox[{"{", 
   RowBox[{"elements", ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["m", "1"], ",", 
      SubscriptBox["m", "0"], ",", 
      SubscriptBox["m", "3"], ",", 
      SubscriptBox["m", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["m", "2"], ",", 
      RowBox[{"-", 
       SubscriptBox["m", "3"]}], ",", 
      SubscriptBox["m", "0"], ",", 
      RowBox[{"-", 
       SubscriptBox["m", "1"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["m", "3"], ",", 
      RowBox[{"-", 
       SubscriptBox["m", "2"]}], ",", 
      SubscriptBox["m", "1"], ",", 
      RowBox[{"-", 
       SubscriptBox["m", "0"]}]}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "0"], ",", 
     SubscriptBox["m", "1"], ",", 
     SubscriptBox["m", "2"], ",", 
     SubscriptBox["m", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "1"], ",", 
     SubscriptBox["m", "0"], ",", 
     SubscriptBox["m", "3"], ",", 
     SubscriptBox["m", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "2"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "3"]}], ",", 
     SubscriptBox["m", "0"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "3"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "2"]}], ",", 
     SubscriptBox["m", "1"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "0"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["makealgebra", "Input",
  FontWeight->"Plain"],
 " command sets the global variable ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " to its argument, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "2"], TraditionalForm]]],
 "[R],"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"makealgebra", "[", 
  RowBox[{
   SubscriptBox["M", "2"], "[", "R", "]"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["algebra"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "0"], ",", 
     SubscriptBox["m", "1"], ",", 
     SubscriptBox["m", "2"], ",", 
     SubscriptBox["m", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "1"], ",", 
     SubscriptBox["m", "0"], ",", 
     SubscriptBox["m", "3"], ",", 
     SubscriptBox["m", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "2"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "3"]}], ",", 
     SubscriptBox["m", "0"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["m", "3"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "2"]}], ",", 
     SubscriptBox["m", "1"], ",", 
     RowBox[{"-", 
      SubscriptBox["m", "0"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["and this outputs the active algebra table as a matrix.", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input",
 PageBreakAbove->False],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["m", "0"], 
      SubscriptBox["m", "1"], 
      SubscriptBox["m", "2"], 
      SubscriptBox["m", "3"]},
     {
      SubscriptBox["m", "1"], 
      SubscriptBox["m", "0"], 
      SubscriptBox["m", "3"], 
      SubscriptBox["m", "2"]},
     {
      SubscriptBox["m", "2"], 
      RowBox[{"-", 
       SubscriptBox["m", "3"]}], 
      SubscriptBox["m", "0"], 
      RowBox[{"-", 
       SubscriptBox["m", "1"]}]},
     {
      SubscriptBox["m", "3"], 
      RowBox[{"-", 
       SubscriptBox["m", "2"]}], 
      SubscriptBox["m", "1"], 
      RowBox[{"-", 
       SubscriptBox["m", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The command ",
 StyleBox["mtx[]", "Input",
  FontWeight->"Plain"],
 " is just an abbreviation for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["MatrixForm[]", "Input",
  FontWeight->"Plain"],
 " and will accept the same arguments. ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " is the default argument."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["II.a.3. Matrix Representations", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "Calculations in ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " are accomplished using the algebra table for products of elements. \
Sometimes it is useful to have a matrix representation of the elements, even \
though the program never requires it. For example, a matrix representation of \
the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "2"], TraditionalForm]]],
 "[R] generators is given by :"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["mat", "0"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["mat", "1"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["mat", "2"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["mat", "3"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], ";"}]}], "Input"],

Cell[TextData[{
 "and their matrix products agree with the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "2"], TraditionalForm]]],
 "[R] algebra table; e.g. ,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["mat", "1"], ")"}], ".", 
   SubscriptBox["mat", "2"]}], "==", 
  SubscriptBox["mat", "3"]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Since the indices of ",
 StyleBox["mat", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["m", "Input",
  FontWeight->"Plain"],
 " agree,  any ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " expression or list can be converted to matrix form by the kernel \
replacement rule, ",
 StyleBox[" /. m -> mat ", "Input",
  FontWeight->"Plain"],
 "; i.e. ,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["m", "0"], ",", 
   SubscriptBox["m", "1"], ",", 
   SubscriptBox["m", "2"], ",", 
   SubscriptBox["m", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"elements", "/.", 
  RowBox[{"m", "->", "mat"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Another example is shown below, and the use of matrices is also developed \
further down .\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["II.a.4. Sample input expressions", "Subsubsection",
 PageBreakAbove->True],

Cell[TextData[{
 "Here are two sample AVF expressions. The first, ",
 StyleBox["avf1", "Input",
  FontWeight->"Plain"],
 ", is an AVF 1-form; the second, ",
 StyleBox["avf2", "Input",
  FontWeight->"Plain"],
 ", has a different kind of factor omitted from each term and is a \
differential form of inhomogeneous degree. The ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " lists are output for reference."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf1", "=", 
  RowBox[{
   RowBox[{"2", "\[Lambda]", " ", "y", " ", "\[Zeta]", " ", 
    SubscriptBox["m", "2"]}], " ", "+", 
   RowBox[{
    SubscriptBox["m", "3"], " ", 
    SuperscriptBox["x", "3"], " ", "dz"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf2", "=", 
  RowBox[{
   RowBox[{"z", " ", 
    SubscriptBox["m", "2"]}], "+", 
   RowBox[{"3", " ", "\[Eta]", " ", "y"}], "+", 
   RowBox[{
    SubscriptBox["m", "1"], " ", 
    RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", "y", " ", "\[Eta]"}], "+", 
  RowBox[{"z", " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{
   SubscriptBox["m", "1"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"scalars", "\n", "forms"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[Xi]", ",", "\[Eta]", ",", "\[Zeta]", ",", "dx", ",", "dy", ",", "dz"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The missing algebra element in the second input term of ",
 StyleBox["avf2", "Input",
  FontWeight->"Plain"],
 " defaults to the identity, ",
 Cell[BoxData[
  SubscriptBox["m", "0"]]],
 ". It never needs to be typed in input, and is generally suppressed in \
output. Note that, except inside a wedge product, the order of factors within \
a term is immaterial."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.b. Algebraic operations", "Subsection"],

Cell[CellGroupData[{

Cell["II.b.1. Multiplication", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "The multiplication operator ",
 StyleBox["**", "Input",
  FontWeight->"Plain"],
 " simultaneously implements the Grassmann algebra of differential forms and \
the specified element algebra. Operator ",
 StyleBox["**", "Input",
  FontWeight->"Plain"],
 " has high precedence; its multiplicands will need parentheses if they're \
not single names, and also in multiple products if the algebra is \
non-associative."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[TextData[{
 "A first example using ordinary differential forms, where ",
 Cell[BoxData[
  SubscriptBox["m", "0"]]],
 " is the implicit algebra element:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"x", " ", "dy"}], "-", 
    RowBox[{"y", " ", "dx"}]}], ")"}], "**", 
  RowBox[{"(", 
   RowBox[{"\[Xi]", "-", "\[Eta]"}], ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"y", " ", 
   RowBox[{"dx", "\[Wedge]", "\[Eta]"}]}], "-", 
  RowBox[{"y", " ", 
   RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}], "-", 
  RowBox[{"x", " ", 
   RowBox[{"dy", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"x", " ", 
   RowBox[{"dy", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Though ",
 StyleBox["avf1", "Input",
  FontWeight->"Plain"],
 " is a 1-form, its algebra-valued self product is non-zero:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf1", "**", "avf1"}]], "Input"],

Cell[BoxData[
 RowBox[{"4", " ", 
  SuperscriptBox["x", "3"], " ", "y", " ", "\[Lambda]", " ", 
  SubscriptBox["m", "1"], " ", 
  RowBox[{"dz", "\[Wedge]", "\[Zeta]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf3", "=", 
  RowBox[{"avf1", "**", "avf2"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
For this matrix algebra, AVF multiplication is associative, but generally \
non-commutative.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"avf1", "**", "avf3", "**", "avf2"}], "==", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"avf1", "**", "avf1"}], ")"}], "**", 
   RowBox[{"(", 
    RowBox[{"avf2", "**", "avf2"}], ")"}]}]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"avf1", "**", "avf2"}], "===", 
  RowBox[{"avf2", "**", "avf1"}]}]], "Input"],

Cell[BoxData["False"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.b.2. Formatting commands", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell["\<\
The non-zero coefficients of the algebra elements in an AVF expression are \
given as a list of differential forms by:\
\>", "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coeffs", "[", "avf3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}], ",", 
   RowBox[{"dz", " ", 
    SuperscriptBox["x", "3"], " ", "z"}], ",", 
   RowBox[{
    RowBox[{"6", " ", 
     SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
     RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", 
     RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}]}], ",", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "3"], " ", "y", " ", 
     RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
    RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
     RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["and the expression is displayed in collected form by:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", "avf3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "0"]}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{
   SubscriptBox["m", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", 
      SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
      RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "+", 
     RowBox[{
      SuperscriptBox["x", "3"], " ", 
      RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["m", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["x", "3"], " ", "y", " ", 
      RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
     RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
      RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}], 
    ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This is the only ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " command that always outputs the identity element ",
 Cell[BoxData[
  SubscriptBox["m", "0"]]],
 " explicitly. It is required in the next statement to give the correct \
matrix representation of ",
 StyleBox["avf3", "Input",
  FontWeight->"Plain"],
 ":"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matavf3", "=", 
  RowBox[{
   RowBox[{"collect", "[", "avf3", "]"}], "/.", 
   RowBox[{"m", "->", "mat"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"dz", " ", 
       SuperscriptBox["x", "3"], " ", "z"}], "+", 
      RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}]}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["x", "3"], " ", "y", " ", 
       RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
       RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "-", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["x", "3"], " ", "y", " ", 
       RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
       RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "+", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "dz"}], " ", 
       SuperscriptBox["x", "3"], " ", "z"}], "+", 
      RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}]}]}],
     "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "matavf3", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"dz", " ", 
        SuperscriptBox["x", "3"], " ", "z"}], "+", 
       RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}]}], 
      
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["x", "3"], " ", "y", " ", 
        RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
        RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "-", 
       RowBox[{
        SuperscriptBox["x", "3"], " ", 
        RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "-", 
       RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
        RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}]},
     {
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["x", "3"], " ", "y", " ", 
        RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
        RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "-", 
       RowBox[{
        SuperscriptBox["x", "3"], " ", 
        RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "+", 
       RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
        RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "dz"}], " ", 
        SuperscriptBox["x", "3"], " ", "z"}], "+", 
       RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["collect[]", "Input",
  FontWeight->"Plain"],
 " command can be applied to arrays of AVFs, but ",
 StyleBox["coeffs[]", "Input",
  FontWeight->"Plain"],
 " must be Mapped onto them,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"{", 
   RowBox[{"avf1", ",", "avf2"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "2"]}], "+", 
    RowBox[{"dz", " ", 
     SuperscriptBox["x", "3"], " ", 
     SubscriptBox["m", "3"]}]}], ",", 
   RowBox[{
    RowBox[{"3", " ", "y", " ", "\[Eta]", " ", 
     SubscriptBox["m", "0"]}], "+", 
    RowBox[{"z", " ", 
     SubscriptBox["m", "2"]}], "+", 
    RowBox[{
     SubscriptBox["m", "1"], " ", 
     RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"coeffs", ",", 
   RowBox[{"{", 
    RowBox[{"avf1", ",", "avf2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]"}], ",", 
     RowBox[{"dz", " ", 
      SuperscriptBox["x", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", "y", " ", "\[Eta]"}], ",", 
     RowBox[{"dx", "\[Wedge]", "\[Xi]"}], ",", "z"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.b.3. Vector contraction", "Subsubsection",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "The infix contraction operator is the small open circle, typed by the \
sequence esc-sc-esc. It is used to contract a vector either on a single AVF, \
or on a list of them. Whenever new 1-forms are defined, the ",
 StyleBox["makeforms", "Input",
  FontWeight->"Plain"],
 " command automatically generates four independent vectors {",
 StyleBox["vec1", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["vec2", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["vec3", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["vec4", "Input",
  FontWeight->"Plain"],
 "} just for convenience. Each vector is a symbol list of the same length as \
the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list. The first two vectors:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["vec1"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"], ",", 
   SubscriptBox["v1", "4"], ",", 
   SubscriptBox["v1", "5"], ",", 
   SubscriptBox["v1", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["vec2"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v2", "1"], ",", 
   SubscriptBox["v2", "2"], ",", 
   SubscriptBox["v2", "3"], ",", 
   SubscriptBox["v2", "4"], ",", 
   SubscriptBox["v2", "5"], ",", 
   SubscriptBox["v2", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Since they are expressed in the dual basis to ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", each component of a vector is its contraction on the corresponding member \
of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 "; i.e. ,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[Xi]", ",", "\[Eta]", ",", "\[Zeta]", ",", "dx", ",", "dy", ",", "dz"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec1", "\[SmallCircle]", 
  RowBox[{"(", 
   RowBox[{"\[Eta]", "+", "dz"}], ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["v1", "2"], "+", 
  SubscriptBox["v1", "6"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["avf2"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", "y", " ", "\[Eta]"}], "+", 
  RowBox[{"z", " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{
   SubscriptBox["m", "1"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec1", "\[SmallCircle]", "avf2"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "dx"}], " ", 
   SubscriptBox["m", "1"], " ", 
   SubscriptBox["v1", "1"]}], "+", 
  RowBox[{"3", " ", "y", " ", 
   SubscriptBox["v1", "2"]}], "+", 
  RowBox[{"\[Xi]", " ", 
   SubscriptBox["m", "1"], " ", 
   SubscriptBox["v1", "4"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec1", "\[SmallCircle]", "%"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["A number of sequential contractions,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec2", "\[SmallCircle]", "vec1", "\[SmallCircle]", 
  "avf3"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "dx", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "3"], " ", 
   SubscriptBox["v2", "1"]}], "-", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "4"], " ", 
   SubscriptBox["v2", "1"]}], "-", 
  RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "4"], " ", 
   SubscriptBox["v2", "1"]}], "+", 
  RowBox[{"dx", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "6"], " ", 
   SubscriptBox["v2", "1"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "3"], " ", 
   SubscriptBox["v2", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "6"], " ", 
   SubscriptBox["v2", "2"]}], "-", 
  RowBox[{"2", " ", "dx", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "1"], " ", 
   SubscriptBox["v2", "3"]}], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "2"], " ", 
   SubscriptBox["v2", "3"]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", "\[Xi]", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "4"], " ", 
   SubscriptBox["v2", "3"]}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "1"], " ", 
   SubscriptBox["v2", "4"]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "1"], " ", 
   SubscriptBox["v2", "4"]}], "-", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", "\[Xi]", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "3"], " ", 
   SubscriptBox["v2", "4"]}], "-", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", "\[Xi]", " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "6"], " ", 
   SubscriptBox["v2", "4"]}], "-", 
  RowBox[{"dx", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "1"], " ", 
   SubscriptBox["v2", "6"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   SubscriptBox["v1", "2"], " ", 
   SubscriptBox["v2", "6"]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", "\[Xi]", " ", 
   SubscriptBox["m", "2"], " ", 
   SubscriptBox["v1", "4"], " ", 
   SubscriptBox["v2", "6"]}]}]], "Output"]
}, Open  ]],

Cell["and contraction on a list,", "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec2", "\[SmallCircle]", "vec3", "\[SmallCircle]", 
  RowBox[{"{", 
   RowBox[{"avf1", ",", "avf2", ",", "avf3"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["m", "1"]}], " ", 
     SubscriptBox["v2", "4"], " ", 
     SubscriptBox["v3", "1"]}], "+", 
    RowBox[{
     SubscriptBox["m", "1"], " ", 
     SubscriptBox["v2", "1"], " ", 
     SubscriptBox["v3", "4"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "dx", " ", "y", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "3"], " ", 
     SubscriptBox["v3", "1"]}], "+", 
    RowBox[{"dz", " ", 
     SuperscriptBox["x", "3"], " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "4"], " ", 
     SubscriptBox["v3", "1"]}], "+", 
    RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "4"], " ", 
     SubscriptBox["v3", "1"]}], "-", 
    RowBox[{"dx", " ", 
     SuperscriptBox["x", "3"], " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "6"], " ", 
     SubscriptBox["v3", "1"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "3"], " ", 
     SubscriptBox["v3", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "3"], " ", "y", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "6"], " ", 
     SubscriptBox["v3", "2"]}], "+", 
    RowBox[{"2", " ", "dx", " ", "y", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "1"], " ", 
     SubscriptBox["v3", "3"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "2"], " ", 
     SubscriptBox["v3", "3"]}], "-", 
    RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", "\[Xi]", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "4"], " ", 
     SubscriptBox["v3", "3"]}], "-", 
    RowBox[{"dz", " ", 
     SuperscriptBox["x", "3"], " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "1"], " ", 
     SubscriptBox["v3", "4"]}], "-", 
    RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "1"], " ", 
     SubscriptBox["v3", "4"]}], "+", 
    RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", "\[Xi]", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "3"], " ", 
     SubscriptBox["v3", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", "\[Xi]", " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "6"], " ", 
     SubscriptBox["v3", "4"]}], "+", 
    RowBox[{"dx", " ", 
     SuperscriptBox["x", "3"], " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "1"], " ", 
     SubscriptBox["v3", "6"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "3"], " ", "y", " ", 
     SubscriptBox["m", "3"], " ", 
     SubscriptBox["v2", "2"], " ", 
     SubscriptBox["v3", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", "\[Xi]", " ", 
     SubscriptBox["m", "2"], " ", 
     SubscriptBox["v2", "4"], " ", 
     SubscriptBox["v3", "6"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    SubscriptBox["m", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["v2", "4"]}], " ", 
       SubscriptBox["v3", "1"]}], "+", 
      RowBox[{
       SubscriptBox["v2", "1"], " ", 
       SubscriptBox["v3", "4"]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["m", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "dx", " ", "y", " ", "\[Lambda]", " ", 
        SubscriptBox["v2", "3"], " ", 
        SubscriptBox["v3", "1"]}], "+", 
       RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
        SubscriptBox["v2", "4"], " ", 
        SubscriptBox["v3", "1"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["x", "3"], " ", "y", " ", 
        SubscriptBox["v2", "6"], " ", 
        SubscriptBox["v3", "2"]}], "+", 
       RowBox[{"2", " ", "dx", " ", "y", " ", "\[Lambda]", " ", 
        SubscriptBox["v2", "1"], " ", 
        SubscriptBox["v3", "3"]}], "-", 
       RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", "\[Xi]", " ", 
        SubscriptBox["v2", "4"], " ", 
        SubscriptBox["v3", "3"]}], "-", 
       RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
        SubscriptBox["v2", "1"], " ", 
        SubscriptBox["v3", "4"]}], "+", 
       RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", "\[Xi]", " ", 
        SubscriptBox["v2", "3"], " ", 
        SubscriptBox["v3", "4"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["x", "3"], " ", "y", " ", 
        SubscriptBox["v2", "2"], " ", 
        SubscriptBox["v3", "6"]}]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["m", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"dz", " ", 
        SuperscriptBox["x", "3"], " ", 
        SubscriptBox["v2", "4"], " ", 
        SubscriptBox["v3", "1"]}], "-", 
       RowBox[{"dx", " ", 
        SuperscriptBox["x", "3"], " ", 
        SubscriptBox["v2", "6"], " ", 
        SubscriptBox["v3", "1"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
        SubscriptBox["v2", "3"], " ", 
        SubscriptBox["v3", "2"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
        SubscriptBox["v2", "2"], " ", 
        SubscriptBox["v3", "3"]}], "-", 
       RowBox[{"dz", " ", 
        SuperscriptBox["x", "3"], " ", 
        SubscriptBox["v2", "1"], " ", 
        SubscriptBox["v3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["x", "3"], " ", "\[Xi]", " ", 
        SubscriptBox["v2", "6"], " ", 
        SubscriptBox["v3", "4"]}], "+", 
       RowBox[{"dx", " ", 
        SuperscriptBox["x", "3"], " ", 
        SubscriptBox["v2", "1"], " ", 
        SubscriptBox["v3", "6"]}], "-", 
       RowBox[{
        SuperscriptBox["x", "3"], " ", "\[Xi]", " ", 
        SubscriptBox["v2", "4"], " ", 
        SubscriptBox["v3", "6"]}]}], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec3", "\[SmallCircle]", "%"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "It is not necessary to use these convenience vectors. Any list of scalar \
variables, including specified or unspecified functions of the elements of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " may be used, so long as the list agrees in length with the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list. Any such list will be interpreted as a vector expressed in the dual \
basis to ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". Components not in ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " (or functions thereof) will be constant parameters, as are the \
convenience-vector components."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell["\<\
A quick way to get a new vector of the correct length is by using a \
replacement,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pvec", "=", 
  RowBox[{"vec1", "/.", 
   RowBox[{"v1", "->", "p"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["p", "1"], ",", 
   SubscriptBox["p", "2"], ",", 
   SubscriptBox["p", "3"], ",", 
   SubscriptBox["p", "4"], ",", 
   SubscriptBox["p", "5"], ",", 
   SubscriptBox["p", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "or by the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " command,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pvec", "=", 
  RowBox[{"Array", "[", 
   RowBox[{"p", ",", "fmdim"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p", "[", "1", "]"}], ",", 
   RowBox[{"p", "[", "2", "]"}], ",", 
   RowBox[{"p", "[", "3", "]"}], ",", 
   RowBox[{"p", "[", "4", "]"}], ",", 
   RowBox[{"p", "[", "5", "]"}], ",", 
   RowBox[{"p", "[", "6", "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "where the global variable ",
 StyleBox["fmdim = Length[forms]", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["II.b.4. Factoring an AVF", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData["avf3"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Any basis form in ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " will be factored out (to the left) of an AVF by:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fac", "=", 
  RowBox[{"factor", "[", 
   RowBox[{"\[Zeta]", ",", "avf3"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "z", " ", "\[Lambda]"}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Eta]", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"]}], "-", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "All terms containing \[Zeta] are factored, so the following expression \
represents the part of ",
 StyleBox["avf3", "Input",
  FontWeight->"Plain"],
 " that is actually independent of ",
 Cell[BoxData[
  FormBox["\[Zeta]", TraditionalForm]]],
 ":"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf3", "-", 
  RowBox[{"\[Zeta]", "\[Wedge]", "fac"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "-", 
  RowBox[{"\[Zeta]", "\[Wedge]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "y", " ", "z", " ", "\[Lambda]"}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["y", "2"], " ", "\[Eta]", " ", "\[Lambda]", " ", 
      SubscriptBox["m", "2"]}], "-", 
     RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
      SubscriptBox["m", "3"], " ", 
      RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This will simplify using the ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"],
 " operator (lower case \"e\"), which is similar to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s upper case ",
 StyleBox["Expand", "Input",
  FontWeight->"Plain"],
 ", except that it operates on wedge products ."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Jose:",
  FontColor->GrayLevel[0]],
 " The function ",
 StyleBox["factor", "Input",
  FontWeight->"Plain"],
 " actually does the equivalent of ",
 StyleBox["Coefficient", "Input",
  FontWeight->"Plain"],
 " in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", not the equivalent of ",
 StyleBox["Factor", "Input",
  FontWeight->"Plain"],
 "."
}], "Text"],

Cell["\<\
An iterative subroutine to factor out any monomial product of basis forms \
from an AVF would be:\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"monomialfactor", "[", 
    RowBox[{"mono_", ",", "avf_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "fac", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fac", "=", "avf"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "mono", "]"}], "=!=", "Wedge"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"fac", "=", 
         RowBox[{"factor", "[", 
          RowBox[{"mono", ",", "fac"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"fac", "=", 
           RowBox[{"factor", "[", 
            RowBox[{
             RowBox[{"mono", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "fac"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "mono", "]"}]}], "}"}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", "fac"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"],

Cell["For example,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"monomialfactor", "[", 
  RowBox[{
   RowBox[{"\[Xi]", "\[Wedge]", "dx"}], ",", "avf3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "II.b.5. The ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"],
 " function"
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "The ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " function ",
 StyleBox["expand[expr]", "Input",
  FontWeight->"Plain"],
 " replaces all wedge products in ",
 StyleBox["expr", "Input",
  FontWeight->"Plain"],
 " with the actual multiplication operator ",
 StyleBox["**", "Input",
  FontWeight->"Plain"],
 ", and so re-calculates the entire expression. Any expression containing \
wedge products of AVF expressions can be expanded in this way. For instance,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf1", "\[Wedge]", "avf2"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "2"]}], "+", 
    RowBox[{"dz", " ", 
     SuperscriptBox["x", "3"], " ", 
     SubscriptBox["m", "3"]}]}], ")"}], "\[Wedge]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", "y", " ", "\[Eta]"}], "+", 
    RowBox[{"z", " ", 
     SubscriptBox["m", "2"]}], "+", 
    RowBox[{
     SubscriptBox["m", "1"], " ", 
     RowBox[{"dx", "\[Wedge]", "\[Xi]"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Only the substitutions occurred because wedge is not recognized as an \
operator, and with the factors being algebra-valued-forms, it is a slight \
abuse of notation. Nevertheless, this re-derives ",
 StyleBox["avf3", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "z", " ", "\[Zeta]", " ", "\[Lambda]"}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that an expression containing wedge products of factors which are not \
simple basis forms, such as ",
 StyleBox["avf1\[Wedge]avf2", "Input",
  FontWeight->"Plain"],
 ", is not an acceptable input for any ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " operations other than ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"],
 ". The operator ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"],
 " must be used to convert such expressions to correct input form for other \
",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " functions."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[TextData[{
 "Since every wedge product at all levels in the expressions will be \
calculated anew, using ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"],
 " allows arbitrary replacements to be made within wedge products, and this \
is its primary function. For example, the \[Zeta]-independent part of ",
 StyleBox["avf3", "Input",
  FontWeight->"Plain"],
 " could also be obtained by"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf3", "/.", 
  RowBox[{"\[Zeta]", "->", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"0", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "0", "\[Wedge]", "\[Xi]"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", "z", " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Clearly, any wedge product in an input expression (even between basis \
forms) could just as well be typed using ",
 StyleBox["**", "Input",
  FontWeight->"Plain"],
 ". This has little real effect when used between basis forms (except perhaps \
to simplify and re-order a product into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s canonical order), but it constitutes a much larger abuse of standard \
nomenclature."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Xi]", "\[Wedge]", "dz"}], "+", 
  RowBox[{"\[Eta]", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Eta]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Xi]", "\[Wedge]", "dz"}], "+", 
  RowBox[{"\[Eta]", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Eta]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{"dz", "\[Wedge]", "\[Xi]"}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Xi]", "**", "dz"}], "+", 
  RowBox[{"\[Eta]", "**", "\[Zeta]", "**", "\[Eta]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{"dz", "\[Wedge]", "\[Xi]"}], ")"}]}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.c. Exterior calculus operations", "Subsection"],

Cell[CellGroupData[{

Cell["II.c.1. Exterior differentiation", "Subsubsection"],

Cell[TextData[{
 "The exterior derivative of an AVF is given by ",
 StyleBox["d[expr]", "Input",
  FontWeight->"Plain"],
 "; e.g. ,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["avf1"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "y", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{"dz", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "avf1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "d\[Zeta]", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "2"], " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}]}], "+", 
  RowBox[{"2", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dy", "\[Wedge]", "\[Zeta]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " are differentiated, but the algebra elements and parameter \[Lambda] are \
not. A more complicated example is:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "avf3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "d\[Zeta]", " ", "y", " ", "z", " ", "\[Lambda]"}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "2"], " ", "z", " ", 
   SubscriptBox["m", "1"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}]}], "+", 
  RowBox[{"2", " ", "z", " ", "\[Lambda]", " ", 
   RowBox[{"dy", "\[Wedge]", "\[Zeta]"}]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", "d\[Eta]"}]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   RowBox[{"dz", "\[Wedge]", "\[Zeta]"}]}], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"\[Zeta]", "\[Wedge]", "d\[Eta]"}]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"\[Eta]", "\[Wedge]", "d\[Zeta]"}]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "d\[Xi]"}]}], "+", 
  RowBox[{"9", " ", 
   SuperscriptBox["x", "2"], " ", "y", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "d\[Xi]"}]}], "-", 
  RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Xi]", "\[Wedge]", "d\[Zeta]"}]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"], " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dy", "\[Wedge]", "dz", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"12", " ", "y", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dy", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "-", 
  RowBox[{"2", " ", "\[Lambda]", " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{
   "dx", "\[Wedge]", "dy", "\[Wedge]", "\[Zeta]", "\[Wedge]", 
    "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The operator ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 " also works on a list of AVF's,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"{", 
   RowBox[{"avf1", ",", "avf2"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "d\[Zeta]", " ", "y", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", 
     SubscriptBox["m", "3"], " ", 
     RowBox[{"dx", "\[Wedge]", "dz"}]}], "+", 
    RowBox[{"2", " ", "\[Lambda]", " ", 
     SubscriptBox["m", "2"], " ", 
     RowBox[{"dy", "\[Wedge]", "\[Zeta]"}]}]}], ",", 
   RowBox[{
    RowBox[{"3", " ", "d\[Eta]", " ", "y"}], "+", 
    RowBox[{"dz", " ", 
     SubscriptBox["m", "2"]}], "-", 
    RowBox[{
     SubscriptBox["m", "1"], " ", 
     RowBox[{"dx", "\[Wedge]", "d\[Xi]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"dy", "\[Wedge]", "\[Eta]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["as well as on a matrix of them,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "matavf3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "d\[Zeta]", " ", "y", " ", "z", " ", "\[Lambda]"}], 
      "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "2"], " ", "z", " ", 
       RowBox[{"dx", "\[Wedge]", "dz"}]}], "+", 
      RowBox[{"2", " ", "z", " ", "\[Lambda]", " ", 
       RowBox[{"dy", "\[Wedge]", "\[Zeta]"}]}], "+", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dz", "\[Wedge]", "\[Zeta]"}]}]}], ",", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["x", "3"], " ", "y", " ", 
       RowBox[{"dz", "\[Wedge]", "d\[Eta]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
       RowBox[{"\[Zeta]", "\[Wedge]", "d\[Eta]"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
       RowBox[{"\[Eta]", "\[Wedge]", "d\[Zeta]"}]}], "-", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "d\[Xi]"}]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["x", "2"], " ", "y", " ", 
       RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "d\[Xi]"}]}], "+", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dx", "\[Wedge]", "\[Xi]", "\[Wedge]", "d\[Zeta]"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"dy", "\[Wedge]", "dz", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{"12", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dy", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "+", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{
       "dx", "\[Wedge]", "dy", "\[Wedge]", "\[Zeta]", "\[Wedge]", 
        "\[Xi]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["x", "3"], " ", "y", " ", 
       RowBox[{"dz", "\[Wedge]", "d\[Eta]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
       RowBox[{"\[Zeta]", "\[Wedge]", "d\[Eta]"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "2"], " ", "\[Lambda]", " ", 
       RowBox[{"\[Eta]", "\[Wedge]", "d\[Zeta]"}]}], "-", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "d\[Xi]"}]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["x", "2"], " ", "y", " ", 
       RowBox[{"dx", "\[Wedge]", "dz", "\[Wedge]", "\[Eta]"}]}], "+", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "d\[Xi]"}]}], "-", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dx", "\[Wedge]", "\[Xi]", "\[Wedge]", "d\[Zeta]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"dy", "\[Wedge]", "dz", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{"12", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dy", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Eta]"}]}], "-", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{
       "dx", "\[Wedge]", "dy", "\[Wedge]", "\[Zeta]", "\[Wedge]", 
        "\[Xi]"}]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "d\[Zeta]", " ", "y", " ", "z", " ", "\[Lambda]"}], 
      "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "2"], " ", "z", " ", 
       RowBox[{"dx", "\[Wedge]", "dz"}]}], "+", 
      RowBox[{"2", " ", "z", " ", "\[Lambda]", " ", 
       RowBox[{"dy", "\[Wedge]", "\[Zeta]"}]}], "+", 
      RowBox[{"2", " ", "y", " ", "\[Lambda]", " ", 
       RowBox[{"dz", "\[Wedge]", "\[Zeta]"}]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The non-commutativity coming from both the Grassmann and the element \
algebras generally forbids any simple application of the Leibnitz rule for \
derivations, unless the leading factors are of homogeneous degree as \
differential forms and the algebraic order of the factors is preserved. The \
following expansion works because ",
 StyleBox["avf1", "Input",
  FontWeight->"Plain"],
 " is a 1-form (note the minus sign)."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"avf1", "**", "avf2"}], "]"}], "==", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "avf1", "]"}], "**", "avf2"}], "-", 
   RowBox[{"avf1", "**", 
    RowBox[{"d", "[", "avf2", "]"}]}]}]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "For simplicity, the input samples, ",
 StyleBox["avf1", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["avf2", "Input",
  FontWeight->"Plain"],
 ", involved only algebraic functions of the scalars. Any functions known to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used in an AVF, but any arguments not appearing in the ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " list will be treated as constant parameters;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avf4", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"k", " ", "y"}], "]"}], "\[Xi]", " ", 
    SubscriptBox["m", "1"]}], "+", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"k", " ", "y"}], "]"}], "\[Eta]", " ", 
    SubscriptBox["m", "2"]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Xi]", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"\[Eta]", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "2"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "avf4", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d\[Xi]", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "1"]}], "+", 
  RowBox[{"d\[Eta]", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "2"], " ", 
   RowBox[{"dy", "\[Wedge]", "\[Eta]"}]}], "-", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "1"], " ", 
   RowBox[{"dy", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"avf4", "**", "avf4"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "k", " ", "y"}], "]"}]}], " ", 
  SubscriptBox["m", "3"], " ", 
  RowBox[{"\[Eta]", "\[Wedge]", "\[Xi]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"\[Eta]", "\[Wedge]", "d\[Xi]"}]}], "-", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"\[Xi]", "\[Wedge]", "d\[Eta]"}]}], "-", 
  RowBox[{"2", " ", "k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "k", " ", "y"}], "]"}], " ", 
   SubscriptBox["m", "3"], " ", 
   RowBox[{"dy", "\[Wedge]", "\[Eta]", "\[Wedge]", "\[Xi]"}]}]}]], "Output"]
}, Open  ]],

Cell["and an unspecified function including a parameter gives,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y", ",", "z", ",", "k"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z", ",", "k"}], "]"}]}], "+", 
  RowBox[{"dy", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z", ",", "k"}], "]"}]}], "+", 
  RowBox[{"dx", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z", ",", "k"}], "]"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "II.c.2. Defining ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "An important feature of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " involves the list of replacement rules for exterior derivatives called ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ". Their primary purpose is to establish properties for the derivatives of \
the non-exact basis forms (the members of ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 ") which can then be easily implemented in AVF expressions. They are not \
restricted to such replacements, however, and may include any other \
appropriate replacement rules.\n                             \nAdditional \
structure for the derivatives in ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " is prescribed by defining a set of replacement rules which are given by \
expansions of the members of ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " in terms of the members of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". If all the non-exact 1-forms are closed, for example, the appropriate \
value for ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " is the global variable ",
 StyleBox["natural", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["natural"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Xi]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Eta]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Zeta]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and this is the default value of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " established initially for all the non-exact members of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " introduced by the ",
 StyleBox["makeforms", "Input",
  FontWeight->"Plain"],
 " command; i.e., currently,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Xi]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Eta]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Zeta]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["A different set of replacements can be defined; e.g.,", "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newdrules", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d\[Xi]", "->", 
     RowBox[{"\[Eta]", "\[Wedge]", "\[Zeta]"}]}], ",", 
    RowBox[{"d\[Eta]", "->", 
     RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}]}], ",", 
    RowBox[{"d\[Zeta]", "->", 
     RowBox[{"\[Xi]", "\[Wedge]", "\[Eta]"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Xi]", "\[Rule]", 
    RowBox[{"\[Eta]", "\[Wedge]", "\[Zeta]"}]}], ",", 
   RowBox[{"d\[Eta]", "\[Rule]", 
    RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}]}], ",", 
   RowBox[{"d\[Zeta]", "\[Rule]", 
    RowBox[{"\[Xi]", "\[Wedge]", "\[Eta]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and this becomes the reserved variable ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " using the ",
 StyleBox["makedrules", "Input",
  FontWeight->"Plain"],
 " command;"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", "newdrules", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Xi]", "\[Rule]", 
    RowBox[{"\[Eta]", "\[Wedge]", "\[Zeta]"}]}], ",", 
   RowBox[{"d\[Eta]", "\[Rule]", 
    RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}]}], ",", 
   RowBox[{"d\[Zeta]", "\[Rule]", 
    RowBox[{"\[Xi]", "\[Wedge]", "\[Eta]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The current ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " can be implemented in any ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " expression with the command ",
 StyleBox["applydrules", "Input",
  FontWeight->"Plain"],
 ", which is defined by: ",
 StyleBox["applydrules[arg_]:=expand[arg/.drules]", "Input",
  FontWeight->"Plain"],
 "; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "avf2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", "d\[Eta]", " ", "y"}], "+", 
  RowBox[{"dz", " ", 
   SubscriptBox["m", "2"]}], "-", 
  RowBox[{
   SubscriptBox["m", "1"], " ", 
   RowBox[{"dx", "\[Wedge]", "d\[Xi]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"dy", "\[Wedge]", "\[Eta]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"applydrules", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"dy", "\[Wedge]", "\[Eta]"}]}], "+", 
  RowBox[{"3", " ", "y", " ", 
   RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}]}], "+", 
  RowBox[{
   SubscriptBox["m", "1"], " ", 
   RowBox[{"dx", "\[Wedge]", "\[Zeta]", "\[Wedge]", "\[Eta]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " can be changed at any time to a different set. As with other ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " commands, ",
 StyleBox["makedrules", "Input",
  FontWeight->"Plain"],
 " won't accumulate replacements, but different sets of rules may be combined \
using ",
 StyleBox["Join", "Input",
  FontWeight->"Plain"],
 " in the argument. The following command simply resets ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " to ",
 StyleBox["natural", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Xi]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Eta]", "\[Rule]", "0"}], ",", 
   RowBox[{"d\[Zeta]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["so that now,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"applydrules", "[", 
  RowBox[{"d", "[", "avf2", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SubscriptBox["m", "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"dy", "\[Wedge]", "\[Eta]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Re-establish ",
 StyleBox["newdrules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", "newdrules", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Xi]", "\[Rule]", 
    RowBox[{"\[Eta]", "\[Wedge]", "\[Zeta]"}]}], ",", 
   RowBox[{"d\[Eta]", "\[Rule]", 
    RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}]}], ",", 
   RowBox[{"d\[Zeta]", "\[Rule]", 
    RowBox[{"\[Xi]", "\[Wedge]", "\[Eta]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The nested command just above, ",
 StyleBox["applydrules[d[arg]]", "Input",
  FontWeight->"Plain"],
 ", is actually used more often than ",
 StyleBox["d[arg]", "Input",
  FontWeight->"Plain"],
 " alone. An abbreviated differentiation operator ",
 StyleBox["da[arg]", "Input",
  FontWeight->"Plain"],
 " is defined for it; i.e.,"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"\[Xi]", "+", "\[Eta]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"d\[Eta]", "+", "d\[Xi]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"applydrules", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}], ")"}]}], "+", 
  RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"\[Xi]", "+", "\[Eta]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}], ")"}]}], "+", 
  RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that in using ",
 StyleBox["da[]", "Input",
  FontWeight->"Plain"],
 ", differentiation occurs ",
 StyleBox["before",
  FontVariations->{"Underline"->True}],
 " the drules are applied, so they have no effect on the derivative of any \
exact form, which necessarily vanishes; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["dforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"d\[Xi]", ",", "d\[Eta]", ",", "d\[Zeta]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "dforms", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", "dforms", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell["but,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[Xi]", ",", "\[Eta]", ",", "\[Zeta]", ",", "dx", ",", "dy", ",", "dz"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "forms", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "d\[Xi]", ",", "d\[Eta]", ",", "d\[Zeta]", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", "forms", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}], ")"}]}], ",", 
   RowBox[{"\[Zeta]", "\[Wedge]", "\[Xi]"}], ",", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"\[Eta]", "\[Wedge]", "\[Xi]"}], ")"}]}], ",", "0", ",", "0", 
   ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Generally, it is important to ensure consistency (closure) of the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", which is not verified automatically by the program; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", "\[Xi]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{"\[Zeta]", "\[Wedge]", "\[Eta]"}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and differentiating without applying the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " gives,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Zeta]", "\[Wedge]", "d\[Eta]"}], "-", 
  RowBox[{"\[Eta]", "\[Wedge]", "d\[Zeta]"}]}]], "Output"]
}, Open  ]],

Cell["but as required for consistency of the double derivative,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"applydrules", "[", "%", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["Checking all of them", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"da", "[", 
   RowBox[{"da", "[", "\[Xi]", "]"}], "]"}], "==", 
  RowBox[{"da", "[", 
   RowBox[{"da", "[", "\[Eta]", "]"}], "]"}], "==", 
  RowBox[{"da", "[", 
   RowBox[{"da", "[", "\[Zeta]", "]"}], "]"}], "==", "0"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell["but again, this could be done in one step on the whole list;", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"da", "[", "forms", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This ensures that both double derivatives will vanish identically for all \
",
 StyleBox["AVF",
  FontWeight->"Plain"],
 " expressions; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"d", "[", "avf2", "]"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"da", "[", "avf2", "]"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Generally, the use of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " is optional, but there is one situation in which they are mandatory, and \
is the reason for establishing a default value for them. The one place ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are required is for vector contractions, which are defined on all members \
of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", but not on their exterior derivative 2-forms. In the case of vector \
contraction, they are invoked automatically before doing the contraction; \
e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec1", "\[SmallCircle]", "dforms"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Zeta]", " ", 
     SubscriptBox["v1", "2"]}], "-", 
    RowBox[{"\[Eta]", " ", 
     SubscriptBox["v1", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[Zeta]"}], " ", 
     SubscriptBox["v1", "1"]}], "+", 
    RowBox[{"\[Xi]", " ", 
     SubscriptBox["v1", "3"]}]}], ",", 
   RowBox[{
    RowBox[{"\[Eta]", " ", 
     SubscriptBox["v1", "1"]}], "-", 
    RowBox[{"\[Xi]", " ", 
     SubscriptBox["v1", "2"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox["all",
  FontVariations->{"Underline"->True}],
 " the replacements that have been established as ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are applied in a contraction, not just those involving ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "In summary, establishing a set of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " is essential for most operations involving contractions, such as the Lie \
derivative of AVFs. In addition: they can be used to define anholonomic basis \
forms; to express derivatives of functions of coordinates in terms of an \
anholonomic basis; and to impose a group structure on the basis 1-forms using \
a set of Maurer-Cartan equations (as in ",
 StyleBox["newdrules", "Input",
  FontWeight->"Plain"],
 ")."
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["II.c.3. Transformations of coordinates", "Subsubsection"],

Cell[TextData[{
 "Call the current scalars ",
 StyleBox["cartesian", "Input",
  FontWeight->"Plain"],
 " and add in a new set, ",
 StyleBox["spherical", "Input",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cartesian", "=", "scalars"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spherical", "=", 
  RowBox[{"{", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"cartesian", ",", "spherical"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "x", ",", "y", ",", "z", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "dx", ",", "dy", ",", "dz", ",", "dr", ",", "d\[Theta]", ",", 
   "d\[CurlyPhi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The transformation from cartesian to spherical coordinates is expressed by \
a list of replacement rules, ",
 StyleBox["not",
  FontVariations->{"Underline"->True}],
 " assignments. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Thread", "Input",
  FontWeight->"Plain"],
 " command is convenient for distributing the ",
 StyleBox["Rule", "Input",
  FontWeight->"Plain"],
 " symbol,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trans", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{"cartesian", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], ",", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], ",", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the transformation can be accomplished by ",
 StyleBox["ReplaceAll", "Input",
  FontWeight->"Plain"],
 " (",
 StyleBox["/.", "Input",
  FontWeight->"Plain"],
 ")."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cartesian", "/.", "trans"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The operator ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 " works on a list of AVFs --not on a list of Rules-- but the transformation \
of derivatives can be constructed quickly by;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dtrans", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"d", "[", "cartesian", "]"}], "->", 
    RowBox[{"d", "[", 
     RowBox[{"(", 
      RowBox[{"cartesian", "/.", "trans"}], ")"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dx", "\[Rule]", 
    RowBox[{
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"dr", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
   RowBox[{"dy", "\[Rule]", 
    RowBox[{
     RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"dr", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
   RowBox[{"dz", "\[Rule]", 
    RowBox[{
     RowBox[{"dr", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
and all of these can be joined into a single list of transformation rules;\
\>", "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tospherical", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"trans", ",", "dtrans"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
   RowBox[{"dx", "\[Rule]", 
    RowBox[{
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"dr", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
   RowBox[{"dy", "\[Rule]", 
    RowBox[{
     RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"dr", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
   RowBox[{"dz", "\[Rule]", 
    RowBox[{
     RowBox[{"dr", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "+", 
    SuperscriptBox["y", "2"]}], "/.", "tospherical"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "2"], " ", 
  SuperscriptBox[
   RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]], "Output"]
}, Open  ]],

Cell["For the volume form,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vol", "=", 
  RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dz"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dz"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vol", "/.", "tospherical"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d\[Theta]", " ", "r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
    RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], ")"}], "\[Wedge]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{"d\[Theta]", " ", "r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], ")"}], "\[Wedge]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"dr", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
    RowBox[{"d\[Theta]", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The substitutions were made, but the expression needs to be simplified. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Expand", "Input",
  FontWeight->"Plain"],
 " has no effect on wedge products,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d\[Theta]", " ", "r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
    RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], ")"}], "\[Wedge]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{"d\[Theta]", " ", "r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], ")"}], "\[Wedge]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"dr", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
    RowBox[{"d\[Theta]", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "but the analogous ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " command does the required expansion of the wedge products,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[CurlyPhi]"}]}], "+", 
  RowBox[{
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"], " ", 
   RowBox[{"dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[CurlyPhi]"}]}], "+", 
  RowBox[{
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
   RowBox[{"dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[CurlyPhi]"}]}], "+", 
  RowBox[{
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
   RowBox[{
   "dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[CurlyPhi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "after which ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will simplify the coefficients,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "2"], " ", 
  RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
  RowBox[{
  "dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[CurlyPhi]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This could also be done with ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", "dtrans", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dx", "\[Rule]", 
    RowBox[{
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"dr", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
   RowBox[{"dy", "\[Rule]", 
    RowBox[{
     RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
     RowBox[{"dr", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
   RowBox[{"dz", "\[Rule]", 
    RowBox[{
     RowBox[{"dr", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"d\[Theta]", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"applydrules", "[", "vol", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "2"], " ", 
  RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
  RowBox[{
  "dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[CurlyPhi]"}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.c.4. Clean up", "Subsubsection"],

Cell[TextData[{
 "To avoid confusion among the variables of different problems, it is \
important to have a way of undeclaring the variables we have registered in \
the various fundamental lists. There are two sets of variables: the private \
global variables of the ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package (in the ",
 StyleBox["xAct`AVF`", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["xAct`AVF`Private`", "Input",
  FontWeight->"Plain"],
 " contexts) and the user variables (in the ",
 StyleBox["Global`", "Input",
  FontWeight->"Plain"],
 " contex)."
}], "Text"],

Cell[TextData[{
 "a) Global variables of the ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package."
}], "Text"],

Cell["\<\
Jose: To help keeping track of which variables are modified, I have added \
these:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"adjlist\"\>", ",", "\<\"algebra\"\>", ",", "\<\"dforms\"\>", 
   ",", "\<\"drules\"\>", ",", "\<\"dscalars\"\>", ",", "\<\"eldim\"\>", 
   ",", "\<\"elements\"\>", ",", "\<\"fderiv\"\>", ",", "\<\"fmdim\"\>", 
   ",", "\<\"forms\"\>", ",", "\<\"natural\"\>", ",", "\<\"scalars\"\>", 
   ",", "\<\"scdim\"\>", ",", "\<\"sderiv\"\>", ",", "\<\"vec1\"\>", 
   ",", "\<\"vec2\"\>", ",", "\<\"vec3\"\>", ",", "\<\"vec4\"\>", 
   ",", "\<\"av$44\"\>", ",", "\<\"av$cs\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", " ", "AVFinitialstate"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"{", "identity", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{"{", "identity", "}"}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox["1",
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "identity", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{"xAct`AVF`Private`av$fm", "\[Rule]", "0"}], "}"}],
    HoldForm], ",", 
   TagBox["0",
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox["0",
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{"{", 
      SubscriptBox["xAct`AVF`Private`av$49", 
       RowBox[{"1", ",", "1"}]], "}"}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", "}"}],
    HoldForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%%", "/.", "AVFstate"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["m", "0"], ",", 
      SubscriptBox["m", "1"], ",", 
      SubscriptBox["m", "2"], ",", 
      SubscriptBox["m", "3"]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["m", "0"], ",", 
        SubscriptBox["m", "1"], ",", 
        SubscriptBox["m", "2"], ",", 
        SubscriptBox["m", "3"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["m", "1"], ",", 
        SubscriptBox["m", "0"], ",", 
        SubscriptBox["m", "3"], ",", 
        SubscriptBox["m", "2"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["m", "2"], ",", 
        RowBox[{"-", 
         SubscriptBox["m", "3"]}], ",", 
        SubscriptBox["m", "0"], ",", 
        RowBox[{"-", 
         SubscriptBox["m", "1"]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["m", "3"], ",", 
        RowBox[{"-", 
         SubscriptBox["m", "2"]}], ",", 
        SubscriptBox["m", "1"], ",", 
        RowBox[{"-", 
         SubscriptBox["m", "0"]}]}], "}"}]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{"d\[Xi]", ",", "d\[Eta]", ",", "d\[Zeta]"}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dx", "\[Rule]", 
       RowBox[{
        RowBox[{"d\[Theta]", " ", "r", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
        RowBox[{"dr", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
      RowBox[{"dy", "\[Rule]", 
       RowBox[{
        RowBox[{"d\[CurlyPhi]", " ", "r", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"d\[Theta]", " ", "r", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
        RowBox[{"dr", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}]}], ",", 
      RowBox[{"dz", "\[Rule]", 
       RowBox[{
        RowBox[{"dr", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"d\[Theta]", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
     "dx", ",", "dy", ",", "dz", ",", "dr", ",", "d\[Theta]", ",", 
      "d\[CurlyPhi]"}], "}"}],
    HoldForm], ",", 
   TagBox["4",
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["m", "0"], ",", 
      SubscriptBox["m", "1"], ",", 
      SubscriptBox["m", "2"], ",", 
      SubscriptBox["m", "3"]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xAct`AVF`Private`av$fm", "\[Rule]", "0"}], ",", 
      RowBox[{"d\[Xi]", "\[Rule]", "0"}], ",", 
      RowBox[{"\[Xi]", "\[Rule]", "d\[Xi]"}], ",", 
      RowBox[{"d\[Eta]", "\[Rule]", "0"}], ",", 
      RowBox[{"\[Eta]", "\[Rule]", "d\[Eta]"}], ",", 
      RowBox[{"d\[Zeta]", "\[Rule]", "0"}], ",", 
      RowBox[{"\[Zeta]", "\[Rule]", "d\[Zeta]"}], ",", 
      RowBox[{"dx", "\[Rule]", "0"}], ",", 
      RowBox[{"dy", "\[Rule]", "0"}], ",", 
      RowBox[{"dz", "\[Rule]", "0"}], ",", 
      RowBox[{"dr", "\[Rule]", "0"}], ",", 
      RowBox[{"d\[Theta]", "\[Rule]", "0"}], ",", 
      RowBox[{"d\[CurlyPhi]", "\[Rule]", "0"}]}], "}"}],
    HoldForm], ",", 
   TagBox["9",
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
     "\[Xi]", ",", "\[Eta]", ",", "\[Zeta]", ",", "dx", ",", "dy", ",", "dz", 
      ",", "dr", ",", "d\[Theta]", ",", "d\[CurlyPhi]"}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"d\[Xi]", "\[Rule]", "0"}], ",", 
      RowBox[{"d\[Eta]", "\[Rule]", "0"}], ",", 
      RowBox[{"d\[Zeta]", "\[Rule]", "0"}]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
     "x", ",", "y", ",", "z", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}],
      "}"}],
    HoldForm], ",", 
   TagBox["6",
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Dt", "[", "x", "]"}], "\[Rule]", "dx"}], ",", 
      RowBox[{
       RowBox[{"Dt", "[", "y", "]"}], "\[Rule]", "dy"}], ",", 
      RowBox[{
       RowBox[{"Dt", "[", "z", "]"}], "\[Rule]", "dz"}], ",", 
      RowBox[{
       RowBox[{"Dt", "[", "r", "]"}], "\[Rule]", "dr"}], ",", 
      RowBox[{
       RowBox[{"Dt", "[", "\[Theta]", "]"}], "\[Rule]", "d\[Theta]"}], ",", 
      RowBox[{
       RowBox[{"Dt", "[", "\[CurlyPhi]", "]"}], "\[Rule]", "d\[CurlyPhi]"}]}],
      "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v1", "1"], ",", 
      SubscriptBox["v1", "2"], ",", 
      SubscriptBox["v1", "3"], ",", 
      SubscriptBox["v1", "4"], ",", 
      SubscriptBox["v1", "5"], ",", 
      SubscriptBox["v1", "6"], ",", 
      SubscriptBox["v1", "7"], ",", 
      SubscriptBox["v1", "8"], ",", 
      SubscriptBox["v1", "9"]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v2", "1"], ",", 
      SubscriptBox["v2", "2"], ",", 
      SubscriptBox["v2", "3"], ",", 
      SubscriptBox["v2", "4"], ",", 
      SubscriptBox["v2", "5"], ",", 
      SubscriptBox["v2", "6"], ",", 
      SubscriptBox["v2", "7"], ",", 
      SubscriptBox["v2", "8"], ",", 
      SubscriptBox["v2", "9"]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v3", "1"], ",", 
      SubscriptBox["v3", "2"], ",", 
      SubscriptBox["v3", "3"], ",", 
      SubscriptBox["v3", "4"], ",", 
      SubscriptBox["v3", "5"], ",", 
      SubscriptBox["v3", "6"], ",", 
      SubscriptBox["v3", "7"], ",", 
      SubscriptBox["v3", "8"], ",", 
      SubscriptBox["v3", "9"]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v4", "1"], ",", 
      SubscriptBox["v4", "2"], ",", 
      SubscriptBox["v4", "3"], ",", 
      SubscriptBox["v4", "4"], ",", 
      SubscriptBox["v4", "5"], ",", 
      SubscriptBox["v4", "6"], ",", 
      SubscriptBox["v4", "7"], ",", 
      SubscriptBox["v4", "8"], ",", 
      SubscriptBox["v4", "9"]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"1", ",", "1"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"1", ",", "2"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"1", ",", "3"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"1", ",", "4"}]]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"2", ",", "1"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"2", ",", "2"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"2", ",", "3"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"2", ",", "4"}]]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"3", ",", "1"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"3", ",", "2"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"3", ",", "3"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"3", ",", "4"}]]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"4", ",", "1"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"4", ",", "2"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"4", ",", "3"}]], ",", 
        SubscriptBox["xAct`AVF`Private`av$49", 
         RowBox[{"4", ",", "4"}]]}], "}"}]}], "}"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["xAct`AVF`Private`av$c", "1"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "2"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "3"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "4"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "5"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "6"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "7"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "8"], ",", 
      SubscriptBox["xAct`AVF`Private`av$c", "9"]}], "}"}],
    HoldForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To restore the original state of the ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " variables we can do the following, in this order:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeelements", "[", 
  RowBox[{"{", "identity", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "identity", "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"makealgebra", "[", 
  RowBox[{"{", 
   RowBox[{"{", "identity", "}"}], "}"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeforms", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "dx", ",", "dy", ",", "dz", ",", "dr", ",", "d\[Theta]", ",", 
   "d\[CurlyPhi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell["Now:", "Text"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Jose: Those four commands (plus some others of the same type) have beeng \
grouped in the single action ",
 StyleBox["makeclear[]", "Input",
  FontWeight->"Plain"],
 ", which will be used from now on in this file for clearing the ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " state."
}], "Text"],

Cell[TextData[{
 "b) Then we also have our own variables, declared in the ",
 StyleBox["Global`", "Input",
  FontWeight->"Plain"],
 " context of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Global`*"}]], "Input"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["Global`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["Global`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["a",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"a", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["dr",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"dr", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["fac",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"fac", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["newdrules",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"newdrules", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["vol",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"vol", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["avf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"avf", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["dtrans",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"dtrans", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["i",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"i", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["Option",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"Option", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["x",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"x", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["avf1",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"avf1", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["dx",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"dx", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["k",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"k", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["p",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"p", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["y",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"y", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["avf2",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"avf2", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["dy",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"dy", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["m",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"m", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["pvec",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"pvec", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["z",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"z", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["avf3",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"avf3", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["dz",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"dz", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["M",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"M", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["r",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"r", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["\[Zeta]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"\[Zeta]", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["avf4",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"avf4", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["d\[Zeta]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"d\[Zeta]", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["mat",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"mat", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["Shift",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"Shift", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["\[Eta]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"\[Eta]", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["cartesian",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"cartesian", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["d\[Eta]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"d\[Eta]", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["matavf3",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"matavf3", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["spherical",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"spherical", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["\[Lambda]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"\[Lambda]", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["Command",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"Command", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["d\[Xi]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"d\[Xi]", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["MenuKey",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"MenuKey", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["taggingrules",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"taggingrules", "Global`"}},
          
          ButtonNote->"Global`"], 
         ButtonBox["\[Xi]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"\[Xi]", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["cs",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"cs", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["d\[CurlyPhi]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"d\[CurlyPhi]", "Global`"}},
          
          ButtonNote->"Global`"], 
         ButtonBox["mono",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"mono", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["tospherical",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"tospherical", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["\[CurlyPhi]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"\[CurlyPhi]", "Global`"}},
          ButtonNote->"Global`"]},
        {
         ButtonBox["cs2",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"cs2", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["f",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"f", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["monomialfactor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3533138458-7301182", {"monomialfactor", "Global`"}},
          ButtonNote->"Global`"], 
         ButtonBox["trans",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3533138458-7301182", {"trans", "Global`"}},
          ButtonNote->"Global`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.19]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell"]
}, Open  ]],

Cell["\<\
We can remove them individually, or can remove all of them using\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[TextData[{
 "Now the ",
 StyleBox["Global`", "Input",
  FontWeight->"Plain"],
 " context is empty:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Global`*"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Information", "::", "nomatch"}], "MessageName"], ":", 
  " ", "\<\"No symbol matching \[NoBreak]\\!\\(\\\"Global`*\\\"\\)\[NoBreak] \
found. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Information/nomatch\\\", ButtonNote -> \
\\\"Information::nomatch\\\"]\\)\"\>"}]], "Message", "MSG"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.d. Lie differentiation", "Subsection"],

Cell[CellGroupData[{

Cell["II.d.1. Setting up some scalar variables", "Subsubsection",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Introducing non-exact 1-forms will be delayed to a later section.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell["\<\
Since the algebra elements are constants, they are not actively involved in \
Lie differentiation. All the operations below can be applied to general \
AVF's, but for illustration we use ordinary differential forms; i.e., the \
trivial default algebra.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"identity"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.d.2. Lie derivative of AVFs, using a coordinate basis", \
"Subsubsection",
 PageWidth->WindowWidth],

Cell[TextData[{
 "The current ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list and the first convenience vector,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["vec1"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["lie[vec, avf]", "Input",
  FontWeight->"Plain"],
 " calculates the Lie derivative of ",
 StyleBox["avf", "Input",
  FontWeight->"Plain"],
 " with respect to a vector ",
 StyleBox["vec", "Input",
  FontWeight->"Plain"],
 " using the expansion ",
 StyleBox["lie[vec_,avf_]:=vec\[SmallCircle]d[avf]+da[vec\[SmallCircle]avf]", 
  "Input",
  FontWeight->"Plain"],
 ". On a function of the scalars, ",
 StyleBox["lie", "Input",
  FontWeight->"Plain"],
 " just gives the directional derivative,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"vec1", ",", 
   RowBox[{"F", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{
    SuperscriptBox["F", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{
    SuperscriptBox["F", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   RowBox[{
    SuperscriptBox["F", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell["But the convenience vector components are constants,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "vec1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and usually one wants a vector field. There are two ways to turn the \
components of ",
 StyleBox["V", "Input",
  FontWeight->"Plain"],
 " into field variables: either write them explicitly as specified or \
unspecified functions of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 "; or add the components into ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " as new independent variables. The problem with the first approach arises \
from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s output notation for derivatives of unspecified multi-variable functions, \
which is lengthy and not very readable. "
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[TextData[{
 "Consider the vector ",
 StyleBox["V", "Input",
  FontWeight->"Plain"],
 " having unspecified functional components dual to ",
 StyleBox["{dx,dy,dz}", "Input",
  FontWeight->"Plain"],
 ", operating on a general 2-form ",
 StyleBox["T", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"v1", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
    RowBox[{"v2", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
    RowBox[{"v3", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v1", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"v2", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"v3", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"T", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"X", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], 
    RowBox[{"dy", "\[Wedge]", "dz"}]}], "+", 
   RowBox[{
    RowBox[{"Y", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], 
    RowBox[{"dz", "\[Wedge]", "dx"}]}], "+", 
   RowBox[{
    RowBox[{"Z", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], 
    RowBox[{"dx", "\[Wedge]", "dy"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", "dx"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{"Z", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "T"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"dy", "\[Wedge]", "dz"}], ")"}]}], " ", 
   RowBox[{"Z", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{"Z", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"v3", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{
    SuperscriptBox["X", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"v3", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{
    SuperscriptBox["Y", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"v3", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{
    SuperscriptBox["Z", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{"Z", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"v2", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{
    SuperscriptBox["X", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"v2", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{
    SuperscriptBox["Y", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"v2", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{
    SuperscriptBox["Z", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{"Z", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["v3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"v1", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{
    SuperscriptBox["X", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"v1", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{
    SuperscriptBox["Y", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"v1", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{
    SuperscriptBox["Z", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "II.d.3. Introducing coordinates with ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "Better output is provided in ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " by establishing a subset of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " as ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 ", using the ",
 StyleBox["makecoords[]", "Input",
  FontWeight->"Plain"],
 " command. More details about ",
 StyleBox["makecoords[]", "Input",
  FontWeight->"Plain"],
 " are given at the end of this section. Any pre-existing members of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " which are not designated as ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " will have subscript partial derivative expansions defined for them using \
Format output, and these are added into the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", which are invoked automatically for Lie derivatives."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[TextData[{
 "Using this approach, the scalar field variables in ",
 StyleBox["V", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["T", "Input",
  FontWeight->"Plain"],
 " are written without functional dependence, and are added into ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " before defining ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"V", "=", 
  RowBox[{"{", 
   RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], "\n", 
 RowBox[{"T", "=", 
  RowBox[{
   RowBox[{"X", " ", 
    RowBox[{"dy", "\[Wedge]", "dz"}]}], "+", 
   RowBox[{"Y", " ", 
    RowBox[{"dz", "\[Wedge]", "dx"}]}], "+", 
   RowBox[{"Z", " ", 
    RowBox[{"dx", "\[Wedge]", "dy"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}]}], "+", 
  RowBox[{"X", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}]}], "+", 
  RowBox[{"Y", " ", 
   RowBox[{"dz", "\[Wedge]", "dx"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"scalars", ",", "V", ",", 
    RowBox[{"{", 
     RowBox[{"X", ",", "Y", ",", "Z"}], "}"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "x", ",", "y", ",", "z", ",", "v1", ",", "v2", ",", "v3", ",", "X", ",", 
   "Y", ",", "Z"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and then ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " is established,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "x", ",", "y", ",", "z", ",", "v1", ",", "v2", ",", "v3", ",", "X", ",", 
   "Y", ",", "Z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dv1", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["v1", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["v1", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["v1", "x"]}]}]}], ",", 
   RowBox[{"dv2", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["v2", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["v2", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["v2", "x"]}]}]}], ",", 
   RowBox[{"dv3", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["v3", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["v3", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["v3", "x"]}]}]}], ",", 
   RowBox[{"dX", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["X", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["X", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["X", "x"]}]}]}], ",", 
   RowBox[{"dY", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["Y", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["Y", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["Y", "x"]}]}]}], ",", 
   RowBox[{"dZ", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["Z", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["Z", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["Z", "x"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Now the same Lie derivative performed above is output in a more readable form:\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "T"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "Z"}], " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v1", "z"]}], "+", 
  RowBox[{"Z", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v2", "z"]}], "-", 
  RowBox[{"Y", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v3", "z"]}], "+", 
  RowBox[{"X", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v3", "z"]}], "+", 
  RowBox[{"v3", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["X", "z"]}], "-", 
  RowBox[{"v3", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["Y", "z"]}], "+", 
  RowBox[{"v3", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox["Z", "z"]}], "-", 
  RowBox[{"Y", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v1", "y"]}], "+", 
  RowBox[{"Z", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox["v2", "y"]}], "+", 
  RowBox[{"X", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v2", "y"]}], "-", 
  RowBox[{"Y", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox["v3", "y"]}], "+", 
  RowBox[{"v2", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["X", "y"]}], "-", 
  RowBox[{"v2", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["Y", "y"]}], "+", 
  RowBox[{"v2", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox["Z", "y"]}], "+", 
  RowBox[{"Z", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox["v1", "x"]}], "-", 
  RowBox[{"Y", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v1", "x"]}], "+", 
  RowBox[{"X", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["v2", "x"]}], "-", 
  RowBox[{"X", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox["v3", "x"]}], "+", 
  RowBox[{"v1", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["X", "x"]}], "-", 
  RowBox[{"v1", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox["Y", "x"]}], "+", 
  RowBox[{"v1", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox["Z", "x"]}]}]], "Output"]
}, Open  ]],

Cell["\<\
To sort that into independent bases, the canonical order of the basis 2-forms \
(as they appear there) must be used. This gives about the simplest possible \
output for general vectors and forms.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dy", "\[Wedge]", "dz"}], ",", 
     RowBox[{"dx", "\[Wedge]", "dz"}], ",", 
     RowBox[{"dx", "\[Wedge]", "dy"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Z"}], " ", 
      SubscriptBox["v1", "z"]}], "+", 
     RowBox[{"X", " ", 
      SubscriptBox["v3", "z"]}], "+", 
     RowBox[{"v3", " ", 
      SubscriptBox["X", "z"]}], "-", 
     RowBox[{"Y", " ", 
      SubscriptBox["v1", "y"]}], "+", 
     RowBox[{"X", " ", 
      SubscriptBox["v2", "y"]}], "+", 
     RowBox[{"v2", " ", 
      SubscriptBox["X", "y"]}], "+", 
     RowBox[{"v1", " ", 
      SubscriptBox["X", "x"]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Z", " ", 
      SubscriptBox["v2", "z"]}], "-", 
     RowBox[{"Y", " ", 
      SubscriptBox["v3", "z"]}], "-", 
     RowBox[{"v3", " ", 
      SubscriptBox["Y", "z"]}], "-", 
     RowBox[{"v2", " ", 
      SubscriptBox["Y", "y"]}], "-", 
     RowBox[{"Y", " ", 
      SubscriptBox["v1", "x"]}], "+", 
     RowBox[{"X", " ", 
      SubscriptBox["v2", "x"]}], "-", 
     RowBox[{"v1", " ", 
      SubscriptBox["Y", "x"]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"v3", " ", 
      SubscriptBox["Z", "z"]}], "+", 
     RowBox[{"Z", " ", 
      SubscriptBox["v2", "y"]}], "-", 
     RowBox[{"Y", " ", 
      SubscriptBox["v3", "y"]}], "+", 
     RowBox[{"v2", " ", 
      SubscriptBox["Z", "y"]}], "+", 
     RowBox[{"Z", " ", 
      SubscriptBox["v1", "x"]}], "-", 
     RowBox[{"X", " ", 
      SubscriptBox["v3", "x"]}], "+", 
     RowBox[{"v1", " ", 
      SubscriptBox["Z", "x"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that the current ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are never invoked automatically in exterior differentiation; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"{", 
   RowBox[{"v1", ",", "Y", ",", "T"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dv1", ",", "dY", ",", 
   RowBox[{
    RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dZ"}], "+", 
    RowBox[{"dx", "\[Wedge]", "dY", "\[Wedge]", "dz"}], "+", 
    RowBox[{"dX", "\[Wedge]", "dy", "\[Wedge]", "dz"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "but they will be applied using ",
 StyleBox["da[]", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"{", 
   RowBox[{"v1", ",", "Y", ",", "T"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"dz", " ", 
     SubscriptBox["v1", "z"]}], "+", 
    RowBox[{"dy", " ", 
     SubscriptBox["v1", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["v1", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"dz", " ", 
     SubscriptBox["Y", "z"]}], "+", 
    RowBox[{"dy", " ", 
     SubscriptBox["Y", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["Y", "x"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["Z", "z"]}], "+", 
    RowBox[{
     RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["Y", "y"]}], "+", 
    RowBox[{
     RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["X", "x"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["and are automatic for all vector contractions,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V", "\[SmallCircle]", 
  RowBox[{"d", "[", 
   RowBox[{"{", 
    RowBox[{"v1", ",", "Y", ",", "T"}], "}"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"v3", " ", 
     SubscriptBox["v1", "z"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["v1", "y"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["v1", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"v3", " ", 
     SubscriptBox["Y", "z"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["Y", "y"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["Y", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"v3", " ", 
     RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
     SubscriptBox["Z", "z"]}], "-", 
    RowBox[{"v2", " ", 
     RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["Z", "z"]}], "+", 
    RowBox[{"v1", " ", 
     RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["Z", "z"]}], "+", 
    RowBox[{"v3", " ", 
     RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
     SubscriptBox["Y", "y"]}], "-", 
    RowBox[{"v2", " ", 
     RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["Y", "y"]}], "+", 
    RowBox[{"v1", " ", 
     RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["Y", "y"]}], "+", 
    RowBox[{"v3", " ", 
     RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
     SubscriptBox["X", "x"]}], "-", 
    RowBox[{"v2", " ", 
     RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["X", "x"]}], "+", 
    RowBox[{"v1", " ", 
     RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
     SubscriptBox["X", "x"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Any variable not in ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " can have the same formatting of partial derivatives by writing it as a \
function of the reserved variable ",
 StyleBox["depend", "Input",
  FontWeight->"Plain"],
 ", which inserts the dependence on ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"F", "[", "depend", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SubscriptBox["F", "z"]}], "+", 
  RowBox[{"dy", " ", 
   SubscriptBox["F", "y"]}], "+", 
  RowBox[{"dx", " ", 
   SubscriptBox["F", "x"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "f"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v3", " ", 
   SubscriptBox["F", "z"]}], "+", 
  RowBox[{"v2", " ", 
   SubscriptBox["F", "y"]}], "+", 
  RowBox[{"v1", " ", 
   SubscriptBox["F", "x"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The operators ",
 StyleBox["d", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["lie", "Input",
  FontWeight->"Plain"],
 " must commute identically for an arbitrary vector field,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"lie", "[", 
    RowBox[{"V", ",", "f"}], "]"}], "]"}], "-", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", 
    RowBox[{"d", "[", "f", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dv3", " ", 
   SubscriptBox["F", "z"]}], "-", 
  RowBox[{"dz", " ", 
   SubscriptBox["F", "z"], " ", 
   SubscriptBox["v3", "z"]}], "+", 
  RowBox[{"dv2", " ", 
   SubscriptBox["F", "y"]}], "-", 
  RowBox[{"dz", " ", 
   SubscriptBox["v2", "z"], " ", 
   SubscriptBox["F", "y"]}], "-", 
  RowBox[{"dy", " ", 
   SubscriptBox["F", "y"], " ", 
   SubscriptBox["v2", "y"]}], "-", 
  RowBox[{"dy", " ", 
   SubscriptBox["F", "z"], " ", 
   SubscriptBox["v3", "y"]}], "+", 
  RowBox[{"dv1", " ", 
   SubscriptBox["F", "x"]}], "-", 
  RowBox[{"dz", " ", 
   SubscriptBox["v1", "z"], " ", 
   SubscriptBox["F", "x"]}], "-", 
  RowBox[{"dy", " ", 
   SubscriptBox["v1", "y"], " ", 
   SubscriptBox["F", "x"]}], "-", 
  RowBox[{"dx", " ", 
   SubscriptBox["F", "x"], " ", 
   SubscriptBox["v1", "x"]}], "-", 
  RowBox[{"dx", " ", 
   SubscriptBox["F", "y"], " ", 
   SubscriptBox["v2", "x"]}], "-", 
  RowBox[{"dx", " ", 
   SubscriptBox["F", "z"], " ", 
   SubscriptBox["v3", "x"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "but the initial ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 " derivative in that statement does ",
 StyleBox["not",
  FontVariations->{"Underline"->True}],
 " invoke the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " required to give the correct result; i.e.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"applydrules", "[", "%", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the identity should be written using ",
 StyleBox["da[]", "Input",
  FontWeight->"Plain"],
 " rather than ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 "; for example, on the 2-form ",
 StyleBox["T", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"da", "[", 
   RowBox[{"lie", "[", 
    RowBox[{"V", ",", "T"}], "]"}], "]"}], "-", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", 
    RowBox[{"da", "[", "T", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Clearly, this technique may not be helpful when some vector components and \
some ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " are independent of some ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 ". In such cases, it may be better to use the standard functional notation, \
although it might also be feasible to edit out any unwanted terms from the \
automatically constructed ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", to use ",
 StyleBox["makedrules[]", "Input",
  FontWeight->"Plain"],
 " with the edited drules, and so preserve the brevity given by the Format \
notation."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["II.d.4. Lie product of vectors", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "Since both ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 " and \[SmallCircle] extend to arrays of AVFs, so does the ",
 StyleBox["lie[]", "Input",
  FontWeight->"Plain"],
 " function. And since a vector is represented as a list of scalar \
components, ",
 StyleBox["lie[]", "Input",
  FontWeight->"Plain"],
 " can be applied to vectors as well. Introduce a new vector ",
 StyleBox["W", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"W", "=", 
  RowBox[{"{", 
   RowBox[{"w1", ",", "w2", ",", "w3"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w1", ",", "w2", ",", "w3"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"scalars", ",", "W"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "x", ",", "y", ",", "z", ",", "v1", ",", "v2", ",", "v3", ",", "X", ",", 
   "Y", ",", "Z", ",", "w1", ",", "w2", ",", "w3"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To avoid duplication of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and now again make ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dv1", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["v1", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["v1", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["v1", "x"]}]}]}], ",", 
   RowBox[{"dv2", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["v2", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["v2", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["v2", "x"]}]}]}], ",", 
   RowBox[{"dv3", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["v3", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["v3", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["v3", "x"]}]}]}], ",", 
   RowBox[{"dw1", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["w1", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["w1", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["w1", "x"]}]}]}], ",", 
   RowBox[{"dw2", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["w2", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["w2", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["w2", "x"]}]}]}], ",", 
   RowBox[{"dw3", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["w3", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["w3", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["w3", "x"]}]}]}], ",", 
   RowBox[{"dX", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["X", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["X", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["X", "x"]}]}]}], ",", 
   RowBox[{"dY", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["Y", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["Y", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["Y", "x"]}]}]}], ",", 
   RowBox[{"dZ", "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox["Z", "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox["Z", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["Z", "x"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "W"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"v3", " ", 
     SubscriptBox["w1", "z"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["w1", "y"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["w1", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"v3", " ", 
     SubscriptBox["w2", "z"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["w2", "y"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["w2", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"v3", " ", 
     SubscriptBox["w3", "z"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["w3", "y"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["w3", "x"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["but for the Lie product this must be anti-symmetrized,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VW", "=", 
  RowBox[{
   RowBox[{"lie", "[", 
    RowBox[{"V", ",", "W"}], "]"}], "-", 
   RowBox[{"lie", "[", 
    RowBox[{"W", ",", "V"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "w3"}], " ", 
     SubscriptBox["v1", "z"]}], "+", 
    RowBox[{"v3", " ", 
     SubscriptBox["w1", "z"]}], "-", 
    RowBox[{"w2", " ", 
     SubscriptBox["v1", "y"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["w1", "y"]}], "-", 
    RowBox[{"w1", " ", 
     SubscriptBox["v1", "x"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["w1", "x"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "w3"}], " ", 
     SubscriptBox["v2", "z"]}], "+", 
    RowBox[{"v3", " ", 
     SubscriptBox["w2", "z"]}], "-", 
    RowBox[{"w2", " ", 
     SubscriptBox["v2", "y"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["w2", "y"]}], "-", 
    RowBox[{"w1", " ", 
     SubscriptBox["v2", "x"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["w2", "x"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "w3"}], " ", 
     SubscriptBox["v3", "z"]}], "+", 
    RowBox[{"v3", " ", 
     SubscriptBox["w3", "z"]}], "-", 
    RowBox[{"w2", " ", 
     SubscriptBox["v3", "y"]}], "+", 
    RowBox[{"v2", " ", 
     SubscriptBox["w3", "y"]}], "-", 
    RowBox[{"w1", " ", 
     SubscriptBox["v3", "x"]}], "+", 
    RowBox[{"v1", " ", 
     SubscriptBox["w3", "x"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["The identity for Lie differentiation reads", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"lie", "[", 
    RowBox[{"VW", ",", "T"}], "]"}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"lie", "[", 
      RowBox[{"V", ",", 
       RowBox[{"lie", "[", 
        RowBox[{"W", ",", "T"}], "]"}]}], "]"}], "-", 
     RowBox[{"lie", "[", 
      RowBox[{"W", ",", 
       RowBox[{"lie", "[", 
        RowBox[{"V", ",", "T"}], "]"}]}], "]"}]}], ")"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.d.5. Anholonomic forms", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell["\<\
Coordinate and anholonomic basis forms can perfectly well be mixed together, \
but for the moment the scalar variables will be dropped,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeforms", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], ",", 
    SubscriptBox["\[Omega]", "2"], ",", 
    SubscriptBox["\[Omega]", "3"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell["The first convenience vector is given a shorter name,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V", "=", "vec1"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "By default, the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " specify closed 1-forms, and ",
 StyleBox["lie", "Input",
  FontWeight->"Plain"],
 " invokes ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " automatically to perform the vector contractions involved. Furthermore, \
the vector ",
 StyleBox["V", "Input",
  FontWeight->"Plain"],
 " is constant,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "3"], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "V", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "so the resulting Lie derivative of the 2-form, ",
 StyleBox["Q", "Input",
  FontWeight->"Plain"],
 " , vanishes."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Q", "=", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
   SubscriptBox["\[Omega]", "2"]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
  SubscriptBox["\[Omega]", "2"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "Q"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
The anholonomic basis can be given the Maurer-Cartan structure relations:\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mcdrules", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["d\[Omega]", "1"], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], ",", 
    RowBox[{
     SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}], ")"}]}]}], ",", 
    RowBox[{
     SubscriptBox["d\[Omega]", "3"], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "3"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", "mcdrules", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "3"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["and checking closure,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"da", "[", "forms", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The vector ",
 StyleBox["V", "Input",
  FontWeight->"Plain"],
 " becomes a field by making its components into independent ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", "V", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", 
   SubscriptBox["dv1", "1"], ",", 
   SubscriptBox["dv1", "2"], ",", 
   SubscriptBox["dv1", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
and now the Lie derivative and commutation property are non-trivial.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "Q"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["dv1", "1"], "\[Wedge]", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   SubscriptBox["dv1", "2"], "\[Wedge]", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "-", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"da", "[", 
   RowBox[{"lie", "[", 
    RowBox[{"V", ",", "Q"}], "]"}], "]"}], "-", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", 
    RowBox[{"da", "[", "Q", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "When new basis forms appear, as the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["dv1", "i"], TraditionalForm]]],
 " above, the convenience vectors will automatically expand to accommodate \
them,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["vec1"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"], ",", 
   SubscriptBox["v1", "4"], ",", 
   SubscriptBox["v1", "5"], ",", 
   SubscriptBox["v1", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "but these 3 new components, representing contractions on the derivatives of \
the original vector components, are not in ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " and so are constant."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "vec1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["dv1", "1"], ",", 
   SubscriptBox["dv1", "2"], ",", 
   SubscriptBox["dv1", "3"], ",", "0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Taking higher Lie derivatives following this approach would require \
expanding the vectors and scalars at each new level. That is possible, but it \
gets out of hand rather quickly. However, the ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 " command can be used here to prevent the expansion; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[TextData[{
 "If higher derivatives are to be calculated, it will be necessary to expand \
V just once to cover contractions on the coordinate basis used to expand all \
scalar variables, say ",
 StyleBox["{x,y,z}", "Input",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", "dx", ",", "dy", ",", "dz"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Since all other ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " will be expanded on the coordinate basis, only these first 6 members of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " need to have vector components, and these components must appear in the \
final ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " list,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V", "=", "vec1"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"], ",", 
   SubscriptBox["v1", "4"], ",", 
   SubscriptBox["v1", "5"], ",", 
   SubscriptBox["v1", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", "V", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"], ",", 
   SubscriptBox["v1", "4"], ",", 
   SubscriptBox["v1", "5"], ",", 
   SubscriptBox["v1", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and now use ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 " to get a complete set of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell["The final lists:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z", ",", 
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"], ",", 
   SubscriptBox["v1", "4"], ",", 
   SubscriptBox["v1", "5"], ",", 
   SubscriptBox["v1", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", "dx", ",", "dy", ",", "dz", ",", 
   SubscriptBox["dv1", "1"], ",", 
   SubscriptBox["dv1", "2"], ",", 
   SubscriptBox["dv1", "3"], ",", 
   SubscriptBox["dv1", "4"], ",", 
   SubscriptBox["dv1", "5"], ",", 
   SubscriptBox["dv1", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "3"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}], ",", 
   RowBox[{
    SubscriptBox["dv1", "1"], "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["v1", "1"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["v1", "1"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["v1", "1"], "x"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dv1", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["v1", "2"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["v1", "2"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["v1", "2"], "x"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dv1", "3"], "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["v1", "3"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["v1", "3"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["v1", "3"], "x"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dv1", "4"], "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["v1", "4"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["v1", "4"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["v1", "4"], "x"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dv1", "5"], "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["v1", "5"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["v1", "5"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["v1", "5"], "x"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dv1", "6"], "\[Rule]", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["v1", "6"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["v1", "6"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["v1", "6"], "x"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["Repeating the same Lie derivative as calculated above,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VQ", "=", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", "Q"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubscriptBox["v1", "1"]}], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "-", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"]}], "-", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"]}], "-", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"da", "[", "VQ", "]"}], "-", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", 
    RowBox[{"da", "[", "Q", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["and a second derivative can now be evaluated,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "VQ"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubsuperscriptBox["v1", "1", "2"]}], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}]}], "-", 
  RowBox[{
   SubsuperscriptBox["v1", "2", "2"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}]}], "-", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   SubscriptBox["v1", "3"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   SubscriptBox["v1", "3"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "z"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "z"]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "z"]}], "-", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "z"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"zz\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"zz\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"]}], "-", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "y"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "y"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "y"]}], "-", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "y"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "y"]}], "-", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "y"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"yz\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"yz\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"yz\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"yz\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"yy\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"yy\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "-", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "-", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "x"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "x"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "x"]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "x"]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "y"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "x"]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "x"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"xz\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"xz\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "6"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"xz\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"xz\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"xy\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"xy\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "5"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"xy\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"xy\"\>"]}], "+", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "\<\"xx\"\>"]}], "-", 
  RowBox[{
   SubscriptBox["v1", "4"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "\<\"xx\"\>"]}]}]], "Output"]
}, Open  ]],

Cell["The coordinates can mix in with the anholonomic forms;", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S", "=", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], "+", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], "+", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dx", "\[Wedge]", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{"dy", "\[Wedge]", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"dz", "\[Wedge]", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VS", "=", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", "S"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubscriptBox["v1", "3"]}], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}]}], "+", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{
   SubscriptBox["v1", "3"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}]}], "-", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "-", 
  RowBox[{
   SubscriptBox["v1", "2"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}]}], "+", 
  RowBox[{
   SubscriptBox["v1", "1"], " ", 
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "z"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "z"]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "z"]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "z"]}], "+", 
  RowBox[{
   RowBox[{"dz", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "z"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "1"], "y"]}], "-", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "y"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "y"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "y"]}], "+", 
  RowBox[{
   RowBox[{"dy", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "y"]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dy"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "2"], "x"]}], "-", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", "dz"}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "3"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "4"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "5"], "x"]}], "+", 
  RowBox[{
   RowBox[{"dx", "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}], " ", 
   SubscriptBox[
    SubscriptBox["v1", "6"], "x"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"da", "[", "VS", "]"}], "-", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", 
    RowBox[{"da", "[", "S", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["lie[]", "Input",
  FontWeight->"Plain"],
 " will operate on any array of AVFs"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"M", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], ",", 
      SubscriptBox["\[Omega]", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["d\[Omega]", "1"], ",", 
      SubscriptBox["d\[Omega]", "2"]}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], ",", 
     SubscriptBox["\[Omega]", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["d\[Omega]", "1"], ",", 
     SubscriptBox["d\[Omega]", "2"]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"V", ",", "M"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["v1", "3"]}], " ", 
       SubscriptBox["\[Omega]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["v1", "2"], " ", 
       SubscriptBox["\[Omega]", "3"]}], "+", 
      RowBox[{"dz", " ", 
       SubscriptBox[
        SubscriptBox["v1", "1"], "z"]}], "+", 
      RowBox[{"dy", " ", 
       SubscriptBox[
        SubscriptBox["v1", "1"], "y"]}], "+", 
      RowBox[{"dx", " ", 
       SubscriptBox[
        SubscriptBox["v1", "1"], "x"]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["v1", "3"], " ", 
       SubscriptBox["\[Omega]", "1"]}], "-", 
      RowBox[{
       SubscriptBox["v1", "1"], " ", 
       SubscriptBox["\[Omega]", "3"]}], "+", 
      RowBox[{"dz", " ", 
       SubscriptBox[
        SubscriptBox["v1", "2"], "z"]}], "+", 
      RowBox[{"dy", " ", 
       SubscriptBox[
        SubscriptBox["v1", "2"], "y"]}], "+", 
      RowBox[{"dx", " ", 
       SubscriptBox[
        SubscriptBox["v1", "2"], "x"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["v1", "2"], " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}]}], "+", 
      RowBox[{
       SubscriptBox["v1", "3"], " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}]}], "+", 
      RowBox[{
       RowBox[{"dz", "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "2"], "z"]}], "-", 
      RowBox[{
       RowBox[{"dz", "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "3"], "z"]}], "+", 
      RowBox[{
       RowBox[{"dy", "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "2"], "y"]}], "-", 
      RowBox[{
       RowBox[{"dy", "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "3"], "y"]}], "+", 
      RowBox[{
       RowBox[{"dx", "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "2"], "x"]}], "-", 
      RowBox[{
       RowBox[{"dx", "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "3"], "x"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["v1", "1"]}], " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}]}], "+", 
      RowBox[{
       SubscriptBox["v1", "3"], " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}]}], "-", 
      RowBox[{
       RowBox[{"dz", "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "1"], "z"]}], "+", 
      RowBox[{
       RowBox[{"dz", "\[Wedge]", 
        SubscriptBox["\[Omega]", "1"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "3"], "z"]}], "-", 
      RowBox[{
       RowBox[{"dy", "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "1"], "y"]}], "+", 
      RowBox[{
       RowBox[{"dy", "\[Wedge]", 
        SubscriptBox["\[Omega]", "1"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "3"], "y"]}], "-", 
      RowBox[{
       RowBox[{"dx", "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "1"], "x"]}], "+", 
      RowBox[{
       RowBox[{"dx", "\[Wedge]", 
        SubscriptBox["\[Omega]", "1"]}], " ", 
       SubscriptBox[
        SubscriptBox["v1", "3"], "x"]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"da", "[", 
   RowBox[{"lie", "[", 
    RowBox[{"V", ",", "M"}], "]"}], "]"}], "-", 
  RowBox[{"lie", "[", 
   RowBox[{"V", ",", 
    RowBox[{"da", "[", "M", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.d.6. Lie products and the Lie algebra of non-exact forms", \
"Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Bold"],

Cell[TextData[{
 "The \"dual\" basis vectors are given by the rows of the identity matrix, \
where ",
 StyleBox["fmdim", "Input",
  FontWeight->"Plain"],
 " is the length of the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list. The duals to the exact 1-forms in ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " must commute, so can be eliminated,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"duals", "=", 
   RowBox[{"IdentityMatrix", "[", "fmdim", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A list of the Lie derivatives of the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list with respect to each of their 3 dual vectors:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lf", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"lie", "[", 
     RowBox[{
      RowBox[{"duals", "[", 
       RowBox[{"[", "m", "]"}], "]"}], ",", "forms"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "fmdim"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      SubscriptBox["\[Omega]", "3"]}], ",", 
     SubscriptBox["\[Omega]", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "3"], ",", "0", ",", 
     RowBox[{"-", 
      SubscriptBox["\[Omega]", "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Omega]", "2"]}], ",", 
     SubscriptBox["\[Omega]", "1"], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "And next, a list of the anti-symmetrized derivatives of each of these with \
respect to the dual vectors; equivalent to the Lie derivative of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " with respect to the Lie brackets of the duals."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"lie", "[", 
     RowBox[{
      RowBox[{"duals", "[", 
       RowBox[{"[", "m", "]"}], "]"}], ",", 
      RowBox[{"lf", "[", 
       RowBox[{"[", "n", "]"}], "]"}]}], "]"}], "-", 
    RowBox[{"lie", "[", 
     RowBox[{
      RowBox[{"duals", "[", 
       RowBox[{"[", "n", "]"}], "]"}], ",", 
      RowBox[{"lf", "[", 
       RowBox[{"[", "m", "]"}], "]"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", 
     RowBox[{"fmdim", "-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", 
     RowBox[{"m", "+", "1"}], ",", "fmdim"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Omega]", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Omega]", "1"]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Omega]", "3"], ",", "0", ",", 
       RowBox[{"-", 
        SubscriptBox["\[Omega]", "1"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["\[Omega]", "3"], ",", 
      RowBox[{"-", 
       SubscriptBox["\[Omega]", "2"]}]}], "}"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Comparing the two lists, which contain the same results up to signs and \
order, reveals the Lie algebra of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[TextData[{
 "The function ",
 StyleBox["liealgebra[]", "Input",
  FontWeight->"Plain"],
 " will return a list of the Lie brackets, L[ ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["V", "m"], ",", 
    OverscriptBox["V", "n"]}], TraditionalForm]]],
 "] , for the full set of vectors dual to the current ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list (excluding any exact basis forms in ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 "), using the current ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " which must be defined for all the non-exact ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"liealgebra", "[", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"order = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], ",", 
     SubscriptBox["\[Omega]", "2"], ",", 
     SubscriptBox["\[Omega]", "3"]}], "}"}]}],
  SequenceForm["order = ", {
    Subscript[xAct`AVF`\[Omega], 1], 
    Subscript[xAct`AVF`\[Omega], 2], 
    Subscript[xAct`AVF`\[Omega], 3]}],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{
      OverscriptBox["V", "1"], ",", 
      OverscriptBox["V", "2"]}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     OverscriptBox["V", "3"]}]}], ",", 
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{
      OverscriptBox["V", "1"], ",", 
      OverscriptBox["V", "3"]}], "]"}], "\[Rule]", 
    OverscriptBox["V", "2"]}], ",", 
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{
      OverscriptBox["V", "2"], ",", 
      OverscriptBox["V", "3"]}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     OverscriptBox["V", "1"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The variable ",
 StyleBox["brackets", "Input",
  FontWeight->"Plain"],
 " contains the same thing, but with the numerical overscripts replaced by \
the corresponding dual 1-forms, which need not be indexed or ordered in the \
same way."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["brackets"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{
      OverscriptBox["V", 
       SubscriptBox["\[Omega]", "1"]], ",", 
      OverscriptBox["V", 
       SubscriptBox["\[Omega]", "2"]]}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     OverscriptBox["V", 
      SubscriptBox["\[Omega]", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{
      OverscriptBox["V", 
       SubscriptBox["\[Omega]", "1"]], ",", 
      OverscriptBox["V", 
       SubscriptBox["\[Omega]", "3"]]}], "]"}], "\[Rule]", 
    OverscriptBox["V", 
     SubscriptBox["\[Omega]", "2"]]}], ",", 
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{
      OverscriptBox["V", 
       SubscriptBox["\[Omega]", "2"]], ",", 
      OverscriptBox["V", 
       SubscriptBox["\[Omega]", "3"]]}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     OverscriptBox["V", 
      SubscriptBox["\[Omega]", "1"]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "brackets", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "II.d.7. ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 ": Format command for coordinates and partial derivatives"
}], "Subsubsection",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Making a new ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " list:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", "w"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", "w"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A special new set of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " (or a subset of the existing ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ") can be designated as ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " by the command:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Any new symbols introduced will be included automatically in ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 ", with ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " moving to the front."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "u", ",", "v", ",", "w"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", "du", ",", "dv", ",", "dw"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Any pre-existing ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " which are not designated as ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " will have subscript partial derivative symbols defined for them using \
Format output. A set of replacement rules, ",
 StyleBox["topartials", "Input",
  FontWeight->"Plain"],
 ", is automatically generated to expand the exterior derivatives of these \
scalars in any AVF as follows:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["topartials"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"du", "\[Rule]", 
    RowBox[{
     RowBox[{"dy", " ", 
      SubscriptBox["u", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["u", "x"]}]}]}], ",", 
   RowBox[{"dv", "\[Rule]", 
    RowBox[{
     RowBox[{"dy", " ", 
      SubscriptBox["v", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["v", "x"]}]}]}], ",", 
   RowBox[{"dw", "\[Rule]", 
    RowBox[{
     RowBox[{"dy", " ", 
      SubscriptBox["w", "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox["w", "x"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the set ",
 StyleBox["topartials", "Input",
  FontWeight->"Plain"],
 " is automatically included in ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", so that,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dscalars", "/.", "topartials"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", 
   RowBox[{
    RowBox[{"dy", " ", 
     SubscriptBox["u", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["u", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"dy", " ", 
     SubscriptBox["v", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["v", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"dy", " ", 
     SubscriptBox["w", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["w", "x"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["can also be accomplished by,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", "scalars", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", 
   RowBox[{
    RowBox[{"dy", " ", 
     SubscriptBox["u", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["u", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"dy", " ", 
     SubscriptBox["v", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["v", "x"]}]}], ",", 
   RowBox[{
    RowBox[{"dy", " ", 
     SubscriptBox["w", "y"]}], "+", 
    RowBox[{"dx", " ", 
     SubscriptBox["w", "x"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["with appropriate closure of the second derivative.", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "These partial derivative expansions provide a more concise and readable \
notation for the output of some AVF expressions. Note that ",
 StyleBox["topartials", "Input",
  FontWeight->"Plain"],
 " is defined only for ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " introduced ",
 StyleBox["before",
  FontVariations->{"Underline"->True}],
 " the ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 " command is executed, and the transformations are implemented only for \
second partials. Furthermore, the subscript symbols are not recognized as \
derivatives by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " for input."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[TextData[{
 "By using contraction with the vectors dual to the ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " basis forms, a particular partial derivative of an AVF (expressed in terms \
of ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 ") is selected by the operator ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "sub"], TraditionalForm]]],
 ", where ",
 StyleBox["sub", "Input",
  FontWeight->"Plain"],
 " can be either the coordinate symbol, or an integer giving the position of \
the coordinate in the ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " list. This operator extends to arrays of AVFs as well. For instance,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "x"], "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "^", "3"}], ",", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["u", "2"], " ", 
    SubscriptBox["u", "x"]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    SubscriptBox["v", "x"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "1"], "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"6", " ", "u", " ", 
     SubsuperscriptBox["u", "x", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["u", "2"], " ", 
     SubscriptBox["u", "\<\"xx\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", "v", "]"}]}], " ", 
     SubsuperscriptBox["v", "x", "2"]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     SubscriptBox["v", "\<\"xx\"\>"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "y"], "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"6", " ", 
     SubscriptBox["u", "y"], " ", 
     SubsuperscriptBox["u", "x", "2"]}], "+", 
    RowBox[{"12", " ", "u", " ", 
     SubscriptBox["u", "x"], " ", 
     SubscriptBox["u", "\<\"xy\"\>"]}], "+", 
    RowBox[{"6", " ", "u", " ", 
     SubscriptBox["u", "y"], " ", 
     SubscriptBox["u", "\<\"xx\"\>"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["u", "2"], " ", 
     RowBox[{
      SuperscriptBox["u", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "v", "]"}]}], " ", 
     SubscriptBox["v", "y"], " ", 
     SubsuperscriptBox["v", "x", "2"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"Sin", "[", "v", "]"}], " ", 
     SubscriptBox["v", "x"], " ", 
     SubscriptBox["v", "\<\"xy\"\>"]}], "-", 
    RowBox[{
     RowBox[{"Sin", "[", "v", "]"}], " ", 
     SubscriptBox["v", "y"], " ", 
     SubscriptBox["v", "\<\"xx\"\>"]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{
      SuperscriptBox["v", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Because the D operator is generated by first taking an exterior derivative, \
it may not give the expected result on a differential form, especially an \
exact one,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "x"], "[", 
  RowBox[{
   RowBox[{"u", " ", "dv"}], "+", 
   RowBox[{"v", " ", "du"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
The selection of independent coordinates and dependent scalars can be changed \
at any time. For example, interchanging roles,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", "w"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", "w"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", "w", ",", "x", ",", "y"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"du", ",", "dv", ",", "dw", ",", "dx", ",", "dy"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dscalars", "/.", "topartials"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"du", ",", "dv", ",", "dw", ",", 
   RowBox[{
    RowBox[{"dw", " ", 
     SubscriptBox["x", "w"]}], "+", 
    RowBox[{"dv", " ", 
     SubscriptBox["x", "v"]}], "+", 
    RowBox[{"du", " ", 
     SubscriptBox["x", "u"]}]}], ",", 
   RowBox[{
    RowBox[{"dw", " ", 
     SubscriptBox["y", "w"]}], "+", 
    RowBox[{"dv", " ", 
     SubscriptBox["y", "v"]}], "+", 
    RowBox[{"du", " ", 
     SubscriptBox["y", "u"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The variable ",
 StyleBox["depend", "Input",
  FontWeight->"Plain"],
 " can be used to make any other variable into a function of ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " with a similar output representation for its first and second derivatives; \
e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G", "[", "depend", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"G", "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dw", " ", 
   SubscriptBox["G", "w"]}], "+", 
  RowBox[{"dv", " ", 
   SubscriptBox["G", "v"]}], "+", 
  RowBox[{"du", " ", 
   SubscriptBox["G", "u"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "which is a bit easier to scan than standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " output;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"G", "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dw", " ", 
   RowBox[{
    SuperscriptBox["G", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
  RowBox[{"dv", " ", 
   RowBox[{
    SuperscriptBox["G", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
  RowBox[{"du", " ", 
   RowBox[{
    SuperscriptBox["G", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
and considerably improves the looks of the spherical Laplacian derived above\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lsph", "=", 
  FractionBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Psi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Psi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], ")"}]}], 
   SuperscriptBox["R", "2"]]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[Psi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], ")"}]}], 
  SuperscriptBox["R", "2"]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Lsph"], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
      SubscriptBox["\[Psi]", "\<\"\[Phi]\[Phi]\"\>"]}], "+", 
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["\[Psi]", "\[Theta]"]}], "+", 
     SubscriptBox["\[Psi]", "\<\"\[Theta]\[Theta]\"\>"]}], ")"}]}], 
  SuperscriptBox["R", "2"]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This format is especially useful for Lie differentiation when the vector \
components are expressed as functions of ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell["\<\
Recalling the curvature on the spheroid from section ?? above,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "\[Theta]\[Phi]"], "=", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"k", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "we want its Lie derivative in the coordinate basis, with respect to a \
vector ",
 StyleBox["vec", "Input",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec", "=", 
  RowBox[{"{", 
   RowBox[{
    OverscriptBox["v", "\[Theta]"], ",", 
    OverscriptBox["v", "\[Phi]"]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["v", "\[Theta]"], ",", 
   OverscriptBox["v", "\[Phi]"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeforms", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "d\[Theta]", ",", "d\[Phi]", ",", "du", ",", "dv", ",", "dw", ",", "dx", 
   ",", "dy"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetSystemOptions", "[", 
   RowBox[{"\"\<DifferentiationOptions\>\"", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<DifferentiateHeads\>\"", "\[Rule]", "False"}], "}"}]}], 
   "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"\[Theta]", ",", "\[Phi]", ",", 
    OverscriptBox["v", "\[Theta]"], ",", 
    OverscriptBox["v", "\[Phi]"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Theta]", ",", "\[Phi]", ",", 
   OverscriptBox["v", "\[Theta]"], ",", 
   OverscriptBox["v", "\[Phi]"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["dv", "\[Theta]"], "\[Rule]", 
    RowBox[{
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox[
       OverscriptBox["v", "\[Theta]"], "\[Phi]"]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox[
       OverscriptBox["v", "\[Theta]"], "\[Theta]"]}]}]}], ",", 
   RowBox[{
    OverscriptBox["dv", "\[Phi]"], "\[Rule]", 
    RowBox[{
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox[
       OverscriptBox["v", "\[Phi]"], "\[Phi]"]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox[
       OverscriptBox["v", "\[Phi]"], "\[Theta]"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lie", "[", 
  RowBox[{"vec", ",", 
   SubscriptBox["\[CapitalOmega]", "\[Theta]\[Phi]"]}], "]"}]], "Input",
 PageBreakAbove->False],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", "k", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
    OverscriptBox["v", "\[Theta]"], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"5", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
    OverscriptBox["v", "\[Theta]"], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"5", "/", "2"}]]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
    OverscriptBox["v", "\[Theta]"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"k", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
    OverscriptBox["v", "\[Theta]"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
    SubscriptBox[
     OverscriptBox["v", "\[Phi]"], "\[Phi]"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"k", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
    SubscriptBox[
     OverscriptBox["v", "\[Phi]"], "\[Phi]"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
    SubscriptBox[
     OverscriptBox["v", "\[Theta]"], "\[Theta]"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"k", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
    SubscriptBox[
     OverscriptBox["v", "\[Theta]"], "\[Theta]"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Trig", "->", "False"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       OverscriptBox["v", "\[Theta]"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "k", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"k", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["v", "\[Phi]"], "\[Phi]"], "+", 
         SubscriptBox[
          OverscriptBox["v", "\[Theta]"], "\[Theta]"]}], ")"}]}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"5", "/", "2"}]]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sph", "=", 
  RowBox[{"%", "/.", 
   RowBox[{"k", "->", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     OverscriptBox["v", "\[Theta]"]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["v", "\[Phi]"], "\[Phi]"], "+", 
       SubscriptBox[
        OverscriptBox["v", "\[Theta]"], "\[Theta]"]}], ")"}]}]}], 
   ")"}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", 
     RowBox[{"vector", 
      StyleBox[
       RowBox[{" ", 
        StyleBox[" ",
         FontSize->14]}]], "(", " ", 
      RowBox[{
       OverscriptBox["v", "\[Theta]"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"\[Theta]", " "}]], 
        RowBox[{"+", " ", 
         OverscriptBox["v", "\[Phi]"]}]}], 
       SubscriptBox["\[PartialD]", "\[Phi]"]}], ")"}], "  ", "making", " ", 
     "these", " ", "expressions", " ", "vanish", " ", "would", " ", "leave", 
     " ", 
     SubscriptBox["\[CapitalOmega]", "\[Theta]\[Phi]"], " ", 
     RowBox[{"unchanged", ".", "\n", "An"}], " ", "obvious", " ", "solution", 
     " ", "from", " ", "symmetry", " ", "in", " ", "both", " ", "cases", " ", 
     "is", " ", "the", " ", "Killing", " ", 
     RowBox[{"vector", ":", " ", 
      RowBox[{
       OverscriptBox["v", "\[Theta]"], 
       FormBox["",
        TraditionalForm]}]}]}], "=", " ", "0"}], " ", ",", " ", 
   RowBox[{
    RowBox[{
     OverscriptBox["v", "\[Phi]"], 
     FormBox["",
      TraditionalForm]}], "=", " ", "1.", " "}]}], TraditionalForm]], "Text"],

Cell[TextData[{
 "\nThe ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 " facility  can be useful also for Hamiltonian mechanics. For a simple \
example using canonical coordinates in two dimensions:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"canonical", "=", 
  RowBox[{"{", 
   RowBox[{"p1", ",", "p2", ",", "q1", ",", "q2"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"p1", ",", "p2", ",", "q1", ",", "q2"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", "canonical", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"p1", ",", "p2", ",", "q1", ",", "q2"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dp1", ",", "dp2", ",", "dq1", ",", "dq2"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Jose: Variable \[Omega] changed to ",
 StyleBox["om", "Input",
  FontWeight->"Plain"],
 " to avoid loading values into the AVF variable \[Omega]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"om", "=", 
  RowBox[{
   RowBox[{"p1", " ", "dq1"}], "+", 
   RowBox[{"p2", " ", "dq2"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dq1", " ", "p1"}], "+", 
  RowBox[{"dq2", " ", "p2"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dom", "=", 
  RowBox[{"d", "[", "om", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dp1", "\[Wedge]", "dq1"}], "+", 
  RowBox[{"dp2", "\[Wedge]", "dq2"}]}]], "Output"]
}, Open  ]],

Cell["A convenience vector,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["vec1"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["v1", "1"], ",", 
   SubscriptBox["v1", "2"], ",", 
   SubscriptBox["v1", "3"], ",", 
   SubscriptBox["v1", "4"]}], "}"}]], "Output"]
}, Open  ]],

Cell["can be edited to adapt it,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec", "=", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["vp", "1"], ",", 
    SubscriptBox["vp", "2"], ",", 
    SubscriptBox["vq", "1"], ",", 
    SubscriptBox["vq", "2"]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["vp", "1"], ",", 
   SubscriptBox["vp", "2"], ",", 
   SubscriptBox["vq", "1"], ",", 
   SubscriptBox["vq", "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vec", "\[SmallCircle]", "dscalars"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["vp", "1"], ",", 
   SubscriptBox["vp", "2"], ",", 
   SubscriptBox["vq", "1"], ",", 
   SubscriptBox["vq", "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Adding in the vector components and an arbitrary Hamiltonian function to \
\"scalars\",\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"scalars", ",", "vec", ",", 
    RowBox[{"{", "H", "}"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"p1", ",", "p2", ",", "q1", ",", "q2", ",", 
   SubscriptBox["vp", "1"], ",", 
   SubscriptBox["vp", "2"], ",", 
   SubscriptBox["vq", "1"], ",", 
   SubscriptBox["vq", "2"], ",", "H"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To avoid including previous ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and now introduce ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", "canonical", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"p1", ",", "p2", ",", "q1", ",", "q2"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dH", "\[Rule]", 
    RowBox[{
     RowBox[{"dq2", " ", 
      SubscriptBox["H", "q2"]}], "+", 
     RowBox[{"dq1", " ", 
      SubscriptBox["H", "q1"]}], "+", 
     RowBox[{"dp2", " ", 
      SubscriptBox["H", "p2"]}], "+", 
     RowBox[{"dp1", " ", 
      SubscriptBox["H", "p1"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dvp", "1"], "\[Rule]", 
    RowBox[{
     RowBox[{"dq2", " ", 
      SubscriptBox[
       SubscriptBox["vp", "1"], "q2"]}], "+", 
     RowBox[{"dq1", " ", 
      SubscriptBox[
       SubscriptBox["vp", "1"], "q1"]}], "+", 
     RowBox[{"dp2", " ", 
      SubscriptBox[
       SubscriptBox["vp", "1"], "p2"]}], "+", 
     RowBox[{"dp1", " ", 
      SubscriptBox[
       SubscriptBox["vp", "1"], "p1"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dvp", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"dq2", " ", 
      SubscriptBox[
       SubscriptBox["vp", "2"], "q2"]}], "+", 
     RowBox[{"dq1", " ", 
      SubscriptBox[
       SubscriptBox["vp", "2"], "q1"]}], "+", 
     RowBox[{"dp2", " ", 
      SubscriptBox[
       SubscriptBox["vp", "2"], "p2"]}], "+", 
     RowBox[{"dp1", " ", 
      SubscriptBox[
       SubscriptBox["vp", "2"], "p1"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dvq", "1"], "\[Rule]", 
    RowBox[{
     RowBox[{"dq2", " ", 
      SubscriptBox[
       SubscriptBox["vq", "1"], "q2"]}], "+", 
     RowBox[{"dq1", " ", 
      SubscriptBox[
       SubscriptBox["vq", "1"], "q1"]}], "+", 
     RowBox[{"dp2", " ", 
      SubscriptBox[
       SubscriptBox["vq", "1"], "p2"]}], "+", 
     RowBox[{"dp1", " ", 
      SubscriptBox[
       SubscriptBox["vq", "1"], "p1"]}]}]}], ",", 
   RowBox[{
    SubscriptBox["dvq", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"dq2", " ", 
      SubscriptBox[
       SubscriptBox["vq", "2"], "q2"]}], "+", 
     RowBox[{"dq1", " ", 
      SubscriptBox[
       SubscriptBox["vq", "2"], "q1"]}], "+", 
     RowBox[{"dp2", " ", 
      SubscriptBox[
       SubscriptBox["vq", "2"], "p2"]}], "+", 
     RowBox[{"dp1", " ", 
      SubscriptBox[
       SubscriptBox["vq", "2"], "p1"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["The Hamiltonian flow equations read,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "\[SmallCircle]", "dom"}], "+", 
  RowBox[{"da", "[", "H", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dq1", " ", 
   SubscriptBox["vp", "1"]}], "+", 
  RowBox[{"dq2", " ", 
   SubscriptBox["vp", "2"]}], "-", 
  RowBox[{"dp1", " ", 
   SubscriptBox["vq", "1"]}], "-", 
  RowBox[{"dp2", " ", 
   SubscriptBox["vq", "2"]}], "+", 
  RowBox[{"dq2", " ", 
   SubscriptBox["H", "q2"]}], "+", 
  RowBox[{"dq1", " ", 
   SubscriptBox["H", "q1"]}], "+", 
  RowBox[{"dp2", " ", 
   SubscriptBox["H", "p2"]}], "+", 
  RowBox[{"dp1", " ", 
   SubscriptBox["H", "p1"]}]}]], "Output"]
}, Open  ]],

Cell["and taking the independent components,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqns", "=", 
  RowBox[{"setzero", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"%", ",", "dscalars"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["vq", "1"]}], "+", 
     SubscriptBox["H", "p1"]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["vq", "2"]}], "+", 
     SubscriptBox["H", "p2"]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["vp", "1"], "+", 
     SubscriptBox["H", "q1"]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["vp", "2"], "+", 
     SubscriptBox["H", "q2"]}], "\[Equal]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["The Hamiltonian for a pair of coupled oscillators could be,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"explicit", "=", 
  RowBox[{"{", 
   RowBox[{"H", "->", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2", ",", "q1", ",", "q2"}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          SuperscriptBox["p1", "2"], "+", 
          SuperscriptBox["p2", "2"]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", "m"}], ")"}]}], "+", 
       RowBox[{"k", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"q1", "-", "L"}], ")"}], "2"], "/", "2"}]}], "+", 
       RowBox[{"k", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"q2", "+", "L"}], ")"}], "2"], "/", "2"}]}], "+", 
       RowBox[{
        RowBox[{"\[Epsilon]", "/", "2"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"q1", "-", "q2"}], ")"}], "2"]}]}]}], "]"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"H", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p1", ",", "p2", ",", "q1", ",", "q2"}], "}"}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"]}], 
       RowBox[{"2", " ", "m"}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "k", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q1", "-", "L"}], ")"}], "2"]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "k", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q2", "+", "L"}], ")"}], "2"]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Epsilon]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q1", "-", "q2"}], ")"}], "2"]}]}]}], "]"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqns", "=", 
  RowBox[{"eqns", "/.", "explicit"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["p1", "m"], "-", 
     SubscriptBox["vq", "1"]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["p2", "m"], "-", 
     SubscriptBox["vq", "2"]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"k", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "L"}], "+", "q1"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"q1", "-", "q2"}], ")"}], " ", "\[Epsilon]"}], "+", 
     SubscriptBox["vp", "1"]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"k", " ", 
      RowBox[{"(", 
       RowBox[{"L", "+", "q2"}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"q1", "-", "q2"}], ")"}], " ", "\[Epsilon]"}], "+", 
     SubscriptBox["vp", "2"]}], "\[Equal]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"equilibrium", "=", 
  RowBox[{"eqns", "/.", 
   RowBox[{"Thread", "[", 
    RowBox[{"vec", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["p1", "m"], "\[Equal]", "0"}], ",", 
   RowBox[{
    FractionBox["p2", "m"], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"k", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "L"}], "+", "q1"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"q1", "-", "q2"}], ")"}], " ", "\[Epsilon]"}]}], "\[Equal]", 
    "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"k", " ", 
      RowBox[{"(", 
       RowBox[{"L", "+", "q2"}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"q1", "-", "q2"}], ")"}], " ", "\[Epsilon]"}]}], "\[Equal]", 
    "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{"%", ",", "canonical"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", "0"}], ",", 
   RowBox[{"q1", "\[Rule]", 
    FractionBox[
     RowBox[{"k", " ", "L"}], 
     RowBox[{"k", "+", 
      RowBox[{"2", " ", "\[Epsilon]"}]}]]}], ",", 
   RowBox[{"q2", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "L"}], 
      RowBox[{"k", "+", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["II.d.8. Clean up", "Subsubsection"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["III. Examples", "Section",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["\<\
III.a. A toy geometry problem -- Almost trivial, but not quite\
\>", "Subsection",
 PageBreakAbove->True],

Cell["This is taken from the file AVF_Demo.nb.", "Text"],

Cell[TextData[{
 "This problem shows how ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands work together, and further illustrates the use of ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "In cylindrical coordinates {r,\[Phi],z}, put r = R sin(\[Theta]) and z = ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", "k"}], ")"}]], TraditionalForm]]],
 " R cos(\[Theta]), so that (1 - k) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SuperscriptBox["r", "2"],
     TraditionalForm], "+", 
    SuperscriptBox["z", "2"]}], TraditionalForm]]],
 "= (1 - k) ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]]],
 ",  a spheroid with equatorial radius R and polar radius ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", "k"}], ")"}]], TraditionalForm]]],
 "R ; i.e., prolate for k < 0 , spherical for k=0, oblate for 0 < k < 1 , a \
disk of radius R for k = 1."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell["\<\
The independent coordinates will be \[Theta] and \[Phi], and we also \
introduce three non-exact basis forms for later use .\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeforms", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], ",", 
    SubscriptBox["\[Omega]", "2"], ",", 
    SubscriptBox["\[Omega]", "3"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", "d\[Theta]", ",", "d\[Phi]"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Previously, the variables r and z were in ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ", but are not there now, so can be assigned values;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"r", "=", 
  RowBox[{"R", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "\n", 
 RowBox[{"z", "=", 
  RowBox[{
   SqrtBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "k"}], ")"}]], "R", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"R", " ", 
  RowBox[{"Sin", "[", "\[Theta]", "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{"1", "-", "k"}]], " ", "R", " ", 
  RowBox[{"Cos", "[", "\[Theta]", "]"}]}]], "Output"]
}, Open  ]],

Cell["\<\
Since k and R are not members of any fundamental list, they are treated as \
constant parameters.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dr", "=", 
  RowBox[{"d", "[", "r", "]"}]}], "\n", 
 RowBox[{"dz", "=", 
  RowBox[{"d", "[", "z", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"d\[Theta]", " ", "R", " ", 
  RowBox[{"Cos", "[", "\[Theta]", "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "d\[Theta]"}], " ", 
  SqrtBox[
   RowBox[{"1", "-", "k"}]], " ", "R", " ", 
  RowBox[{"Sin", "[", "\[Theta]", "]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["AVF",
  FontSlant->"Italic"],
 " knows that d\[Theta] and d\[Phi] are 1-forms, but ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " doesn't, so the Euclidean line element in cylindrical coordinates can be \
input as:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["dr", "2"], "+", 
    SuperscriptBox["dz", "2"], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], 
     SuperscriptBox["d\[Phi]", "2"]}]}], "/.", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], "->", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["R", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["d\[Theta]", "2"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["d\[Phi]", "2"], "-", 
       RowBox[{
        SuperscriptBox["d\[Theta]", "2"], " ", "k"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Collect[]", "Input",
  FontWeight->"Plain"],
 " command,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["d\[Theta]", "2"], ",", 
     SuperscriptBox["d\[Phi]", "2"]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["d\[Phi]", "2"], " ", 
   SuperscriptBox["R", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["d\[Theta]", "2"], " ", 
   SuperscriptBox["R", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"k", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "showing the induced metric on the spheroid has orthonormal basis forms,  \
R",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"1", "-", 
     RowBox[{"k", " ", 
      FormBox[
       SuperscriptBox["sin", "2"],
       TraditionalForm], 
      RowBox[{"(", "\[Theta]", ")"}]}]}]], TraditionalForm]]],
 "d\[Theta]  and  R sin(\[Theta]) d\[Phi], which can be identified with the \
non-exact basis forms, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "1"], TraditionalForm]]],
 " and  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "2"], TraditionalForm]]],
 " . Here again we use replacement rules, not assignments, which are \
forbidden for the members of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". It's actually much more useful to express the relations this way, so that \
transformations between the orthonormal and coordinate bases are easily made \
in both directions. "
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tocoords", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "->", 
     RowBox[{"R", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}]], 
      "d\[Theta]"}]}], ",", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"2", " "}]], "->", 
     RowBox[{"R", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "d\[Phi]"}]}]}], 
   "}"}]}]], "Input",
 PageBreakAbove->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Rule]", 
    RowBox[{"d\[Theta]", " ", "R", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"k", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Rule]", 
    RowBox[{"d\[Phi]", " ", "R", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The rules can be turned into equations to solve for the inverse \
transformation. Writing equations does not involve assignments, nor does \
their solution.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqns", "=", 
  RowBox[{"tocoords", "/.", 
   RowBox[{"Rule", "->", "Equal"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Equal]", 
    RowBox[{"d\[Theta]", " ", "R", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"k", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Equal]", 
    RowBox[{"d\[Phi]", " ", "R", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toortho", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{"eqns", ",", "dscalars"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     SubscriptBox["\[Omega]", "1"], 
     RowBox[{"R", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "R"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "In a 2-dim space, the only independent connection form is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "12"], TraditionalForm]]],
 ". Since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", 
    RowBox[{"3", " "}]], TraditionalForm]]],
 "is already in the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list, that symbol will be used for it temporarily. The Cartan structure \
equations,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d\[Omega]", "i"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "ij"], TraditionalForm]]],
 "\[Wedge]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "j"], TraditionalForm]]],
 " = 0 , then can be expressed by the replacement rules:"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"structure", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["d\[Omega]", "1"], "->", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], ",", 
    RowBox[{
     SubscriptBox["d\[Omega]", "2"], "->", 
     RowBox[{
      SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "1"]}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "1"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The transformations ",
 StyleBox["toortho", "Input",
  FontWeight->"Plain"],
 " can also be entered as ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", so that everything, including derivatives of functions, will be converted \
automatically to the orthobasis."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"structure", ",", "toortho"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "1"]}]}], ",", 
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     SubscriptBox["\[Omega]", "1"], 
     RowBox[{"R", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "R"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Because no drule has been established for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "3"], TraditionalForm]]],
 ", these ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are not properly closed. Imposing closure can be used to determine ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "3"], TraditionalForm]]],
 "; i.e., for consistency the following conditions must vanish,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"conditions", "=", 
  RowBox[{"da", "[", 
   RowBox[{"da", "[", "scalars", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}], 
    RowBox[{"R", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"k", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}]}], 
      RowBox[{
       SuperscriptBox["R", "2"], " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"k", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}]}], "R"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Vanishing of the first condition requires ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", 
    RowBox[{"3", " "}]], TraditionalForm]]],
 "proportional to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "2"], TraditionalForm]]],
 "with no component on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "1"], TraditionalForm]]],
 ". So we can safely factor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "1"], TraditionalForm]]],
 " out of the second condition, and equate the result to zero."
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"factor", "[", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], ",", 
    RowBox[{"conditions", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", "0"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["\[Omega]", "3"]}], "R"]}], "\[Equal]", "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{"%", ",", 
     SubscriptBox["\[Omega]", "3"]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "3"], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], 
     RowBox[{"R", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Put this into ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ":"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newdrules", "=", 
  RowBox[{"expand", "[", 
   RowBox[{"drules", "/.", "soln"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}]}], 
     RowBox[{"R", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], ",", 
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     SubscriptBox["\[Omega]", "1"], 
     RowBox[{"R", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "R"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the obvious fact that  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "1"], TraditionalForm]]],
 " is closed appears explicitly. Now establish these as the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", "newdrules", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}]}], 
     RowBox[{"R", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], ",", 
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     SubscriptBox["\[Omega]", "1"], 
     RowBox[{"R", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "R"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note: the last two statements could be combined into one (without defining ",
 StyleBox["newdrules", "Input",
  FontWeight->"Plain"],
 "), but ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " is Protected, so it can't be accomplished just by assignment without using \
",
 StyleBox["makedrules[]", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell["Checking for consistency:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"da", "[", "scalars", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"da", "[", "forms", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Set the connection form equal to the solution for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "3"], TraditionalForm]]],
 ", and find the curvature 2-form expressed in orthobasis:"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Omega]", "12"], "=", 
  RowBox[{
   SubscriptBox["\[Omega]", "3"], "/.", "soln"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[Omega]", "2"]}], 
   RowBox[{"R", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "12"], "=", 
  RowBox[{"da", "[", 
   SubscriptBox["\[Omega]", "12"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"k", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}]}], 
    RowBox[{
     SuperscriptBox["R", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "2"]}]]}], 
  "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"], " ", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}], 
   RowBox[{
    SuperscriptBox["R", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}], 
   RowBox[{
    SuperscriptBox["R", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "12"], "=", 
  RowBox[{"Simplify", "[", "%", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}], 
   RowBox[{
    SuperscriptBox["R", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"k", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
     "2"]}]]}]], "Output"]
}, Open  ]],

Cell["The same quantity in the coordinate basis:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "\[Theta]\[Phi]"], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"expand", "[", 
     RowBox[{
      SubscriptBox["\[CapitalOmega]", "12"], "/.", "tocoords"}], "]"}], ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output"]
}, Open  ]],

Cell["\<\
Interpretation of the following special values (as products of the Gaussian \
curvatures) is much simpler in the orthonormal basis than in the coordinate \
basis.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell["At the poles:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "12"], "/.", 
  RowBox[{"\[Theta]", "->", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}], 
   SuperscriptBox["R", "2"]]}]], "Output"]
}, Open  ]],

Cell["At the equator:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "12"], "/.", 
  RowBox[{"\[Theta]", "->", 
   RowBox[{"Pi", "/", "2"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
    SuperscriptBox["R", "2"]}]]}]], "Output"]
}, Open  ]],

Cell["And for a sphere:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "12"], "/.", 
  RowBox[{"k", "->", "0"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
   SubscriptBox["\[Omega]", "2"]}], 
  SuperscriptBox["R", "2"]]], "Output"]
}, Open  ]],

Cell["In 2-dim the Bianchi identity is trivial:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  SubscriptBox["\[CapitalOmega]", "12"], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The surface element in the orthonormal basis ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     RowBox[{"is", "  ", 
      SubscriptBox["\[Omega]", "1"]}],
     TraditionalForm], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], TraditionalForm]]],
 ", while in the coordinate basis:"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], "/.", "tocoords"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["R", "2"], " ", 
  RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
  SqrtBox[
   RowBox[{"1", "-", 
    RowBox[{"k", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]], " ", 
  RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The area of a polar cap, where ",
 StyleBox["pa", "Input",
  FontWeight->"Plain"],
 " is the polar angle or colatitude, is (Jose: The following few definitions \
have been deactivated because they take a long time and demonstrate nothing \
of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 "):"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"polarcap", "=", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", "pa"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Phi]", ",", "0", ",", 
       RowBox[{"2", " ", "Pi"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"98.05741700000002`", ",", 
   RowBox[{"ConditionalExpression", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Pi]", " ", 
      SuperscriptBox["R", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SqrtBox["k"]}], "-", 
           RowBox[{"Log", "[", "2", "]"}], "+", 
           RowBox[{"k", " ", 
            RowBox[{"Log", "[", "2", "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
            RowBox[{"Log", "[", 
             RowBox[{"1", "+", 
              SqrtBox["k"]}], "]"}]}]}], 
          RowBox[{"4", " ", 
           SqrtBox["k"]}]]}], "+", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"4", " ", 
           SqrtBox["k"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SqrtBox["2"]}], " ", 
            SqrtBox["k"], " ", 
            RowBox[{"Cos", "[", "pa", "]"}], " ", 
            SqrtBox[
             RowBox[{"2", "-", "k", "+", 
              RowBox[{"k", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "pa"}], "]"}]}]}]]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["k"], " ", 
               RowBox[{"Cos", "[", "pa", "]"}]}], "+", 
              SqrtBox[
               RowBox[{"2", "-", "k", "+", 
                RowBox[{"k", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "pa"}], "]"}]}]}]]}], "]"}]}]}], 
          ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"k", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "pa", "]"}], "2"]}], "\[NotElement]", 
         "Reals"}], "||", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"k", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "pa", "]"}], "2"]}], "]"}], "\[LessEqual]", 
         "1"}]}], ")"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "-", "k", "+", 
             RowBox[{"k", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "pa"}], "]"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "pa", "]"}], "2"]}], "k"], "\[NotElement]", 
         "Reals"}], "||", 
        RowBox[{
         RowBox[{"Re", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "-", "k", "+", 
              RowBox[{"k", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "pa"}], "]"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Csc", "[", "pa", "]"}], "2"]}], "k"], "]"}], 
         "\[GreaterEqual]", "0"}], "||", 
        RowBox[{
         RowBox[{"Re", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "-", "k", "+", 
              RowBox[{"k", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "pa"}], "]"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Csc", "[", "pa", "]"}], "2"]}], "k"], "]"}], 
         "\[LessEqual]", 
         RowBox[{"-", "2"}]}]}], ")"}], "&&", 
      RowBox[{
       RowBox[{"2", "+", 
        RowBox[{"k", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "pa"}], "]"}]}]}], "\[NotEqual]", "k"}]}]}], 
    "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["and this gives the familiar result for a sphere;", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"First", "@", "polarcap"}], ",", 
    RowBox[{"k", "->", "0"}]}], "]"}], "]"}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "\[Pi]", " ", 
  SuperscriptBox["R", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"Cos", "[", "pa", "]"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell["The total surface area for any spheroid is,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"area", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"polarcap", "/.", 
    RowBox[{"pa", "->", "Pi"}]}], "]"}]}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Pi]", " ", 
   SuperscriptBox["R", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SqrtBox["k"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", 
        SqrtBox["k"]}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", 
        SqrtBox["k"]}], "]"}]}]}], ")"}]}], 
  SqrtBox["k"]]], "Output"]
}, Open  ]],

Cell["For the sphere:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"area", ",", 
   RowBox[{"k", "->", "0"}]}], "]"}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"4", " ", "\[Pi]", " ", 
  SuperscriptBox["R", "2"]}]], "Output"]
}, Open  ]],

Cell["For the flat disk:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"area", ",", 
   RowBox[{"k", "->", "1"}]}], "]"}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]", " ", 
  SuperscriptBox["R", "2"]}]], "Output"]
}, Open  ]],

Cell["\<\
In this simple 2-dim. case, the Hodge star operation is easily defined in the \
orthonormal basis.\
\>", "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toduals", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "->", 
     SubscriptBox["\[Omega]", "2"]}], ",", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "->", 
     RowBox[{"-", 
      SubscriptBox["\[Omega]", "1"]}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Rule]", 
    SubscriptBox["\[Omega]", "2"]}], ",", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Rule]", 
    RowBox[{"-", 
     SubscriptBox["\[Omega]", "1"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "For a function, ",
 StyleBox["\[Psi][\[Theta],\[Phi]]", "Input",
  FontWeight->"Plain"],
 " , with exterior derivative in the coordinate basis,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"\[Psi]", "[", 
   RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d\[Phi]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
  RowBox[{"d\[Theta]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "the  ",
 StyleBox["*d[\[Psi]]", "Input",
  FontWeight->"Plain"],
 "  operation is given by"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->Automatic,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"da", "[", 
   RowBox[{"\[Psi]", "[", 
    RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}], "]"}], "/.", 
  "toduals"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     RowBox[{
      SuperscriptBox["\[Psi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "R"]}], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Omega]", "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Psi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], 
   RowBox[{"R", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the Laplacian on the spheroid, ",
 StyleBox["d*d[\[Psi]]", "Input",
  FontWeight->"Plain"],
 ", is the factor of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", 
     RowBox[{"2", " "}]]}], TraditionalForm]]],
 "in the next expression,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"da", "[", "%", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["R", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"k", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "2"]}]], 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], "+", 
        RowBox[{"k", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]}], 
       ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["which becomes the usual expression for a sphere,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"k", "->", "0"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[Psi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], ")"}]}], 
  SuperscriptBox["R", "2"]]], "Output"]
}, Open  ]],

Cell["Clean up:", "Text"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b. The quaternion algebra", "Subsection"],

Cell["This is taken from the file AVF_Commands.nb.", "Text"],

Cell[CellGroupData[{

Cell["III.b.1. Establishing the quaternion algebra H", "Subsubsection"],

Cell[TextData[{
 "Introduce a list of four elements, where the initial element ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "0"], TraditionalForm]]],
 " is the identity."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeelements", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Sigma]", "0"], ",", 
    SubscriptBox["\[Sigma]", "1"], ",", 
    SubscriptBox["\[Sigma]", "2"], ",", 
    SubscriptBox["\[Sigma]", "3"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], ",", 
   SubscriptBox["\[Sigma]", "1"], ",", 
   SubscriptBox["\[Sigma]", "2"], ",", 
   SubscriptBox["\[Sigma]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell["The multiplication table defining H is entered,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "0"], ",", 
       SubscriptBox["\[Sigma]", "1"], ",", 
       SubscriptBox["\[Sigma]", "2"], ",", 
       SubscriptBox["\[Sigma]", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "0"]}], ",", 
       SubscriptBox["\[Sigma]", "3"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "3"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "0"]}], ",", 
       SubscriptBox["\[Sigma]", "1"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], ",", 
       SubscriptBox["\[Sigma]", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "1"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "0"]}]}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[TextData[{
 "and this becomes the established ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " by,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makealgebra", "[", "H", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["algebra"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Sigma]", "0"], ",", 
     SubscriptBox["\[Sigma]", "1"], ",", 
     SubscriptBox["\[Sigma]", "2"], ",", 
     SubscriptBox["\[Sigma]", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], ",", 
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "0"]}], ",", 
     SubscriptBox["\[Sigma]", "3"], ",", 
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Sigma]", "2"], ",", 
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "3"]}], ",", 
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "0"]}], ",", 
     SubscriptBox["\[Sigma]", "1"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Sigma]", "3"], ",", 
     SubscriptBox["\[Sigma]", "2"], ",", 
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "1"]}], ",", 
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "0"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "With no argument, ",
 StyleBox["mtx[]", "Input",
  FontWeight->"Plain"],
 " outputs its default argument ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " as a matrix"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Sigma]", "0"], 
      SubscriptBox["\[Sigma]", "1"], 
      SubscriptBox["\[Sigma]", "2"], 
      SubscriptBox["\[Sigma]", "3"]},
     {
      SubscriptBox["\[Sigma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "2"]}]},
     {
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "1"]},
     {
      SubscriptBox["\[Sigma]", "3"], 
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Input a general quaternion,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "i"], 
     SubscriptBox["\[Sigma]", "i"]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell["and construct its conjugate,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["q", "_"], "=", 
  RowBox[{
   RowBox[{"-", "q"}], "/.", 
   RowBox[{
    SubscriptBox["x", "0"], "->", 
    RowBox[{"-", 
     SubscriptBox["x", "0"]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "-", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "-", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "-", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.2. Multiplication", "Subsubsection"],

Cell[TextData[{
 StyleBox["AVF",
  FontSlant->"Italic"],
 " multiplication uses **, the ",
 StyleBox["NonCommutativeMultiply", "Input",
  FontWeight->"Plain"],
 " infix operator,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "**", 
  OverscriptBox["q", "_"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["x", "0", "2"], "+", 
  SubsuperscriptBox["x", "1", "2"], "+", 
  SubsuperscriptBox["x", "2", "2"], "+", 
  SubsuperscriptBox["x", "3", "2"]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The identity element generally is suppressed in output from ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " operations. An independent quaternion,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Q", "=", 
  RowBox[{"q", "/.", 
   RowBox[{"x", "->", "\[Omega]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell["with the non-commutative quaternion product,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qQ", "=", 
  RowBox[{"q", "**", "Q"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "-", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "-", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "+", 
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "**", "Q"}], "-", 
  RowBox[{"Q", "**", "q"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell["Any number of AVFs can be multiplied together,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "**", "Q", "**", 
  OverscriptBox["q", "_"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["x", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "2"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "0", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "0", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   SubsuperscriptBox["x", "1", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "0", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "-", 
  RowBox[{
   SubsuperscriptBox["x", "1", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "-", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and if the ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " table specifies a non-associative algebra, the order of performing triple \
products may be important. But for H it's not,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"q", "**", "Q"}], ")"}], "**", 
   OverscriptBox["q", "_"]}], "-", 
  RowBox[{"q", "**", 
   RowBox[{"(", 
    RowBox[{"Q", "**", 
     OverscriptBox["q", "_"]}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
All the commands used herein can be applied to non-associative cases, such as \
octonions and Lie algebras, with due regard for the ordering of triple \
products.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.3. Format commands", "Subsubsection"],

Cell[TextData[{
 "The non-zero coefficients of the algebra elements in an AVF, such as ",
 StyleBox["qQ", "Input",
  FontWeight->"Plain"],
 " , are returned in a list by"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coeffs", "[", "qQ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], " ", 
     SubscriptBox["\[Omega]", "0"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "-", 
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["\[Omega]", "0"]}], "+", 
    RowBox[{
     SubscriptBox["x", "0"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["\[Omega]", "0"]}], "+", 
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["x", "0"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Omega]", "0"]}], "-", 
    RowBox[{
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["x", "0"], " ", 
     SubscriptBox["\[Omega]", "3"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["and the AVF expression is output in collected form by,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", "qQ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Omega]", "0"]}], "-", 
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SubscriptBox["x", "0"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Omega]", "0"]}], "+", 
     RowBox[{
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      SubscriptBox["x", "0"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["\[Omega]", "0"]}], "+", 
     RowBox[{
      SubscriptBox["x", "0"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "0"], " ", 
      SubscriptBox["\[Omega]", "0"]}], "-", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This is the only ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " command that always outputs the identity element explicitly. The result \
contains the usual scalar and vector products for 3-vectors,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "->", "0"}], ",", 
    RowBox[{
     SubscriptBox["\[Omega]", "0"], "->", "0"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["x", "2"]}], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["x", "3"]}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["x", "1"]}], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.4. Differentiation", "Subsubsection"],

Cell[TextData[{
 "Exterior differentiation is accomplished with the operator ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 " , but since no ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " lists have been established yet, all quantities are treated as constants,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "qQ", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["The coefficients in q", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["q"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell["can be made into independent scalar fields by,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"coeffs", "[", "q", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "0"], ",", 
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the ",
 StyleBox["makescalars", "Input",
  FontWeight->"Plain"],
 " command also generates their 1-form derivative symbols, ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["dx", "0"], ",", 
   SubscriptBox["dx", "1"], ",", 
   SubscriptBox["dx", "2"], ",", 
   SubscriptBox["dx", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " elements themselves are always constants, but ",
 StyleBox["q", "Input",
  FontWeight->"Plain"],
 " has become a quaternion field,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "q", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["dx", "0"], "+", 
  RowBox[{
   SubscriptBox["dx", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["dx", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["dx", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"q", "**", 
   OverscriptBox["q", "_"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["dx", "0"], " ", 
   SubscriptBox["x", "0"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["dx", "1"], " ", 
   SubscriptBox["x", "1"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["dx", "2"], " ", 
   SubscriptBox["x", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["dx", "3"], " ", 
   SubscriptBox["x", "3"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The coefficients in ",
 StyleBox["Q", "Input",
  FontWeight->"Plain"],
 " can be established as non-exact basis 1-forms by"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeforms", "[", 
  RowBox[{"coeffs", "[", "Q", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", 
   SubscriptBox["dx", "0"], ",", 
   SubscriptBox["dx", "1"], ",", 
   SubscriptBox["dx", "2"], ",", 
   SubscriptBox["dx", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "where the independent basis 1-forms will include ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " automatically, and the non-exact forms have derivative symbols in ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["dforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["d\[Omega]", "0"], ",", 
   SubscriptBox["d\[Omega]", "1"], ",", 
   SubscriptBox["d\[Omega]", "2"], ",", 
   SubscriptBox["d\[Omega]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The quantity ",
 StyleBox["Q", "Input",
  FontWeight->"Plain"],
 " is now a quaternion-valued 1-form field with the 2-form derivative,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "Q", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["d\[Omega]", "0"], "+", 
  RowBox[{
   SubscriptBox["d\[Omega]", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["d\[Omega]", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["d\[Omega]", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell["and the AVF self-product,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QQ", "=", 
  RowBox[{"Q", "**", "Q"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The derivative of the previously defined variable ",
 StyleBox["qQ", "Input",
  FontWeight->"Plain"],
 " now gives the quaternion 2-form,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"d", "[", "qQ", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Omega]", "3"], " ", 
      SubscriptBox["x", "0"]}], "+", 
     RowBox[{
      SubscriptBox["d\[Omega]", "2"], " ", 
      SubscriptBox["x", "1"]}], "-", 
     RowBox[{
      SubscriptBox["d\[Omega]", "1"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      SubscriptBox["d\[Omega]", "0"], " ", 
      SubscriptBox["x", "3"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "0"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SubscriptBox["dx", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "3"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "0"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Omega]", "2"], " ", 
      SubscriptBox["x", "0"]}], "-", 
     RowBox[{
      SubscriptBox["d\[Omega]", "3"], " ", 
      SubscriptBox["x", "1"]}], "+", 
     RowBox[{
      SubscriptBox["d\[Omega]", "0"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      SubscriptBox["d\[Omega]", "1"], " ", 
      SubscriptBox["x", "3"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "0"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SubscriptBox["dx", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "0"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "3"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Omega]", "1"], " ", 
      SubscriptBox["x", "0"]}], "+", 
     RowBox[{
      SubscriptBox["d\[Omega]", "0"], " ", 
      SubscriptBox["x", "1"]}], "+", 
     RowBox[{
      SubscriptBox["d\[Omega]", "3"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{
      SubscriptBox["d\[Omega]", "2"], " ", 
      SubscriptBox["x", "3"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "0"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "0"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}], "-", 
     RowBox[{
      SubscriptBox["dx", "3"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Omega]", "0"], " ", 
      SubscriptBox["x", "0"]}], "-", 
     RowBox[{
      SubscriptBox["d\[Omega]", "1"], " ", 
      SubscriptBox["x", "1"]}], "-", 
     RowBox[{
      SubscriptBox["d\[Omega]", "2"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{
      SubscriptBox["d\[Omega]", "3"], " ", 
      SubscriptBox["x", "3"]}], "+", 
     RowBox[{
      SubscriptBox["dx", "0"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "0"]}], "-", 
     RowBox[{
      SubscriptBox["dx", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      SubscriptBox["dx", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SubscriptBox["dx", "3"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "In field theories, the AVF 2-form field ",
 StyleBox["F", "Input",
  FontWeight->"Plain"],
 " is important,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "=", 
  RowBox[{"collect", "[", 
   RowBox[{
    RowBox[{"d", "[", "Q", "]"}], "+", 
    RowBox[{"QQ", "/", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["d\[Omega]", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["d\[Omega]", "3"], "+", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["d\[Omega]", "2"], "-", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["d\[Omega]", "1"], "+", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
where the coefficients have the structure of Maurer-Cartan forms for the \
quaternion algebra,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coeffs", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["d\[Omega]", "0"], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "1"], "+", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "2"], "-", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["d\[Omega]", "3"], "+", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
and the quaternion-valued \[OpenCurlyDoubleQuote]curvature\
\[CloseCurlyDoubleQuote] 2-form satisfies the 3-form Bianchi identity,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "F", "]"}], "+", 
  RowBox[{"Q", "**", 
   RowBox[{"(", 
    RowBox[{"F", "/", "2"}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"F", "/", "2"}], ")"}], "**", "Q"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
Similar AVF structures can be defined for other associative algebras (such as \
the geometric Clifford algebras, which include H), and for non-associative \
algebras (e.g., Lie or supersymmetric graded Lie algebras).\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell["\<\
The derivative operator can also be applied to a list of AVFs.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"q", "**", 
     OverscriptBox["q", "_"]}], ",", "QQ"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["dx", "0"], " ", 
     SubscriptBox["x", "0"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "1"], " ", 
     SubscriptBox["x", "1"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "2"], " ", 
     SubscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "3"], " ", 
     SubscriptBox["x", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["\[Sigma]", "3"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "2"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "3"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "3"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "1"]}]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "1"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "3"]}]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "1"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "1"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "2"]}]}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.5. Ordinary differential forms", "Subsubsection"],

Cell[TextData[{
 "Any ordinary differential form expression can be input simply by omitting \
the algebra elements. Absent elements default to the identity element of the \
algebra, which only appears with ",
 StyleBox["collect", "Input",
  FontWeight->"Plain"],
 "; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], 
      RowBox[{
       SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
       SubscriptBox["dx", "2"]}]}], "+", 
     RowBox[{
      SubscriptBox["x", "0"], 
      SubscriptBox["d\[Omega]", "3"]}]}], ")"}], "**", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Omega]", "3"], "+", 
     SubscriptBox["\[Omega]", "2"]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"collect", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"df", "=", 
  RowBox[{"d", "[", "f", "]"}]}]], "Input"],

Cell[TextData[{
 "Since ordinary differential forms are treated as a trivial ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 ", all ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " commands will work equally well in either case."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "III.b.6. ",
 StyleBox["factor", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"]
}], "Subsubsection"],

Cell[TextData[{
 "Any member of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " can be factored out to the left of an AVF by the following command, where \
all terms containing the basis form will be factored."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fac", "=", 
  RowBox[{"factor", "[", 
   RowBox[{
    SubscriptBox["d\[Omega]", "3"], ",", "df"}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "and so the original ",
 StyleBox["df", "Input",
  FontWeight->"Plain"],
 " can be recovered by using ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"],
 " on the next expression,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"df", "/.", 
    RowBox[{
     SubscriptBox["d\[Omega]", "3"], "->", "0"}]}], ")"}], "+", 
  RowBox[{
   SubscriptBox["d\[Omega]", "3"], "\[Wedge]", "fac"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"df", "+", 
  RowBox[{
   SubscriptBox["d\[Omega]", "3"], "\[Wedge]", "0"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", "%", "]"}]], "Input"],

Cell[BoxData["df"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " command ",
 StyleBox["expand", "Input",
  FontWeight->"Plain"],
 " is analogous to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Expand", "Input",
  FontWeight->"Plain"],
 ", except that it also expands wedge products, and so allows arbitrary \
replacements within them at all levels of an AVF expression. Note that the \
wedge symbol has the usual meaning of exterior product between basis forms, \
but is neither recognized nor used as an operator."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Q", "\[Wedge]", "QQ"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "0"], " ", 
     SubscriptBox["\[Omega]", "0"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "2"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "3"], " ", 
     SubscriptBox["\[Omega]", "3"]}]}], ")"}], "\[Wedge]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "3"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "1"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{
   SubscriptBox["\[Omega]", "2"], "->", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["dx", "1"], "+", 
     SubscriptBox["dx", "3"]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["dx", "1"], "+", 
       SubscriptBox["dx", "3"]}], ")"}], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "0"], " ", 
     SubscriptBox["\[Omega]", "0"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "3"], " ", 
     SubscriptBox["\[Omega]", "3"]}]}], ")"}], "\[Wedge]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "1"], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["dx", "1"], "+", 
        SubscriptBox["dx", "3"]}], ")"}], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "3"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["dx", "1"], "+", 
        SubscriptBox["dx", "3"]}], ")"}]}]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Sigma]", "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["dx", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "0"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["dx", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "0"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{
    SubscriptBox["dx", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["dx", "3"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "0"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"]}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["dx", "3"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "0"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{
    SubscriptBox["dx", "3"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "0"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.7. Vector contraction", "Subsubsection"],

Cell[TextData[{
 "A vector in ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " is a list of scalar variables with the same length as the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list. The list represents the components of the vector in the dual basis \
to ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ". The components will be constants, unless they are chosen from the ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " list, or are input as specified or unspecified functions of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ". Define two independent vectors, ",
 StyleBox["V1", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["V2", "Input",
  FontWeight->"Plain"],
 ",  with symbols adapted to the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", 
   SubscriptBox["dx", "0"], ",", 
   SubscriptBox["dx", "1"], ",", 
   SubscriptBox["dx", "2"], ",", 
   SubscriptBox["dx", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"V1", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["W1", "0"], ",", 
     SubscriptBox["W1", "1"], ",", 
     SubscriptBox["W1", "2"], ",", 
     SubscriptBox["W1", "3"], ",", 
     SubscriptBox["X1", "0"], ",", 
     SubscriptBox["X1", "1"], ",", 
     SubscriptBox["X1", "2"], ",", 
     SubscriptBox["X1", "3"]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"V2", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["W2", "0"], ",", 
     SubscriptBox["W2", "1"], ",", 
     SubscriptBox["W2", "2"], ",", 
     SubscriptBox["W2", "3"], ",", 
     SubscriptBox["X2", "0"], ",", 
     SubscriptBox["X2", "1"], ",", 
     SubscriptBox["X2", "2"], ",", 
     SubscriptBox["X2", "3"]}], "}"}]}], ";"}]}], "Input"],

Cell[TextData[{
 "Vector contractions are given by the ",
 StyleBox["SmallCircle", "Input",
  FontWeight->"Plain"],
 " infix operator, typed as esc-sc-esc; i.e., vector \[SmallCircle] AVF . \
Contraction can also be applied to a list of AVFs, and multiple contractions \
can be performed together. On the list of basis 1-forms, it simply returns \
the vector itself;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V1", "\[SmallCircle]", "forms"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["W1", "0"], ",", 
   SubscriptBox["W1", "1"], ",", 
   SubscriptBox["W1", "2"], ",", 
   SubscriptBox["W1", "3"], ",", 
   SubscriptBox["X1", "0"], ",", 
   SubscriptBox["X1", "1"], ",", 
   SubscriptBox["X1", "2"], ",", 
   SubscriptBox["X1", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V1", "\[SmallCircle]", 
  RowBox[{"{", 
   RowBox[{"QQ", ",", 
    RowBox[{"d", "[", "q", "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["W1", "3"], " ", 
     SubscriptBox["\[Sigma]", "2"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["W1", "2"], " ", 
     SubscriptBox["\[Sigma]", "3"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["W1", "3"], " ", 
     SubscriptBox["\[Sigma]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["W1", "1"], " ", 
     SubscriptBox["\[Sigma]", "3"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["W1", "2"], " ", 
     SubscriptBox["\[Sigma]", "1"], " ", 
     SubscriptBox["\[Omega]", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["W1", "1"], " ", 
     SubscriptBox["\[Sigma]", "2"], " ", 
     SubscriptBox["\[Omega]", "3"]}]}], ",", 
   RowBox[{
    SubscriptBox["X1", "0"], "+", 
    RowBox[{
     SubscriptBox["X1", "1"], " ", 
     SubscriptBox["\[Sigma]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["X1", "2"], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["X1", "3"], " ", 
     SubscriptBox["\[Sigma]", "3"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V1", "\[SmallCircle]", "V2", "\[SmallCircle]", "QQ"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["W1", "3"], " ", 
   SubscriptBox["W2", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["W1", "2"], " ", 
   SubscriptBox["W2", "3"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["W1", "3"], " ", 
   SubscriptBox["W2", "1"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["W1", "1"], " ", 
   SubscriptBox["W2", "3"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["W1", "2"], " ", 
   SubscriptBox["W2", "1"], " ", 
   SubscriptBox["\[Sigma]", "3"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["W1", "1"], " ", 
   SubscriptBox["W2", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["W1", "3"], " ", 
      SubscriptBox["W2", "2"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["W1", "2"], " ", 
      SubscriptBox["W2", "3"]}]}], ")"}], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["W1", "3"], " ", 
      SubscriptBox["W2", "1"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["W1", "1"], " ", 
      SubscriptBox["W2", "3"]}]}], ")"}], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["W1", "2"], " ", 
      SubscriptBox["W2", "1"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["W1", "1"], " ", 
      SubscriptBox["W2", "2"]}]}], ")"}], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell["These vectors are constant,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "V1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}],
   "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "but the components can be input as functions of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["W1", "0"], "[", 
     SubscriptBox["x", "0"], "]"}], ",", 
    RowBox[{
     SubscriptBox["W1", "1"], "[", 
     SubscriptBox["x", "1"], "]"}], ",", 
    RowBox[{
     SubscriptBox["W1", "2"], "[", 
     SubscriptBox["x", "2"], "]"}], ",", 
    RowBox[{
     SubscriptBox["W1", "3"], "[", 
     SubscriptBox["x", "3"], "]"}], ",", 
    SubscriptBox["X1", "0"], ",", 
    SubscriptBox["X1", "1"], ",", 
    SubscriptBox["X1", "2"], ",", 
    SubscriptBox["X1", "3"]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["W1", "0"], "[", 
    SubscriptBox["x", "0"], "]"}], ",", 
   RowBox[{
    SubscriptBox["W1", "1"], "[", 
    SubscriptBox["x", "1"], "]"}], ",", 
   RowBox[{
    SubscriptBox["W1", "2"], "[", 
    SubscriptBox["x", "2"], "]"}], ",", 
   RowBox[{
    SubscriptBox["W1", "3"], "[", 
    SubscriptBox["x", "3"], "]"}], ",", 
   SubscriptBox["X1", "0"], ",", 
   SubscriptBox["X1", "1"], ",", 
   SubscriptBox["X1", "2"], ",", 
   SubscriptBox["X1", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "V1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["dx", "0"], " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["W1", "0"], "\[Prime]",
      MultilineFunction->None], "[", 
     SubscriptBox["x", "0"], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["dx", "1"], " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["W1", "1"], "\[Prime]",
      MultilineFunction->None], "[", 
     SubscriptBox["x", "1"], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["dx", "2"], " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["W1", "2"], "\[Prime]",
      MultilineFunction->None], "[", 
     SubscriptBox["x", "2"], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["dx", "3"], " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["W1", "3"], "\[Prime]",
      MultilineFunction->None], "[", 
     SubscriptBox["x", "3"], "]"}]}], ",", "0", ",", "0", ",", "0", ",", 
   "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V1", "\[SmallCircle]", "QQ"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "2"], " ", 
   RowBox[{
    SubscriptBox["W1", "1"], "[", 
    SubscriptBox["x", "1"], "]"}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "3"], " ", 
   RowBox[{
    SubscriptBox["W1", "1"], "[", 
    SubscriptBox["x", "1"], "]"}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   RowBox[{
    SubscriptBox["W1", "2"], "[", 
    SubscriptBox["x", "2"], "]"}]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "3"], " ", 
   RowBox[{
    SubscriptBox["W1", "2"], "[", 
    SubscriptBox["x", "2"], "]"}]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   RowBox[{
    SubscriptBox["W1", "3"], "[", 
    SubscriptBox["x", "3"], "]"}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "2"], " ", 
   RowBox[{
    SubscriptBox["W1", "3"], "[", 
    SubscriptBox["x", "3"], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"d", "[", "%", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "2"], " ", 
      RowBox[{
       SubscriptBox["W1", "1"], "[", 
       SubscriptBox["x", "1"], "]"}]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "1"], " ", 
      RowBox[{
       SubscriptBox["W1", "2"], "[", 
       SubscriptBox["x", "2"], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dx", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}], " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["W1", "1"], "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["x", "1"], "]"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dx", "2"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "1"]}], " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["W1", "2"], "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["x", "2"], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["d\[Omega]", "3"], " ", 
      RowBox[{
       SubscriptBox["W1", "1"], "[", 
       SubscriptBox["x", "1"], "]"}]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "1"], " ", 
      RowBox[{
       SubscriptBox["W1", "3"], "[", 
       SubscriptBox["x", "3"], "]"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dx", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}], " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["W1", "1"], "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["x", "1"], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dx", "3"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "1"]}], " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["W1", "3"], "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["x", "3"], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "3"], " ", 
      RowBox[{
       SubscriptBox["W1", "2"], "[", 
       SubscriptBox["x", "2"], "]"}]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "2"], " ", 
      RowBox[{
       SubscriptBox["W1", "3"], "[", 
       SubscriptBox["x", "3"], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dx", "2"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}], " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["W1", "2"], "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["x", "2"], "]"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dx", "3"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}], " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["W1", "3"], "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["x", "3"], "]"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "or even be entered into ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " themselves to make them independent fields with their own derivatives,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"scalars", ",", "V2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "0"], ",", 
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["W2", "0"], ",", 
   SubscriptBox["W2", "1"], ",", 
   SubscriptBox["W2", "2"], ",", 
   SubscriptBox["W2", "3"], ",", 
   SubscriptBox["X2", "0"], ",", 
   SubscriptBox["X2", "1"], ",", 
   SubscriptBox["X2", "2"], ",", 
   SubscriptBox["X2", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", 
   SubscriptBox["dx", "0"], ",", 
   SubscriptBox["dx", "1"], ",", 
   SubscriptBox["dx", "2"], ",", 
   SubscriptBox["dx", "3"], ",", 
   SubscriptBox["dW2", "0"], ",", 
   SubscriptBox["dW2", "1"], ",", 
   SubscriptBox["dW2", "2"], ",", 
   SubscriptBox["dW2", "3"], ",", 
   SubscriptBox["dX2", "0"], ",", 
   SubscriptBox["dX2", "1"], ",", 
   SubscriptBox["dX2", "2"], ",", 
   SubscriptBox["dX2", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"V2", "\[SmallCircle]", "QQ"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["W2", "3"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["W2", "2"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["W2", "3"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["W2", "1"], " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["W2", "2"], " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["\[Omega]", "3"]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["W2", "1"], " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"d", "[", "%", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "2"], " ", 
      SubscriptBox["W2", "1"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "1"], " ", 
      SubscriptBox["W2", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dW2", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dW2", "2"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "1"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["d\[Omega]", "3"], " ", 
      SubscriptBox["W2", "1"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "1"], " ", 
      SubscriptBox["W2", "3"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dW2", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dW2", "3"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "1"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "3"], " ", 
      SubscriptBox["W2", "2"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["d\[Omega]", "2"], " ", 
      SubscriptBox["W2", "3"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dW2", "2"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox["dW2", "3"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Contraction on this last expression would require a longer vector to \
encompass the additional independent basis 1-forms created by extending the \
",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " list. It would also require defining contractions on the members of ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "The ",
 StyleBox["makescalars", "Input",
  FontWeight->"Plain"],
 " command just above illustrates a general feature of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 "; i.e., that the fundamental lists ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " can be changed at any time by executing the respective ",
 StyleBox["make", "Input",
  FontWeight->"Plain"],
 " command. For instance, the vector components can be deleted from ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " by"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"Complement", "[", 
   RowBox[{"scalars", ",", "V2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "0"], ",", 
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"], ",", 
   SubscriptBox["dx", "0"], ",", 
   SubscriptBox["dx", "1"], ",", 
   SubscriptBox["dx", "2"], ",", 
   SubscriptBox["dx", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell["This doesn't delete them from memory,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["V2"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["W2", "0"], ",", 
   SubscriptBox["W2", "1"], ",", 
   SubscriptBox["W2", "2"], ",", 
   SubscriptBox["W2", "3"], ",", 
   SubscriptBox["X2", "0"], ",", 
   SubscriptBox["X2", "1"], ",", 
   SubscriptBox["X2", "2"], ",", 
   SubscriptBox["X2", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "but they do revert to being constant parameters in ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "V2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}],
   "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.8. Matrix representations and operations", "Subsubsection"],

Cell["\<\
Sometimes it is useful to have a matrix representation of the algebra \
elements, even though the program never requires it. For example, the \
quaternion elements can be represented by Pauli-type matrices, which have the \
same multiplication table as H,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Sigma]", "0"], 
      SubscriptBox["\[Sigma]", "1"], 
      SubscriptBox["\[Sigma]", "2"], 
      SubscriptBox["\[Sigma]", "3"]},
     {
      SubscriptBox["\[Sigma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "2"]}]},
     {
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "1"]},
     {
      SubscriptBox["\[Sigma]", "3"], 
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["for instance,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalSigma]", "0"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalSigma]", "1"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "I"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"I", ",", "0"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalSigma]", "2"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   SubscriptBox["\[CapitalSigma]", "3"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"I", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "I"}]}], "}"}]}], "}"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["\[CapitalSigma]", "1"], ")"}], ".", 
   SubscriptBox["\[CapitalSigma]", "1"]}], "==", 
  RowBox[{"-", 
   SubscriptBox["\[CapitalSigma]", "0"]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["\[CapitalSigma]", "1"], ")"}], ".", 
   SubscriptBox["\[CapitalSigma]", "2"]}], "==", 
  SubscriptBox["\[CapitalSigma]", "3"]}]}], "Input"],

Cell[BoxData["True"], "Output"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "and since the indices of these matrices agree with the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "i"], TraditionalForm]]],
 ", any quaternion expression or list can be converted to a matrix by \
replacement of the symbol kernel; i.e.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], ",", 
   SubscriptBox["\[Sigma]", "1"], ",", 
   SubscriptBox["\[Sigma]", "2"], ",", 
   SubscriptBox["\[Sigma]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"elements", "/.", 
  RowBox[{"\[Sigma]", "->", "\[CapitalSigma]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "\[ImaginaryI]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["q"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mq", "=", 
  RowBox[{"q", "/.", 
   RowBox[{"\[Sigma]", "->", "\[CapitalSigma]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "0"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "3"]}]}], ",", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "1"]}], "-", 
      SubscriptBox["x", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "1"]}], "+", 
      SubscriptBox["x", "2"]}], ",", 
     RowBox[{
      SubscriptBox["x", "0"], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "3"]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SubscriptBox["x", "0"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "3"]}]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"]}], "-", 
       SubscriptBox["x", "2"]}]},
     {
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"]}], "+", 
       SubscriptBox["x", "2"]}], 
      RowBox[{
       SubscriptBox["x", "0"], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "3"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["QQ"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "2"]}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
    SubscriptBox["\[Omega]", "3"]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mQQ", "=", 
  RowBox[{"QQ", "/.", 
   RowBox[{"\[Sigma]", "->", "\[CapitalSigma]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "\[ImaginaryI]", " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "3"]}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}]}], 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "When the AVF includes a suppressed identity element, it is necessary to \
make it explicit by using ",
 StyleBox["collect", "Input",
  FontWeight->"Plain"],
 " before conversion; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "**", "q"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["x", "0", "2"], "-", 
  SubsuperscriptBox["x", "1", "2"], "-", 
  SubsuperscriptBox["x", "2", "2"], "-", 
  SubsuperscriptBox["x", "3", "2"], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "0"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"collect", "[", 
   RowBox[{"q", "**", "q"}], "]"}], "/.", 
  RowBox[{"\[Sigma]", "->", "\[CapitalSigma]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["x", "0", "2"], "-", 
      SubsuperscriptBox["x", "1", "2"], "-", 
      SubsuperscriptBox["x", "2", "2"], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "3"]}], "-", 
      SubsuperscriptBox["x", "3", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "1"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "1"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "2"]}]}], ",", 
     RowBox[{
      SubsuperscriptBox["x", "0", "2"], "-", 
      SubsuperscriptBox["x", "1", "2"], "-", 
      SubsuperscriptBox["x", "2", "2"], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "3"]}], "-", 
      SubsuperscriptBox["x", "3", "2"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Since the matrix mq has only scalar components, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s matrix product gives the same result,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"mq", ".", "mq"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["x", "0", "2"], "-", 
      SubsuperscriptBox["x", "1", "2"], "-", 
      SubsuperscriptBox["x", "2", "2"], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "3"]}], "-", 
      SubsuperscriptBox["x", "3", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "1"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "1"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "2"]}]}], ",", 
     RowBox[{
      SubsuperscriptBox["x", "0", "2"], "-", 
      SubsuperscriptBox["x", "1", "2"], "-", 
      SubsuperscriptBox["x", "2", "2"], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["x", "0"], " ", 
       SubscriptBox["x", "3"]}], "-", 
      SubsuperscriptBox["x", "3", "2"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.9. AVF matrices", "Subsubsection"],

Cell[TextData[{
 "The ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " program includes an infix operator, denoted ",
 StyleBox["CircleTimes", "Input",
  FontWeight->"Plain"],
 " and typed by esc-c*-esc}, that can be used when the matrix elements are \
complete AVFs, such as quaternion-valued p-forms. For instance, the above \
matrix ",
 StyleBox["mQQ", "Input",
  FontWeight->"Plain"],
 " can be calculated using the matrix form of ",
 StyleBox["Q", "Input",
  FontWeight->"Plain"],
 " having 1-form elements,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mQ", "=", 
  RowBox[{"Q", "/.", 
   RowBox[{"\[Sigma]", "->", "\[CapitalSigma]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", "0"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "3"]}]}], ",", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "1"]}], "-", 
      SubscriptBox["\[Omega]", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "1"]}], "+", 
      SubscriptBox["\[Omega]", "2"]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", "0"], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "3"]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", 
  RowBox[{"mQ", "\[CircleTimes]", "mQ"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}]}], 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
        SubscriptBox["\[Omega]", "2"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["BlockMatrix[]", "Input",
  FontWeight->"Plain"],
 " command, the matrices ",
 StyleBox["mq", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["mQ", "Input",
  FontWeight->"Plain"],
 " can be combined to give a graded matrix, ",
 StyleBox["GM", "Input",
  FontWeight->"Plain"],
 ", with diagonal blocks of even grade (0-forms) and off-diagonal blocks of \
odd grade (1-forms). Such matrices generate supergroups and their commutators \
generate the associated Lie superalgebras."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["<< LinearAlgebra`MatrixManipulation`;", "Input",
 PageWidth->WindowWidth,
 CellTags->"S5.52.1"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "obspkg"}], "MessageName"], ":", 
  " ", "\<\"\[NoBreak]\\!\\(\\\"LinearAlgebra`MatrixManipulation`\\\"\\)\
\[NoBreak] is now obsolete. The legacy version being loaded may conflict with \
current Mathematica functionality. See the Compatibility Guide for updating \
information. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:Compatibility/Tutorials/LinearAlgebra/\
MatrixManipulation\\\", ButtonNote -> \\\"General::obspkg\\\"]\\)\"\>"}]], \
"Message", "MSG",
 CellTags->"S5.52.1"]
}, Open  ]],

Cell["\<\
For brevity, the identity elements are deleted in this example,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"GM", "=", 
   RowBox[{
    RowBox[{"BlockMatrix", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mq", ",", "mQ"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"mQ", ",", 
         RowBox[{"-", "mq"}]}], "}"}]}], "}"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "0"], "->", "0"}], ",", 
      RowBox[{
       SubscriptBox["\[Omega]", "0"], "->", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"mtx", "[", "GM", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"]}], "-", 
       SubscriptBox["x", "2"]}], 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       SubscriptBox["\[Omega]", "2"]}]},
     {
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"]}], "+", 
       SubscriptBox["x", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["x", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       SubscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Omega]", "3"]}]},
     {
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       SubscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["x", "3"]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["x", "1"]}], "+", 
       SubscriptBox["x", "2"]}]},
     {
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       SubscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Omega]", "3"]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["x", "1"]}], "-", 
       SubscriptBox["x", "2"]}], 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "3"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
The product is a graded matrix of the same general type; i.e., diagonal \
blocks of even grades in the Grassmann algebra and off-diagonal blocks of odd \
grade:\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", 
  RowBox[{"GM", "\[CircleTimes]", "GM"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["x", "1", "2"]}], "-", 
       SubsuperscriptBox["x", "2", "2"], "-", 
       SubsuperscriptBox["x", "3", "2"], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "2"]}]}]}], 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "2"]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "2"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "3"]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}], 
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["x", "1", "2"]}], "-", 
       SubsuperscriptBox["x", "2", "2"], "-", 
       SubsuperscriptBox["x", "3", "2"], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "2"]}]}]}], 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "3"]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "3"]}]}], 
      RowBox[{
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "2"]}]}]},
     {
      RowBox[{
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "2"]}]}], 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "3"]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "3"]}]}], 
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["x", "1", "2"]}], "-", 
       SubsuperscriptBox["x", "2", "2"], "-", 
       SubsuperscriptBox["x", "3", "2"], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "2"]}]}]}], 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Omega]", "2"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "3"]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "3"]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Omega]", "2"]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}], 
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["x", "1", "2"]}], "-", 
       SubsuperscriptBox["x", "2", "2"], "-", 
       SubsuperscriptBox["x", "3", "2"], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "2"]}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
A graded matrix equivalent to GM can be expressed more concisely with a 2\
\[Times]2 matrix of the quaternion-valued AVFs,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QM", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "Q"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Q", ",", 
        RowBox[{"-", "q"}]}], "}"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "0"], "->", "0"}], ",", 
      RowBox[{
       SubscriptBox["\[Omega]", "0"], "->", "0"}]}], "}"}]}]}], ";", 
  RowBox[{"mtx", "[", "QM", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["\[Sigma]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Sigma]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Sigma]", "3"]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        SubscriptBox["\[Omega]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        SubscriptBox["\[Omega]", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        SubscriptBox["\[Omega]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        SubscriptBox["\[Omega]", "3"]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["x", "1"]}], " ", 
        SubscriptBox["\[Sigma]", "1"]}], "-", 
       RowBox[{
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["\[Sigma]", "2"]}], "-", 
       RowBox[{
        SubscriptBox["x", "3"], " ", 
        SubscriptBox["\[Sigma]", "3"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", 
  RowBox[{"BlockMatrix", "[", 
   RowBox[{"QM", "/.", 
    RowBox[{"\[Sigma]", "->", "\[CapitalSigma]"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"]}], "-", 
       SubscriptBox["x", "2"]}], 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       SubscriptBox["\[Omega]", "2"]}]},
     {
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["x", "1"]}], "+", 
       SubscriptBox["x", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["x", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       SubscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Omega]", "3"]}]},
     {
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Omega]", "3"]}], 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "-", 
       SubscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["x", "3"]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["x", "1"]}], "+", 
       SubscriptBox["x", "2"]}]},
     {
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       SubscriptBox["\[Omega]", "2"]}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Omega]", "3"]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["x", "1"]}], "-", 
       SubscriptBox["x", "2"]}], 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["x", "3"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and it can be multiplied directly with the ",
 StyleBox["CircleTimes", "Input",
  FontWeight->"Plain"],
 " operator, giving essentially the same result for the matrix product, but \
in a representation-independent and slightly more compact form,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"QM2", "=", 
   RowBox[{"collect", "[", 
    RowBox[{"QM", "\[CircleTimes]", "QM"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"mtx", "[", "QM2", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["x", "1", "2"]}], "-", 
          SubsuperscriptBox["x", "2", "2"], "-", 
          SubsuperscriptBox["x", "3", "2"]}], ")"}], " ", 
        SubscriptBox["\[Sigma]", "0"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "2"]}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["x", "2"], " ", 
           SubscriptBox["\[Omega]", "1"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["x", "1"], " ", 
           SubscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["x", "3"], " ", 
           SubscriptBox["\[Omega]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["x", "1"], " ", 
           SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["x", "3"], " ", 
           SubscriptBox["\[Omega]", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["x", "2"], " ", 
           SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["x", "2"], " ", 
           SubscriptBox["\[Omega]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["x", "1"], " ", 
           SubscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["x", "3"], " ", 
           SubscriptBox["\[Omega]", "1"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["x", "1"], " ", 
           SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["x", "3"], " ", 
           SubscriptBox["\[Omega]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["x", "2"], " ", 
           SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["x", "1", "2"]}], "-", 
          SubsuperscriptBox["x", "2", "2"], "-", 
          SubsuperscriptBox["x", "3", "2"]}], ")"}], " ", 
        SubscriptBox["\[Sigma]", "0"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "2"]}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that as a matrix ",
 StyleBox["QM", "Input",
  FontWeight->"Plain"],
 " is symmetric, but its expanded form ",
 StyleBox["GM", "Input",
  FontWeight->"Plain"],
 " is unsymmetric (anti-Hermitian), so matrix operations involving transposes \
and conjugates must be defined and handled differently."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "Since ",
 StyleBox["d[]", "Input",
  FontWeight->"Plain"],
 " maps recursively onto AVF lists, it also extends to AVF matrices,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"d", "[", "QM2", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["dx", "1"], " ", 
          SubscriptBox["x", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["dx", "2"], " ", 
          SubscriptBox["x", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["dx", "3"], " ", 
          SubscriptBox["x", "3"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "0"]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "2"]}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "3"]}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "3"]}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "2"]}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "2"], " ", 
          SubscriptBox["x", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "1"], " ", 
          SubscriptBox["x", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "1"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "2"]}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "2"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["d\[Omega]", "3"], " ", 
          SubscriptBox["x", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "1"], " ", 
          SubscriptBox["x", "3"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "1"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "3"]}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "3"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "3"], " ", 
          SubscriptBox["x", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "2"], " ", 
          SubscriptBox["x", "3"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "2"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "3"]}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "3"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "2"]}]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["d\[Omega]", "2"], " ", 
          SubscriptBox["x", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "1"], " ", 
          SubscriptBox["x", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "1"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "2"]}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "2"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "3"], " ", 
          SubscriptBox["x", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "1"], " ", 
          SubscriptBox["x", "3"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "1"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "3"]}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "3"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["d\[Omega]", "3"], " ", 
          SubscriptBox["x", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["d\[Omega]", "2"], " ", 
          SubscriptBox["x", "3"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "2"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "3"]}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["dx", "3"], "\[Wedge]", 
           SubscriptBox["\[Omega]", "2"]}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["dx", "1"], " ", 
          SubscriptBox["x", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["dx", "2"], " ", 
          SubscriptBox["x", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["dx", "3"], " ", 
          SubscriptBox["x", "3"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "0"]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "2"]}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "3"]}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "1"]}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "3"]}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
           SubscriptBox["d\[Omega]", "2"]}]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["and the same is true for contractions,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"V2", "\[SmallCircle]", "QM2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["\[Omega]", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["\[Omega]", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["\[Omega]", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["x", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["x", "3"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "1"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["x", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["x", "3"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["x", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["x", "2"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "3"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["x", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["x", "3"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "1"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["x", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["x", "3"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["x", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["x", "2"]}]}], ")"}], " ", 
       SubscriptBox["\[Sigma]", "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["\[Omega]", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["\[Omega]", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "1"], " ", 
          SubscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W2", "3"], " ", 
          SubscriptBox["\[Omega]", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W2", "2"], " ", 
          SubscriptBox["\[Omega]", "3"]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["For a quaternion-valued, even-odd, column vector,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QV", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      OverscriptBox["q", "_"], "}"}], ",", 
     RowBox[{"{", "Q", "}"}]}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "0"], "->", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", "0"], "->", "0"}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["x", "1"]}], " ", 
      SubscriptBox["\[Sigma]", "1"]}], "-", 
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Sigma]", "2"]}], "-", 
     RowBox[{
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Sigma]", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "the ",
 StyleBox["QM\[CircleTimes]QV", "Input",
  FontWeight->"Plain"],
 " product returns an even-odd column vector"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QM", "\[CircleTimes]", "QV"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["x", "1", "2"], "+", 
     SubsuperscriptBox["x", "2", "2"], "+", 
     SubsuperscriptBox["x", "3", "2"], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Sigma]", "3"], " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "2"]}]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Sigma]", "2"], " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Sigma]", "1"], " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
       SubscriptBox["\[Omega]", "3"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "3"], " ", 
      SubscriptBox["\[Omega]", "3"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
and finally, a single, quaternion-valued, even-grade, p-form,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", "QV", "]"}], "\[CircleTimes]", "%"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["x", "1", "3"]}], "-", 
       RowBox[{
        SubscriptBox["x", "1"], " ", 
        SubsuperscriptBox["x", "2", "2"]}], "-", 
       RowBox[{
        SubscriptBox["x", "1"], " ", 
        SubsuperscriptBox["x", "3", "2"]}]}], ")"}], " ", 
     SubscriptBox["\[Sigma]", "1"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["x", "1", "2"]}], " ", 
        SubscriptBox["x", "2"]}], "-", 
       SubsuperscriptBox["x", "2", "3"], "-", 
       RowBox[{
        SubscriptBox["x", "2"], " ", 
        SubsuperscriptBox["x", "3", "2"]}]}], ")"}], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["x", "1", "2"]}], " ", 
        SubscriptBox["x", "3"]}], "-", 
       RowBox[{
        SubsuperscriptBox["x", "2", "2"], " ", 
        SubscriptBox["x", "3"]}], "-", 
       SubsuperscriptBox["x", "3", "3"]}], ")"}], " ", 
     SubscriptBox["\[Sigma]", "3"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "0"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["x", "3"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "2"]}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["x", "2"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["x", "1"], " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
         SubscriptBox["\[Omega]", "3"]}]}]}], ")"}]}]}], "}"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SubscriptBox["dx", "1"], " ", 
     SubsuperscriptBox["x", "1", "2"], " ", 
     SubscriptBox["\[Sigma]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "2"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["\[Sigma]", "1"]}], "-", 
    RowBox[{
     SubscriptBox["dx", "1"], " ", 
     SubsuperscriptBox["x", "2", "2"], " ", 
     SubscriptBox["\[Sigma]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "3"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Sigma]", "1"]}], "-", 
    RowBox[{
     SubscriptBox["dx", "1"], " ", 
     SubsuperscriptBox["x", "3", "2"], " ", 
     SubscriptBox["\[Sigma]", "1"]}], "-", 
    RowBox[{
     SubscriptBox["dx", "2"], " ", 
     SubsuperscriptBox["x", "1", "2"], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "1"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["dx", "2"], " ", 
     SubsuperscriptBox["x", "2", "2"], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "3"], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "-", 
    RowBox[{
     SubscriptBox["dx", "2"], " ", 
     SubsuperscriptBox["x", "3", "2"], " ", 
     SubscriptBox["\[Sigma]", "2"]}], "-", 
    RowBox[{
     SubscriptBox["dx", "3"], " ", 
     SubsuperscriptBox["x", "1", "2"], " ", 
     SubscriptBox["\[Sigma]", "3"]}], "-", 
    RowBox[{
     SubscriptBox["dx", "3"], " ", 
     SubsuperscriptBox["x", "2", "2"], " ", 
     SubscriptBox["\[Sigma]", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "1"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Sigma]", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["dx", "2"], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["\[Sigma]", "3"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["dx", "3"], " ", 
     SubsuperscriptBox["x", "3", "2"], " ", 
     SubscriptBox["\[Sigma]", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "3"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "2"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "3"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "3"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "1"]}]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "1"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "3"]}]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "1"]}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "1"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "3"], "\[Wedge]", 
      SubscriptBox["d\[Omega]", "2"]}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SubscriptBox["dx", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{
      SubscriptBox["dx", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SubscriptBox["dx", "3"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "0", "}"}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.b.10. Clean up", "Subsubsection"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c. More general algebras", "Subsection"],

Cell["This is taken from the file Miscellany_Demo.nb", "Text"],

Cell[CellGroupData[{

Cell["III.c.1. General comments", "Subsubsection"],

Cell[TextData[{
 "This section contains a miscellaneous collection of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " calculations. Most of the operations used are introduced and explained in \
other sections. The first example treats the Dirac equation with quaternion \
matrices. The rest involve a variety of non-associative algebras.  Some of \
these exercises were suggested by the fine review book on non-associative \
algebras by Susumu Okubo:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 StyleBox["Introduction to Octonion and Other Non-Associative Algebras in \
Physics",
  FontSlant->"Italic"],
 ", S. Okubo, Montroll Memorial Lecture Series in Mathematical Physics: 2, \
Cambridge University Press, 1995"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain",
 CellTags->"reference"]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.2. Quaternions", "Subsubsection"],

Cell["Setting up the quaternion algebra, H", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeelements", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Sigma]", "0"], ",", 
    SubscriptBox["\[Sigma]", "1"], ",", 
    SubscriptBox["\[Sigma]", "2"], ",", 
    SubscriptBox["\[Sigma]", "3"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], ",", 
   SubscriptBox["\[Sigma]", "1"], ",", 
   SubscriptBox["\[Sigma]", "2"], ",", 
   SubscriptBox["\[Sigma]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "0"], ",", 
       SubscriptBox["\[Sigma]", "1"], ",", 
       SubscriptBox["\[Sigma]", "2"], ",", 
       SubscriptBox["\[Sigma]", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "0"]}], ",", 
       SubscriptBox["\[Sigma]", "3"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "3"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "0"]}], ",", 
       SubscriptBox["\[Sigma]", "1"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], ",", 
       SubscriptBox["\[Sigma]", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "1"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "0"]}]}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"makealgebra", "[", "H", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Sigma]", "0"], 
      SubscriptBox["\[Sigma]", "1"], 
      SubscriptBox["\[Sigma]", "2"], 
      SubscriptBox["\[Sigma]", "3"]},
     {
      SubscriptBox["\[Sigma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "2"]}]},
     {
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "1"]},
     {
      SubscriptBox["\[Sigma]", "3"], 
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["with three independent quaternions,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q1", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["X", "i"], 
     SubscriptBox["\[Sigma]", "i"]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["X", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["X", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["X", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["X", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q2", "=", 
  RowBox[{"q1", "/.", 
   RowBox[{"X", "->", "Y"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["Y", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["Y", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["Y", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["Y", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q3", "=", 
  RowBox[{"q1", "/.", 
   RowBox[{"X", "->", "Z"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["Z", "0"], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["Z", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["Z", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["Z", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.3. The Dirac equation using quaternions", "Subsubsection"],

Cell["\<\
A familiar 2\[Times]2 representation of Dirac matrices can be expressed by \
the quaternion elements, \[Sigma] ;\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "0"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       SubscriptBox["\[Sigma]", "2"]}], "}"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{
       SubscriptBox["\[Sigma]", "2"], ",", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "1"], "=", 
   RowBox[{"I", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        SubscriptBox["\[Sigma]", "1"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], ",", "0"}], "}"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "2"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "0"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", 
        SubscriptBox["\[Sigma]", "0"]}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "3"], "=", 
   RowBox[{"I", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        SubscriptBox["\[Sigma]", "3"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], ",", "0"}], "}"}]}], "}"}]}]}], 
  ";"}]}], "Input"],

Cell[TextData[{
 "The operator ",
 StyleBox["CircleTimes", "Input",
  FontWeight->"Plain"],
 " multiplies matrices of ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " expressions, and for the squares of the \[CapitalGamma]'s gives the \
Lorentz signature, ",
 StyleBox["{-1,1,1,1}", "Input",
  FontWeight->"Plain"],
 "; i.e.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubscriptBox["\[CapitalGamma]", "0"]}], "\[CircleTimes]", 
   SubscriptBox["\[CapitalGamma]", "0"]}], "==", 
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "1"], "\[CircleTimes]", 
   SubscriptBox["\[CapitalGamma]", "1"]}], "==", 
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "2"], "\[CircleTimes]", 
   SubscriptBox["\[CapitalGamma]", "2"]}], "==", 
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "3"], "\[CircleTimes]", 
   SubscriptBox["\[CapitalGamma]", "3"]}], "==", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "where, as usual, the identity element ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", 
    RowBox[{"0", " "}]], TraditionalForm]]],
 "is suppressed in ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " results, but can be recovered using ",
 StyleBox["collect", "Input",
  FontWeight->"Plain"],
 ". They all anti-commute among themselves, and also with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalGamma]", "5"], TraditionalForm]]],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalGamma]", "5"], "=", 
  RowBox[{
   SubscriptBox["\[CapitalGamma]", "0"], "\[CircleTimes]", 
   SubscriptBox["\[CapitalGamma]", "1"], "\[CircleTimes]", 
   SubscriptBox["\[CapitalGamma]", "2"], "\[CircleTimes]", 
   SubscriptBox["\[CapitalGamma]", "3"]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "0"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Sigma]", "0"], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalGamma]", "5"], "\[CircleTimes]", 
  SubscriptBox["\[CapitalGamma]", "5"]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Make the coefficients of ",
 StyleBox["q1", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["q2", "Input",
  FontWeight->"Plain"],
 " into scalar variables,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"coeffs", "[", "q1", "]"}], ",", 
    RowBox[{"coeffs", "[", "q2", "]"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["X", "0"], ",", 
   SubscriptBox["X", "1"], ",", 
   SubscriptBox["X", "2"], ",", 
   SubscriptBox["X", "3"], ",", 
   SubscriptBox["Y", "0"], ",", 
   SubscriptBox["Y", "1"], ",", 
   SubscriptBox["Y", "2"], ",", 
   SubscriptBox["Y", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and define a quaternion-valued 2-vector ",
 StyleBox["qV", "Input",
  FontWeight->"Plain"],
 " to represent the Dirac field,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"qV", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "q1", "}"}], ",", 
     RowBox[{"{", "q2", "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"mtx", "[", "qV", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        SubscriptBox["X", "0"], " ", 
        SubscriptBox["\[Sigma]", "0"]}], "+", 
       RowBox[{
        SubscriptBox["X", "1"], " ", 
        SubscriptBox["\[Sigma]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["X", "2"], " ", 
        SubscriptBox["\[Sigma]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["X", "3"], " ", 
        SubscriptBox["\[Sigma]", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["Y", "0"], " ", 
        SubscriptBox["\[Sigma]", "0"]}], "+", 
       RowBox[{
        SubscriptBox["Y", "1"], " ", 
        SubscriptBox["\[Sigma]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["Y", "2"], " ", 
        SubscriptBox["\[Sigma]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["Y", "3"], " ", 
        SubscriptBox["\[Sigma]", "3"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Introducing a new set of ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " called ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " will automatically construct partial derivative expansions for the \
exterior derivatives of ",
 StyleBox["q1", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["q2", "Input",
  FontWeight->"Plain"],
 ", and these expressions are incorporated in ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " by the ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 " command, as is described more fully in the sectioin on LieDerivative below."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", ",", "x", ",", "y", ",", "z", ",", 
   SubscriptBox["X", "0"], ",", 
   SubscriptBox["X", "1"], ",", 
   SubscriptBox["X", "2"], ",", 
   SubscriptBox["X", "3"], ",", 
   SubscriptBox["Y", "0"], ",", 
   SubscriptBox["Y", "1"], ",", 
   SubscriptBox["Y", "2"], ",", 
   SubscriptBox["Y", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell["Thus,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "q1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["dX", "0"], "+", 
  RowBox[{
   SubscriptBox["dX", "1"], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["dX", "2"], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["dX", "3"], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"applydrules", "[", "%", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "t"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "t"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "t"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "t"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "or equivalently, using the compound operator, ",
 StyleBox["da[arg] = applydrules[d[arg]]", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"da", "[", "q1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "0"], "t"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "t"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "t"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dz", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "z"]}], "+", 
     RowBox[{"dy", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "y"]}], "+", 
     RowBox[{"dx", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "x"]}], "+", 
     RowBox[{"dt", " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "t"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A particular partial derivative of an ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " expression, or list, is given either by the coordinate name appearing as a \
subscript on D,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "x"], "[", "qV", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox[
      SubscriptBox["X", "0"], "x"], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "x"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "x"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "x"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox[
      SubscriptBox["Y", "0"], "x"], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      SubscriptBox[
       SubscriptBox["Y", "1"], "x"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      SubscriptBox[
       SubscriptBox["Y", "2"], "x"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      SubscriptBox[
       SubscriptBox["Y", "3"], "x"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "or by the position of the coordinate variable in the ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " list,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "1"], "[", "qV", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox[
      SubscriptBox["X", "0"], "t"], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      SubscriptBox[
       SubscriptBox["X", "1"], "t"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      SubscriptBox[
       SubscriptBox["X", "2"], "t"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      SubscriptBox[
       SubscriptBox["X", "3"], "t"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox[
      SubscriptBox["Y", "0"], "t"], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      SubscriptBox[
       SubscriptBox["Y", "1"], "t"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      SubscriptBox[
       SubscriptBox["Y", "2"], "t"]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      SubscriptBox[
       SubscriptBox["Y", "3"], "t"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The Dirac equation can then be written as the quaternion-valued 2-vector \
equation,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dirac", "=", 
  RowBox[{"collect", "[", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "3"], 
     RowBox[{"I", " ", 
      RowBox[{
       SubscriptBox["\[CapitalGamma]", "i"], "\[CircleTimes]", 
       RowBox[{
        SubscriptBox["D", 
         RowBox[{"i", "+", "1"}]], "[", "qV", "]"}]}]}]}], "+", 
    RowBox[{"I", " ", "m", " ", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", "5"], "\[CircleTimes]", "qV"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "m", " ", 
         SubscriptBox["Y", "2"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "1"], "z"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "2"], "y"]}], "+", 
        SubscriptBox[
         SubscriptBox["Y", "3"], "x"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "0"], "t"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "m", " ", 
         SubscriptBox["Y", "3"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "0"], "z"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "3"], "y"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "2"], "x"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "1"], "t"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "m", " ", 
         SubscriptBox["Y", "0"]}], "+", 
        SubscriptBox[
         SubscriptBox["Y", "3"], "z"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "0"], "y"]}], "+", 
        SubscriptBox[
         SubscriptBox["Y", "1"], "x"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "2"], "t"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "m", " ", 
         SubscriptBox["Y", "1"]}], "+", 
        SubscriptBox[
         SubscriptBox["Y", "2"], "z"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "1"], "y"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "0"], "x"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "3"], "t"]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "m", " ", 
         SubscriptBox["X", "2"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "1"], "z"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "2"], "y"]}], "+", 
        SubscriptBox[
         SubscriptBox["X", "3"], "x"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "0"], "t"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "m", " ", 
         SubscriptBox["X", "3"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "0"], "z"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "3"], "y"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "2"], "x"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "1"], "t"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "m", " ", 
         SubscriptBox["X", "0"]}], "+", 
        SubscriptBox[
         SubscriptBox["X", "3"], "z"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "0"], "y"]}], "+", 
        SubscriptBox[
         SubscriptBox["X", "1"], "x"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "2"], "t"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "m", " ", 
         SubscriptBox["X", "1"]}], "+", 
        SubscriptBox[
         SubscriptBox["X", "2"], "z"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["Y", "1"], "y"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "0"], "x"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox[
          SubscriptBox["X", "3"], "t"]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\
and applying the same operator a second time returns the Klein-Gordon \
equation for each quaternion component,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KG", "=", 
  RowBox[{"collect", "[", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "3"], 
     RowBox[{"I", " ", 
      RowBox[{
       SubscriptBox["\[CapitalGamma]", "i"], "\[CircleTimes]", 
       RowBox[{
        SubscriptBox["D", 
         RowBox[{"i", "+", "1"}]], "[", "dirac", "]"}]}]}]}], "+", 
    RowBox[{"I", " ", "m", " ", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", "5"], "\[CircleTimes]", " ", 
      "dirac"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["X", "0"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "0"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "0"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "0"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["X", "0"], "\<\"tt\"\>"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["X", "1"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "1"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "1"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "1"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["X", "1"], "\<\"tt\"\>"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["X", "2"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "2"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "2"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "2"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["X", "2"], "\<\"tt\"\>"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["X", "3"]}], "-", 
        SubscriptBox[
         SubscriptBox["X", "3"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "3"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["X", "3"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["X", "3"], "\<\"tt\"\>"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["Y", "0"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "0"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "0"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "0"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["Y", "0"], "\<\"tt\"\>"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["Y", "1"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "1"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "1"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "1"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["Y", "1"], "\<\"tt\"\>"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["Y", "2"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "2"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "2"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "2"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["Y", "2"], "\<\"tt\"\>"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         SubscriptBox["Y", "3"]}], "-", 
        SubscriptBox[
         SubscriptBox["Y", "3"], "\<\"zz\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "3"], "\<\"yy\"\>"], "-", 
        SubscriptBox[
         SubscriptBox["Y", "3"], "\<\"xx\"\>"], "+", 
        SubscriptBox[
         SubscriptBox["Y", "3"], "\<\"tt\"\>"]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.4. General algebras", "Subsubsection"],

Cell[TextData[{
 "The ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " table may contain unspecified parameters in the products. For example, the \
procedure ",
 StyleBox["generic[]", "Input",
  FontWeight->"Plain"],
 " constructs a completely general algebra for ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " using structure parameters ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["sy", 
     RowBox[{"i", ",", "j", ",", "k"}]], "Input"], TraditionalForm]]],
 " which are symmetric in the {j,k} indices and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["sk", 
     RowBox[{"i", ",", "j", ",", "k"}]], "Input"], TraditionalForm]]],
 "which are skew-symmetric in {j,k}. The indices {i,j,k} start at (0,1,1) \
with 0 denoting the \"identity\" element. Only the independent parameters \
with j \[LessEqual] k are defined. The algebra can be established by:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makealgebra", "[", 
  RowBox[{"generic", "[", "]"}], "]"}]], "Input"],

Cell[TextData[{
 "and so with the present ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " constructs the lists ",
 StyleBox["symm", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["skew", "Input",
  FontWeight->"Plain"],
 " and the generic algebra"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "                                              ",
 Cell[BoxData[
  FormBox[
   RowBox[{"      ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Sigma]", "j"],
      TraditionalForm], 
     SubscriptBox["\[Sigma]", "k"]}]}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["\[CapitalSigma]", "i"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"  ", 
     FormBox[
      RowBox[{
       FormBox[
        RowBox[{"(", " ", 
         SubscriptBox["sy", 
          RowBox[{"i", ",", "j", ",", "k"}]]}],
        TraditionalForm], "+", 
       SubscriptBox["sk", 
        RowBox[{"i", ",", "j", ",", "k"}]]}],
      TraditionalForm], ")"}], 
    SubscriptBox["\[Sigma]", "i"]}], TraditionalForm]]],
 "                     "
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["symm"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["sy", 
    RowBox[{"0", ",", "1", ",", "1"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"0", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"0", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"0", ",", "2", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"0", ",", "2", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"0", ",", "3", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"1", ",", "1", ",", "1"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"1", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"1", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"1", ",", "2", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"1", ",", "2", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"1", ",", "3", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"2", ",", "1", ",", "1"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"2", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"2", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"2", ",", "2", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"2", ",", "2", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"2", ",", "3", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"3", ",", "1", ",", "1"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"3", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"3", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"3", ",", "2", ",", "2"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"3", ",", "2", ",", "3"}]], ",", 
   SubscriptBox["sy", 
    RowBox[{"3", ",", "3", ",", "3"}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["skew"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["sk", 
    RowBox[{"0", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"0", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"0", ",", "2", ",", "3"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"1", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"1", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"1", ",", "2", ",", "3"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"2", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"2", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"2", ",", "2", ",", "3"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"3", ",", "1", ",", "2"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"3", ",", "1", ",", "3"}]], ",", 
   SubscriptBox["sk", 
    RowBox[{"3", ",", "2", ",", "3"}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Sigma]", "0"], 
      SubscriptBox["\[Sigma]", "1"], 
      SubscriptBox["\[Sigma]", "2"], 
      SubscriptBox["\[Sigma]", "3"]},
     {
      SubscriptBox["\[Sigma]", "1"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        SubscriptBox["sy", 
         RowBox[{"0", ",", "1", ",", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        SubscriptBox["sy", 
         RowBox[{"1", ",", "1", ",", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        SubscriptBox["sy", 
         RowBox[{"2", ",", "1", ",", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        SubscriptBox["sy", 
         RowBox[{"3", ",", "1", ",", "1"}]]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"0", ",", "1", ",", "2"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"0", ",", "1", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"1", ",", "1", ",", "2"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"1", ",", "1", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"2", ",", "1", ",", "2"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"2", ",", "1", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"3", ",", "1", ",", "2"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"3", ",", "1", ",", "2"}]]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"0", ",", "1", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"0", ",", "1", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"1", ",", "1", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"1", ",", "1", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"2", ",", "1", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"2", ",", "1", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"3", ",", "1", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"3", ",", "1", ",", "3"}]]}], ")"}]}]}]},
     {
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"0", ",", "1", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"1", ",", "1", ",", "2"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"1", ",", "1", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"2", ",", "1", ",", "2"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"2", ",", "1", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"3", ",", "1", ",", "2"}]]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        SubscriptBox["sy", 
         RowBox[{"0", ",", "2", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        SubscriptBox["sy", 
         RowBox[{"1", ",", "2", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        SubscriptBox["sy", 
         RowBox[{"2", ",", "2", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        SubscriptBox["sy", 
         RowBox[{"3", ",", "2", ",", "2"}]]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"0", ",", "2", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"0", ",", "2", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"1", ",", "2", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"1", ",", "2", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"2", ",", "2", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"2", ",", "2", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["sk", 
           RowBox[{"3", ",", "2", ",", "3"}]], "+", 
          SubscriptBox["sy", 
           RowBox[{"3", ",", "2", ",", "3"}]]}], ")"}]}]}]},
     {
      SubscriptBox["\[Sigma]", "3"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"0", ",", "1", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"0", ",", "1", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"1", ",", "1", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"1", ",", "1", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"2", ",", "1", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"2", ",", "1", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"3", ",", "1", ",", "3"}]]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"0", ",", "2", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"0", ",", "2", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"1", ",", "2", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"1", ",", "2", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"2", ",", "2", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"2", ",", "2", ",", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["sk", 
            RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
          SubscriptBox["sy", 
           RowBox[{"3", ",", "2", ",", "3"}]]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], " ", 
        SubscriptBox["sy", 
         RowBox[{"0", ",", "3", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], " ", 
        SubscriptBox["sy", 
         RowBox[{"1", ",", "3", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "2"], " ", 
        SubscriptBox["sy", 
         RowBox[{"2", ",", "3", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Sigma]", "3"], " ", 
        SubscriptBox["sy", 
         RowBox[{"3", ",", "3", ",", "3"}]]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Either ",
 StyleBox["Expand", "Input",
  FontWeight->"Plain"],
 " or ",
 StyleBox["collect", "Input",
  FontWeight->"Plain"],
 " can be used to obtain appropriate cancellations here;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"commutator", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], "**", 
     SubscriptBox["\[Sigma]", "2"]}], "-", 
    RowBox[{
     SubscriptBox["\[Sigma]", "2"], "**", 
     SubscriptBox["\[Sigma]", "1"]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["sk", 
    RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["sk", 
    RowBox[{"1", ",", "1", ",", "2"}]]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["sk", 
    RowBox[{"2", ",", "1", ",", "2"}]]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["sk", 
    RowBox[{"3", ",", "1", ",", "2"}]]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"anticommutator", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], "**", 
     SubscriptBox["\[Sigma]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["\[Sigma]", "2"], "**", 
     SubscriptBox["\[Sigma]", "1"]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["sy", 
    RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "1"], " ", 
   SubscriptBox["sy", 
    RowBox[{"1", ",", "1", ",", "2"}]]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "2"], " ", 
   SubscriptBox["sy", 
    RowBox[{"2", ",", "1", ",", "2"}]]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Sigma]", "3"], " ", 
   SubscriptBox["sy", 
    RowBox[{"3", ",", "1", ",", "2"}]]}]}]], "Output"]
}, Open  ]],

Cell["The arbitrary algebra is non-associative,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], "**", 
      SubscriptBox["\[Sigma]", "2"]}], ")"}], "**", 
    SubscriptBox["\[Sigma]", "1"]}], "-", 
   RowBox[{
    SubscriptBox["\[Sigma]", "1"], "**", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Sigma]", "2"], "**", 
      SubscriptBox["\[Sigma]", "1"]}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "3"}]]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "1", ",", "3"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "2"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "3"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "2"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "3"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "2"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "2"}]]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "3"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "2"}]], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "3"}]]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["generic[]", "Input",
  FontWeight->"Plain"],
 " product of ",
 StyleBox["q1", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["q2", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"q1", "**", "q2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "0"]}], "-", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "1", ",", "2"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "1", ",", "3"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"0", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "2", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"0", ",", "3", ",", "3"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "0"]}], "+", 
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "1"]}], "-", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"1", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "2", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"1", ",", "3", ",", "3"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "0"]}], "+", 
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "2"]}], "-", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"2", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "2", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"2", ",", "3", ",", "3"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "0"]}], "+", 
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "3"]}], "-", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "2"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "1", ",", "3"}]]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sk", 
       RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "2", ",", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "3"], " ", 
      SubscriptBox["sy", 
       RowBox[{"3", ",", "3", ",", "3"}]]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "One application of ",
 StyleBox["generic[]", "Input",
  FontWeight->"Plain"],
 " is simply to solve for the structure constants of a given algebra table. \
The subroutine, ",
 StyleBox["structure[]", "Input",
  FontWeight->"Plain"],
 ", gives the solution:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"structure", "[", "arg_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"diff", ",", "eqns"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"makealgebra", "[", 
       RowBox[{"generic", "[", "]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"diff", "=", 
       RowBox[{"collect", "[", 
        RowBox[{"arg", "-", "algebra"}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"eqns", "=", 
       RowBox[{"setzero", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Map", "[", 
          RowBox[{"coeffs", ",", 
           RowBox[{"Flatten", "[", "diff", "]"}]}], "]"}], "]"}], "]"}]}], 
      ";", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{"eqns", ",", 
         RowBox[{"Join", "[", 
          RowBox[{"skew", ",", "symm"}], "]"}]}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"],

Cell["For H,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"constants", "=", 
  RowBox[{"structure", "[", "H", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"0", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"0", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"0", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "1"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "1"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sk", 
     RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"0", ",", "1", ",", "1"}]], "\[Rule]", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"0", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"0", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"0", ",", "2", ",", "2"}]], "\[Rule]", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"0", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"0", ",", "3", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"1", ",", "1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"1", ",", "2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"1", ",", "3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"2", ",", "1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"2", ",", "2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"2", ",", "3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"3", ",", "1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"3", ",", "2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["sy", 
     RowBox[{"3", ",", "3", ",", "3"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["The quaternion product can be recovered by,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   RowBox[{"q1", "**", "q2"}], "/.", "constants"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "0"]}], "-", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "1"]}], "-", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "2"]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "3"]}]}], ")"}], " ", 
   SubscriptBox["\[Sigma]", "0"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "0"]}], "+", 
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "1"]}], "-", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "2"]}], "+", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "3"]}]}], ")"}], " ", 
   SubscriptBox["\[Sigma]", "1"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "0"]}], "+", 
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "1"]}], "+", 
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "2"]}], "-", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "3"]}]}], ")"}], " ", 
   SubscriptBox["\[Sigma]", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "3"], " ", 
      SubscriptBox["Y", "0"]}], "-", 
     RowBox[{
      SubscriptBox["X", "2"], " ", 
      SubscriptBox["Y", "1"]}], "+", 
     RowBox[{
      SubscriptBox["X", "1"], " ", 
      SubscriptBox["Y", "2"]}], "+", 
     RowBox[{
      SubscriptBox["X", "0"], " ", 
      SubscriptBox["Y", "3"]}]}], ")"}], " ", 
   SubscriptBox["\[Sigma]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and H is restored as the active ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " by replacing the constants in the current generic algebra,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makealgebra", "[", 
  RowBox[{"algebra", "/.", "constants"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Sigma]", "0"], 
      SubscriptBox["\[Sigma]", "1"], 
      SubscriptBox["\[Sigma]", "2"], 
      SubscriptBox["\[Sigma]", "3"]},
     {
      SubscriptBox["\[Sigma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "2"]}]},
     {
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}], 
      SubscriptBox["\[Sigma]", "1"]},
     {
      SubscriptBox["\[Sigma]", "3"], 
      SubscriptBox["\[Sigma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
The generic algebra may not be of much use beyond demonstrating generality; \
i.e., one can use p-form AVFs defined over: Clifford, Lie, and Jordan \
algebras, other non-associative(e.g., octonion) algebras, gauge group \
algebras, and superalgebras.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"symm", ",", "skew"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.5. Derived algebras", "Subsubsection"],

Cell[TextData[{
 "The non-associative derived algebras, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "-"], TraditionalForm]]],
 "  and  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "+"], TraditionalForm]]],
 ", for AVFs may also be defined: (",
 ButtonBox["see Okubo, p.19",
  BaseStyle->"Hyperlink",
  ButtonData:>"reference"],
 "). In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", they can be easily input using the following two infix operators:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell["The commutator function for AVFs, typed by esc- c- -esc;", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CircleMinus", "[", 
   RowBox[{"arg1_", ",", "arg2_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"arg1", "**", 
    RowBox[{"(", 
     RowBox[{"arg2", "/", "2"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"arg2", "/", "2"}], ")"}], "**", "arg1"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "q1", "]"}], "\[CircleMinus]", 
  RowBox[{"d", "[", "q2", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["dX", "0"], "\[Wedge]", 
   SubscriptBox["dY", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["dX", "0"], "\[Wedge]", 
    SubscriptBox["dY", "1"]}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{
    SubscriptBox["dX", "0"], "\[Wedge]", 
    SubscriptBox["dY", "2"]}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["dX", "0"], "\[Wedge]", 
    SubscriptBox["dY", "3"]}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["dX", "1"], "\[Wedge]", 
    SubscriptBox["dY", "0"]}]}], "-", 
  RowBox[{
   SubscriptBox["dX", "1"], "\[Wedge]", 
   SubscriptBox["dY", "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{
    SubscriptBox["dX", "2"], "\[Wedge]", 
    SubscriptBox["dY", "0"]}]}], "-", 
  RowBox[{
   SubscriptBox["dX", "2"], "\[Wedge]", 
   SubscriptBox["dY", "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["dX", "3"], "\[Wedge]", 
    SubscriptBox["dY", "0"]}]}], "-", 
  RowBox[{
   SubscriptBox["dX", "3"], "\[Wedge]", 
   SubscriptBox["dY", "3"]}]}]], "Output"]
}, Open  ]],

Cell["\<\
The anti-commutator function for AVFs, typed by esc- c+ -esc;\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CirclePlus", "[", 
   RowBox[{"arg1_", ",", "arg2_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"arg1", "**", 
    RowBox[{"(", 
     RowBox[{"arg2", "/", "2"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"arg2", "/", "2"}], ")"}], "**", "arg1"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "q1", "]"}], "\[CirclePlus]", 
  RowBox[{"d", "[", "q2", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["dX", "1"], "\[Wedge]", 
    SubscriptBox["dY", "2"]}]}], "-", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{
    SubscriptBox["dX", "1"], "\[Wedge]", 
    SubscriptBox["dY", "3"]}]}], "-", 
  RowBox[{
   SubscriptBox["\[Sigma]", "3"], " ", 
   RowBox[{
    SubscriptBox["dX", "2"], "\[Wedge]", 
    SubscriptBox["dY", "1"]}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["dX", "2"], "\[Wedge]", 
    SubscriptBox["dY", "3"]}]}], "+", 
  RowBox[{
   SubscriptBox["\[Sigma]", "2"], " ", 
   RowBox[{
    SubscriptBox["dX", "3"], "\[Wedge]", 
    SubscriptBox["dY", "1"]}]}], "-", 
  RowBox[{
   SubscriptBox["\[Sigma]", "1"], " ", 
   RowBox[{
    SubscriptBox["dX", "3"], "\[Wedge]", 
    SubscriptBox["dY", "2"]}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "For an associative underlying algebra, such as H , operator \[CircleMinus] \
defines a Lie-algebra, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "-"], TraditionalForm]]],
 ", over AVFs with the Jacobi identity,"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "q1", "]"}], "\[CircleMinus]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q2", "]"}], "\[CircleMinus]", "q3"}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"d", "[", "q2", "]"}], "\[CircleMinus]", 
   RowBox[{"(", 
    RowBox[{"q3", "\[CircleMinus]", 
     RowBox[{"d", "[", "q1", "]"}]}], ")"}]}], "+", 
  RowBox[{"q3", "\[CircleMinus]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q1", "]"}], "\[CircleMinus]", 
     RowBox[{"d", "[", "q2", "]"}]}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the \[CirclePlus] operator gives a special Jordan algebra, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "+"], TraditionalForm]]],
 ", satisfying the Jordan identity,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", "q1", "]"}], "**", 
       RowBox[{"d", "[", "q1", "]"}]}], ")"}], "\[CirclePlus]", "q3"}], ")"}],
    "\[CirclePlus]", 
   RowBox[{"d", "[", "q1", "]"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q1", "]"}], "**", 
     RowBox[{"d", "[", "q1", "]"}]}], ")"}], "\[CirclePlus]", 
   RowBox[{"(", 
    RowBox[{"q3", "\[CirclePlus]", 
     RowBox[{"d", "[", "q1", "]"}]}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
The following joint identity also holds in the underlying associative case, \
as well as in some special non-associative cases,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "q1", "]"}], "\[CircleMinus]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q2", "]"}], "\[CirclePlus]", "q3"}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q1", "]"}], "\[CircleMinus]", 
     RowBox[{"d", "[", "q2", "]"}]}], ")"}], "\[CirclePlus]", "q3"}], "-", 
  RowBox[{
   RowBox[{"d", "[", "q2", "]"}], "\[CirclePlus]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q1", "]"}], "\[CircleMinus]", "q3"}], 
    ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
and that expression implies the cyclic super-Jacobi identity,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "q1", "]"}], "\[CircleMinus]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q2", "]"}], "\[CirclePlus]", "q3"}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"d", "[", "q2", "]"}], "\[CircleMinus]", 
   RowBox[{"(", 
    RowBox[{"q3", "\[CirclePlus]", 
     RowBox[{"d", "[", "q1", "]"}]}], ")"}]}], "+", 
  RowBox[{"q3", "\[CircleMinus]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "q1", "]"}], "\[CirclePlus]", 
     RowBox[{"d", "[", "q2", "]"}]}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "These operations are not supplied in ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " as reserved functions, but can be introduced as above."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.6. Generating a Lie algebra", "Subsubsection",
 PageBreakAbove->True],

Cell[TextData[{
 "We start with the associative Clifford algebra, ",
 StyleBox["signature={-1,1,1,1}", "Input",
  FontWeight->"Plain"],
 ", but with the algebra table truncated to grade(2) products;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makeclifford", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}], ",", "2"}], 
  "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Gamma]", "0"], ",", 
   SubscriptBox["\[Gamma]", "1"], ",", 
   SubscriptBox["\[Gamma]", "2"], ",", 
   SubscriptBox["\[Gamma]", "3"], ",", 
   SubscriptBox["\[Gamma]", "4"], ",", 
   SubscriptBox["\[Gamma]", "12"], ",", 
   SubscriptBox["\[Gamma]", "13"], ",", 
   SubscriptBox["\[Gamma]", "14"], ",", 
   SubscriptBox["\[Gamma]", "23"], ",", 
   SubscriptBox["\[Gamma]", "24"], ",", 
   SubscriptBox["\[Gamma]", "34"], ",", 
   SubscriptBox["\[Gamma]", "15"], ",", 
   SubscriptBox["\[Gamma]", "25"], ",", 
   SubscriptBox["\[Gamma]", "35"], ",", 
   SubscriptBox["\[Gamma]", "45"], ",", 
   SubscriptBox["\[Gamma]", "5"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The full ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " list must be retained, since they all appear in ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 ", though products of grades higher than grade(2) cannot be performed."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "1"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "34"]},
     {
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}]},
     {
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "45"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}]},
     {
      SubscriptBox["\[Gamma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "4"]},
     {
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}]},
     {
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "35"], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "5"]},
     {
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "45"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "14"]},
     {
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}]},
     {
      SubscriptBox["\[Gamma]", "23"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "24"]},
     {
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}]},
     {
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      SubscriptBox["\[Gamma]", "13"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      SubscriptBox["\[Gamma]", "23"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The table of commutator products for the truncated ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " is given by"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"liealg", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"algebra", "-", 
      RowBox[{"Transpose", "[", "algebra", "]"}]}], ")"}], "/", "2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"mtx", "[", "liealg", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], "0", 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], "0", "0", 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], "0"},
     {"0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], "0", 
      SubscriptBox["\[Gamma]", "34"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], "0", 
      SubscriptBox["\[Gamma]", "4"]},
     {"0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], "0", "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}]},
     {"0", 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "1"], "0", "0", "0", 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], "0"},
     {"0", 
      SubscriptBox["\[Gamma]", "3"], "0", 
      SubscriptBox["\[Gamma]", "1"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], "0", 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], "0", 
      SubscriptBox["\[Gamma]", "14"]},
     {"0", 
      SubscriptBox["\[Gamma]", "4"], "0", "0", 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}]},
     {"0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "2"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      SubscriptBox["\[Gamma]", "12"], "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "24"]},
     {"0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], "0", 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], "0", 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "34"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}]},
     {"0", "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "3"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      SubscriptBox["\[Gamma]", "13"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      SubscriptBox["\[Gamma]", "23"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and this closed 10-dimensional Lie algebra, isomorphic to so(3,2), can be \
the established ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "Some remarks are necessary here:\n\nThe Lie algebras are among those that \
do not include an ",
 StyleBox["identity", "Input",
  FontWeight->"Plain"],
 " element. However, ",
 StyleBox["identity", "Input",
  FontWeight->"Plain"],
 " serves as an essential placeholder in many ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " calculations, so the fundamental list ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " ",
 StyleBox["must always",
  FontVariations->{"Underline"->True}],
 " include an initial member to ",
 StyleBox["act",
  FontVariations->{"Underline"->True}],
 " as the ",
 StyleBox["identity", "Input",
  FontWeight->"Plain"],
 " element. If the algebra does not include an ",
 StyleBox["identity", "Input",
  FontWeight->"Plain"],
 ", it must be supplied as the first member of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " and to preserve its \"unital\" action, the top row and left column of ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " must equal ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " (or a truncated portion thereof).\n\nSince this is essential for correct \
operation of the program, the ",
 StyleBox["makealgebra[]", "Input",
  FontWeight->"Plain"],
 " command will always modify any multiplication table (supplied as its \
argument) so that this requirement is met; i.e., the top row and left column \
will be changed to ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " before being assigned to ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 ". If the algebra includes the ",
 StyleBox["identity", "Input",
  FontWeight->"Plain"],
 " in the first member of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 ", this actually leaves it unchanged. If there is no identity element, a \
symbol for it may be entered as the second (optional) argument of ",
 StyleBox["makealgebra", "Input",
  FontWeight->"Plain"],
 " to become a new element in the first position of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 ". The multiplication table entered in the mandatory first argument will \
appear unchanged, except for having the new ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " list prepended as the first row and column of ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 ". Products with the spurious ",
 StyleBox["identity", "Input",
  FontWeight->"Plain"],
 " will not conform to the algebra, but products of all other elements (which \
do belong to the algebra) will be unchanged. The new row and column can be \
considered just as convenient headers for the others."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell["For example,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makealgebra", "[", 
  RowBox[{"liealg", ",", "e"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"e", 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "1"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "34"]},
     {
      SubscriptBox["\[Gamma]", "0"], "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0"},
     {
      SubscriptBox["\[Gamma]", "1"], "0", "0", 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], "0", "0", "0"},
     {
      SubscriptBox["\[Gamma]", "2"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], "0", 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], "0", "0", 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], "0"},
     {
      SubscriptBox["\[Gamma]", "3"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], "0", 
      SubscriptBox["\[Gamma]", "34"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], "0", 
      SubscriptBox["\[Gamma]", "4"]},
     {
      SubscriptBox["\[Gamma]", "4"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], "0", "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}]},
     {
      SubscriptBox["\[Gamma]", "12"], "0", 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "1"], "0", "0", "0", 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], "0"},
     {
      SubscriptBox["\[Gamma]", "13"], "0", 
      SubscriptBox["\[Gamma]", "3"], "0", 
      SubscriptBox["\[Gamma]", "1"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], "0", 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], "0", 
      SubscriptBox["\[Gamma]", "14"]},
     {
      SubscriptBox["\[Gamma]", "14"], "0", 
      SubscriptBox["\[Gamma]", "4"], "0", "0", 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}]},
     {
      SubscriptBox["\[Gamma]", "23"], "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "2"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      SubscriptBox["\[Gamma]", "12"], "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "24"]},
     {
      SubscriptBox["\[Gamma]", "24"], "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], "0", 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], "0", 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "34"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}]},
     {
      SubscriptBox["\[Gamma]", "34"], "0", "0", "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "3"], "0", 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      SubscriptBox["\[Gamma]", "13"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      SubscriptBox["\[Gamma]", "23"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["and the full list of elements is still retained,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"e", ",", 
   SubscriptBox["\[Gamma]", "0"], ",", 
   SubscriptBox["\[Gamma]", "1"], ",", 
   SubscriptBox["\[Gamma]", "2"], ",", 
   SubscriptBox["\[Gamma]", "3"], ",", 
   SubscriptBox["\[Gamma]", "4"], ",", 
   SubscriptBox["\[Gamma]", "12"], ",", 
   SubscriptBox["\[Gamma]", "13"], ",", 
   SubscriptBox["\[Gamma]", "14"], ",", 
   SubscriptBox["\[Gamma]", "23"], ",", 
   SubscriptBox["\[Gamma]", "24"], ",", 
   SubscriptBox["\[Gamma]", "34"], ",", 
   SubscriptBox["\[Gamma]", "15"], ",", 
   SubscriptBox["\[Gamma]", "25"], ",", 
   SubscriptBox["\[Gamma]", "35"], ",", 
   SubscriptBox["\[Gamma]", "45"], ",", 
   SubscriptBox["\[Gamma]", "5"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Basic ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " multiplication, ** , now gives the non-associative Lie product for all \
Lie-algebra-valued forms, which in standard notation is written as a bracket. \
The CAV defined 1-form, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " , becomes a Lie-algebra-valued gauge potential,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 OverscriptBox["\[Omega]", "^"]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["\[Omega]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "34"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "where the expansion of the Lie bracket [",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " ,",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    OverscriptBox["\[Omega]", "^"]}], TraditionalForm]]],
 "] is given directly by,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "**", 
   OverscriptBox["\[Omega]", "^"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "14"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "24"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "12"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "13"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "14"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "12"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "23"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "24"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "13"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "23"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "4"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "24"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "2"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "23"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "24"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "3"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "23"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "4"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "14"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "24"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "4"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "14"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "1"], "3"]}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "13"]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "All the Jacobi identities of the structure constants of this Lie algebra \
are involved in the triple self-product of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " , regardless of parentheses;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["\[Omega]", "^"], "**", 
     OverscriptBox["\[Omega]", "^"]}], ")"}], "**", 
   OverscriptBox["\[Omega]", "^"]}], "==", 
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "**", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["\[Omega]", "^"], "**", 
     OverscriptBox["\[Omega]", "^"]}], ")"}]}], "==", 
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "**", 
   OverscriptBox["\[Omega]", "^"], "**", 
   OverscriptBox["\[Omega]", "^"]}], "==", "0"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The AVF form of the Yang-Mills equation includes the grades(0,1,2) \
curvature fields, ",
 StyleBox["F", "Input",
  FontWeight->"Plain"],
 ", for the gauge potential, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " ,"
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "=", 
  RowBox[{"collect", "[", 
   RowBox[{
    RowBox[{"d", "[", 
     OverscriptBox["\[Omega]", "^"], "]"}], "+", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Omega]", "^"], "**", 
      OverscriptBox["\[Omega]", "^"]}], "/", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["d\[Omega]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "4"], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "1"], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "2"], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "3"], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "14"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "12"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "13"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "34"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "24"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "23"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
In the Clifford algebra, the curvature identity is expressed by,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "F", "]"}], "+", 
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "**", 
   RowBox[{"(", 
    RowBox[{"F", "/", "2"}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"F", "/", "2"}], ")"}], "**", 
   OverscriptBox["\[Omega]", "^"]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "but in the Lie algebra, AVF 1-forms and 2-forms anti-commute and the Jacobi \
identities annul the triple ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " product, so the curvature identity simplifies to,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "F", "]"}], "+", 
   RowBox[{
    OverscriptBox["\[Omega]", "^"], "**", "F"}]}], "==", 
  RowBox[{
   RowBox[{"d", "[", "F", "]"}], "-", 
   RowBox[{"F", "**", 
    OverscriptBox["\[Omega]", "^"]}]}], "==", "0"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.7. The non-associative octonions algebra", "Subsubsection",
 PageBreakAbove->True],

Cell[TextData[{
 "Introduce a new ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " list,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"octonionbasis", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["e", "0"], ",", 
     SubscriptBox["e", "1"], ",", 
     SubscriptBox["e", "2"], ",", 
     SubscriptBox["e", "3"], ",", 
     SubscriptBox["e", "4"], ",", 
     SubscriptBox["e", "5"], ",", 
     SubscriptBox["e", "6"], ",", 
     SubscriptBox["e", "7"]}], "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeelements", "[", "octonionbasis", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["e", "0"], ",", 
   SubscriptBox["e", "1"], ",", 
   SubscriptBox["e", "2"], ",", 
   SubscriptBox["e", "3"], ",", 
   SubscriptBox["e", "4"], ",", 
   SubscriptBox["e", "5"], ",", 
   SubscriptBox["e", "6"], ",", 
   SubscriptBox["e", "7"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A particular representation, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["C", "+"], ","}], " "}], TraditionalForm]]],
 "of the octonion multiplication table is:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"octoniontable", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "0"], ",", 
       SubscriptBox["e", "1"], ",", 
       SubscriptBox["e", "2"], ",", 
       SubscriptBox["e", "3"], ",", 
       SubscriptBox["e", "4"], ",", 
       SubscriptBox["e", "5"], ",", 
       SubscriptBox["e", "6"], ",", 
       SubscriptBox["e", "7"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "1"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "0"]}], ",", 
       SubscriptBox["e", "4"], ",", 
       SubscriptBox["e", "7"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "2"]}], ",", 
       SubscriptBox["e", "6"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "5"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "3"]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "4"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "0"]}], ",", 
       SubscriptBox["e", "5"], ",", 
       SubscriptBox["e", "1"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "3"]}], ",", 
       SubscriptBox["e", "7"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "6"]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "3"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "7"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "5"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "0"]}], ",", 
       SubscriptBox["e", "6"], ",", 
       SubscriptBox["e", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "4"]}], ",", 
       SubscriptBox["e", "1"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "4"], ",", 
       SubscriptBox["e", "2"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "1"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "6"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "0"]}], ",", 
       SubscriptBox["e", "7"], ",", 
       SubscriptBox["e", "3"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "5"]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "5"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "6"]}], ",", 
       SubscriptBox["e", "3"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "2"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "7"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "0"]}], ",", 
       SubscriptBox["e", "1"], ",", 
       SubscriptBox["e", "4"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "6"], ",", 
       SubscriptBox["e", "5"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "7"]}], ",", 
       SubscriptBox["e", "4"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "3"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "1"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "0"]}], ",", 
       SubscriptBox["e", "2"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["e", "7"], ",", 
       SubscriptBox["e", "3"], ",", 
       SubscriptBox["e", "6"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "1"]}], ",", 
       SubscriptBox["e", "5"], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "4"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "2"]}], ",", 
       RowBox[{"-", 
        SubscriptBox["e", "0"]}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"makealgebra", "[", "octoniontable", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["e", "0"], 
      SubscriptBox["e", "1"], 
      SubscriptBox["e", "2"], 
      SubscriptBox["e", "3"], 
      SubscriptBox["e", "4"], 
      SubscriptBox["e", "5"], 
      SubscriptBox["e", "6"], 
      SubscriptBox["e", "7"]},
     {
      SubscriptBox["e", "1"], 
      RowBox[{"-", 
       SubscriptBox["e", "0"]}], 
      SubscriptBox["e", "4"], 
      SubscriptBox["e", "7"], 
      RowBox[{"-", 
       SubscriptBox["e", "2"]}], 
      SubscriptBox["e", "6"], 
      RowBox[{"-", 
       SubscriptBox["e", "5"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "3"]}]},
     {
      SubscriptBox["e", "2"], 
      RowBox[{"-", 
       SubscriptBox["e", "4"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "0"]}], 
      SubscriptBox["e", "5"], 
      SubscriptBox["e", "1"], 
      RowBox[{"-", 
       SubscriptBox["e", "3"]}], 
      SubscriptBox["e", "7"], 
      RowBox[{"-", 
       SubscriptBox["e", "6"]}]},
     {
      SubscriptBox["e", "3"], 
      RowBox[{"-", 
       SubscriptBox["e", "7"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "5"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "0"]}], 
      SubscriptBox["e", "6"], 
      SubscriptBox["e", "2"], 
      RowBox[{"-", 
       SubscriptBox["e", "4"]}], 
      SubscriptBox["e", "1"]},
     {
      SubscriptBox["e", "4"], 
      SubscriptBox["e", "2"], 
      RowBox[{"-", 
       SubscriptBox["e", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "6"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "0"]}], 
      SubscriptBox["e", "7"], 
      SubscriptBox["e", "3"], 
      RowBox[{"-", 
       SubscriptBox["e", "5"]}]},
     {
      SubscriptBox["e", "5"], 
      RowBox[{"-", 
       SubscriptBox["e", "6"]}], 
      SubscriptBox["e", "3"], 
      RowBox[{"-", 
       SubscriptBox["e", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "7"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "0"]}], 
      SubscriptBox["e", "1"], 
      SubscriptBox["e", "4"]},
     {
      SubscriptBox["e", "6"], 
      SubscriptBox["e", "5"], 
      RowBox[{"-", 
       SubscriptBox["e", "7"]}], 
      SubscriptBox["e", "4"], 
      RowBox[{"-", 
       SubscriptBox["e", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "0"]}], 
      SubscriptBox["e", "2"]},
     {
      SubscriptBox["e", "7"], 
      SubscriptBox["e", "3"], 
      SubscriptBox["e", "6"], 
      RowBox[{"-", 
       SubscriptBox["e", "1"]}], 
      SubscriptBox["e", "5"], 
      RowBox[{"-", 
       SubscriptBox["e", "4"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["e", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["associators[n]", "Input",
  FontWeight->"Plain"],
 " searches the algebra table for non-associative triple products and prints \
the first ",
 StyleBox["n", "Input",
  FontWeight->"Plain"],
 " it finds. If fewer than ",
 StyleBox["n", "Input",
  FontWeight->"Plain"],
 " are present, it prints ",
 StyleBox["Done", "Input",
  FontWeight->"Plain"],
 " and the number actually found, but in that case it could take a long time \
to search a high-dimension algebra."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"associators", "[", "9", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubscriptBox["e", "6"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 2], ")", 
   Subscript[$CellContext`e, 3], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 2], "", 
   Subscript[$CellContext`e, 3], ") = ", (-2) Subscript[$CellContext`e, 6]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "5"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "5"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"2", " ", 
    SubscriptBox["e", "7"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 2], ")", 
   Subscript[$CellContext`e, 5], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 2], "", 
   Subscript[$CellContext`e, 5], ") = ", 2 Subscript[$CellContext`e, 7]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "6"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "6"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"2", " ", 
    SubscriptBox["e", "3"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 2], ")", 
   Subscript[$CellContext`e, 6], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 2], "", 
   Subscript[$CellContext`e, 6], ") = ", 2 Subscript[$CellContext`e, 3]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "7"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "7"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubscriptBox["e", "5"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 2], ")", 
   Subscript[$CellContext`e, 7], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 2], "", 
   Subscript[$CellContext`e, 7], ") = ", (-2) Subscript[$CellContext`e, 5]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "2"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"2", " ", 
    SubscriptBox["e", "6"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 3], ")", 
   Subscript[$CellContext`e, 2], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 3], "", 
   Subscript[$CellContext`e, 2], ") = ", 2 Subscript[$CellContext`e, 6]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "4"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "4"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"2", " ", 
    SubscriptBox["e", "5"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 3], ")", 
   Subscript[$CellContext`e, 4], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 3], "", 
   Subscript[$CellContext`e, 4], ") = ", 2 Subscript[$CellContext`e, 5]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "5"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "5"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubscriptBox["e", "4"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 3], ")", 
   Subscript[$CellContext`e, 5], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 3], "", 
   Subscript[$CellContext`e, 5], ") = ", (-2) Subscript[$CellContext`e, 4]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "6"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "6"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubscriptBox["e", "2"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 3], ")", 
   Subscript[$CellContext`e, 6], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 3], "", 
   Subscript[$CellContext`e, 6], ") = ", (-2) Subscript[$CellContext`e, 2]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"(\"\>", "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "4"], "\[InvisibleSpace]", "\<\")\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\" - \"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "1"], "\[InvisibleSpace]", "\<\"(\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "4"], "\[InvisibleSpace]", "\<\"\"\>", 
   "\[InvisibleSpace]", 
   SubscriptBox["e", "3"], "\[InvisibleSpace]", "\<\") = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubscriptBox["e", "5"]}]}],
  SequenceForm["(", 
   Subscript[$CellContext`e, 1], "", 
   Subscript[$CellContext`e, 4], ")", 
   Subscript[$CellContext`e, 3], " - ", 
   Subscript[$CellContext`e, 1], "(", 
   Subscript[$CellContext`e, 4], "", 
   Subscript[$CellContext`e, 3], ") = ", (-2) Subscript[$CellContext`e, 5]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Done. Found:\"\>", "\[InvisibleSpace]", "9"}],
  SequenceForm["Done. Found:", 9],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The absence of the triple ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["e", "1"], ",", 
     SubscriptBox["e", "2"], ",", 
     SubscriptBox["e", "4"]}], "}"}], TraditionalForm]]],
 " implies that this is an associative quaternion subalgebra; i.e.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["e", "1"], "**", 
     SubscriptBox["e", "2"]}], ")"}], "**", 
   SubscriptBox["e", "4"]}], "-", 
  RowBox[{
   SubscriptBox["e", "1"], "**", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["e", "2"], "**", 
     SubscriptBox["e", "4"]}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["e", "1"], ",", 
     SubscriptBox["e", "2"], ",", 
     SubscriptBox["e", "3"]}], "}"}], TraditionalForm]]],
 " do not associate, the 0-forms ",
 StyleBox["{q1,q2,q3}", "Input",
  FontWeight->"Plain"],
 " introduced at the start as quaternions, become truncated octonions by \
\[Sigma] \[Rule] e ,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"o1", "=", 
  RowBox[{"q1", "/.", 
   RowBox[{"\[Sigma]", "->", "e"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "0"], " ", 
   SubscriptBox["X", "0"]}], "+", 
  RowBox[{
   SubscriptBox["e", "1"], " ", 
   SubscriptBox["X", "1"]}], "+", 
  RowBox[{
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["X", "2"]}], "+", 
  RowBox[{
   SubscriptBox["e", "3"], " ", 
   SubscriptBox["X", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"o2", "=", 
  RowBox[{"q2", "/.", 
   RowBox[{"\[Sigma]", "->", "e"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "0"], " ", 
   SubscriptBox["Y", "0"]}], "+", 
  RowBox[{
   SubscriptBox["e", "1"], " ", 
   SubscriptBox["Y", "1"]}], "+", 
  RowBox[{
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["Y", "2"]}], "+", 
  RowBox[{
   SubscriptBox["e", "3"], " ", 
   SubscriptBox["Y", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"o3", "=", 
  RowBox[{"q3", "/.", 
   RowBox[{"\[Sigma]", "->", "e"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "0"], " ", 
   SubscriptBox["Z", "0"]}], "+", 
  RowBox[{
   SubscriptBox["e", "1"], " ", 
   SubscriptBox["Z", "1"]}], "+", 
  RowBox[{
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["Z", "2"]}], "+", 
  RowBox[{
   SubscriptBox["e", "3"], " ", 
   SubscriptBox["Z", "3"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and ",
 StyleBox["O1", "Input",
  FontWeight->"Plain"],
 " will be an octonion-valued 1-form,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"O1", "=", 
  RowBox[{"o1", "/.", 
   RowBox[{"X", "->", "\[Omega]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "0"], " ", 
   SubscriptBox["\[Omega]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["e", "1"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["e", "3"], " ", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "when ",
 StyleBox["makeforms", "Input",
  FontWeight->"Plain"],
 " is used,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeforms", "[", 
  RowBox[{"coeffs", "[", "O1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"], ",", 
   SubscriptBox["\[Omega]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
A special property of octonions guarantees that any two octonion 0-forms are \
associative; e.g.,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"o1", "**", "o2"}], ")"}], "**", "o1"}], "-", 
  RowBox[{"o1", "**", 
   RowBox[{"(", 
    RowBox[{"o2", "**", "o1"}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"o1", "**", "o2"}], ")"}], "**", "o2"}], "-", 
  RowBox[{"o1", "**", 
   RowBox[{"(", 
    RowBox[{"o2", "**", "o2"}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["For three independent octonions, associativity is lost,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"o1", "**", "o2"}], ")"}], "**", "o3"}], "-", 
   RowBox[{"o1", "**", 
    RowBox[{"(", 
     RowBox[{"o2", "**", "o3"}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["e", "6"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["X", "3"], " ", 
     SubscriptBox["Y", "2"], " ", 
     SubscriptBox["Z", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "2"], " ", 
     SubscriptBox["Y", "3"], " ", 
     SubscriptBox["Z", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "3"], " ", 
     SubscriptBox["Y", "1"], " ", 
     SubscriptBox["Z", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "1"], " ", 
     SubscriptBox["Y", "3"], " ", 
     SubscriptBox["Z", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "2"], " ", 
     SubscriptBox["Y", "1"], " ", 
     SubscriptBox["Z", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "1"], " ", 
     SubscriptBox["Y", "2"], " ", 
     SubscriptBox["Z", "3"]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell["\<\
but the \"flexible\" property is demonstrated by the opposite signs of the \
next expression,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"o3", "**", "o2"}], ")"}], "**", "o1"}], "-", 
   RowBox[{"o3", "**", 
    RowBox[{"(", 
     RowBox[{"o2", "**", "o1"}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["e", "6"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["X", "3"], " ", 
     SubscriptBox["Y", "2"], " ", 
     SubscriptBox["Z", "1"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "2"], " ", 
     SubscriptBox["Y", "3"], " ", 
     SubscriptBox["Z", "1"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "3"], " ", 
     SubscriptBox["Y", "1"], " ", 
     SubscriptBox["Z", "2"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "1"], " ", 
     SubscriptBox["Y", "3"], " ", 
     SubscriptBox["Z", "2"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "2"], " ", 
     SubscriptBox["Y", "1"], " ", 
     SubscriptBox["Z", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["X", "1"], " ", 
     SubscriptBox["Y", "2"], " ", 
     SubscriptBox["Z", "3"]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell["\<\
The above associative property does not hold in general for octonion-valued \
1-forms, which are not even triply power associative,\
\>", "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"O1", "**", "O1"}], ")"}], "**", "O1"}], "-", 
  RowBox[{"O1", "**", 
   RowBox[{"(", 
    RowBox[{"O1", "**", "O1"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "12"}], " ", 
  SubscriptBox["e", "6"], " ", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
   SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
   SubscriptBox["\[Omega]", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"O1", "**", "O1"}], ")"}], "**", "o1"}], "-", 
   RowBox[{"O1", "**", 
    RowBox[{"(", 
     RowBox[{"O1", "**", "o1"}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["e", "6"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SubscriptBox["X", "3"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "2"]}]}], "+", 
    RowBox[{"4", " ", 
     SubscriptBox["X", "2"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}], "-", 
    RowBox[{"4", " ", 
     SubscriptBox["X", "1"], " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox["\[Omega]", "3"]}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell["but with no exterior product involved,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"o1", "**", "O1"}], ")"}], "**", "o1"}], "-", 
  RowBox[{"o1", "**", 
   RowBox[{"(", 
    RowBox[{"O1", "**", "o1"}], ")"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.8. The exceptional Jordan algebra", "Subsubsection",
 PageBreakAbove->True],

Cell[TextData[{
 "All the finite Jordan algebras with one exception can be obtained from the \
symmetric derived algebras using \[CirclePlus] with associative underlying \
algebras. As mentioned in ",
 ButtonBox["Okubo's book (p.81)",
  BaseStyle->"Hyperlink",
  ButtonData:>"reference"],
 ", octonion-valued matrices provide a representation for the single 27-dim. \
exceptional Jordan algebra. For brevity, we shall use the truncated octonion \
triplet ",
 StyleBox["{o1,o2,o3}", "Input",
  FontWeight->"Plain"],
 ", their conjugates, and 3 additional diagonal elements, to write a reduced \
15-dim. example,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   OverscriptBox["o1", "_"], "=", 
   RowBox[{
    RowBox[{"-", "o1"}], "/.", 
    RowBox[{
     SubscriptBox["X", "0"], "->", 
     RowBox[{"-", 
      SubscriptBox["X", "0"]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   OverscriptBox["o2", "_"], "=", 
   RowBox[{
    RowBox[{"-", "o2"}], "/.", 
    RowBox[{
     SubscriptBox["Y", "0"], "->", 
     RowBox[{"-", 
      SubscriptBox["Y", "0"]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  OverscriptBox["o3", "_"], "=", 
  RowBox[{
   RowBox[{"-", "o3"}], "/.", 
   RowBox[{
    SubscriptBox["Z", "0"], "->", 
    RowBox[{"-", 
     SubscriptBox["Z", "0"]}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "0"], " ", 
   SubscriptBox["Z", "0"]}], "-", 
  RowBox[{
   SubscriptBox["e", "1"], " ", 
   SubscriptBox["Z", "1"]}], "-", 
  RowBox[{
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["Z", "2"]}], "-", 
  RowBox[{
   SubscriptBox["e", "3"], " ", 
   SubscriptBox["Z", "3"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The matrix ",
 StyleBox["J1", "Input",
  FontWeight->"Plain"],
 " then represents a truncated element of the exceptional Jordan algebra,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], 
       SubscriptBox["e", "0"]}], ",", "o1", ",", "o2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      OverscriptBox["o1", "_"], ",", 
      RowBox[{
       SubscriptBox["a", "2"], 
       SubscriptBox["e", "0"]}], ",", "o3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      OverscriptBox["o2", "_"], ",", 
      OverscriptBox["o3", "_"], ",", 
      RowBox[{
       SubscriptBox["a", "3"], 
       SubscriptBox["e", "0"]}]}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      SubscriptBox["e", "0"]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       SubscriptBox["X", "0"]}], "+", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       SubscriptBox["X", "1"]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["X", "2"]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       SubscriptBox["X", "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       SubscriptBox["Y", "0"]}], "+", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       SubscriptBox["Y", "1"]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["Y", "2"]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       SubscriptBox["Y", "3"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       SubscriptBox["X", "0"]}], "-", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       SubscriptBox["X", "1"]}], "-", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["X", "2"]}], "-", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       SubscriptBox["X", "3"]}]}], ",", 
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      SubscriptBox["e", "0"]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       SubscriptBox["Z", "0"]}], "+", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       SubscriptBox["Z", "1"]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["Z", "2"]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       SubscriptBox["Z", "3"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       SubscriptBox["Y", "0"]}], "-", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       SubscriptBox["Y", "1"]}], "-", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["Y", "2"]}], "-", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       SubscriptBox["Y", "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       SubscriptBox["Z", "0"]}], "-", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       SubscriptBox["Z", "1"]}], "-", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["Z", "2"]}], "-", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       SubscriptBox["Z", "3"]}]}], ",", 
     RowBox[{
      SubscriptBox["a", "3"], " ", 
      SubscriptBox["e", "0"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       SubscriptBox["e", "0"]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["X", "0"]}], "+", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["X", "1"]}], "+", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["X", "2"]}], "+", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["X", "3"]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["Y", "0"]}], "+", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["Y", "1"]}], "+", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["Y", "2"]}], "+", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["Y", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["X", "0"]}], "-", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["X", "1"]}], "-", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["X", "2"]}], "-", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["X", "3"]}]}], 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["e", "0"]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["Z", "0"]}], "+", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["Z", "1"]}], "+", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["Z", "2"]}], "+", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["Z", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["Y", "0"]}], "-", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["Y", "1"]}], "-", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["Y", "2"]}], "-", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["Y", "3"]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["Z", "0"]}], "-", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["Z", "1"]}], "-", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["Z", "2"]}], "-", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["Z", "3"]}]}], 
      RowBox[{
       SubscriptBox["a", "3"], " ", 
       SubscriptBox["e", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["An independent matrix of the same form is given by,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"J2", "=", 
   RowBox[{"J1", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "->", "b"}], ",", 
      RowBox[{"X", "->", "U"}], ",", 
      RowBox[{"Y", "->", "V"}], ",", 
      RowBox[{"Z", "->", "W"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"mtx", "[", "J2", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SubscriptBox["b", "1"], " ", 
       SubscriptBox["e", "0"]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["U", "0"]}], "+", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["U", "1"]}], "+", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["U", "2"]}], "+", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["U", "3"]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["V", "0"]}], "+", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["V", "1"]}], "+", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["V", "2"]}], "+", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["V", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["U", "0"]}], "-", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["U", "1"]}], "-", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["U", "2"]}], "-", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["U", "3"]}]}], 
      RowBox[{
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["e", "0"]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["W", "0"]}], "+", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["W", "1"]}], "+", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["W", "2"]}], "+", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["W", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["V", "0"]}], "-", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["V", "1"]}], "-", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["V", "2"]}], "-", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["V", "3"]}]}], 
      RowBox[{
       RowBox[{
        SubscriptBox["e", "0"], " ", 
        SubscriptBox["W", "0"]}], "-", 
       RowBox[{
        SubscriptBox["e", "1"], " ", 
        SubscriptBox["W", "1"]}], "-", 
       RowBox[{
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["W", "2"]}], "-", 
       RowBox[{
        SubscriptBox["e", "3"], " ", 
        SubscriptBox["W", "3"]}]}], 
      RowBox[{
       SubscriptBox["b", "3"], " ", 
       SubscriptBox["e", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
and the symmetrized Jordan product \[CirclePlus] can be modified for matrix \
arguments to,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CirclePlus", "[", 
   RowBox[{"arg1_", ",", "arg2_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"arg1", "\[CircleTimes]", 
    RowBox[{"(", 
     RowBox[{"arg2", "/", "2"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"arg2", "/", "2"}], ")"}], "\[CircleTimes]", 
    "arg1"}]}]}]], "Input"],

Cell["For example,", "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->True,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J3", "=", 
  RowBox[{"collect", "[", 
   RowBox[{"J1", "\[CirclePlus]", "J1"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["e", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["a", "1", "2"], "+", 
        SubsuperscriptBox["X", "0", "2"], "+", 
        SubsuperscriptBox["X", "1", "2"], "+", 
        SubsuperscriptBox["X", "2", "2"], "+", 
        SubsuperscriptBox["X", "3", "2"], "+", 
        SubsuperscriptBox["Y", "0", "2"], "+", 
        SubsuperscriptBox["Y", "1", "2"], "+", 
        SubsuperscriptBox["Y", "2", "2"], "+", 
        SubsuperscriptBox["Y", "3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["X", "1"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "1"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["X", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "2"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["X", "3"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "3"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["X", "0"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "0"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "2"]}], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "3"]}], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "3"]}], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "1"]}], " ", 
          SubscriptBox["X", "1"]}], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "1"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "1"]}], " ", 
          SubscriptBox["X", "2"]}], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "2"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["Y", "2"]}], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "1"]}], " ", 
          SubscriptBox["X", "3"]}], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "3"]}], "-", 
         RowBox[{
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["Y", "3"]}], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["Y", "3"]}], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["X", "0"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["X", "0"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["e", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["a", "2", "2"], "+", 
        SubsuperscriptBox["X", "0", "2"], "+", 
        SubsuperscriptBox["X", "1", "2"], "+", 
        SubsuperscriptBox["X", "2", "2"], "+", 
        SubsuperscriptBox["X", "3", "2"], "+", 
        SubsuperscriptBox["Z", "0", "2"], "+", 
        SubsuperscriptBox["Z", "1", "2"], "+", 
        SubsuperscriptBox["Z", "2", "2"], "+", 
        SubsuperscriptBox["Z", "3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "0"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "1"]}], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "2"]}], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "3"]}], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "1"]}], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "1"]}], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "1"]}], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "2"]}], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "3"]}], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["X", "3"]}], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "0"]}], "+", 
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "0"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"]}], "-", 
         RowBox[{
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["e", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["a", "3", "2"], "+", 
        SubsuperscriptBox["Y", "0", "2"], "+", 
        SubsuperscriptBox["Y", "1", "2"], "+", 
        SubsuperscriptBox["Y", "2", "2"], "+", 
        SubsuperscriptBox["Y", "3", "2"], "+", 
        SubsuperscriptBox["Z", "0", "2"], "+", 
        SubsuperscriptBox["Z", "1", "2"], "+", 
        SubsuperscriptBox["Z", "2", "2"], "+", 
        SubsuperscriptBox["Z", "3", "2"]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Using matrix multiplication, the Jordan identity as introduced for the \
derived algebra ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "+"], TraditionalForm]]],
 " becomes,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J1", "\[CircleTimes]", "J1"}], ")"}], "\[CirclePlus]", "J2"}], 
    ")"}], "\[CirclePlus]", "J1"}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"J1", "\[CircleTimes]", "J1"}], ")"}], "\[CirclePlus]", 
   RowBox[{"(", 
    RowBox[{"J2", "\[CirclePlus]", "J1"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
or equivalently, using J3 = J1\[CirclePlus]J1, just calculated,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"J3", "\[CirclePlus]", "J2"}], ")"}], "\[CirclePlus]", "J1"}], 
  "-", 
  RowBox[{"J3", "\[CirclePlus]", 
   RowBox[{"(", 
    RowBox[{"J2", "\[CirclePlus]", "J1"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Executing the next statement confirms that the unsymmetrized matrix product \
is not associative.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"J3", "\[CircleTimes]", "J2"}], ")"}], "\[CircleTimes]", "J1"}], 
   "-", 
   RowBox[{"J3", "\[CircleTimes]", 
    RowBox[{"(", 
     RowBox[{"J2", "\[CircleTimes]", "J1"}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubsuperscriptBox["Y", "1", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubsuperscriptBox["Y", "1", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W", "3"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubsuperscriptBox["Y", "2", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubsuperscriptBox["Y", "2", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubsuperscriptBox["Y", "3", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubsuperscriptBox["Y", "3", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubsuperscriptBox["Y", "1", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubsuperscriptBox["Y", "1", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubsuperscriptBox["Y", "2", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubsuperscriptBox["Y", "2", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubsuperscriptBox["Y", "3", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubsuperscriptBox["Y", "3", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubsuperscriptBox["Y", "1", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubsuperscriptBox["Y", "1", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubsuperscriptBox["Y", "2", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubsuperscriptBox["Y", "2", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubsuperscriptBox["Y", "3", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubsuperscriptBox["Y", "3", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Y", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Y", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Y", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Y", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Y", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Y", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "0"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Y", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Y", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Y", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Y", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Y", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Y", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "0"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubsuperscriptBox["X", "1", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubsuperscriptBox["X", "2", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Y", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubsuperscriptBox["X", "3", "2"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["W", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["V", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "0"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "1"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "3"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["a", "3"], " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "0"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Y", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Y", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Z", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Y", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Y", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubsuperscriptBox["Z", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["e", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "1"], " ", 
          SubscriptBox["Y", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Y", "2"], " ", 
          SubscriptBox["Y", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Y", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Y", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "1"], " ", 
          SubscriptBox["Z", "3"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "3"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "3"], " ", 
          SubscriptBox["Z", "2"], " ", 
          SubscriptBox["Z", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "2"], " ", 
          SubscriptBox["X", "1"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["U", "1"], " ", 
          SubscriptBox["X", "2"], " ", 
          SubsuperscriptBox["Z", "3", "2"]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["III.c.9. Clean up", "Subsubsection"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IV. Advanced computations", "Section",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["IV.a. Orthonormal frames and Hodge star operations", "Subsection",
 PageWidth->WindowWidth],

Cell["This is taken from the file HodgeStar_Demo.nb.", "Text"],

Cell[CellGroupData[{

Cell["IV.a.1. General comments", "Subsubsection"],

Cell[TextData[{
 "A set of up to 6 basis forms (which may include a subset of the existing ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ") can be designated as an ",
 StyleBox["orthonormal",
  FontVariations->{"Underline"->True}],
 " frame by the command ",
 StyleBox["makeframe[list]", "Input",
  FontWeight->"Plain"],
 ". The argument is just a list of form symbols, except that the symbol for \
any frame form with negative signature must be preceded by a minus sign.\n\n\
The basis forms may be input in any order, but will be re-arranged into \
canonical order (and the signs stripped off) before being assigned to the \
reserved variable ",
 StyleBox["frame", "Input",
  FontWeight->"Plain"],
 ". The signs are saved in the reserved variable ",
 StyleBox["signature", "Input",
  FontWeight->"Plain"],
 ". Any new symbols are added to ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 ", and the frame forms will be moved to the front of the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list.  Existing ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are left unchanged, so any new frame forms (even exact ones, if new) will \
require them."
}], "Text",
 PageWidth->WindowWidth,
 PageBreakAbove->False,
 FontFamily->"Times",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.a.2. Cartesian orthogonal frame", "Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[TextData[{
 "The first example sets up for Euclidean 3-space using Cartesian coordinates \
and the associated natural orthogonal basis. The ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 " command is described fully at the end of the Lie differentiation section."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Using the argument ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " in the next statement avoids introducing new basis forms, and obviates any \
need for ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeframe", "[", "dscalars", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["signature"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dx", ",", "dy", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["drules"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["makeframe", "Input",
  FontWeight->"Plain"],
 " command implements the Hodge star operation for ",
 StyleBox["frame", "Input",
  FontWeight->"Plain"],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not include an appropriate prefix operator for this, so it is written \
",
 StyleBox["hs[arg]", "Input",
  FontWeight->"Plain"],
 ", where ",
 StyleBox["arg", "Input",
  FontWeight->"Plain"],
 " is any AVF, or list of AVF's. "
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"vol", "=", 
  RowBox[{"hs", "[", "1", "]"}]}], "\n", 
 RowBox[{"hs", "[", "vol", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dz"}]], "Output"],

Cell[BoxData["1"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"f", "=", 
  RowBox[{"Y", "[", "depend", "]"}]}], "\n", 
 RowBox[{"hs", "[", "f", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Y", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dx", "\[Wedge]", "dy", "\[Wedge]", "dz"}], " ", 
  RowBox[{"Y", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"A", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"A1", "[", "depend", "]"}], "dx"}], "+", 
   RowBox[{
    RowBox[{"A2", "[", "depend", "]"}], "dy"}], "+", 
   RowBox[{
    RowBox[{"A3", "[", "depend", "]"}], "dz"}]}]}], "\n", 
 RowBox[{"hs", "[", "A", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dx", " ", 
   RowBox[{"A1", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"dy", " ", 
   RowBox[{"A2", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"dz", " ", 
   RowBox[{"A3", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A3", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dy"}]}], "-", 
  RowBox[{
   RowBox[{"A2", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dx", "\[Wedge]", "dz"}]}], "+", 
  RowBox[{
   RowBox[{"A1", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"dy", "\[Wedge]", "dz"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A co-derivative operator, \[Delta] , is also defined:  ",
 StyleBox["\[Delta][arg] = hs[hs[1]] hs[d[hs[arg]]]", "Input",
  FontWeight->"Plain"],
 ". No universally accepted convention exists for the overall sign of Hodge \
star operations; the use of the factor ",
 StyleBox["hs[hs[1]]", "Input",
  FontWeight->"Plain"],
 " in \[Delta] generally gives results consistent with ",
 StyleBox["signature", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"df", "=", 
  RowBox[{"d", "[", "f", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dz", " ", 
   SubscriptBox["Y", "z"]}], "+", 
  RowBox[{"dy", " ", 
   SubscriptBox["Y", "y"]}], "+", 
  RowBox[{"dx", " ", 
   SubscriptBox["Y", "x"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"delsquaredf", "=", 
  RowBox[{"\[Delta]", "[", "df", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["Y", "\<\"zz\"\>"], "+", 
  SubscriptBox["Y", "\<\"yy\"\>"], "+", 
  SubscriptBox["Y", "\<\"xx\"\>"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curlgradf", "=", 
  RowBox[{"\[Delta]", "[", 
   RowBox[{"hs", "[", "df", "]"}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divA", "=", 
  RowBox[{"\[Delta]", "[", "A", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["A3", "z"], "+", 
  SubscriptBox["A2", "y"], "+", 
  SubscriptBox["A1", "x"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curlA", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"hs", "[", 
     RowBox[{"d", "[", "A", "]"}], "]"}], ",", "frame"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dx", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["A2", "z"]}], "+", 
     SubscriptBox["A3", "y"]}], ")"}]}], "+", 
  RowBox[{"dz", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["A1", "y"]}], "+", 
     SubscriptBox["A2", "x"]}], ")"}]}], "+", 
  RowBox[{"dy", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["A1", "z"], "-", 
     SubscriptBox["A3", "x"]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divcurlA", "=", 
  RowBox[{"\[Delta]", "[", "curlA", "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note the use of ",
 StyleBox["da[]", "Input",
  FontWeight->"Plain"],
 " in the next statement which (with appropriate ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", when necessary) ensures that the result of that derivative is expressed \
in terms of ",
 StyleBox["frame", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"delsquaredA", "=", " ", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"da", "[", 
      RowBox[{"\[Delta]", "[", "A", "]"}], "]"}], "-", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"d", "[", "A", "]"}], "]"}]}], ",", "frame"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dx", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["A1", "\<\"zz\"\>"], "+", 
     SubscriptBox["A1", "\<\"yy\"\>"], "+", 
     SubscriptBox["A1", "\<\"xx\"\>"]}], ")"}]}], "+", 
  RowBox[{"dy", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["A2", "\<\"zz\"\>"], "+", 
     SubscriptBox["A2", "\<\"yy\"\>"], "+", 
     SubscriptBox["A2", "\<\"xx\"\>"]}], ")"}]}], "+", 
  RowBox[{"dz", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["A3", "\<\"zz\"\>"], "+", 
     SubscriptBox["A3", "\<\"yy\"\>"], "+", 
     SubscriptBox["A3", "\<\"xx\"\>"]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.a.3. A non-Cartesian orthogonal frame", "Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[TextData[{
 "Except in flat space with a Cartesian frame, the orthonormal frame forms \
will have unspecified exterior derivatives which need ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " to be expressed back in terms of ",
 StyleBox["frame", "Input",
  FontWeight->"Plain"],
 " (unless they have been selected from the ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " list, as was done above). \n\nFurthermore, if the frame forms are not in \
",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 ", the transformations ",
 StyleBox["dcoords", "Input",
  FontWeight->"Plain"],
 "->",
 StyleBox["frame", "Input",
  FontWeight->"Plain"],
 " must be provided in ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", so that exterior differentiation of all frame forms and scalar functions \
of the coordinates can be accomplished using the ",
 StyleBox["da[]", "Input",
  FontWeight->"Plain"],
 " operator. All calculations are performed in the orthonormal frame. \
However, input expressions may be expressed in the coordinate frame, and the \
orthonormal output is convertible, as shown in the examples.\n\nThe example \
of spherical coordinates shows what is required."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeframe", "[", 
  RowBox[{"{", 
   RowBox[{
    OverscriptBox["r", "^"], ",", 
    OverscriptBox["\[Theta]", "^"], ",", 
    OverscriptBox["\[Phi]", "^"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["r", "^"], ",", 
   OverscriptBox["\[Theta]", "^"], ",", 
   OverscriptBox["\[Phi]", "^"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["signature"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["scalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]", ",", "x", ",", "y", ",", "z"}],
   "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "dr", ",", "d\[Theta]", ",", "d\[Phi]", ",", "dx", ",", "dy", ",", "dz"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["r", "^"], ",", 
   OverscriptBox["\[Theta]", "^"], ",", 
   OverscriptBox["\[Phi]", "^"], ",", "dr", ",", "d\[Theta]", ",", "d\[Phi]", 
   ",", "dx", ",", "dy", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["dr", "^"], ",", 
   OverscriptBox["d\[Theta]", "^"], ",", 
   OverscriptBox["d\[Phi]", "^"]}], "}"}]], "Output"]
}, Open  ]],

Cell["Now the framedrules will be established:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tocoords", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"frame", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "->", "dr"}], ",", 
    RowBox[{
     RowBox[{"frame", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "->", 
     RowBox[{"r", " ", "d\[Theta]"}]}], ",", 
    RowBox[{
     RowBox[{"frame", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", "d\[Phi]"}]}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["r", "^"], "\[Rule]", "dr"}], ",", 
   RowBox[{
    OverscriptBox["\[Theta]", "^"], "\[Rule]", 
    RowBox[{"d\[Theta]", " ", "r"}]}], ",", 
   RowBox[{
    OverscriptBox["\[Phi]", "^"], "\[Rule]", 
    RowBox[{"d\[Phi]", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["The shortcut for this is:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tocoords", " ", "=", " ", 
  RowBox[{"Thread", "[", 
   RowBox[{"frame", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{"dr", ",", " ", 
      RowBox[{"r", " ", "d\[Theta]"}], ",", " ", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", "d\[Phi]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["r", "^"], "\[Rule]", "dr"}], ",", 
   RowBox[{
    OverscriptBox["\[Theta]", "^"], "\[Rule]", 
    RowBox[{"d\[Theta]", " ", "r"}]}], ",", 
   RowBox[{
    OverscriptBox["\[Phi]", "^"], "\[Rule]", 
    RowBox[{"d\[Phi]", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " command ",
 StyleBox["prune[list,expr]", "Input",
  FontWeight->"Plain"],
 " is useful to select the relevant part of a longer list. In this case, it \
returns a list containing the members of ",
 StyleBox["dscalars", "Input",
  FontWeight->"Plain"],
 " that appear in ",
 StyleBox["tocoords", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prunedlist", "=", 
  RowBox[{"prune", "[", 
   RowBox[{"dscalars", ",", "tocoords"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dr", ",", "d\[Theta]", ",", "d\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toframe", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"tocoords", "/.", 
       RowBox[{"Rule", "->", "Equal"}]}], ")"}], ",", "prunedlist"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dr", "\[Rule]", 
    OverscriptBox["r", "^"]}], ",", 
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     OverscriptBox["\[Theta]", "^"], "r"]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      OverscriptBox["\[Phi]", "^"]}], "r"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The next command constructs the appropriate ",
 StyleBox["frame", "Input",
  FontWeight->"Plain"],
 " derivatives to be used in ",
 StyleBox["framedrules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dframe", "=", 
  RowBox[{"expand", "[", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"frame", "/.", "tocoords"}], "]"}], "/.", "toframe"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{
     OverscriptBox["r", "^"], "\[Wedge]", 
     OverscriptBox["\[Theta]", "^"]}], "r"], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      OverscriptBox["r", "^"], "\[Wedge]", 
      OverscriptBox["\[Phi]", "^"]}], "r"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
       OverscriptBox["\[Phi]", "^"]}]}], "r"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"framedrules", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{"dforms", "->", "dframe"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["dr", "^"], "\[Rule]", "0"}], ",", 
   RowBox[{
    OverscriptBox["d\[Theta]", "^"], "\[Rule]", 
    FractionBox[
     RowBox[{
      OverscriptBox["r", "^"], "\[Wedge]", 
      OverscriptBox["\[Theta]", "^"]}], "r"]}], ",", 
   RowBox[{
    OverscriptBox["d\[Phi]", "^"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       OverscriptBox["r", "^"], "\[Wedge]", 
       OverscriptBox["\[Phi]", "^"]}], "r"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{
        OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
        OverscriptBox["\[Phi]", "^"]}]}], "r"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "And now these  are established as ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"framedrules", ",", "toframe"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["dr", "^"], "\[Rule]", "0"}], ",", 
   RowBox[{
    OverscriptBox["d\[Theta]", "^"], "\[Rule]", 
    FractionBox[
     RowBox[{
      OverscriptBox["r", "^"], "\[Wedge]", 
      OverscriptBox["\[Theta]", "^"]}], "r"]}], ",", 
   RowBox[{
    OverscriptBox["d\[Phi]", "^"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       OverscriptBox["r", "^"], "\[Wedge]", 
       OverscriptBox["\[Phi]", "^"]}], "r"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{
        OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
        OverscriptBox["\[Phi]", "^"]}]}], "r"]}]}], ",", 
   RowBox[{"dr", "\[Rule]", 
    OverscriptBox["r", "^"]}], ",", 
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     OverscriptBox["\[Theta]", "^"], "r"]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      OverscriptBox["\[Phi]", "^"]}], "r"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Of course, it would be convenient to collect these preparation commands \
into a subroutine. Problems may arise from using ",
 StyleBox["Solve", "Input",
  FontWeight->"Plain"],
 " to get the inverse transformation and the possible need at times for ",
 StyleBox["Simplify", "Input",
  FontWeight->"Plain"],
 ". A better approach for other cases is to copy the relevant parts of this \
program into a new Notebook and modify them as necessary."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"vol", "=", 
  RowBox[{"hs", "[", "1", "]"}]}], "\n", 
 RowBox[{"expand", "[", 
  RowBox[{"vol", "/.", "tocoords"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  OverscriptBox["r", "^"], "\[Wedge]", 
  OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
  OverscriptBox["\[Phi]", "^"]}]], "Output"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "2"], " ", 
  RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
  RowBox[{"dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[Phi]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Using Hodge, an inner product, called ",
 StyleBox["dot", "Input",
  FontWeight->"Plain"],
 ", can be defined for any two p-forms (of the same degree). For the frame \
forms themselves, it exhibits the orthonormality;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dot", "[", 
  RowBox[{
   OverscriptBox["\[Phi]", "^"], ",", 
   OverscriptBox["\[Phi]", "^"]}], "]"}], "\n", 
 RowBox[{"dot", "[", 
  RowBox[{
   OverscriptBox["r", "^"], ",", 
   OverscriptBox["\[Theta]", "^"]}], "]"}]}], "Input"],

Cell[BoxData["1"], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
and for the coordinate basis it will give the covariant metric,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", 
  RowBox[{"Inverse", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"dot", "[", 
      RowBox[{
       RowBox[{"dscalars", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", 
       RowBox[{"dscalars", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "coordsdim"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "coordsdim"}], "}"}]}], "]"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", 
      SuperscriptBox["r", "2"], "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"f", "=", 
  RowBox[{"Y", "[", "depend", "]"}]}], "\n", 
 RowBox[{"hs", "[", "f", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Y", "[", 
  RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["r", "^"], "\[Wedge]", 
   OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
   OverscriptBox["\[Phi]", "^"]}], " ", 
  RowBox[{"Y", "[", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"df", "=", 
  RowBox[{"d", "[", "f", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d\[Phi]", " ", 
   SubscriptBox["Y", "\[Phi]"]}], "+", 
  RowBox[{"d\[Theta]", " ", 
   SubscriptBox["Y", "\[Theta]"]}], "+", 
  RowBox[{"dr", " ", 
   SubscriptBox["Y", "r"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
    OverscriptBox["\[Phi]", "^"], " ", 
    SubscriptBox["Y", "\[Phi]"]}], "r"], "+", 
  FractionBox[
   RowBox[{
    OverscriptBox["\[Theta]", "^"], " ", 
    SubscriptBox["Y", "\[Theta]"]}], "r"], "+", 
  RowBox[{
   OverscriptBox["r", "^"], " ", 
   SubscriptBox["Y", "r"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divdf", "=", 
  RowBox[{"\[Delta]", "[", "df", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
    SubscriptBox["Y", "\<\"\[Phi]\[Phi]\"\>"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["Y", "\[Theta]"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   SubscriptBox["Y", "\<\"\[Theta]\[Theta]\"\>"], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["Y", "r"]}], "r"], "+", 
  SubscriptBox["Y", "\<\"rr\"\>"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curldf", "=", 
  RowBox[{"\[Delta]", "[", 
   RowBox[{"hs", "[", "df", "]"}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"A", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"A1", "[", "depend", "]"}], " ", 
    OverscriptBox["r", "^"]}], "+", 
   RowBox[{
    RowBox[{"A2", "[", "depend", "]"}], " ", 
    OverscriptBox["\[Theta]", "^"]}], "+", 
   RowBox[{
    RowBox[{"A3", "[", "depend", "]"}], " ", 
    OverscriptBox["\[Phi]", "^"]}]}]}], "\n", 
 RowBox[{"hs", "[", "A", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   OverscriptBox["r", "^"]}], "+", 
  RowBox[{
   RowBox[{"A2", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   OverscriptBox["\[Theta]", "^"]}], "+", 
  RowBox[{
   RowBox[{"A3", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   OverscriptBox["\[Phi]", "^"]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A3", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   RowBox[{
    OverscriptBox["r", "^"], "\[Wedge]", 
    OverscriptBox["\[Theta]", "^"]}]}], "-", 
  RowBox[{
   RowBox[{"A2", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   RowBox[{
    OverscriptBox["r", "^"], "\[Wedge]", 
    OverscriptBox["\[Phi]", "^"]}]}], "+", 
  RowBox[{
   RowBox[{"A1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   RowBox[{
    OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
    OverscriptBox["\[Phi]", "^"]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"B", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"B1", "[", "depend", "]"}], " ", "dr"}], "+", 
   RowBox[{
    RowBox[{"B2", "[", "depend", "]"}], " ", "d\[Theta]"}], "+", 
   RowBox[{
    RowBox[{"B3", "[", "depend", "]"}], " ", "d\[Phi]"}]}]}], "\n", 
 RowBox[{"hs", "[", "B", "]"}], "\n", 
 RowBox[{"expand", "[", 
  RowBox[{"%", "/.", "tocoords"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dr", " ", 
   RowBox[{"B1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
  RowBox[{"d\[Theta]", " ", 
   RowBox[{"B2", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]}], "+", 
  RowBox[{"d\[Phi]", " ", 
   RowBox[{"B3", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"B3", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
    RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
    RowBox[{
     OverscriptBox["r", "^"], "\[Wedge]", 
     OverscriptBox["\[Theta]", "^"]}]}], "r"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"B2", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
    RowBox[{
     OverscriptBox["r", "^"], "\[Wedge]", 
     OverscriptBox["\[Phi]", "^"]}]}], "r"], "+", 
  RowBox[{
   RowBox[{"B1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   RowBox[{
    OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
    OverscriptBox["\[Phi]", "^"]}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"B3", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], "-", 
  RowBox[{
   RowBox[{"B2", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "+", 
  RowBox[{
   SuperscriptBox["r", "2"], " ", 
   RowBox[{"B1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The Hodge operator ",
 StyleBox["hs[]", "Input",
  FontWeight->"Plain"],
 " also can be applied to AVF arrays."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hs", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"df", ",", "A"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"B", ",", "df"}], "}"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         OverscriptBox["r", "^"], "\[Wedge]", 
         OverscriptBox["\[Theta]", "^"]}], " ", 
        SubscriptBox["Y", "\[Phi]"]}], "r"], "-", 
      FractionBox[
       RowBox[{
        RowBox[{
         OverscriptBox["r", "^"], "\[Wedge]", 
         OverscriptBox["\[Phi]", "^"]}], " ", 
        SubscriptBox["Y", "\[Theta]"]}], "r"], "+", 
      RowBox[{
       RowBox[{
        OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
        OverscriptBox["\[Phi]", "^"]}], " ", 
       SubscriptBox["Y", "r"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"A3", "[", 
        RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
       RowBox[{
        OverscriptBox["r", "^"], "\[Wedge]", 
        OverscriptBox["\[Theta]", "^"]}]}], "-", 
      RowBox[{
       RowBox[{"A2", "[", 
        RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
       RowBox[{
        OverscriptBox["r", "^"], "\[Wedge]", 
        OverscriptBox["\[Phi]", "^"]}]}], "+", 
      RowBox[{
       RowBox[{"A1", "[", 
        RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
       RowBox[{
        OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
        OverscriptBox["\[Phi]", "^"]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"B3", "[", 
         RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         OverscriptBox["r", "^"], "\[Wedge]", 
         OverscriptBox["\[Theta]", "^"]}]}], "r"], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"B2", "[", 
         RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
        RowBox[{
         OverscriptBox["r", "^"], "\[Wedge]", 
         OverscriptBox["\[Phi]", "^"]}]}], "r"], "+", 
      RowBox[{
       RowBox[{"B1", "[", 
        RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
       RowBox[{
        OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
        OverscriptBox["\[Phi]", "^"]}]}]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         OverscriptBox["r", "^"], "\[Wedge]", 
         OverscriptBox["\[Theta]", "^"]}], " ", 
        SubscriptBox["Y", "\[Phi]"]}], "r"], "-", 
      FractionBox[
       RowBox[{
        RowBox[{
         OverscriptBox["r", "^"], "\[Wedge]", 
         OverscriptBox["\[Phi]", "^"]}], " ", 
        SubscriptBox["Y", "\[Theta]"]}], "r"], "+", 
      RowBox[{
       RowBox[{
        OverscriptBox["\[Theta]", "^"], "\[Wedge]", 
        OverscriptBox["\[Phi]", "^"]}], " ", 
       SubscriptBox["Y", "r"]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divA", "=", 
  RowBox[{"\[Delta]", "[", "A", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"A1", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]}], "r"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"A2", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
    RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "r"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["A3", "\[Phi]"]}], "r"], "+", 
  FractionBox[
   SubscriptBox["A2", "\[Theta]"], "r"], "+", 
  SubscriptBox["A1", "r"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curlA", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"hs", "[", 
     RowBox[{"d", "[", "A", "]"}], "]"}], ",", "frame"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["r", "^"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"A3", "[", 
        RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "r"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A2", "\[Phi]"]}], "r"], "+", 
     FractionBox[
      SubscriptBox["A3", "\[Theta]"], "r"]}], ")"}]}], "+", 
  RowBox[{
   OverscriptBox["\[Phi]", "^"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"A2", "[", 
       RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "r"], "-", 
     FractionBox[
      SubscriptBox["A1", "\[Theta]"], "r"], "+", 
     SubscriptBox["A2", "r"]}], ")"}]}], "+", 
  RowBox[{
   OverscriptBox["\[Theta]", "^"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"A3", "[", 
        RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "r"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A1", "\[Phi]"]}], "r"], "-", 
     SubscriptBox["A3", "r"]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curlB", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"expand", "[", 
     RowBox[{
      RowBox[{"hs", "[", 
       RowBox[{"d", "[", "B", "]"}], "]"}], "/.", "tocoords"}], "]"}], ",", 
    "prunedlist"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dr", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        SubscriptBox["B2", "\[Phi]"]}], 
       SuperscriptBox["r", "2"]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["B3", "\[Theta]"]}], 
      SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
  RowBox[{"d\[Phi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], " ", 
      SubscriptBox["B1", "\[Theta]"]}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["B2", "r"]}]}], ")"}]}], "+", 
  RowBox[{"d\[Theta]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["B1", "\[Phi]"]}], "-", 
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["B3", "r"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"divcurlA", "=", 
  RowBox[{"\[Delta]", "[", "curlA", "]"}]}], "\n", 
 RowBox[{"divcurlB", "=", 
  RowBox[{"\[Delta]", "[", "curlB", "]"}]}]}], "Input"],

Cell[BoxData["0"], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"delsquaredA", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"da", "[", 
      RowBox[{"\[Delta]", "[", "A", "]"}], "]"}], "-", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"d", "[", "A", "]"}], "]"}]}], ",", "frame"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["r", "^"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"A1", "[", 
         RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]}], 
       SuperscriptBox["r", "2"]]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"A2", "[", 
        RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A3", "\[Phi]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
       SubscriptBox["A1", "\<\"\[Phi]\[Phi]\"\>"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A1", "\[Theta]"]}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SubscriptBox["A2", "\[Theta]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      SubscriptBox["A1", "\<\"\[Theta]\[Theta]\"\>"], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SubscriptBox["A1", "r"]}], "r"], "+", 
     SubscriptBox["A1", "\<\"rr\"\>"]}], ")"}]}], "+", 
  RowBox[{
   OverscriptBox["\[Theta]", "^"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"A2", "[", 
         RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], 
       SuperscriptBox["r", "2"]]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A3", "\[Phi]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
       SubscriptBox["A2", "\<\"\[Phi]\[Phi]\"\>"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SubscriptBox["A1", "\[Theta]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A2", "\[Theta]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      SubscriptBox["A2", "\<\"\[Theta]\[Theta]\"\>"], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SubscriptBox["A2", "r"]}], "r"], "+", 
     SubscriptBox["A2", "\<\"rr\"\>"]}], ")"}]}], "+", 
  RowBox[{
   OverscriptBox["\[Phi]", "^"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"A3", "[", 
         RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], 
       SuperscriptBox["r", "2"]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A1", "\[Phi]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A2", "\[Phi]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
       SubscriptBox["A3", "\<\"\[Phi]\[Phi]\"\>"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       SubscriptBox["A3", "\[Theta]"]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      SubscriptBox["A3", "\<\"\[Theta]\[Theta]\"\>"], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SubscriptBox["A3", "r"]}], "r"], "+", 
     SubscriptBox["A3", "\<\"rr\"\>"]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Some inner products calculated by ",
 StyleBox["dot", "Input",
  FontWeight->"Plain"],
 ", where the second and third demonstrate its symmetry;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dot", "[", 
  RowBox[{"B", ",", "B"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"B1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "2"], "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"B2", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "2"], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"B3", "[", 
      RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], 
   SuperscriptBox["r", "2"]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dot", "[", 
  RowBox[{"A", ",", "df"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"A3", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
    RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["Y", "\[Phi]"]}], "r"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"A2", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
    SubscriptBox["Y", "\[Theta]"]}], "r"], "+", 
  RowBox[{
   RowBox[{"A1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   SubscriptBox["Y", "r"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dot", "[", 
  RowBox[{"df", ",", "A"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"A3", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
    RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["Y", "\[Phi]"]}], "r"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"A2", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
    SubscriptBox["Y", "\[Theta]"]}], "r"], "+", 
  RowBox[{
   RowBox[{"A1", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], " ", 
   SubscriptBox["Y", "r"]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.a.4. Clean up", "Subsubsection"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.b. Implementing Clifford algebras", "Subsection"],

Cell["This is taken from the file CAV_Demo.nb.", "Text"],

Cell[CellGroupData[{

Cell["IV.b.1. Making a Clifford algebra", "Subsubsection"],

Cell[TextData[{
 "A Clifford algebra representation of quaternions will be used as the first \
example. The argument of ",
 StyleBox["makeclifford[arg]", "Input",
  FontWeight->"Plain"],
 " is the desired signature list; i.e., for quaternions, ",
 StyleBox["{-1,-1}", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makeclifford", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{"-", "1"}]}], "}"}], "]"}]], "Input"],

Cell[TextData[{
 "The dimension is given by ",
 StyleBox["cadim", "Input",
  FontWeight->"Plain"],
 ", and the ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " list has length ",
 StyleBox["eldim=2^cadim", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["dforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["d\[Theta]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["d\[Theta]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["d\[Theta]", "1"], "2"], ",", 
   OverscriptBox["d\[Theta]", "2"], ",", 
   OverscriptBox["d\[Omega]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["d\[Omega]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["d\[Omega]", "1"], "2"], ",", 
   OverscriptBox["d\[Omega]", "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["cadim"], "Input"],

Cell[BoxData["2"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Gamma]", "0"], ",", 
   SubscriptBox["\[Gamma]", "1"], ",", 
   SubscriptBox["\[Gamma]", "2"], ",", 
   SubscriptBox["\[Gamma]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["eldim"], "Input"],

Cell[BoxData["4"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The first element, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "0"], TraditionalForm]]],
 ", is the identity; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "2"], TraditionalForm]]],
 "are the orthonormal generators, both with negative signature; and the \
complete product element here is, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "3"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["\[Gamma]", "1"],
     TraditionalForm], 
    SubscriptBox["\[Gamma]", "2"]}], TraditionalForm]]],
 ", which also has a negative square. The command ",
 StyleBox["mtx[]", "Input",
  FontWeight->"Plain"],
 " outputs the algebra table in MatrixForm."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "1"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "3"]},
     {
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}]},
     {
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      SubscriptBox["\[Gamma]", "1"]},
     {
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
As described in the Introduction section, all the following graded symbol \
lists and CAV quantites are constructed:\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["gammas"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Gamma]", "0"], ",", 
   SubscriptBox["\[Gamma]", "1"], ",", 
   SubscriptBox["\[Gamma]", "2"], ",", 
   SubscriptBox["\[Gamma]", "3"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["thetas"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["\[Theta]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"], ",", 
   OverscriptBox["\[Theta]", "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["omegas"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "2"], ",", 
   OverscriptBox["\[Omega]", "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["\[Theta]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"], ",", 
   OverscriptBox["\[Theta]", "2"], ",", 
   OverscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "2"], ",", 
   OverscriptBox["\[Omega]", "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 OverscriptBox["\[Theta]", "^"]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["\[Theta]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   OverscriptBox["\[Theta]", "2"], " ", 
   SubscriptBox["\[Gamma]", "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 OverscriptBox["\[Omega]", "^"]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["\[Omega]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   OverscriptBox["\[Omega]", "2"], " ", 
   SubscriptBox["\[Gamma]", "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "2"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The generalized torsion and curvature 2-forms are defined by the CAV \
expressions;\n\n          ",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    OverscriptBox["\[CapitalTheta]", "^"], " ", "=", " ", 
    RowBox[{
     RowBox[{"d", "[", 
      OverscriptBox["\[Theta]", "^"], "]"}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[Omega]", "^"], "**", 
         OverscriptBox["\[Theta]", "^"]}], "+", 
        RowBox[{
         OverscriptBox["\[Theta]", "^"], "**", 
         OverscriptBox["\[Omega]", "^"]}]}], ")"}]}]}]}]}]], "Input"],
 "\n          \n           ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    OverscriptBox["\[CapitalOmega]", "^"], " ", "=", " ", 
    RowBox[{
     RowBox[{"d", "[", 
      OverscriptBox["\[Omega]", "^"], "]"}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Omega]", "^"], "**", 
        OverscriptBox["\[Omega]", "^"]}], ")"}], " "}]}]}]}]], "Input"],
 "\n\nand can be evaluated for any assigned { ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "^"], TraditionalForm]]],
 " , ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " } with the functions;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"maketorsion", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["d\[Theta]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "1"], "2"], "+", 
     RowBox[{
      OverscriptBox["\[Theta]", "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "1"], "1"], "-", 
     RowBox[{
      OverscriptBox["\[Theta]", "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["d\[Theta]", "2"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecurvature", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["d\[Omega]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "2"], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "1"], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["d\[Omega]", "2"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The identity element, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "0"], TraditionalForm]]],
 ", appears explicitly because the functions use the ",
 StyleBox["collect", "Input",
  FontWeight->"Plain"],
 " command to group the expressions into coefficients of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 ". These expressions are assigned to the variable names, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[CapitalTheta]", "^"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[CapitalOmega]", "^"], TraditionalForm]]],
 " . They satisfy the general differential identities given in the \
Introduction section."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curvatureidentity", "[", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"torsionidentity", "[", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell["\<\
A general 0-form quaternion with constant components can be constructed by\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["q", "^"], "=", 
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "/.", 
   RowBox[{"\[Omega]", "->", "q"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["q", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   OverscriptBox["q", "2"], " ", 
   SubscriptBox["\[Gamma]", "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["q", "1"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["q", "1"], "2"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the components become scalar fields when established as ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"coeffs", "[", 
   OverscriptBox["q", "^"], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["q", "0"], ",", 
   SubscriptBox[
    OverscriptBox["q", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["q", "1"], "2"], ",", 
   OverscriptBox["q", "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{
   OverscriptBox["q", "^"], "**", 
   RowBox[{"d", "[", 
    OverscriptBox["q", "^"], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      OverscriptBox["q", "2"], " ", 
      SubscriptBox[
       OverscriptBox["dq", "1"], "1"]}], "+", 
     RowBox[{
      OverscriptBox["q", "0"], " ", 
      SubscriptBox[
       OverscriptBox["dq", "1"], "2"]}], "-", 
     RowBox[{
      OverscriptBox["dq", "2"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "1"]}], "+", 
     RowBox[{
      OverscriptBox["dq", "0"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      OverscriptBox["q", "0"], " ", 
      SubscriptBox[
       OverscriptBox["dq", "1"], "1"]}], "-", 
     RowBox[{
      OverscriptBox["q", "2"], " ", 
      SubscriptBox[
       OverscriptBox["dq", "1"], "2"]}], "+", 
     RowBox[{
      OverscriptBox["dq", "0"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "1"]}], "+", 
     RowBox[{
      OverscriptBox["dq", "2"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      OverscriptBox["dq", "2"], " ", 
      OverscriptBox["q", "0"]}], "+", 
     RowBox[{
      OverscriptBox["dq", "0"], " ", 
      OverscriptBox["q", "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["dq", "1"], "2"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["dq", "1"], "1"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      OverscriptBox["dq", "0"], " ", 
      OverscriptBox["q", "0"]}], "-", 
     RowBox[{
      OverscriptBox["dq", "2"], " ", 
      OverscriptBox["q", "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["dq", "1"], "1"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["dq", "1"], "2"], " ", 
      SubscriptBox[
       OverscriptBox["q", "1"], "2"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{
    OverscriptBox["dq", "2"], "\[Wedge]", 
    SubscriptBox[
     OverscriptBox["dq", "1"], "1"]}]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{
    OverscriptBox["dq", "2"], "\[Wedge]", 
    SubscriptBox[
     OverscriptBox["dq", "1"], "2"]}]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["dq", "1"], "1"], "\[Wedge]", 
    SubscriptBox[
     OverscriptBox["dq", "1"], "2"]}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.b.2. Clifford algebra for a spacetime metric", "Subsubsection"],

Cell["Using a Lorentzian 4-space signature:", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makeclifford", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["elements"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Gamma]", "0"], ",", 
   SubscriptBox["\[Gamma]", "1"], ",", 
   SubscriptBox["\[Gamma]", "2"], ",", 
   SubscriptBox["\[Gamma]", "3"], ",", 
   SubscriptBox["\[Gamma]", "4"], ",", 
   SubscriptBox["\[Gamma]", "12"], ",", 
   SubscriptBox["\[Gamma]", "13"], ",", 
   SubscriptBox["\[Gamma]", "14"], ",", 
   SubscriptBox["\[Gamma]", "23"], ",", 
   SubscriptBox["\[Gamma]", "24"], ",", 
   SubscriptBox["\[Gamma]", "34"], ",", 
   SubscriptBox["\[Gamma]", "15"], ",", 
   SubscriptBox["\[Gamma]", "25"], ",", 
   SubscriptBox["\[Gamma]", "35"], ",", 
   SubscriptBox["\[Gamma]", "45"], ",", 
   SubscriptBox["\[Gamma]", "5"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   OverscriptBox["\[Theta]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "4"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "12"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "13"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "14"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "23"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "24"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "34"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "4"], ",", 
   OverscriptBox["\[Theta]", "4"], ",", 
   OverscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "4"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "12"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "13"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "14"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "23"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "24"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "34"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "4"], ",", 
   OverscriptBox["\[Omega]", "4"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "1"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "34"], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "35"], 
      SubscriptBox["\[Gamma]", "45"], 
      SubscriptBox["\[Gamma]", "5"]},
     {
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "15"]},
     {
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "45"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "25"]},
     {
      SubscriptBox["\[Gamma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "4"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      SubscriptBox["\[Gamma]", "35"]},
     {
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "5"], 
      SubscriptBox["\[Gamma]", "45"]},
     {
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "35"], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "5"], 
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "34"]},
     {
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "45"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}]},
     {
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      SubscriptBox["\[Gamma]", "45"], 
      SubscriptBox["\[Gamma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "23"]},
     {
      SubscriptBox["\[Gamma]", "23"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}]},
     {
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "13"]},
     {
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      SubscriptBox["\[Gamma]", "13"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      SubscriptBox["\[Gamma]", "23"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}]},
     {
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "24"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}]},
     {
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "14"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "35"], 
      SubscriptBox["\[Gamma]", "45"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}]},
     {
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "45"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}]},
     {
      SubscriptBox["\[Gamma]", "45"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "13"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}]},
     {
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      SubscriptBox["\[Gamma]", "23"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      SubscriptBox["\[Gamma]", "13"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      SubscriptBox["\[Gamma]", "1"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The general values of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "^"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " , including all grades, are assigned by the ",
 StyleBox["makeclifford", "Input",
  FontWeight->"Plain"],
 " command."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 OverscriptBox["\[Theta]", "^"]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["\[Theta]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   OverscriptBox["\[Theta]", "4"], " ", 
   SubscriptBox["\[Gamma]", "5"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "4"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "12"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "13"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "14"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "23"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "24"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "34"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "15"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "25"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "35"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "45"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "3"], "4"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 OverscriptBox["\[Omega]", "^"]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["\[Omega]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   OverscriptBox["\[Omega]", "4"], " ", 
   SubscriptBox["\[Gamma]", "5"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "15"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "25"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "35"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "45"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "3"], "4"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The CAV 2-forms of generalized torsion  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[CapitalTheta]", "^"], TraditionalForm]]],
 "  and curvature  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[CapitalOmega]", "^"], TraditionalForm]]],
 "  can be constructed using those values:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"maketorsion", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["d\[Theta]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "1"], "1"], "+", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "1"], "2"], "+", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "1"], "4"], "+", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "1"], "3"], "+", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "2"], "12"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "45"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "3"], "4"], "-", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "2"], "13"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "2"], "23"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["d\[Theta]", "4"], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "15"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "3"], "1"], "-", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "25"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "3"], "2"], "-", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "35"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "3"], "3"], "-", 
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "2"], "14"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "2"], "24"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Theta]", "2"], "34"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecurvature", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["d\[Omega]", "0"], " ", 
   SubscriptBox["\[Gamma]", "0"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "4"], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "1"], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "2"], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "1"], "3"], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["d\[Omega]", "4"], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "15"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "3"], "1"], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "25"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "3"], "2"], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "45"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "3"], "4"], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "35"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "3"], "3"], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "12"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "13"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "14"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "23"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "24"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["d\[Omega]", "2"], "34"], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["and again the differential identities can be verified.", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"torsionidentity", "[", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curvatureidentity", "[", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The following two commands solve for all ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " by annulling first torsion and then curvature,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zt", "=", 
  RowBox[{"zerotorsion", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["d\[Theta]", "0"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "1"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "1"]}], ")"}]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "2"]}], ")"}]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "3"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "3"]}], ")"}]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "4"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "4"]}], ")"}]}], "-", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "2"], "12"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "2"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "2"], "13"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "3"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "2"], "14"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "4"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "2"], "23"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "3"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "2"], "24"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "4"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "2"], "34"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "4"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "3"], "1"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "3"], "2"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "3"], "3"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "3"], "4"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Theta]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "+", 
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ",", 
   RowBox[{
    OverscriptBox["d\[Theta]", "4"], "\[Rule]", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "3"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zc", "=", 
  RowBox[{"zerocurvature", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["d\[Omega]", "0"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "1"], "1"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "1"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "1"], "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "2"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "1"], "3"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "3"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "1"], "4"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "3"], "4"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "2"], "12"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "2"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "2"], "13"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "3"]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "2"], "14"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "4"]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "2"], "23"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "3"]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "2"], "24"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "4"]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "2"], "34"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Omega]", "1"], "4"]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "3"], "1"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "3"], "2"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "12"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "3"], "3"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "13"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "23"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Omega]", "3"], "4"], "\[Rule]", 
    RowBox[{
     RowBox[{
      OverscriptBox["\[Omega]", "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "14"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "24"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "2"], "34"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}]}]}], ",", 
   RowBox[{
    OverscriptBox["d\[Omega]", "4"], "\[Rule]", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "1"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "1"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "2"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "3"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "3"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Omega]", "1"], "4"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Omega]", "3"], "4"]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and this establishes the solution as ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makedrules", "[", 
   RowBox[{"Join", "[", 
    RowBox[{"zt", ",", "zc"}], "]"}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"applydrules", "[", 
  RowBox[{"{", 
   RowBox[{
    OverscriptBox["\[CapitalTheta]", "^"], ",", 
    OverscriptBox["\[CapitalOmega]", "^"]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "These ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " are shown to represent valid Maurer-Cartan relations of a closed Lie \
algebra by the next result. The inner application ",
 StyleBox["da[forms]", "Input",
  FontWeight->"Plain"],
 " just returns ",
 StyleBox["dforms", "Input",
  FontWeight->"Plain"],
 " and then replaces them by the rhs of the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 ", but the second outer ",
 StyleBox["da[]", "Input",
  FontWeight->"Plain"],
 " differentiates each of those expressions, substitutes back all the ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " into them, and expands the resulting 3-forms. For 32 such lengthy \
expressions, this takes some time."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"da", "[", 
  RowBox[{"da", "[", "forms", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.b.3. A Riemannian geometry problem", "Subsubsection"],

Cell[TextData[{
 "For the following problem of spherically symmetric spacetimes, we use a \
truncated Clifford algebra. The ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " can be truncated since Riemannian geometry only requires doing products up \
to grade[2];"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{"makeclifford", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}], ",", "2"}], 
  "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "1"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "34"]},
     {
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}]},
     {
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "45"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}]},
     {
      SubscriptBox["\[Gamma]", "3"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "4"]},
     {
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "1"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "2"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}]},
     {
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "2"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      SubscriptBox["\[Gamma]", "35"], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "23"], 
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "5"]},
     {
      SubscriptBox["\[Gamma]", "13"], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "45"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "14"]},
     {
      SubscriptBox["\[Gamma]", "14"], 
      SubscriptBox["\[Gamma]", "4"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "35"]}], 
      SubscriptBox["\[Gamma]", "25"], 
      SubscriptBox["\[Gamma]", "1"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "0"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "12"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}]},
     {
      SubscriptBox["\[Gamma]", "23"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "45"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "3"]}], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "13"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "34"]}], 
      SubscriptBox["\[Gamma]", "24"]},
     {
      SubscriptBox["\[Gamma]", "24"], 
      SubscriptBox["\[Gamma]", "35"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "15"], 
      SubscriptBox["\[Gamma]", "2"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "5"]}], 
      SubscriptBox["\[Gamma]", "12"], 
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "23"]}]},
     {
      SubscriptBox["\[Gamma]", "34"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "25"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "15"]}], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "4"]}], 
      SubscriptBox["\[Gamma]", "3"], 
      SubscriptBox["\[Gamma]", "5"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "14"]}], 
      SubscriptBox["\[Gamma]", "13"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "24"]}], 
      SubscriptBox["\[Gamma]", "23"], 
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "0"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
We want the CAV co-frame to be grade[1] and the CAV connection to be grade[2],\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  OverscriptBox["\[Theta]", "^"], "=", 
  RowBox[{"grade", "[", 
   RowBox[{"1", ",", 
    OverscriptBox["\[Theta]", "^"]}], "]"}]}], "\n", 
 RowBox[{
  OverscriptBox["\[Omega]", "^"], "=", 
  RowBox[{"grade", "[", 
   RowBox[{"2", ",", 
    OverscriptBox["\[Omega]", "^"]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "3"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "4"]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "12"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "13"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "14"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "23"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "24"]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "34"]}]}]], "Output"]
}, Open  ]],

Cell["Introduce a set of scalar variables for coordinates,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["dscalars"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dt", ",", "dr", ",", "d\[Theta]", ",", "d\[Phi]"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The input required is to give coordinate expressions for the orthonormal \
frame forms. We specify r as the curvature coordinate in the line element,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"T", "[", "r", "]"}], "2"]}], 
    SuperscriptBox["dt", "2"]}], "+", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"R", "[", "r", "]"}], "2"], 
    SuperscriptBox["dr", "2"]}], "+", " ", 
   RowBox[{
    SuperscriptBox["r", "2"], 
    SuperscriptBox["d\[Theta]", "2"]}], "+", " ", 
   RowBox[{
    SuperscriptBox["r", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], 
    SuperscriptBox["d\[Phi]", "2"]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tocoords", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"coeffs", "[", 
     OverscriptBox["\[Theta]", "^"], "]"}], "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"T", "[", "r", "]"}], "dt"}], ",", 
      RowBox[{
       RowBox[{"R", "[", "r", "]"}], "dr"}], ",", 
      RowBox[{"r", " ", "d\[Theta]"}], ",", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", "d\[Phi]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Theta]", "1"], "1"], "\[Rule]", 
    RowBox[{"dt", " ", 
     RowBox[{"T", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Theta]", "1"], "2"], "\[Rule]", 
    RowBox[{"dr", " ", 
     RowBox[{"R", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Theta]", "1"], "3"], "\[Rule]", 
    RowBox[{"d\[Theta]", " ", "r"}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Theta]", "1"], "4"], "\[Rule]", 
    RowBox[{"d\[Phi]", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "so in the coordinate basis, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "^"], TraditionalForm]]],
 " becomes,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["\[Theta]", "^"], "=", 
  RowBox[{
   OverscriptBox["\[Theta]", "^"], "/.", "tocoords"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dr", " ", 
   RowBox[{"R", "[", "r", "]"}], " ", 
   SubscriptBox["\[Gamma]", "2"]}], "+", 
  RowBox[{"d\[Theta]", " ", "r", " ", 
   SubscriptBox["\[Gamma]", "3"]}], "+", 
  RowBox[{"d\[Phi]", " ", "r", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   SubscriptBox["\[Gamma]", "4"]}], "+", 
  RowBox[{"dt", " ", 
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"T", "[", "r", "]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "At this point, many Clifford algebra approaches define new variable ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " by,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"%", ",", "dscalars"}], "]"}], "->", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Gamma]", "t"], ",", 
     SubscriptBox["\[Gamma]", "r"], ",", 
     SubscriptBox["\[Gamma]", "\[Theta]"], ",", 
     SubscriptBox["\[Gamma]", "\[Phi]"]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "1"], " ", 
     RowBox[{"T", "[", "r", "]"}]}], "\[Rule]", 
    SubscriptBox["\[Gamma]", "t"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["\[Gamma]", "2"]}], "\[Rule]", 
    SubscriptBox["\[Gamma]", "r"]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     SubscriptBox["\[Gamma]", "3"]}], "\[Rule]", 
    SubscriptBox["\[Gamma]", "\[Theta]"]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["\[Gamma]", "4"]}], "\[Rule]", 
    SubscriptBox["\[Gamma]", "\[Phi]"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "giving an equivalent expression for ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "^"], TraditionalForm]]],
 " ,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["\[Theta]", "^"], "/.", "%"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dr", " ", 
   SubscriptBox["\[Gamma]", "r"]}], "+", 
  RowBox[{"dt", " ", 
   SubscriptBox["\[Gamma]", "t"]}], "+", 
  RowBox[{"d\[Theta]", " ", 
   SubscriptBox["\[Gamma]", "\[Theta]"]}], "+", 
  RowBox[{"d\[Phi]", " ", 
   SubscriptBox["\[Gamma]", "\[Phi]"]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["AVF",
  FontSlant->"Italic"],
 " package, however, is based throughout on constant algebra elements with \
any spatial dependence residing in their p-form coefficients."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.b.4. Deriving the field equations", "Subsubsection"],

Cell["\<\
For demonstration, the steps will be presented in detail. Generally most of \
it can be automated, as shown in the Riemann section below.\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "To find the connection we can expand its components on the frame 1-forms, \
using a non-standard matrix of 24 rotation coefficients. Either the \
coordinate, or the orthonormal, basis 1-forms can be used. Here we use the \
coordinate 1-forms, which is a bit more straightforward since it doesn't \
require defining ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MK", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"i", ",", "j"}]], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"1", ",", "1"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "2"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "3"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "4"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "5"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "6"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"2", ",", "1"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "2"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "3"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "4"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "5"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "6"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"3", ",", "1"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "2"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "3"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "4"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "5"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "6"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"4", ",", "1"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "2"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "3"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "4"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "5"}]], ",", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "6"}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"onframe", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"coeffs", "[", 
     OverscriptBox["\[Omega]", "^"], "]"}], "->", 
    RowBox[{"dscalars", ".", "MK"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Omega]", "2"], "12"], "\[Rule]", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "1"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "1"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "1"}]]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Omega]", "2"], "13"], "\[Rule]", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "2"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "2"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "2"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "2"}]]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Omega]", "2"], "14"], "\[Rule]", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "3"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "3"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "3"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "3"}]]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Omega]", "2"], "23"], "\[Rule]", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "4"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "4"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "4"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "4"}]]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Omega]", "2"], "24"], "\[Rule]", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "5"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "5"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "5"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "5"}]]}]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Omega]", "2"], "34"], "\[Rule]", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "6"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "6"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "6"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "6"}]]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["\[Omega]", "^"], "=", 
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "/.", "onframe"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "1"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "1"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "1"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "13"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "2"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "2"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "2"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "2"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "14"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "3"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "3"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "3"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "3"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "23"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "4"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "4"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "4"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "4"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "24"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "5"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "5"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "5"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "5"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"dt", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "6"}]]}], "+", 
     RowBox[{"dr", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "6"}]]}], "+", 
     RowBox[{"d\[Theta]", " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "6"}]]}], "+", 
     RowBox[{"d\[Phi]", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "6"}]]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "With this  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 "  the torsion becomes,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tor", "=", 
  RowBox[{"maketorsion", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "4"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "dt"}]}], "+", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"2", ",", "2"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dr", "\[Wedge]", "dt"}]}], "+", 
     RowBox[{"dr", "\[Wedge]", "d\[Theta]"}], "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "4"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "6"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "4"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"3", ",", "2"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "6"}]], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"4", ",", "2"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "6"}]], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"2", ",", "1"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dr", "\[Wedge]", "dt"}]}], "+", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "4"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "5"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "4"}]], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"3", ",", "1"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "5"}]], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"4", ",", "1"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "5"}]], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "-", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "4"}]], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "5"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "dt"}]}], "+", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"2", ",", "3"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dr", "\[Wedge]", "dt"}]}], "-", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "6"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "5"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "5"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "-", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "6"}]], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"3", ",", "3"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"4", ",", "3"}]], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "6"}]], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"R", "[", "r", "]"}]}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "1"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "dt"}]}], "+", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "2"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], "-", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "1"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "3"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "-", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "1"}]], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "2"}]], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "3"}]], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "3"}]], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "-", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "2"}]], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{
      RowBox[{"dr", "\[Wedge]", "dt"}], " ", 
      RowBox[{
       SuperscriptBox["T", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["The independent 2-forms are given by", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"twobasis", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dr", "\[Wedge]", "d\[Theta]"}], ",", 
    RowBox[{"dr", "\[Wedge]", "d\[Phi]"}], ",", 
    RowBox[{"dr", "\[Wedge]", "dt"}], ",", 
    RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], ",", 
    RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], ",", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dr", "\[Wedge]", "d\[Theta]"}], ",", 
   RowBox[{"dr", "\[Wedge]", "d\[Phi]"}], ",", 
   RowBox[{"dr", "\[Wedge]", "dt"}], ",", 
   RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], ",", 
   RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], ",", 
   RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the List multiplication statement ",
 StyleBox["Outer[]", "Input",
  FontWeight->"Plain"],
 " constructs the 24 independent  (gammas)*(twobasis) components,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"comps", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Outer", "[", 
    RowBox[{"Times", ",", 
     RowBox[{"prune", "[", 
      RowBox[{"elements", ",", "tor"}], "]"}], ",", "twobasis"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "1"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "1"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "1"], " ", 
    RowBox[{"dr", "\[Wedge]", "dt"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "1"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "1"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "1"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "2"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "2"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "2"], " ", 
    RowBox[{"dr", "\[Wedge]", "dt"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "2"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "2"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "2"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "3"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "3"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "3"], " ", 
    RowBox[{"dr", "\[Wedge]", "dt"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "3"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "3"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "3"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "4"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "4"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "4"], " ", 
    RowBox[{"dr", "\[Wedge]", "dt"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "4"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Theta]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "4"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Phi]"}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "4"], " ", 
    RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["all coefficients of which must vanish for zero torsion.", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"terms", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"tor", ",", "comps"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"r", " ", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "2"}]]}], "-", 
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "1"}]]}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "3"}]]}], "-", 
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "1"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"R", "[", "r", "]"}]}], " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["T", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], ",", 
   RowBox[{"r", " ", 
    SubscriptBox["K", 
     RowBox[{"1", ",", "2"}]]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["K", 
     RowBox[{"1", ",", "3"}]]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "3"}]]}], "-", 
    RowBox[{"r", " ", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "2"}]]}]}], ",", 
   RowBox[{"r", " ", 
    SubscriptBox["K", 
     RowBox[{"2", ",", "4"}]]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["K", 
     RowBox[{"2", ",", "5"}]]}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"2", ",", "1"}]], " ", 
    RowBox[{"T", "[", "r", "]"}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "4"}]]}], "-", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"3", ",", "1"}]], " ", 
     RowBox[{"T", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"4", ",", "1"}]], " ", 
     RowBox[{"T", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "5"}]]}], "-", 
    RowBox[{"r", " ", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "4"}]]}]}], ",", 
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "4"}]]}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "6"}]]}], "+", 
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "4"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "4"}]]}], "+", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"2", ",", "2"}]], " ", 
     RowBox[{"T", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "2"}]]}], " ", 
    RowBox[{"T", "[", "r", "]"}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"4", ",", "2"}]], " ", 
     RowBox[{"T", "[", "r", "]"}]}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["K", 
     RowBox[{"3", ",", "6"}]]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "r"}], " ", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "6"}]]}], "+", 
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "5"}]]}]}], ",", 
   RowBox[{
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "+", 
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "5"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"R", "[", "r", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "5"}]]}], "+", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"2", ",", "3"}]], " ", 
     RowBox[{"T", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "r"}], " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"3", ",", "3"}]], " ", 
     RowBox[{"T", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "3"}]]}], " ", 
    RowBox[{"T", "[", "r", "]"}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{"r", " ", 
     SubscriptBox["K", 
      RowBox[{"4", ",", "6"}]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["setzero", "Input",
  FontWeight->"Plain"],
 " command simply equates its list of arguments to zero giving equations for ",
 StyleBox["Solve", "Input",
  FontWeight->"Plain"],
 ","
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqns", "=", 
  RowBox[{"setzero", "[", "terms", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "2"}]]}], "-", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "1"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "3"}]]}], "-", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "1"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"R", "[", "r", "]"}]}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     RowBox[{
      SuperscriptBox["T", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "2"}]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"1", ",", "3"}]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "3"}]]}], "-", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "2"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "4"}]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"2", ",", "5"}]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"2", ",", "1"}]], " ", 
     RowBox[{"T", "[", "r", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "4"}]]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"3", ",", "1"}]], " ", 
      RowBox[{"T", "[", "r", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "5"}]]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"4", ",", "1"}]], " ", 
      RowBox[{"T", "[", "r", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "5"}]]}], "-", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "4"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "4"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "6"}]]}], "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "4"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "4"}]]}], "+", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"2", ",", "2"}]], " ", 
      RowBox[{"T", "[", "r", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "2"}]]}], " ", 
     RowBox[{"T", "[", "r", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "6"}]]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"4", ",", "2"}]], " ", 
      RowBox[{"T", "[", "r", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     SubscriptBox["K", 
      RowBox[{"3", ",", "6"}]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "r"}], " ", 
      SubscriptBox["K", 
       RowBox[{"2", ",", "6"}]]}], "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"3", ",", "5"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], "+", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "5"}]]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "5"}]]}], "+", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"2", ",", "3"}]], " ", 
      RowBox[{"T", "[", "r", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "r"}], " ", 
      SubscriptBox["K", 
       RowBox[{"1", ",", "6"}]]}], "-", 
     RowBox[{
      SubscriptBox["K", 
       RowBox[{"3", ",", "3"}]], " ", 
      RowBox[{"T", "[", "r", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "3"}]]}], " ", 
     RowBox[{"T", "[", "r", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"r", " ", 
      SubscriptBox["K", 
       RowBox[{"4", ",", "6"}]]}]}], "\[Equal]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Flatten", "[", "MK", "]"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["T", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], 
     RowBox[{"R", "[", "r", "]"}]]}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"1", ",", "5"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"1", ",", "6"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"2", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"2", ",", "5"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"2", ",", "6"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"3", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"3", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"3", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"R", "[", "r", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"3", ",", "5"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"3", ",", "6"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"4", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"4", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"4", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"4", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"4", ",", "5"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"R", "[", "r", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["K", 
     RowBox[{"4", ",", "6"}]], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and the final result for ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " is,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["\[Omega]", "^"], "=", 
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "/.", "soln"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"d\[Theta]", " ", 
     SubscriptBox["\[Gamma]", "23"]}], 
    RowBox[{"R", "[", "r", "]"}]]}], "-", 
  FractionBox[
   RowBox[{"d\[Phi]", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[Gamma]", "24"]}], 
   RowBox[{"R", "[", "r", "]"}]], "-", 
  RowBox[{"d\[Phi]", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   SubscriptBox["\[Gamma]", "34"]}], "+", 
  FractionBox[
   RowBox[{"dt", " ", 
    SubscriptBox["\[Gamma]", "12"], " ", 
    RowBox[{
     SuperscriptBox["T", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   RowBox[{"R", "[", "r", "]"}]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To verify the solution, this ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " can be used to calculate the torsion again,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"maketorsion", "[", "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Constructing the CAV curvature 2-form from this  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "^"], TraditionalForm]]],
 " ,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecurvature", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "34"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Gamma]", "23"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Theta]"}], " ", 
    RowBox[{
     SuperscriptBox["R", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   SuperscriptBox[
    RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[Gamma]", "24"], " ", 
    RowBox[{"dr", "\[Wedge]", "d\[Phi]"}], " ", 
    RowBox[{
     SuperscriptBox["R", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   SuperscriptBox[
    RowBox[{"R", "[", "r", "]"}], "2"]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Gamma]", "13"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
    RowBox[{
     SuperscriptBox["T", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   SuperscriptBox[
    RowBox[{"R", "[", "r", "]"}], "2"]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[Gamma]", "14"], " ", 
    RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
    RowBox[{
     SuperscriptBox["T", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   SuperscriptBox[
    RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"dr", "\[Wedge]", "dt"}], " ", 
        RowBox[{
         SuperscriptBox["R", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"dr", "\[Wedge]", "dt"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"R", "[", "r", "]"}]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "which shows only ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", 
    RowBox[{"i", ",", "j", ",", "i", ",", "j"}]], TraditionalForm]]],
 " components."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[TextData[{
 "The CAV grade[3] 3-form, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["G", "^"], TraditionalForm]]],
 " , is the differential form expression of the Einstein tensor,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["G", "^"], "=", 
  RowBox[{"collect", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"makeeinstein", "[", "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "15"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
      RowBox[{"R", "[", "r", "]"}]], "-", 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"dr", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"]]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "25"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], " ", 
      RowBox[{"T", "[", "r", "]"}], " ", 
      RowBox[{"dt", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"T", "[", "r", "]"}], " ", 
       RowBox[{"dt", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"dt", "\[Wedge]", "d\[Theta]", "\[Wedge]", "d\[Phi]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"]]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "45"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"T", "[", "r", "]"}], " ", 
       RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Theta]"}], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Theta]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"R", "[", "r", "]"}]], "+", 
     FractionBox[
      RowBox[{"r", " ", 
       RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Theta]"}], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"]], "-", 
     FractionBox[
      RowBox[{"r", " ", 
       RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Theta]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"R", "[", "r", "]"}]]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "35"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"T", "[", "r", "]"}], " ", 
        RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["R", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Phi]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"R", "[", "r", "]"}]], "-", 
     FractionBox[
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Phi]"}], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
     FractionBox[
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"dr", "\[Wedge]", "dt", "\[Wedge]", "d\[Phi]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"R", "[", "r", "]"}]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " could be asked to ",
 StyleBox["DSolve", "Input",
  FontWeight->"Plain"],
 " the field equations ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    RowBox[{"G", " "}], "^"], TraditionalForm]]],
 "= 0 but just for demonstration,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Schwarzschild", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"R", "->", 
     RowBox[{"Function", "[", 
      RowBox[{"r", ",", 
       RowBox[{"1", "/", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", 
           RowBox[{"m", "/", "r"}]}]}]]}]}], "]"}]}], ",", 
    RowBox[{"T", "->", 
     RowBox[{"Function", "[", 
      RowBox[{"r", ",", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", 
          RowBox[{"m", "/", "r"}]}]}]]}], "]"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"R", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"r", ",", 
      FractionBox["1", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "m"}], "r"]}]]]}], "]"}]}], ",", 
   RowBox[{"T", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"r", ",", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"2", " ", "m"}], "r"]}]]}], "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   OverscriptBox["G", "^"], "/.", "Schwarzschild"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "One advantage of using orthonormal frame forms is that the built-in Hodge \
star operator becomes available. See section on Hodge duality below. Using \
the ",
 StyleBox["thetas", "Input",
  FontWeight->"Plain"],
 " list, and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Thread", "Input",
  FontWeight->"Plain"],
 " to get the Clifford signature in, saves some typing,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{"signature", "  ", 
   RowBox[{"Take", "[", 
    RowBox[{"thetas", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    SubscriptBox[
     OverscriptBox["\[Theta]", "1"], "1"]}], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "4"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeframe", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "4"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["signature"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "and ",
 StyleBox["frame", "Input",
  FontWeight->"Plain"],
 " is now at the front of ",
 StyleBox["form", "Input",
  FontWeight->"Plain"],
 "s:"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "1"], "4"], ",", 
   OverscriptBox["\[Theta]", "0"], ",", 
   OverscriptBox["\[Omega]", "0"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "12"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "13"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "14"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "23"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "24"], ",", 
   SubscriptBox[
    OverscriptBox["\[Theta]", "2"], "34"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "1"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "2"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "3"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "1"], "4"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "12"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "13"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "14"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "23"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "24"], ",", 
   SubscriptBox[
    OverscriptBox["\[Omega]", "2"], "34"], ",", "dt", ",", "dr", ",", 
   "d\[Theta]", ",", "d\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The Hodge star function is written ",
 StyleBox["hs[arg]", "Input",
  FontWeight->"Plain"],
 "; e.g.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hs", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
  SubscriptBox[
   OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
  SubscriptBox[
   OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
  SubscriptBox[
   OverscriptBox["\[Theta]", "1"], "4"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hs", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Using it on more general expressions requires setting up the inverse \
transformation and appropriate ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 "; i.e.,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toframe", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"tocoords", "/.", 
       RowBox[{"Rule", "->", "Equal"}]}], ")"}], ",", "dscalars"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"dt", "\[Rule]", 
    FractionBox[
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "1"], 
     RowBox[{"T", "[", "r", "]"}]]}], ",", 
   RowBox[{"dr", "\[Rule]", 
    FractionBox[
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "2"], 
     RowBox[{"R", "[", "r", "]"}]]}], ",", 
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "3"], "r"]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"]}], "r"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dframe", "=", 
  RowBox[{"expand", "[", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"frame", "/.", "tocoords"}], "]"}], "/.", "toframe"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "2"]}], " ", 
      RowBox[{
       SuperscriptBox["T", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], 
     RowBox[{
      RowBox[{"R", "[", "r", "]"}], " ", 
      RowBox[{"T", "[", "r", "]"}]}]]}], ",", "0", ",", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "3"]}], 
    RowBox[{"r", " ", 
     RowBox[{"R", "[", "r", "]"}]}]], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"]}], 
     RowBox[{"r", " ", 
      RowBox[{"R", "[", "r", "]"}]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "4"]}]}], "r"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dframerules", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"d", "[", "frame", "]"}], "->", "dframe"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "1"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "2"]}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{
       RowBox[{"R", "[", "r", "]"}], " ", 
       RowBox[{"T", "[", "r", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "3"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"]}], 
     RowBox[{"r", " ", 
      RowBox[{"R", "[", "r", "]"}]}]]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "4"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "4"]}], 
      RowBox[{"r", " ", 
       RowBox[{"R", "[", "r", "]"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "4"]}]}], "r"]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makedrules", "[", 
  RowBox[{"Join", "[", 
   RowBox[{"dframerules", ",", "toframe"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "1"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "1"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "2"]}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{
       RowBox[{"R", "[", "r", "]"}], " ", 
       RowBox[{"T", "[", "r", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "3"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "3"]}], 
     RowBox[{"r", " ", 
      RowBox[{"R", "[", "r", "]"}]}]]}], ",", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["d\[Theta]", "1"], "4"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "2"], "\[Wedge]", 
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "4"]}], 
      RowBox[{"r", " ", 
       RowBox[{"R", "[", "r", "]"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "3"], "\[Wedge]", 
        SubscriptBox[
         OverscriptBox["\[Theta]", "1"], "4"]}]}], "r"]}]}], ",", 
   RowBox[{"dt", "\[Rule]", 
    FractionBox[
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "1"], 
     RowBox[{"T", "[", "r", "]"}]]}], ",", 
   RowBox[{"dr", "\[Rule]", 
    FractionBox[
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "2"], 
     RowBox[{"R", "[", "r", "]"}]]}], ",", 
   RowBox[{"d\[Theta]", "\[Rule]", 
    FractionBox[
     SubscriptBox[
      OverscriptBox["\[Theta]", "1"], "3"], "r"]}], ",", 
   RowBox[{"d\[Phi]", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "4"]}], "r"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The HodgeStar algorithm includes a symmetric product for p-forms of the \
same degree, denoted ",
 StyleBox["dot[p1,p2]", "Input",
  FontWeight->"Plain"],
 ", and with the above ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " it can be used to give the covariant metric tensor in the coordinate \
basis, which simply confirms the set-up statements,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mtx", "[", 
  RowBox[{"Inverse", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"dot", "[", 
      RowBox[{
       RowBox[{"dscalars", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"dscalars", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"T", "[", "r", "]"}], "2"]}], "0", "0", "0"},
     {"0", 
      SuperscriptBox[
       RowBox[{"R", "[", "r", "]"}], "2"], "0", "0"},
     {"0", "0", 
      SuperscriptBox["r", "2"], "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
and the AVF Einstein 3-form can be converted to a dual 1-form, making its \
diagonal structure clearer,\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"collect", "[", 
  RowBox[{"hs", "[", 
   OverscriptBox["G", "^"], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "15"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "1"], 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "1"], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"r", " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "3"]}]]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "25"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      SubscriptBox[
       OverscriptBox["\[Theta]", "1"], "2"], 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "2"], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"r", " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"], " ", 
       RowBox[{"T", "[", "r", "]"}]}]]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "35"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "3"], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"r", " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "3"]}]], "-", 
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "3"], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"r", " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"], " ", 
       RowBox[{"T", "[", "r", "]"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "3"], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "3"], " ", 
       RowBox[{"T", "[", "r", "]"}]}]], "-", 
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "3"], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"], " ", 
       RowBox[{"T", "[", "r", "]"}]}]]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Gamma]", "45"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "4"], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"r", " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "3"]}]], "-", 
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "4"], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"r", " ", 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"], " ", 
       RowBox[{"T", "[", "r", "]"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "4"], " ", 
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "3"], " ", 
       RowBox[{"T", "[", "r", "]"}]}]], "-", 
     FractionBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Theta]", "1"], "4"], " ", 
       RowBox[{
        SuperscriptBox["T", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"], " ", 
       RowBox[{"T", "[", "r", "]"}]}]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/.", "Schwarzschild"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The Hodge operators will return the wave equation for a function of \
coordinates in this metric. Defining the ",
 StyleBox["scalars", "Input",
  FontWeight->"Plain"],
 " as ",
 StyleBox["coords", "Input",
  FontWeight->"Plain"],
 " simply gives a better formatting for partial derivatives;"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makecoords", "[", "scalars", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"\[CapitalPsi]", "[", "depend", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", 
  RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d\[Phi]", " ", 
   SubscriptBox["\[CapitalPsi]", "\[Phi]"]}], "+", 
  RowBox[{"d\[Theta]", " ", 
   SubscriptBox["\[CapitalPsi]", "\[Theta]"]}], "+", 
  RowBox[{"dr", " ", 
   SubscriptBox["\[CapitalPsi]", "r"]}], "+", 
  RowBox[{"dt", " ", 
   SubscriptBox["\[CapitalPsi]", "t"]}]}]], "Output"]
}, Open  ]],

Cell["The scalar wave equation is,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]", "[", 
  RowBox[{"d", "[", "f", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
    SubscriptBox["\[CapitalPsi]", "\<\"\[Phi]\[Phi]\"\>"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[CapitalPsi]", "\[Theta]"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   SubscriptBox["\[CapitalPsi]", "\<\"\[Theta]\[Theta]\"\>"], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalPsi]", "r"]}], 
   RowBox[{"r", " ", 
    SuperscriptBox[
     RowBox[{"R", "[", "r", "]"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["R", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    SubscriptBox["\[CapitalPsi]", "r"]}], 
   SuperscriptBox[
    RowBox[{"R", "[", "r", "]"}], "3"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["T", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    SubscriptBox["\[CapitalPsi]", "r"]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"R", "[", "r", "]"}], "2"], " ", 
    RowBox[{"T", "[", "r", "]"}]}]], "+", 
  FractionBox[
   SubscriptBox["\[CapitalPsi]", "\<\"rr\"\>"], 
   SuperscriptBox[
    RowBox[{"R", "[", "r", "]"}], "2"]], "-", 
  FractionBox[
   SubscriptBox["\[CapitalPsi]", "\<\"tt\"\>"], 
   SuperscriptBox[
    RowBox[{"T", "[", "r", "]"}], "2"]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", "Schwarzschild"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
    SubscriptBox["\[CapitalPsi]", "\<\"\[Phi]\[Phi]\"\>"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[CapitalPsi]", "\[Theta]"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   SubscriptBox["\[CapitalPsi]", "\<\"\[Theta]\[Theta]\"\>"], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", "m", " ", 
    SubscriptBox["\[CapitalPsi]", "r"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "m"}], "r"]}], ")"}], " ", 
    SubscriptBox["\[CapitalPsi]", "r"]}], "r"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"2", " ", "m"}], "r"]}], ")"}], " ", 
   SubscriptBox["\[CapitalPsi]", "\<\"rr\"\>"]}], "-", 
  FractionBox[
   SubscriptBox["\[CapitalPsi]", "\<\"tt\"\>"], 
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{"2", " ", "m"}], "r"]}]]}]], "Output"]
}, Open  ]],

Cell["and for flat spacetime,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"m", "->", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
    SubscriptBox["\[CapitalPsi]", "\<\"\[Phi]\[Phi]\"\>"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[CapitalPsi]", "\[Theta]"]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   SubscriptBox["\[CapitalPsi]", "\<\"\[Theta]\[Theta]\"\>"], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalPsi]", "r"]}], "r"], "+", 
  SubscriptBox["\[CapitalPsi]", "\<\"rr\"\>"], "-", 
  SubscriptBox["\[CapitalPsi]", "\<\"tt\"\>"]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.b.5. Matrix representations for Clifford algebras", "Subsubsection"],

Cell[TextData[{
 "The CAV facilities include a ",
 StyleBox["makematrices[]", "Input",
  FontWeight->"Plain"],
 " command which constructs a set of matrices for the algebra ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " (gammas) of the active Clifford algebra. They are denoted by upper case, \
\[CapitalGamma], with the same indices as the lower case ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 ", so that CAV expressions can be converted to matrix form by replacement of \
the symbol kernel. The matrices have dimension ",
 StyleBox["2^p", "Input",
  FontWeight->"Plain"],
 " with ",
 StyleBox["p=cadim/2", "Input",
  FontWeight->"Plain"],
 " for ",
 StyleBox["cadim", "Input",
  FontWeight->"Plain"],
 " even, and ",
 StyleBox["p=(cadim-1)/2", "Input",
  FontWeight->"Plain"],
 " for ",
 StyleBox["cadim", "Input",
  FontWeight->"Plain"],
 " odd. For example, in the present case,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"makematrices", "[", "]"}], "\n", 
 SubscriptBox["\[CapitalGamma]", "0"], "\n", 
 SubscriptBox["\[CapitalGamma]", "1"]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[ImaginaryI]", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", "\[ImaginaryI]"}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", 
     SubscriptBox["\[CapitalGamma]", "1"]}], ")"}], ".", 
   SubscriptBox["\[CapitalGamma]", "1"]}], "==", 
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["\[CapitalGamma]", "2"], ")"}], ".", 
   SubscriptBox["\[CapitalGamma]", "2"]}], "==", 
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["\[CapitalGamma]", "3"], ")"}], ".", 
   SubscriptBox["\[CapitalGamma]", "3"]}], "==", 
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["\[CapitalGamma]", "4"], ")"}], ".", 
   SubscriptBox["\[CapitalGamma]", "4"]}], "==", 
  SubscriptBox["\[CapitalGamma]", "0"]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 SubscriptBox["\[CapitalGamma]", "24"]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "\[ImaginaryI]"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Gamma]", "24"], "/.", 
  RowBox[{"\[Gamma]", "->", "\[CapitalGamma]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "\[ImaginaryI]"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["and for a CAV expression,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 OverscriptBox["\[Omega]", "^"]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"d\[Theta]", " ", 
     SubscriptBox["\[Gamma]", "23"]}], 
    RowBox[{"R", "[", "r", "]"}]]}], "-", 
  FractionBox[
   RowBox[{"d\[Phi]", " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
    SubscriptBox["\[Gamma]", "24"]}], 
   RowBox[{"R", "[", "r", "]"}]], "-", 
  RowBox[{"d\[Phi]", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   SubscriptBox["\[Gamma]", "34"]}], "+", 
  FractionBox[
   RowBox[{"dt", " ", 
    SubscriptBox["\[Gamma]", "12"], " ", 
    RowBox[{
     SuperscriptBox["T", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   RowBox[{"R", "[", "r", "]"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mat\[Omega]", "=", 
  RowBox[{"%", "/.", 
   RowBox[{"\[Gamma]", "->", "\[CapitalGamma]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "d\[Phi]", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{"R", "[", "r", "]"}]], ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"d\[Phi]", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "d\[Theta]"}], 
       RowBox[{"R", "[", "r", "]"}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "dt", " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"R", "[", "r", "]"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "d\[Phi]", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{"R", "[", "r", "]"}]], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "d\[Phi]"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "d\[Theta]"}], 
       RowBox[{"R", "[", "r", "]"}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "dt", " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"R", "[", "r", "]"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"d\[Phi]", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "d\[Theta]"}], 
       RowBox[{"R", "[", "r", "]"}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "dt", " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"R", "[", "r", "]"}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "d\[Phi]", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
       RowBox[{"R", "[", "r", "]"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "d\[Phi]"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "d\[Theta]"}], 
       RowBox[{"R", "[", "r", "]"}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "dt", " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"R", "[", "r", "]"}]]}], ",", "0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "d\[Phi]", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
       RowBox[{"R", "[", "r", "]"}]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Any AVF matrices can be multiplied by the ",
 StyleBox["CircleTimes", "Input",
  FontWeight->"Plain"],
 " infix operator,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mat\[Omega]", "\[CircleTimes]", "mat\[Omega]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        RowBox[{"R", "[", "r", "]"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        RowBox[{"R", "[", "r", "]"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        SuperscriptBox[
         RowBox[{"R", "[", "r", "]"}], "2"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       RowBox[{"R", "[", "r", "]"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        SuperscriptBox[
         RowBox[{"R", "[", "r", "]"}], "2"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       RowBox[{"R", "[", "r", "]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["which must give the same result as,", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["\[Omega]", "^"], "**", 
   OverscriptBox["\[Omega]", "^"]}], "/.", 
  RowBox[{"\[Gamma]", "->", "\[CapitalGamma]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        RowBox[{"R", "[", "r", "]"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        RowBox[{"R", "[", "r", "]"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        SuperscriptBox[
         RowBox[{"R", "[", "r", "]"}], "2"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       RowBox[{"R", "[", "r", "]"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
        SuperscriptBox[
         RowBox[{"R", "[", "r", "]"}], "2"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Phi]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}], ",", "0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"d\[Theta]", "\[Wedge]", "d\[Phi]"}]}], 
       RowBox[{"R", "[", "r", "]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"dt", "\[Wedge]", "d\[Theta]"}], " ", 
        RowBox[{
         SuperscriptBox["T", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       SuperscriptBox[
        RowBox[{"R", "[", "r", "]"}], "2"]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["makematrices[S]", "Input",
  FontWeight->"Plain"],
 " command will accept as an argument any invertible ",
 StyleBox["2^p", "Input",
  FontWeight->"Plain"],
 " matrix ",
 StyleBox["S", "Input",
  FontWeight->"Plain"],
 " and will perform a similarity transformation ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalGamma]", "i"], TraditionalForm]]],
 "\[Rule] S ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["\[CapitalGamma]", "i"],
     TraditionalForm], 
    SuperscriptBox["S", 
     RowBox[{"-", "1"}]]}], TraditionalForm]]],
 " on the matrices returned by the function. For example,"
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Q", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "a", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "b"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", 
      RowBox[{"-", "c"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "d", ",", "0"}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "a", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "b"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{"-", "c"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "d", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Inverse", "[", "Q", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox["1", "b"]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "a"], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox["1", "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox["1", "c"]}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"makematrices", "[", "Q", "]"}], "\n", 
 SubscriptBox["\[CapitalGamma]", "1"], "\n", 
 SubscriptBox["\[CapitalGamma]", "4"]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "a"}], "b"]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "b"}], "a"]}], ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "c"}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "d"}], "c"], ",", "0"}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "a"}], "c"]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "b"}], "d"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "c"}], "a"], ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "d"}], "b"], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   SubscriptBox["\[CapitalGamma]", "1"], ")"}], ".", 
  SubscriptBox["\[CapitalGamma]", "1"]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["\[CapitalGamma]", "1"], ")"}], ".", 
   SubscriptBox["\[CapitalGamma]", "4"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    SubscriptBox["\[CapitalGamma]", "4"], ")"}], ".", 
   SubscriptBox["\[CapitalGamma]", "1"]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.b.6. The CliffordAlgebras folder", "Subsubsection"],

Cell[TextData[{
 "There is just one CAV variable available before using ",
 StyleBox["makeclifford[]", "Input",
  FontWeight->"Plain"],
 ". Named ",
 StyleBox["clifflist", "Input",
  FontWeight->"Plain"],
 ", it contains a list of the files in the \"CliffordAlgebras\" folder."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData["clifflist"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Cl()\"\>", ",", "\<\"Cl(-)\"\>", ",", "\<\"Cl(+)\"\>", 
   ",", "\<\"Cl(--)\"\>", ",", "\<\"Cl(-+)\"\>", ",", "\<\"Cl(+-)\"\>", 
   ",", "\<\"Cl(++)\"\>", ",", "\<\"Cl(---)\"\>", ",", "\<\"Cl(--+)\"\>", 
   ",", "\<\"Cl(-+-)\"\>", ",", "\<\"Cl(-++)\"\>", ",", "\<\"Cl(+--)\"\>", 
   ",", "\<\"Cl(+-+)\"\>", ",", "\<\"Cl(++-)\"\>", ",", "\<\"Cl(+++)\"\>", 
   ",", "\<\"Cl(-+++)\"\>", ",", "\<\"Cl(+---)\"\>", ",", "\<\"Cl(+++-)\"\>", 
   ",", "\<\"Cl(++++)\"\>", ",", "\<\"Cl(-++++)\"\>", 
   ",", "\<\"Cl(+++++)\"\>", ",", "\<\"Cl(-+++++)\"\>", 
   ",", "\<\"Cl(++++++)\"\>", ",", "\<\"Cl(-++++++++++,2)\"\>", 
   ",", "\<\"Cl(-+++++++++,2)\"\>", ",", "\<\"Cl(-++++++++,2)\"\>", 
   ",", "\<\"Cl(-+++++++,2)\"\>", ",", "\<\"Cl(-++++++,2)\"\>", 
   ",", "\<\"Cl(-+++++,2)\"\>", ",", "\<\"Cl(-++++,2)\"\>", 
   ",", "\<\"Cl(+++++,2)\"\>", ",", "\<\"Cl(-+++,2)\"\>", 
   ",", "\<\"Cl(+++-,2)\"\>", ",", "\<\"Cl(++++,2)\"\>", 
   ",", "\<\"Cl(+---,3)\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Filenames begin with \"Cl\" followed by parentheses containing either 1 or \
2 parameters, separated by commas. The first is just a string of plus and \
minus signs, representing the signature. The second parameter is optional. It \
specifies the highest grade of ",
 StyleBox["elements", "Input",
  FontWeight->"Plain"],
 " (gammas) for which the table of products (",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 ") has been calculated. When omitted, the ",
 StyleBox["algebra", "Input",
  FontWeight->"Plain"],
 " table is constructed for all grades, assuming enough memory is available \
to accomplish it. In the ",
 StyleBox["clifflist", "Input",
  FontWeight->"Plain"],
 " given above, all the higher dimensional algebras (",
 StyleBox["cadim>6", "Input",
  FontWeight->"Plain"],
 ") have been truncated to grade(2) for economy.\n\nNote that the signature \
argument for the ",
 StyleBox["makeclifford[]", "Input",
  FontWeight->"Plain"],
 " function is not in the same format as the filenames. It is typed by giving \
the List of  \[PlusMinus] 1 eigenvalues, as demonstrated in the above \
examples, followed by the grade restriction if desired. After converting that \
List to the appropriate filename, ",
 StyleBox["makeclifford[]", "Input",
  FontWeight->"Plain"],
 " looks for it in ",
 StyleBox["clifflist", "Input",
  FontWeight->"Plain"],
 " and if found, reads the file. For example, the quaternion filename Cl(- -) \
was found and that file was input, as were all the other examples used above.\
\n\nIf the filename of the required algebra is not included in the list, the \
algebra will be constructed, which will take some time for ",
 StyleBox["cadim>5", "Input",
  FontWeight->"Plain"],
 ". Any difference in the signature from those in ",
 StyleBox["clifflist", "Input",
  FontWeight->"Plain"],
 " will launch a new construction; i.e., unless all positions of  \
\[PlusMinus] 1 match. The resulting algebra and associated quantities are \
output to a file in the CliffordAlgebras folder, and it's filename is added \
to ",
 StyleBox["clifflist", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.b.7. Clean up", "Subsubsection"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c. Riemannian geometry with orthonormal frames", "Subsection"],

Cell["This is taken from the file Riemann.nb.", "Text"],

Cell[CellGroupData[{

Cell["IV.c.1. General comments", "Subsubsection"],

Cell[TextData[{
 "Here we calculate the Ricci rotation coefficients, Cartan connection forms, \
and Riemann, Ricci and Weyl curvature components in an orthonormal co-frame, \
orthoframe = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", " ", 
    SubscriptBox["\[Theta]", "i"]}], TraditionalForm]]],
 "},  defined in terms of a set of coordinates. The space may have any \
dimension, and the orthonormal basis may have any ",
 StyleBox["signature", "Input",
  FontWeight->"Plain"],
 "."
}], "Text",
 FontFamily->"Times"],

Cell[TextData[{
 "The algorithm has syntax ",
 StyleBox["makeorthonormalcurvature[signature, tocoords, output]", "Input",
  FontWeight->"Plain"],
 ". If ",
 StyleBox["output=True", "Input",
  FontWeight->"Plain"],
 ", unsimplified results are printed as obtained; ",
 StyleBox["output=False", "Input",
  FontWeight->"Plain"],
 " specifies printing just a line of text describing what's being calculated \
at that time and a name for the results so they can be accessed at the end. \
Then select ",
 StyleBox["toortho", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["rotationcomps", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["ricciscalar", "Input",
  FontWeight->"Plain"],
 ", etc. for what is desired."
}], "Text",
 FontFamily->"Times"],

Cell[TextData[{
 "The ",
 StyleBox["Simplify", "Input",
  FontWeight->"Plain"],
 " commands at the very end of the program can be executed to see the \
results, which are presented as replacement rules obtained from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Solve", "Input",
  FontWeight->"Plain"],
 " command. Unsimplified results can be displayed just by typing their names.\
\n\nA new problem can be inserted by copying one of these problem cells and \
making the appropriate changes in ",
 StyleBox["signature", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["makecoords", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["tocoords", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["explicit", "Input",
  FontWeight->"Plain"],
 ". For speed and economy, it is generally preferable to leave any \
complicated metric functions unspecified, and use ",
 StyleBox["explicit", "Input",
  FontWeight->"Plain"],
 " to replace them at the end."
}], "Text",
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.2. Metric on a spheroid", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"signature", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makecoords", "[", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "\[Phi]"}], "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tocoords", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "->", 
      RowBox[{"r0", " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"k", " ", 
          RowBox[{
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}]], 
       "d\[Theta]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "->", 
      RowBox[{"r0", "  ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "d\[Phi]"}]}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{"dummy", "->", "dummy"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d\[Theta]", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "1"], 
       RowBox[{"r0", " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}], ",", 
     RowBox[{"d\[Phi]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        SubscriptBox["\[Theta]", "2"]}], "r0"]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {
   xAct`AVF`d\[Theta] -> ($CellContext`r0^(-1) (1 - $CellContext`k 
        Sin[xAct`AVF`\[Theta]]^2)^Rational[-1, 2]) 
     Subscript[
      xAct`AVF`\[Theta], 1], $CellContext`d\[Phi] -> ($CellContext`r0^(-1) 
      Csc[xAct`AVF`\[Theta]]) Subscript[xAct`AVF`\[Theta], 2]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
         SubscriptBox["\[Theta]", "2"]}]}], 
       RowBox[{"r0", " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[xAct`AVF`d\[Theta], 1] -> 0, 
    Subscript[
     xAct`AVF`d\[Theta], 
      2] -> (($CellContext`r0^(-1) 
       Cot[xAct`AVF`\[Theta]]) (1 - $CellContext`k Sin[xAct`AVF`\[Theta]]^2)^
       Rational[-1, 2]) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 2]]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "2"}]], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Theta]", "1"]}], " ", 
       SubscriptBox["\[CapitalGamma]", 
        RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       SubscriptBox["\[CapitalGamma]", 
        RowBox[{"2", ",", "1", ",", "2"}]]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"Cot", "[", "\[Theta]", "]"}], 
       RowBox[{"r0", " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 1, 2] -> ($CellContext`r0^(-1) 
      Cot[xAct`AVF`\[Theta]]) (1 - $CellContext`k Sin[xAct`AVF`\[Theta]]^2)^
      Rational[-1, 2]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "2"}]], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SubscriptBox["\[Theta]", "2"]}], 
       RowBox[{"r0", " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]]}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 
      2] -> ((((-1)/$CellContext`r0) 
       Cot[xAct`AVF`\[Theta]]) (1 - $CellContext`k Sin[xAct`AVF`\[Theta]]^2)^
       Rational[-1, 2]) Subscript[xAct`AVF`\[Theta], 2]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", 
      RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
     FractionBox[
      RowBox[{"1", "-", "k"}], 
      RowBox[{
       SuperscriptBox["r0", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "2"]}]]}],
     "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[
     xAct`AVF`R, 1, 2, 1, 
      2] -> ((1 - $CellContext`k) $CellContext`r0^(-2)) (-1 + $CellContext`k 
        Sin[xAct`AVF`\[Theta]]^2)^(-2)}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", "k"}], 
       RowBox[{
        SuperscriptBox["r0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
         "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", "k"}], 
       RowBox[{
        SuperscriptBox["r0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
         "2"]}]]}]}], "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[
     xAct`AVF`R, 1, 
      1] -> ((1 - $CellContext`k) $CellContext`r0^(-2)) (-1 + $CellContext`k 
        Sin[xAct`AVF`\[Theta]]^2)^(-2), Subscript[xAct`AVF`R, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 
      2] -> ((1 - $CellContext`k) $CellContext`r0^(-2)) (-1 + $CellContext`k 
        Sin[xAct`AVF`\[Theta]]^2)^(-2)}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "k"}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
         "2"]}]]}]}], "}"}]}],
  SequenceForm[
  "ricciscalar = ", {
   Subscript[
     xAct`AVF`R, 
      "s"] -> (((-2) (-1 + $CellContext`k)) $CellContext`r0^(-2)) (-1 + \
$CellContext`k Sin[xAct`AVF`\[Theta]]^2)^(-2)}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.3. Ruled surface taken from Eisenhart", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"signature", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makecoords", "[", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tocoords", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "->", "du"}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "->", 
      RowBox[{
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"u", "-", 
            RowBox[{"\[Alpha]", "[", "v", "]"}]}], ")"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"\[Beta]", "[", "v", "]"}], "^", "2"}]}]], "dv"}]}]}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{"dummy", "->", "dummy"}], "}"}]}], ";"}], "\n", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"du", "\[Rule]", 
      SubscriptBox["\[Theta]", "1"]}], ",", 
     RowBox[{"dv", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "2"], 
       SqrtBox[
        RowBox[{
         SuperscriptBox["u", "2"], "-", 
         RowBox[{"2", " ", "u", " ", 
          RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
         SuperscriptBox[
          RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}]]]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {$CellContext`du -> 
    Subscript[xAct`AVF`\[Theta], 1], $CellContext`dv -> 
    Subscript[
      xAct`AVF`\[Theta], 
       2] ($CellContext`u^2 - (
        2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + \
$CellContext`\[Alpha][$CellContext`v]^2 + \
$CellContext`\[Beta][$CellContext`v]^2)^Rational[-1, 2]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
         SubscriptBox["\[Theta]", "2"]}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", 
          RowBox[{"\[Alpha]", "[", "v", "]"}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["u", "2"], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}]]}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[xAct`AVF`d\[Theta], 1] -> 0, Subscript[xAct`AVF`d\[Theta], 2] -> 
    Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[
       xAct`AVF`\[Theta], 
        2]] (($CellContext`u - \
$CellContext`\[Alpha][$CellContext`v])/($CellContext`u^2 - (
       2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + \
$CellContext`\[Alpha][$CellContext`v]^2 + \
$CellContext`\[Beta][$CellContext`v]^2))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "2"}]], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Theta]", "1"]}], " ", 
       SubscriptBox["\[CapitalGamma]", 
        RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       SubscriptBox["\[CapitalGamma]", 
        RowBox[{"2", ",", "1", ",", "2"}]]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"u", "-", 
        RowBox[{"\[Alpha]", "[", "v", "]"}]}], 
       RowBox[{
        SuperscriptBox["u", "2"], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}]]}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 1, 
      2] -> ($CellContext`u - \
$CellContext`\[Alpha][$CellContext`v])/($CellContext`u^2 - (
      2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + $CellContext`\
\[Alpha][$CellContext`v]^2 + $CellContext`\[Beta][$CellContext`v]^2)}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "2"}]], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", 
          RowBox[{"\[Alpha]", "[", "v", "]"}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["u", "2"], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}]]}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-
      Subscript[
       xAct`AVF`\[Theta], 
        2]) (($CellContext`u - \
$CellContext`\[Alpha][$CellContext`v])/($CellContext`u^2 - (
       2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + \
$CellContext`\[Alpha][$CellContext`v]^2 + \
$CellContext`\[Beta][$CellContext`v]^2))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", 
      RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"\[Beta]", "[", "v", "]"}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "2"], "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
          SuperscriptBox[
           RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}], ")"}], "2"]]}]}], 
    "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[
     xAct`AVF`R, 1, 2, 1, 
      2] -> (-$CellContext`\[Beta][$CellContext`v]^2) ($CellContext`u^2 - (
        2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + \
$CellContext`\[Alpha][$CellContext`v]^2 + \
$CellContext`\[Beta][$CellContext`v]^2)^(-2)}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"\[Beta]", "[", "v", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["u", "2"], "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
           SuperscriptBox[
            RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}], ")"}], "2"]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"\[Beta]", "[", "v", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["u", "2"], "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
           SuperscriptBox[
            RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}], ")"}], "2"]]}]}]}], 
    "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[
     xAct`AVF`R, 1, 
      1] -> (-$CellContext`\[Beta][$CellContext`v]^2) ($CellContext`u^2 - (
        2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + \
$CellContext`\[Alpha][$CellContext`v]^2 + \
$CellContext`\[Beta][$CellContext`v]^2)^(-2), Subscript[xAct`AVF`R, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 2, 
      2] -> (-$CellContext`\[Beta][$CellContext`v]^2) ($CellContext`u^2 - (
        2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + \
$CellContext`\[Alpha][$CellContext`v]^2 + \
$CellContext`\[Beta][$CellContext`v]^2)^(-2)}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "2"], "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{"\[Alpha]", "[", "v", "]"}]}], "+", 
          SuperscriptBox[
           RowBox[{"\[Alpha]", "[", "v", "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[Beta]", "[", "v", "]"}], "2"]}], ")"}], "2"]]}]}], 
    "}"}]}],
  SequenceForm[
  "ricciscalar = ", {
   Subscript[
     xAct`AVF`R, 
      "s"] -> ((-2) $CellContext`\[Beta][$CellContext`v]^2) ($CellContext`u^2 - \
(2 $CellContext`u) $CellContext`\[Alpha][$CellContext`v] + $CellContext`\
\[Alpha][$CellContext`v]^2 + $CellContext`\[Beta][$CellContext`v]^2)^(-2)}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.4. Exterior Schwarzschild", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"signature", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]", ",", "t"}], "}"}], 
  "]"}], "\n", 
 RowBox[{
  RowBox[{"tocoords", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "->", 
      RowBox[{"dr", "/", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", 
          RowBox[{"m", "/", "r"}]}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "->", 
      RowBox[{"r", "  ", "d\[Theta]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "3"], "->", 
      RowBox[{"r", "  ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "d\[Phi]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "4"], "->", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", 
          RowBox[{"m", "/", "r"}]}]}]], "  ", "dt"}]}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{"dummy", "->", "dummy"}], "}"}]}], ";"}], "\n", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}], "\n"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]", ",", "t"}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dr", "\[Rule]", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "m"}], "r"]}]], " ", 
       SubscriptBox["\[Theta]", "1"]}]}], ",", 
     RowBox[{"d\[Theta]", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "2"], "r"]}], ",", 
     RowBox[{"d\[Phi]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        SubscriptBox["\[Theta]", "3"]}], "r"]}], ",", 
     RowBox[{"dt", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "4"], 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "m"}], "r"]}]]]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {$CellContext`dr -> (1 - 2 ($CellContext`m/$CellContext`r))^
      Rational[1, 2] Subscript[xAct`AVF`\[Theta], 1], 
    xAct`AVF`d\[Theta] -> $CellContext`r^(-1) 
     Subscript[
      xAct`AVF`\[Theta], 2], $CellContext`d\[Phi] -> ($CellContext`r^(-1) 
      Csc[xAct`AVF`\[Theta]]) 
     Subscript[
      xAct`AVF`\[Theta], 3], $CellContext`dt -> (1 - 
       2 ($CellContext`m/$CellContext`r))^Rational[-1, 2] 
     Subscript[xAct`AVF`\[Theta], 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", "m"}], "r"]}]], " ", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
         SubscriptBox["\[Theta]", "2"]}]}], "r"]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "3"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "m"}], "r"]}]], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "3"]}]}], "+", 
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "3"]}]}]}], "r"]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "4"], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
         SubscriptBox["\[Theta]", "4"]}]}], 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", "m"}], "r"]}]], " ", 
        SuperscriptBox["r", "2"]}]]}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[xAct`AVF`d\[Theta], 1] -> 0, 
    Subscript[
     xAct`AVF`d\[Theta], 
      2] -> ((1 - 2 ($CellContext`m/$CellContext`r))^
       Rational[1, 2]/$CellContext`r) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 2]], 
    Subscript[
     xAct`AVF`d\[Theta], 
      3] -> $CellContext`r^(-1) ((1 - 2 ($CellContext`m/$CellContext`r))^
        Rational[1, 2] Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[xAct`AVF`\[Theta], 3]] + Cot[xAct`AVF`\[Theta]] Wedge[
         Subscript[xAct`AVF`\[Theta], 2], 
         Subscript[xAct`AVF`\[Theta], 3]]), 
    Subscript[
     xAct`AVF`d\[Theta], 
      4] -> (($CellContext`m (1 - 2 ($CellContext`m/$CellContext`r))^
        Rational[-1, 2]) $CellContext`r^(-2)) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 4]]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "2"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "3", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "3", ",", "4"}]]}]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4], 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3], 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4], 
    Subscript[
     xAct`AVF`\[Omega], 3, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "m"}], "r"]}]], "r"]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "m"}], "r"]}]], "r"]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"Cot", "[", "\[Theta]", "]"}], "r"]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["m", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "m"}], "r"]}]], " ", 
         SuperscriptBox["r", "2"]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 1, 
      2] -> (1 - 2 ($CellContext`m/$CellContext`r))^
      Rational[1, 2]/$CellContext`r, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 1, 
      3] -> (1 - 2 ($CellContext`m/$CellContext`r))^
      Rational[1, 2]/$CellContext`r, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] -> $CellContext`r^(-1) 
     Cot[xAct`AVF`\[Theta]], Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] -> 
    0, Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 1, 
      4] -> ((-$CellContext`m) (1 - 2 ($CellContext`m/$CellContext`r))^
       Rational[-1, 2]) $CellContext`r^(-2), 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "m"}], "r"]}]], " ", 
         SubscriptBox["\[Theta]", "2"]}], "r"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "m"}], "r"]}]], " ", 
         SubscriptBox["\[Theta]", "3"]}], "r"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"m", " ", 
         SubscriptBox["\[Theta]", "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "m"}], "r"]}]], " ", 
         SuperscriptBox["r", "2"]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         SubscriptBox["\[Theta]", "3"]}], "r"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 
      2] -> ((-(1 - 2 ($CellContext`m/$CellContext`r))^
        Rational[1, 2])/$CellContext`r) Subscript[xAct`AVF`\[Theta], 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      3] -> ((-(1 - 2 ($CellContext`m/$CellContext`r))^
        Rational[1, 2])/$CellContext`r) Subscript[xAct`AVF`\[Theta], 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      4] -> (((-$CellContext`m) (1 - 2 ($CellContext`m/$CellContext`r))^
        Rational[-1, 2]) $CellContext`r^(-2)) Subscript[xAct`AVF`\[Theta], 4],
     Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (((-1)/$CellContext`r) 
      Cot[xAct`AVF`\[Theta]]) Subscript[xAct`AVF`\[Theta], 3], 
    Subscript[xAct`AVF`\[Omega], 2, 4] -> 0, 
    Subscript[xAct`AVF`\[Omega], 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["m", 
        SuperscriptBox["r", "3"]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["m", 
        SuperscriptBox["r", "3"]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "m"}], 
        SuperscriptBox["r", "3"]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "m"}], 
       SuperscriptBox["r", "3"]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      FractionBox["m", 
       SuperscriptBox["r", "3"]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      FractionBox["m", 
       SuperscriptBox["r", "3"]]}]}], "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[xAct`AVF`R, 1, 2, 1, 2] -> (-$CellContext`m) $CellContext`r^(-3),
     Subscript[xAct`AVF`R, 1, 2, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 2, 1, 4] -> 0, Subscript[xAct`AVF`R, 1, 2, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 1, 2, 2, 4] -> 0, 
    Subscript[xAct`AVF`R, 1, 2, 3, 4] -> 0, Subscript[xAct`AVF`R, 1, 3, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 1, 3, 1, 3] -> (-$CellContext`m) $CellContext`r^(-3), 
    Subscript[xAct`AVF`R, 1, 3, 1, 4] -> 0, Subscript[xAct`AVF`R, 1, 3, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 1, 3, 2, 4] -> 0, 
    Subscript[xAct`AVF`R, 1, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 1, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 1, 4, 1, 3] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 4, 1, 4] -> ((-2) $CellContext`m) $CellContext`r^(-3), 
    Subscript[xAct`AVF`R, 1, 4, 2, 3] -> 0, Subscript[xAct`AVF`R, 1, 4, 2, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 4, 3, 4] -> 0, 
    Subscript[xAct`AVF`R, 2, 3, 1, 2] -> 0, Subscript[xAct`AVF`R, 2, 3, 1, 3] -> 
    0, Subscript[xAct`AVF`R, 2, 3, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 3] -> (2 $CellContext`m) $CellContext`r^(-3), 
    Subscript[xAct`AVF`R, 2, 3, 2, 4] -> 0, Subscript[xAct`AVF`R, 2, 3, 3, 4] -> 
    0, Subscript[xAct`AVF`R, 2, 4, 1, 2] -> 0, 
    Subscript[xAct`AVF`R, 2, 4, 1, 3] -> 0, Subscript[xAct`AVF`R, 2, 4, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 2, 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 2, 4, 2, 4] -> $CellContext`m $CellContext`r^(-3), 
    Subscript[xAct`AVF`R, 2, 4, 3, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 1, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 2, 4] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 3, 4] -> $CellContext`m $CellContext`r^(-3)}],
  
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"4", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[xAct`AVF`R, 1, 1] -> 0, Subscript[xAct`AVF`R, 1, 2] -> 0, 
    Subscript[xAct`AVF`R, 1, 3] -> 0, Subscript[xAct`AVF`R, 1, 4] -> 0, 
    Subscript[xAct`AVF`R, 2, 2] -> 0, Subscript[xAct`AVF`R, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 2, 4] -> 0, Subscript[xAct`AVF`R, 3, 3] -> 0, 
    Subscript[xAct`AVF`R, 3, 4] -> 0, Subscript[xAct`AVF`R, 4, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", "0"}], "}"}]}],
  SequenceForm["ricciscalar = ", {Subscript[xAct`AVF`R, "s"] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Weyl \
tensor:'weylcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"weylcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["m", 
        SuperscriptBox["r", "3"]]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["m", 
        SuperscriptBox["r", "3"]]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "m"}], 
        SuperscriptBox["r", "3"]]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "m"}], 
       SuperscriptBox["r", "3"]]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      FractionBox["m", 
       SuperscriptBox["r", "3"]]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      FractionBox["m", 
       SuperscriptBox["r", "3"]]}]}], "}"}]}],
  SequenceForm[
  "weylcomps = ", {
   Subscript[C, 1, 2, 1, 2] -> (-$CellContext`m) $CellContext`r^(-3), 
    Subscript[C, 1, 2, 1, 3] -> 0, Subscript[C, 1, 2, 1, 4] -> 0, 
    Subscript[C, 1, 2, 2, 3] -> 0, Subscript[C, 1, 2, 2, 4] -> 0, 
    Subscript[C, 1, 2, 3, 4] -> 0, Subscript[C, 1, 3, 1, 2] -> 0, 
    Subscript[C, 1, 3, 1, 3] -> (-$CellContext`m) $CellContext`r^(-3), 
    Subscript[C, 1, 3, 1, 4] -> 0, Subscript[C, 1, 3, 2, 3] -> 0, 
    Subscript[C, 1, 3, 2, 4] -> 0, Subscript[C, 1, 3, 3, 4] -> 0, 
    Subscript[C, 1, 4, 1, 2] -> 0, Subscript[C, 1, 4, 1, 3] -> 0, 
    Subscript[C, 1, 4, 1, 4] -> ((-2) $CellContext`m) $CellContext`r^(-3), 
    Subscript[C, 1, 4, 2, 3] -> 0, Subscript[C, 1, 4, 2, 4] -> 0, 
    Subscript[C, 1, 4, 3, 4] -> 0, 
    Subscript[C, 2, 3, 2, 3] -> (2 $CellContext`m) $CellContext`r^(-3), 
    Subscript[C, 2, 3, 2, 4] -> 0, Subscript[C, 2, 3, 3, 4] -> 0, 
    Subscript[C, 2, 4, 2, 3] -> 0, 
    Subscript[C, 2, 4, 2, 4] -> $CellContext`m $CellContext`r^(-3), 
    Subscript[C, 2, 4, 3, 4] -> 0, 
    Subscript[C, 3, 4, 3, 4] -> $CellContext`m $CellContext`r^(-3)}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.5. Interior Schwarzschild", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"signature", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"makecoords", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]", ",", "t"}], "}"}], 
  "]"}], "\n", 
 RowBox[{
  RowBox[{"tocoords", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "->", 
      RowBox[{"dr", "/", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", "\[Rho]0", " ", 
          RowBox[{
           RowBox[{"r", "^", "2"}], "/", "3"}]}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "->", 
      RowBox[{"r", "  ", "d\[Theta]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "3"], "->", 
      RowBox[{"r", "  ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "d\[Phi]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "4"], "->", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", 
          SqrtBox[
           RowBox[{"1", "-", 
            RowBox[{"2", "\[Rho]0", " ", 
             RowBox[{
              RowBox[{"R", "^", "2"}], "/", "3"}]}]}]]}], "-", 
         SqrtBox[
          RowBox[{"1", "-", 
           RowBox[{"2", "\[Rho]0", " ", 
            RowBox[{
             RowBox[{"r", "^", "2"}], "/", "3"}]}]}]]}], ")"}], "  ", 
       "dt"}]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{"dummy", "->", "dummy"}], "}"}]}], ";"}], "\n", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]", ",", "t"}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dr", "\[Rule]", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "3"]}]], " ", 
       SubscriptBox["\[Theta]", "1"]}]}], ",", 
     RowBox[{"d\[Theta]", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "2"], "r"]}], ",", 
     RowBox[{"d\[Phi]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        SubscriptBox["\[Theta]", "3"]}], "r"]}], ",", 
     RowBox[{"dt", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox["3"], " ", 
         SubscriptBox["\[Theta]", "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{"3", "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{"3", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}]]}]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {$CellContext`dr -> (
       1 + (Rational[-2, 3] $CellContext`r^2) $CellContext`\[Rho]0)^
      Rational[1, 2] Subscript[xAct`AVF`\[Theta], 1], 
    xAct`AVF`d\[Theta] -> $CellContext`r^(-1) 
     Subscript[
      xAct`AVF`\[Theta], 2], $CellContext`d\[Phi] -> ($CellContext`r^(-1) 
      Csc[xAct`AVF`\[Theta]]) 
     Subscript[
      xAct`AVF`\[Theta], 
       3], $CellContext`dt -> ((-3^Rational[1, 2])/((
        3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
      3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])) 
     Subscript[xAct`AVF`\[Theta], 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "3"]}]], " ", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
         SubscriptBox["\[Theta]", "2"]}]}], "r"]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "3"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"9", "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "3"]}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "3"]}]}]}], 
       RowBox[{"3", " ", "r"}]]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "4"], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "r", " ", "\[Rho]0", " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "4"]}]}], 
        RowBox[{
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], 
          ")"}]}]]}]}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[xAct`AVF`d\[Theta], 1] -> 0, 
    Subscript[
     xAct`AVF`d\[Theta], 
      2] -> ($CellContext`r^(-1) (
        1 + (Rational[-2, 3] $CellContext`r^2) $CellContext`\[Rho]0)^
       Rational[1, 2]) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 2]], 
    Subscript[
     xAct`AVF`d\[Theta], 3] -> (
      Rational[1, 
        3]/$CellContext`r) ((9 - (6 $CellContext`r^2) $CellContext`\[Rho]0)^
        Rational[1, 2] Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[xAct`AVF`\[Theta], 3]] + (3 Cot[xAct`AVF`\[Theta]]) Wedge[
         Subscript[xAct`AVF`\[Theta], 2], 
         Subscript[xAct`AVF`\[Theta], 3]]), 
    Subscript[
     xAct`AVF`d\[Theta], 
      4] -> (((((-2) 
         3^Rational[-1, 2]) $CellContext`r) $CellContext`\[Rho]0)/((
        3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
      3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 4]]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "2"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "3", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "3", ",", "4"}]]}]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4], 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3], 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4], 
    Subscript[
     xAct`AVF`\[Omega], 3, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "3"]}]], "r"]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "3"]}]], "r"]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"Cot", "[", "\[Theta]", "]"}], "r"]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "r", " ", "\[Rho]0"}], 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{"3", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}]}]]}], 
     ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 1, 
      2] -> $CellContext`r^(-1) (
       1 + (Rational[-2, 3] $CellContext`r^2) $CellContext`\[Rho]0)^
      Rational[1, 2], Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 1, 
      3] -> $CellContext`r^(-1) (
       1 + (Rational[-2, 3] $CellContext`r^2) $CellContext`\[Rho]0)^
      Rational[1, 2], Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] -> $CellContext`r^(-1) 
     Cot[xAct`AVF`\[Theta]], Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] -> 
    0, Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 1, 
      4] -> ((2 
       3^Rational[-1, 2]) $CellContext`r) ($CellContext`\[Rho]0/((
        3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
      3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])), 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "3"]}]], " ", 
         SubscriptBox["\[Theta]", "2"]}], "r"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "3"]}]], " ", 
         SubscriptBox["\[Theta]", "3"]}], "r"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "r", " ", "\[Rho]0", " ", 
        SubscriptBox["\[Theta]", "4"]}], 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{"3", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}]}]]}], 
     ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         SubscriptBox["\[Theta]", "3"]}], "r"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 
      2] -> (((-1)/$CellContext`r) (
        1 + (Rational[-2, 3] $CellContext`r^2) $CellContext`\[Rho]0)^
       Rational[1, 2]) Subscript[xAct`AVF`\[Theta], 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      3] -> (((-1)/$CellContext`r) (
        1 + (Rational[-2, 3] $CellContext`r^2) $CellContext`\[Rho]0)^
       Rational[1, 2]) Subscript[xAct`AVF`\[Theta], 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      4] -> ((((2 3^Rational[-1, 2]) $CellContext`r) $CellContext`\[Rho]0)/((
        3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
      3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])) 
     Subscript[xAct`AVF`\[Theta], 4], 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (((-1)/$CellContext`r) 
      Cot[xAct`AVF`\[Theta]]) Subscript[xAct`AVF`\[Theta], 3], 
    Subscript[xAct`AVF`\[Omega], 2, 4] -> 0, 
    Subscript[xAct`AVF`\[Omega], 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "\[Rho]0"}], "3"]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "\[Rho]0"}], "3"]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "\[Rho]0", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "+", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}]}], 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}], 
         "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "\[Rho]0"}], "3"]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[Rho]0", " ", 
         SqrtBox[
          RowBox[{"3", "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], 
          ")"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[Rho]0", " ", 
         SqrtBox[
          RowBox[{"3", "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], 
          ")"}]}]]}]}]}], "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[xAct`AVF`R, 1, 2, 1, 2] -> Rational[2, 3] $CellContext`\[Rho]0, 
    Subscript[xAct`AVF`R, 1, 2, 1, 3] -> 0, Subscript[xAct`AVF`R, 1, 2, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 2, 2, 4] -> 0, Subscript[xAct`AVF`R, 1, 2, 3, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 3, 1, 2] -> 0, 
    Subscript[xAct`AVF`R, 1, 3, 1, 3] -> Rational[2, 3] $CellContext`\[Rho]0, 
    Subscript[xAct`AVF`R, 1, 3, 1, 4] -> 0, Subscript[xAct`AVF`R, 1, 3, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 1, 3, 2, 4] -> 0, 
    Subscript[xAct`AVF`R, 1, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 1, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 1, 4, 1, 3] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 4, 1, 
      4] -> ((
       Rational[
        2, 3] $CellContext`\[Rho]0) ((
          3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
        3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^
         Rational[1, 2])^(-2)) (-3 + (
        2 $CellContext`r^2) $CellContext`\[Rho]0 + (
        3 (3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2]) (
         3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2]), 
    Subscript[xAct`AVF`R, 1, 4, 2, 3] -> 0, Subscript[xAct`AVF`R, 1, 4, 2, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 4, 3, 4] -> 0, 
    Subscript[xAct`AVF`R, 2, 3, 1, 2] -> 0, Subscript[xAct`AVF`R, 2, 3, 1, 3] -> 
    0, Subscript[xAct`AVF`R, 2, 3, 1, 4] -> 0, 
    Subscript[xAct`AVF`R, 2, 3, 2, 3] -> Rational[2, 3] $CellContext`\[Rho]0, 
    Subscript[xAct`AVF`R, 2, 3, 2, 4] -> 0, Subscript[xAct`AVF`R, 2, 3, 3, 4] -> 
    0, Subscript[xAct`AVF`R, 2, 4, 1, 2] -> 0, 
    Subscript[xAct`AVF`R, 2, 4, 1, 3] -> 0, Subscript[xAct`AVF`R, 2, 4, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 2, 4, 2, 3] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 4, 2, 4] -> (
      Rational[-2, 3] $CellContext`\[Rho]0) ((
        3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
       Rational[1, 2]/((3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
       Rational[1, 2] - 
      3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])), 
    Subscript[xAct`AVF`R, 2, 4, 3, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 1, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 4, 3, 4] -> (
      Rational[-2, 3] $CellContext`\[Rho]0) ((
        3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
       Rational[1, 2]/((3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
       Rational[1, 2] - 
      3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2]))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", 
      RowBox[{
       FractionBox["2", "3"], " ", "\[Rho]0", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox[
          RowBox[{"3", "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SqrtBox[
              RowBox[{"3", "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
             RowBox[{"3", " ", 
              SqrtBox[
               RowBox[{"3", "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}], 
           "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{
       FractionBox["2", "3"], " ", "\[Rho]0", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox[
          SqrtBox[
           RowBox[{"3", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], 
          RowBox[{
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}]]}], 
        ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox["2", "3"], " ", "\[Rho]0", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox[
          SqrtBox[
           RowBox[{"3", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], 
          RowBox[{
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"3", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}]]}], 
        ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"4", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"2", " ", "\[Rho]0", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "+", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{"3", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}], 
        "2"]]}]}], "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[
     xAct`AVF`R, 1, 1] -> (Rational[2, 3] $CellContext`\[Rho]0) (
      2 + ((3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
         3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])^(-2) (
        3 - (2 $CellContext`r^2) $CellContext`\[Rho]0 - (
         3 (3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2]) (
          3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])), 
    Subscript[xAct`AVF`R, 1, 2] -> 0, Subscript[xAct`AVF`R, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 2] -> (Rational[2, 3] $CellContext`\[Rho]0) (
      2 + (3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
        Rational[1, 2]/((3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
        Rational[1, 2] - 
       3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])), 
    Subscript[xAct`AVF`R, 2, 3] -> 0, Subscript[xAct`AVF`R, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 3] -> (Rational[2, 3] $CellContext`\[Rho]0) (
      2 + (3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
        Rational[1, 2]/((3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^
        Rational[1, 2] - 
       3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])), 
    Subscript[xAct`AVF`R, 3, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 4, 
      4] -> ((2 $CellContext`\[Rho]0) ((
          3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
        3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^
         Rational[1, 2])^(-2)) (-3 + (
        2 $CellContext`r^2) $CellContext`\[Rho]0 + (
        3 (3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2]) (
         3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "\[Rho]0", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "33"}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["r", "2"], " ", "\[Rho]0"}], "+", 
          RowBox[{"18", " ", 
           SuperscriptBox["R", "2"], " ", "\[Rho]0"}], "+", 
          RowBox[{"9", " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{"3", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", "\[Rho]0"}]}]], "-", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{"3", "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["R", "2"], " ", "\[Rho]0"}]}]]}]}], ")"}], 
        "2"]]}]}], "}"}]}],
  SequenceForm[
  "ricciscalar = ", {
   Subscript[
     xAct`AVF`R, 
      "s"] -> (((-4) $CellContext`\[Rho]0) ((
          3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2] - 
        3 (3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^
         Rational[1, 2])^(-2)) (-33 + (
        4 $CellContext`r^2) $CellContext`\[Rho]0 + (18 
        xAct`AVF`R^2) $CellContext`\[Rho]0 + (
        9 (3 - (2 $CellContext`r^2) $CellContext`\[Rho]0)^Rational[1, 2]) (
         3 - (2 xAct`AVF`R^2) $CellContext`\[Rho]0)^Rational[1, 2])}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Weyl \
tensor:'weylcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"weylcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], 
    "}"}]}],
  SequenceForm[
  "weylcomps = ", {
   Subscript[C, 1, 2, 1, 2] -> 0, Subscript[C, 1, 2, 1, 3] -> 0, 
    Subscript[C, 1, 2, 1, 4] -> 0, Subscript[C, 1, 2, 2, 3] -> 0, 
    Subscript[C, 1, 2, 2, 4] -> 0, Subscript[C, 1, 2, 3, 4] -> 0, 
    Subscript[C, 1, 3, 1, 2] -> 0, Subscript[C, 1, 3, 1, 3] -> 0, 
    Subscript[C, 1, 3, 1, 4] -> 0, Subscript[C, 1, 3, 2, 3] -> 0, 
    Subscript[C, 1, 3, 2, 4] -> 0, Subscript[C, 1, 3, 3, 4] -> 0, 
    Subscript[C, 1, 4, 1, 2] -> 0, Subscript[C, 1, 4, 1, 3] -> 0, 
    Subscript[C, 1, 4, 1, 4] -> 0, Subscript[C, 1, 4, 2, 3] -> 0, 
    Subscript[C, 1, 4, 2, 4] -> 0, Subscript[C, 1, 4, 3, 4] -> 0, 
    Subscript[C, 2, 3, 2, 3] -> 0, Subscript[C, 2, 3, 2, 4] -> 0, 
    Subscript[C, 2, 3, 3, 4] -> 0, Subscript[C, 2, 4, 2, 3] -> 0, 
    Subscript[C, 2, 4, 2, 4] -> 0, Subscript[C, 2, 4, 3, 4] -> 0, 
    Subscript[C, 3, 4, 3, 4] -> 0}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.6. Robertson-Walker (closed)", "Subsubsection"],

Cell["\<\
The flat and open models can be obtained by changing \"explicit\" at the end \
and re - simplifying with it.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"signature", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makecoords", "[", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]", ",", "t"}], "}"}], "]"}], 
  ";"}], "\n", 
 RowBox[{"tocoords", "=", "\n", "\t", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "->", 
     RowBox[{
      RowBox[{"R", "[", "t", "]"}], "dr"}]}], ",", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "->", 
     RowBox[{
      RowBox[{"R", "[", "t", "]"}], 
      RowBox[{"S", "[", "r", "]"}], " ", "d\[Theta]"}]}], ",", "\n", "\t\t", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "->", 
     RowBox[{
      RowBox[{"R", "[", "t", "]"}], 
      RowBox[{"S", "[", "r", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "d\[Phi]"}]}], ",", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "->", "dt"}]}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{"S", "->", 
     RowBox[{"Function", "[", 
      RowBox[{"r", ",", 
       RowBox[{"Sin", "[", "r", "]"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "\[Rule]", 
    RowBox[{"dr", " ", 
     RowBox[{"R", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "2"], "\[Rule]", 
    RowBox[{"d\[Theta]", " ", 
     RowBox[{"R", "[", "t", "]"}], " ", 
     RowBox[{"S", "[", "r", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "3"], "\[Rule]", 
    RowBox[{"d\[Phi]", " ", 
     RowBox[{"R", "[", "t", "]"}], " ", 
     RowBox[{"S", "[", "r", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "4"], "\[Rule]", "dt"}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dr", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "1"], 
       RowBox[{"R", "[", "t", "]"}]]}], ",", 
     RowBox[{"d\[Theta]", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "2"], 
       RowBox[{
        RowBox[{"R", "[", "t", "]"}], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{"d\[Phi]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        SubscriptBox["\[Theta]", "3"]}], 
       RowBox[{
        RowBox[{"R", "[", "t", "]"}], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{"dt", "\[Rule]", 
      SubscriptBox["\[Theta]", "4"]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {$CellContext`dr -> 
    xAct`AVF`R[$CellContext`t]^(-1) Subscript[xAct`AVF`\[Theta], 1], 
    xAct`AVF`d\[Theta] -> (
      xAct`AVF`R[$CellContext`t]^(-1)/$CellContext`S[$CellContext`r]) 
     Subscript[
      xAct`AVF`\[Theta], 2], $CellContext`d\[Phi] -> ((Csc[xAct`AVF`\[Theta]]/
       xAct`AVF`R[$CellContext`t])/$CellContext`S[$CellContext`r]) 
     Subscript[xAct`AVF`\[Theta], 3], $CellContext`dt -> 
    Subscript[xAct`AVF`\[Theta], 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "4"]}], " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"R", "[", "t", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S", "[", "r", "]"}]}], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "4"]}], " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "2"]}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{
        RowBox[{"R", "[", "t", "]"}], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "3"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "3"]}]}], "-", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "4"]}], " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "3"]}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{
        RowBox[{"R", "[", "t", "]"}], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "4"], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[
     xAct`AVF`d\[Theta], 1] -> (((-1)/xAct`AVF`R[$CellContext`t]) Wedge[
        Subscript[xAct`AVF`\[Theta], 1], 
        Subscript[xAct`AVF`\[Theta], 4]]) 
     Derivative[1][xAct`AVF`R][$CellContext`t], 
    Subscript[
     xAct`AVF`d\[Theta], 2] -> (
      xAct`AVF`R[$CellContext`t]^(-1)/$CellContext`S[$CellContext`r]) \
(((-$CellContext`S[$CellContext`r]) Wedge[
          Subscript[xAct`AVF`\[Theta], 2], 
          Subscript[xAct`AVF`\[Theta], 4]]) 
       Derivative[1][xAct`AVF`R][$CellContext`t] + Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[xAct`AVF`\[Theta], 2]] 
       Derivative[1][$CellContext`S][$CellContext`r]), 
    Subscript[
     xAct`AVF`d\[Theta], 3] -> (
      xAct`AVF`R[$CellContext`t]^(-1)/$CellContext`S[$CellContext`r]) (
      Cot[xAct`AVF`\[Theta]] Wedge[
         Subscript[xAct`AVF`\[Theta], 2], 
         Subscript[xAct`AVF`\[Theta], 3]] - ($CellContext`S[$CellContext`r] 
       Wedge[
         Subscript[xAct`AVF`\[Theta], 3], 
         Subscript[xAct`AVF`\[Theta], 4]]) 
      Derivative[1][xAct`AVF`R][$CellContext`t] + Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[xAct`AVF`\[Theta], 3]] 
       Derivative[1][$CellContext`S][$CellContext`r]), 
    Subscript[xAct`AVF`d\[Theta], 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "2"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "3", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "3", ",", "4"}]]}]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4], 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3], 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4], 
    Subscript[
     xAct`AVF`\[Omega], 3, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], 
       RowBox[{"R", "[", "t", "]"}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["S", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], 
       RowBox[{
        RowBox[{"R", "[", "t", "]"}], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], 
       RowBox[{"R", "[", "t", "]"}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["S", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], 
       RowBox[{
        RowBox[{"R", "[", "t", "]"}], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"Cot", "[", "\[Theta]", "]"}], 
       RowBox[{
        RowBox[{"R", "[", "t", "]"}], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["R", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], 
       RowBox[{"R", "[", "t", "]"}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] -> 
    xAct`AVF`R[$CellContext`t]^(-1) Derivative[1][xAct`AVF`R][$CellContext`t],
     Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 1, 2] -> (
      xAct`AVF`R[$CellContext`t]^(-1)/$CellContext`S[$CellContext`r]) 
     Derivative[1][$CellContext`S][$CellContext`r], 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] -> 
    xAct`AVF`R[$CellContext`t]^(-1) Derivative[1][xAct`AVF`R][$CellContext`t],
     Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 1, 3] -> (
      xAct`AVF`R[$CellContext`t]^(-1)/$CellContext`S[$CellContext`r]) 
     Derivative[1][$CellContext`S][$CellContext`r], 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] -> 
    Cot[xAct`AVF`\[Theta]] (
      xAct`AVF`R[$CellContext`t]^(-1)/$CellContext`S[$CellContext`r]), 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] -> 
    xAct`AVF`R[$CellContext`t]^(-1) Derivative[1][xAct`AVF`R][$CellContext`t],
     Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[Theta]", "2"], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], 
        RowBox[{
         RowBox[{"R", "[", "t", "]"}], " ", 
         RowBox[{"S", "[", "r", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[Theta]", "3"], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], 
        RowBox[{
         RowBox[{"R", "[", "t", "]"}], " ", 
         RowBox[{"S", "[", "r", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[Theta]", "1"], " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"R", "[", "t", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         SubscriptBox["\[Theta]", "3"]}], 
        RowBox[{
         RowBox[{"R", "[", "t", "]"}], " ", 
         RowBox[{"S", "[", "r", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[Theta]", "2"], " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"R", "[", "t", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[Theta]", "3"], " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"R", "[", "t", "]"}]]}]}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 
      2] -> ((((-1)/
        xAct`AVF`R[$CellContext`t])/$CellContext`S[$CellContext`r]) 
      Subscript[xAct`AVF`\[Theta], 2]) 
     Derivative[1][$CellContext`S][$CellContext`r], 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      3] -> ((((-1)/
        xAct`AVF`R[$CellContext`t])/$CellContext`S[$CellContext`r]) 
      Subscript[xAct`AVF`\[Theta], 3]) 
     Derivative[1][$CellContext`S][$CellContext`r], 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (((-1)/xAct`AVF`R[$CellContext`t]) 
      Subscript[xAct`AVF`\[Theta], 1]) 
     Derivative[1][xAct`AVF`R][$CellContext`t], 
    Subscript[
     xAct`AVF`\[Omega], 2, 
      3] -> (((-Cot[xAct`AVF`\[Theta]])/
       xAct`AVF`R[$CellContext`t])/$CellContext`S[$CellContext`r]) 
     Subscript[xAct`AVF`\[Theta], 3], 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (((-1)/xAct`AVF`R[$CellContext`t]) 
      Subscript[xAct`AVF`\[Theta], 2]) 
     Derivative[1][xAct`AVF`R][$CellContext`t], 
    Subscript[
     xAct`AVF`\[Omega], 3, 4] -> (((-1)/xAct`AVF`R[$CellContext`t]) 
      Subscript[xAct`AVF`\[Theta], 3]) 
     Derivative[1][xAct`AVF`R][$CellContext`t]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["R", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["S", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["R", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["S", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["R", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
        RowBox[{"R", "[", "t", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"S", "[", "r", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["R", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["R", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
        RowBox[{"R", "[", "t", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["R", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
        RowBox[{"R", "[", "t", "]"}]]}]}]}], "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[
     xAct`AVF`R, 1, 2, 1, 2] -> (
      xAct`AVF`R[$CellContext`t]^(-2)/$CellContext`S[$CellContext`r]) \
($CellContext`S[$CellContext`r] Derivative[1][xAct`AVF`R][$CellContext`t]^2 - 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[xAct`AVF`R, 1, 2, 1, 3] -> 0, Subscript[xAct`AVF`R, 1, 2, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 2, 2, 4] -> 0, Subscript[xAct`AVF`R, 1, 2, 3, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 3, 1, 3] -> (
      xAct`AVF`R[$CellContext`t]^(-2)/$CellContext`S[$CellContext`r]) \
($CellContext`S[$CellContext`r] Derivative[1][xAct`AVF`R][$CellContext`t]^2 - 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[xAct`AVF`R, 1, 3, 1, 4] -> 0, Subscript[xAct`AVF`R, 1, 3, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 1, 3, 2, 4] -> 0, 
    Subscript[xAct`AVF`R, 1, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 1, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 1, 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 4, 1, 4] -> ((-1)/xAct`AVF`R[$CellContext`t]) 
     Derivative[2][xAct`AVF`R][$CellContext`t], 
    Subscript[xAct`AVF`R, 1, 4, 2, 3] -> 0, Subscript[xAct`AVF`R, 1, 4, 2, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 4, 3, 4] -> 0, 
    Subscript[xAct`AVF`R, 2, 3, 1, 2] -> 0, Subscript[xAct`AVF`R, 2, 3, 1, 3] -> 
    0, Subscript[xAct`AVF`R, 2, 3, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 3] -> (
      xAct`AVF`R[$CellContext`t]^(-2) $CellContext`S[$CellContext`r]^(-2)) (
      1 + $CellContext`S[$CellContext`r]^2 
       Derivative[1][xAct`AVF`R][$CellContext`t]^2 - 
      Derivative[1][$CellContext`S][$CellContext`r]^2), 
    Subscript[xAct`AVF`R, 2, 3, 2, 4] -> 0, Subscript[xAct`AVF`R, 2, 3, 3, 4] -> 
    0, Subscript[xAct`AVF`R, 2, 4, 1, 2] -> 0, 
    Subscript[xAct`AVF`R, 2, 4, 1, 3] -> 0, Subscript[xAct`AVF`R, 2, 4, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 2, 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 2, 4, 2, 4] -> ((-1)/xAct`AVF`R[$CellContext`t]) 
     Derivative[2][xAct`AVF`R][$CellContext`t], 
    Subscript[xAct`AVF`R, 2, 4, 3, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 1, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 2, 4] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 3, 4] -> ((-1)/xAct`AVF`R[$CellContext`t]) 
     Derivative[2][xAct`AVF`R][$CellContext`t]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"S", "[", "r", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["R", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"R", "[", "t", "]"}], " ", 
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        RowBox[{"S", "[", "r", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"S", "[", "r", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["R", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"R", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["R", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"S", "[", "r", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["R", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"R", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["R", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"4", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"R", "[", "t", "]"}]]}]}]}], "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[
     xAct`AVF`R, 1, 1] -> (
      xAct`AVF`R[$CellContext`t]^(-2)/$CellContext`S[$CellContext`r]) ((
        2 $CellContext`S[$CellContext`r]) 
       Derivative[1][xAct`AVF`R][$CellContext`t]^2 + (
        xAct`AVF`R[$CellContext`t] $CellContext`S[$CellContext`r]) 
       Derivative[2][xAct`AVF`R][$CellContext`t] - 2 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[xAct`AVF`R, 1, 2] -> 0, Subscript[xAct`AVF`R, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 2] -> (
      xAct`AVF`R[$CellContext`t]^(-2) $CellContext`S[$CellContext`r]^(-2)) (1 - 
      Derivative[
       1][$CellContext`S][$CellContext`r]^2 + \
$CellContext`S[$CellContext`r]^2 (
        2 Derivative[1][xAct`AVF`R][$CellContext`t]^2 + 
        xAct`AVF`R[$CellContext`t] 
         Derivative[2][
          xAct`AVF`R][$CellContext`t]) - $CellContext`S[$CellContext`r] 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[xAct`AVF`R, 2, 3] -> 0, Subscript[xAct`AVF`R, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 3] -> (
      xAct`AVF`R[$CellContext`t]^(-2) $CellContext`S[$CellContext`r]^(-2)) (1 - 
      Derivative[
       1][$CellContext`S][$CellContext`r]^2 + \
$CellContext`S[$CellContext`r]^2 (
        2 Derivative[1][xAct`AVF`R][$CellContext`t]^2 + 
        xAct`AVF`R[$CellContext`t] 
         Derivative[2][
          xAct`AVF`R][$CellContext`t]) - $CellContext`S[$CellContext`r] 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[xAct`AVF`R, 3, 4] -> 0, 
    Subscript[xAct`AVF`R, 4, 4] -> ((-3)/xAct`AVF`R[$CellContext`t]) 
     Derivative[2][xAct`AVF`R][$CellContext`t]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", 
     FractionBox[
      RowBox[{"2", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["R", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
          RowBox[{
           RowBox[{"R", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["R", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", 
        RowBox[{"S", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["S", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"R", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"S", "[", "r", "]"}], "2"]}]]}], "}"}]}],
  SequenceForm[
  "ricciscalar = ", {
   Subscript[
     xAct`AVF`R, "s"] -> (
      xAct`AVF`R[$CellContext`t]^(-2) $CellContext`S[$CellContext`r]^(-2)) (2 - 
      2 Derivative[1][$CellContext`S][$CellContext`r]^2 + (
        6 $CellContext`S[$CellContext`r]^2) (
        Derivative[1][xAct`AVF`R][$CellContext`t]^2 + 
        xAct`AVF`R[$CellContext`t] 
         Derivative[2][xAct`AVF`R][$CellContext`t]) - (
       4 $CellContext`S[$CellContext`r]) 
      Derivative[2][$CellContext`S][$CellContext`r])}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Weyl \
tensor:'weylcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"weylcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "-", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "-", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "-", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "+", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "+", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["S", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"], "+", 
        RowBox[{
         RowBox[{"S", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["S", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{"R", "[", "t", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"S", "[", "r", "]"}], "2"]}]]}]}], "}"}]}],
  SequenceForm[
  "weylcomps = ", {
   Subscript[
     C, 1, 2, 1, 
      2] -> ((Rational[1, 6] 
       xAct`AVF`R[$CellContext`t]^(-2)) $CellContext`S[$CellContext`r]^(-2)) \
(-1 + Derivative[
        1][$CellContext`S][$CellContext`r]^2 - $CellContext`S[$CellContext`r] 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[C, 1, 2, 1, 3] -> 0, Subscript[C, 1, 2, 1, 4] -> 0, 
    Subscript[C, 1, 2, 2, 3] -> 0, Subscript[C, 1, 2, 2, 4] -> 0, 
    Subscript[C, 1, 2, 3, 4] -> 0, Subscript[C, 1, 3, 1, 2] -> 0, 
    Subscript[
     C, 1, 3, 1, 
      3] -> ((Rational[1, 6] 
       xAct`AVF`R[$CellContext`t]^(-2)) $CellContext`S[$CellContext`r]^(-2)) \
(-1 + Derivative[
        1][$CellContext`S][$CellContext`r]^2 - $CellContext`S[$CellContext`r] 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[C, 1, 3, 1, 4] -> 0, Subscript[C, 1, 3, 2, 3] -> 0, 
    Subscript[C, 1, 3, 2, 4] -> 0, Subscript[C, 1, 3, 3, 4] -> 0, 
    Subscript[C, 1, 4, 1, 2] -> 0, Subscript[C, 1, 4, 1, 3] -> 0, 
    Subscript[
     C, 1, 4, 1, 
      4] -> ((Rational[1, 3] 
       xAct`AVF`R[$CellContext`t]^(-2)) $CellContext`S[$CellContext`r]^(-2)) \
(-1 + Derivative[
        1][$CellContext`S][$CellContext`r]^2 - $CellContext`S[$CellContext`r] 
      Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[C, 1, 4, 2, 3] -> 0, Subscript[C, 1, 4, 2, 4] -> 0, 
    Subscript[C, 1, 4, 3, 4] -> 0, 
    Subscript[
     C, 2, 3, 2, 
      3] -> ((Rational[1, 3] 
       xAct`AVF`R[$CellContext`t]^(-2)) $CellContext`S[$CellContext`r]^(-2)) (
      1 - Derivative[
       1][$CellContext`S][$CellContext`r]^2 + $CellContext`S[$CellContext`r] 
       Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[C, 2, 3, 2, 4] -> 0, Subscript[C, 2, 3, 3, 4] -> 0, 
    Subscript[C, 2, 4, 2, 3] -> 0, 
    Subscript[
     C, 2, 4, 2, 
      4] -> ((Rational[1, 6] 
       xAct`AVF`R[$CellContext`t]^(-2)) $CellContext`S[$CellContext`r]^(-2)) (
      1 - Derivative[
       1][$CellContext`S][$CellContext`r]^2 + $CellContext`S[$CellContext`r] 
       Derivative[2][$CellContext`S][$CellContext`r]), 
    Subscript[C, 2, 4, 3, 4] -> 0, 
    Subscript[
     C, 3, 4, 3, 
      4] -> ((Rational[1, 6] 
       xAct`AVF`R[$CellContext`t]^(-2)) $CellContext`S[$CellContext`r]^(-2)) (
      1 - Derivative[
       1][$CellContext`S][$CellContext`r]^2 + $CellContext`S[$CellContext`r] 
       Derivative[2][$CellContext`S][$CellContext`r])}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.7. Kerr metric in spheroidal coordinates", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"signature", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makecoords", "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "\[Phi]", ",", "t"}], "}"}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{
    RowBox[{"x", "^", "2"}], "+", 
    RowBox[{"y", "^", "2"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "=", 
   SqrtBox[
    RowBox[{"g", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"h1", "[", "x", "]"}], "-", 
       RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"radius", "=", 
   RowBox[{"\[Delta]", " ", "r0", " ", "\[CapitalPhi]", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"h1", "[", "x", "]"}], " ", 
      RowBox[{"h2", "[", "y", "]"}]}]]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"twist", "=", 
   RowBox[{"2", " ", "\[Delta]", "  ", "m", " ", "x", " ", 
    RowBox[{
     RowBox[{"h2", "[", "y", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"h1", "[", "x", "]"}], "-", 
       RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tocoords", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "->", 
      RowBox[{"r0", " ", 
       SqrtBox[
        RowBox[{"g", "/", 
         RowBox[{"h1", "[", "x", "]"}]}]], "dx"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "->", 
      RowBox[{"r0", " ", 
       SqrtBox[
        RowBox[{"g", "/", 
         RowBox[{"h2", "[", "y", "]"}]}]], "dy"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "3"], "->", 
      RowBox[{"radius", " ", "d\[Phi]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "4"], "->", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dt", "-", 
         RowBox[{"twist", " ", "d\[Phi]"}]}], ")"}], "/", 
       "\[CapitalPhi]"}]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h1", "->", 
      RowBox[{"Function", "[", 
       RowBox[{"x", ",", 
        RowBox[{"1", "+", 
         RowBox[{"x", "^", "2"}], "-", 
         RowBox[{"2", " ", "m", " ", 
          RowBox[{"x", "/", "r0"}]}]}]}], "]"}]}], ",", 
     RowBox[{"h2", "->", 
      RowBox[{"Function", "[", 
       RowBox[{"y", ",", 
        RowBox[{"1", "-", 
         RowBox[{"y", "^", "2"}]}]}], "]"}]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dx", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "1"], 
       RowBox[{"r0", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{"h1", "[", "x", "]"}]]]}]]}], ",", 
     RowBox[{"dy", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "2"], 
       RowBox[{"r0", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{"h2", "[", "y", "]"}]]]}]]}], ",", 
     RowBox[{"d\[Phi]", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "3"], 
       RowBox[{"r0", " ", "\[Delta]", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}]]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]]}]]}], ",", 
     RowBox[{"dt", "\[Rule]", 
      FractionBox[
       RowBox[{
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}]]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "m", " ", "x", " ", 
           RowBox[{"h2", "[", "y", "]"}], " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"r0", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"h1", "[", "x", "]"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}]], " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], 
       RowBox[{"r0", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]]}]]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {$CellContext`dx -> ($CellContext`r0^(-1) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^Rational[-1, 2]) 
     Subscript[
      xAct`AVF`\[Theta], 
       1], $CellContext`dy -> ($CellContext`r0^(-1) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^Rational[-1, 2]) 
     Subscript[
      xAct`AVF`\[Theta], 
       2], $CellContext`d\[Phi] -> ((($CellContext`r0^(-1)/
        xAct`AVF`\[Delta]) (($CellContext`x^2 + \
$CellContext`y^2)/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y]))^
        Rational[-1, 
          2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[-1, 2]) 
     Subscript[
      xAct`AVF`\[Theta], 
       3], $CellContext`dt -> ((($CellContext`r0^(-1)/($CellContext`x^2 + \
$CellContext`y^2)) (($CellContext`x^2 + \
$CellContext`y^2)/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) ((((2 $CellContext`m) $CellContext`x) \
$CellContext`h2[$CellContext`y]) 
       Subscript[
        xAct`AVF`\[Theta], 
         3] + (($CellContext`r0 ($CellContext`x^2 + $CellContext`y^2)) \
($CellContext`h1[$CellContext`x] $CellContext`h2[$CellContext`y])^
         Rational[1, 2]) Subscript[xAct`AVF`\[Theta], 4])}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"y", " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "2"]}]}], 
        RowBox[{"r0", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"h2", "[", "y", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      FractionBox[
       RowBox[{"x", " ", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
         SubscriptBox["\[Theta]", "2"]}]}], 
       RowBox[{"r0", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"h1", "[", "x", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "3"], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "x", " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"]}], 
             RowBox[{"h1", "[", "x", "]"}]]], " ", 
           SuperscriptBox[
            RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
           RowBox[{
            SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
            SubscriptBox["\[Theta]", "3"]}]}], "+", 
          RowBox[{
           RowBox[{"h2", "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "y", " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], 
                RowBox[{"h2", "[", "y", "]"}]]], " ", 
              RowBox[{"h2", "[", "y", "]"}], " ", 
              RowBox[{
               SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
               SubscriptBox["\[Theta]", "3"]}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], 
                 RowBox[{"h1", "[", "x", "]"}]], ")"}], 
               RowBox[{"3", "/", "2"}]], " ", 
              RowBox[{"h1", "[", "x", "]"}], " ", 
              RowBox[{
               SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
               SubscriptBox["\[Theta]", "3"]}], " ", 
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "x", " ", 
              SqrtBox[
               FractionBox[
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], 
                RowBox[{"h1", "[", "x", "]"}]]], " ", 
              RowBox[{
               SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
               SubscriptBox["\[Theta]", "3"]}]}], "-", 
             FractionBox[
              RowBox[{
               SqrtBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], 
                 RowBox[{"h2", "[", "y", "]"}]]], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "y", " ", 
                  RowBox[{"h2", "[", "y", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
              RowBox[{"h2", "[", "y", "]"}]]}], ")"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", "r0", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "4"], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "r0", " ", "x", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h1", "[", "x", "]"}]]], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
           SubscriptBox["\[Theta]", "4"]}]}], "+", 
         RowBox[{"2", " ", "r0", " ", "y", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]]], " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
           SubscriptBox["\[Theta]", "4"]}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "m", " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], 
               RowBox[{"h1", "[", "x", "]"}]]], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "x", "]"}], " ", 
               RowBox[{"h2", "[", "y", "]"}]}]], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "3"]}]}], "+", 
            RowBox[{"2", " ", "r0", " ", "x", " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], 
               RowBox[{"h1", "[", "x", "]"}]]], " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "4"]}]}], "-", 
            RowBox[{"2", " ", "r0", " ", "y", " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], 
               RowBox[{"h2", "[", "y", "]"}]]], " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "4"]}]}], "+", 
            RowBox[{"r0", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], 
                RowBox[{"h1", "[", "x", "]"}]], ")"}], 
              RowBox[{"3", "/", "2"}]], " ", 
             RowBox[{"h1", "[", "x", "]"}], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "4"]}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "m", " ", "x", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], 
               RowBox[{"h1", "[", "x", "]"}]]], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "3"]}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], 
               RowBox[{"h2", "[", "y", "]"}]]], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "3"]}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "m", " ", 
             SqrtBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], 
               RowBox[{"h1", "[", "x", "]"}]]], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "x", "]"}], " ", 
               RowBox[{"h2", "[", "y", "]"}]}]], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "3"]}]}], "-", 
            RowBox[{"r0", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], 
                RowBox[{"h2", "[", "y", "]"}]], ")"}], 
              RowBox[{"3", "/", "2"}]], " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{
              SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
              SubscriptBox["\[Theta]", "4"]}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[
     xAct`AVF`d\[Theta], 
      1] -> (((((-1)/$CellContext`r0) $CellContext`y) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[-3, 2])/$CellContext`h2[$CellContext`y]) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 2]], 
    Subscript[
     xAct`AVF`d\[Theta], 
      2] -> ((($CellContext`r0^(-1) $CellContext`x) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
        Rational[-3, 2])/$CellContext`h1[$CellContext`x]) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 2]], 
    Subscript[
     xAct`AVF`d\[Theta], 
      3] -> (((Rational[-1, 
          2]/$CellContext`r0) ($CellContext`x^2 + \
$CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (((((-2) $CellContext`x) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[1, 2]) $CellContext`h1[$CellContext`x]^2) Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[
         xAct`AVF`\[Theta], 
          3]] + $CellContext`h2[$CellContext`y] ((((
            2 $CellContext`y) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
            Rational[1, 2]) $CellContext`h2[$CellContext`y]) Wedge[
           Subscript[xAct`AVF`\[Theta], 2], 
           Subscript[
           xAct`AVF`\[Theta], 
            3]] + (((($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
            Rational[3, 2] $CellContext`h1[$CellContext`x]) Wedge[
            Subscript[xAct`AVF`\[Theta], 1], 
            Subscript[xAct`AVF`\[Theta], 3]]) 
         Derivative[
          1][$CellContext`h1][$CellContext`x]) + \
($CellContext`h1[$CellContext`x] $CellContext`h2[$CellContext`y]) (((
           2 $CellContext`x) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^Rational[1, 2]) Wedge[
           Subscript[xAct`AVF`\[Theta], 1], 
           Subscript[
           xAct`AVF`\[Theta], 
            3]] - (((($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
           Rational[1, 2]/$CellContext`h2[$CellContext`y]) Wedge[
           Subscript[xAct`AVF`\[Theta], 2], 
           Subscript[xAct`AVF`\[Theta], 3]]) ((
           2 $CellContext`y) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) 
          Derivative[1][$CellContext`h2][$CellContext`y]))), 
    Subscript[
     xAct`AVF`d\[Theta], 
      4] -> (((Rational[
         1, 2] $CellContext`r0^(-2)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ((((((-2) $CellContext`r0) $CellContext`x) \
(($CellContext`x^2 + $CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[1, 2]) $CellContext`h1[$CellContext`x]^2) Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[
         xAct`AVF`\[Theta], 
          4]] + ((((
           2 $CellContext`r0) $CellContext`y) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
          Rational[1, 2]) $CellContext`h2[$CellContext`y]^2) Wedge[
         Subscript[xAct`AVF`\[Theta], 2], 
         Subscript[
         xAct`AVF`\[Theta], 
          4]] + $CellContext`h1[$CellContext`x] (((((-4) $CellContext`m) \
(($CellContext`x^2 + $CellContext`y^2)/$CellContext`h1[$CellContext`x])^
            Rational[
             1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) Wedge[
           Subscript[xAct`AVF`\[Theta], 1], 
           Subscript[
           xAct`AVF`\[Theta], 
            3]] + ((((
             2 $CellContext`r0) $CellContext`x) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
            Rational[1, 2]) $CellContext`h2[$CellContext`y]) Wedge[
           Subscript[xAct`AVF`\[Theta], 1], 
           Subscript[
           xAct`AVF`\[Theta], 4]] - ((((
            2 $CellContext`r0) $CellContext`y) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
           Rational[1, 2]) $CellContext`h2[$CellContext`y]) Wedge[
          Subscript[xAct`AVF`\[Theta], 2], 
          Subscript[
          xAct`AVF`\[Theta], 
           4]] + ((($CellContext`r0 (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
             Rational[3, 2]) $CellContext`h1[$CellContext`x]) Wedge[
            Subscript[xAct`AVF`\[Theta], 1], 
            Subscript[xAct`AVF`\[Theta], 4]]) 
         Derivative[1][$CellContext`h1][$CellContext`x]) + (((
          4 $CellContext`m) $CellContext`x) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
         Rational[
          1, 2]) (((($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^Rational[1, 2] Wedge[
            Subscript[xAct`AVF`\[Theta], 1], 
            Subscript[xAct`AVF`\[Theta], 3]]) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ((($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^Rational[1, 2] Wedge[
           Subscript[xAct`AVF`\[Theta], 2], 
           Subscript[xAct`AVF`\[Theta], 3]]) 
        Derivative[
         1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h2[$CellContext`y] ((((
            4 $CellContext`m) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
            Rational[
             1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) Wedge[
           Subscript[xAct`AVF`\[Theta], 1], 
           Subscript[
           xAct`AVF`\[Theta], 
            3]] - ((($CellContext`r0 (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
            Rational[3, 2]) $CellContext`h2[$CellContext`y]) Wedge[
           Subscript[xAct`AVF`\[Theta], 2], 
           Subscript[xAct`AVF`\[Theta], 4]]) 
        Derivative[1][$CellContext`h2][$CellContext`y]))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "2"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "3", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "3", ",", "4"}]]}]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4], 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3], 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4], 
    Subscript[
     xAct`AVF`\[Omega], 3, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["y", 
        RowBox[{"r0", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"h2", "[", "y", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"m", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h1", "[", "x", "]"}]}], "+", 
           RowBox[{"h2", "[", "y", "]"}], "+", 
           RowBox[{"x", " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
        RowBox[{
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", 
      FractionBox["x", 
       RowBox[{"r0", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"h1", "[", "x", "]"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", "x", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{"h2", "[", "y", "]"}]]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{
         SuperscriptBox["h2", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], 
       RowBox[{
        SuperscriptBox["r0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "x", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "x", "]"}], "2"]}], "+", 
           RowBox[{"2", " ", "x", " ", 
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"]}], ")"}], " ", 
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", "r0", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{"h1", "[", "x", "]"}]]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"h1", "[", "x", "]"}]}], "+", 
          RowBox[{"h2", "[", "y", "]"}], "+", 
          RowBox[{"x", " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{"h2", "[", "y", "]"}]]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "y", " ", 
           SuperscriptBox[
            RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "y", " ", 
              RowBox[{"h2", "[", "y", "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{"2", " ", "r0", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"m", " ", "x", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{
          SuperscriptBox["h2", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], 
        RowBox[{
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], 
          RowBox[{"h1", "[", "x", "]"}]]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"h1", "[", "x", "]"}]}], "+", 
          RowBox[{"h2", "[", "y", "]"}], "+", 
          RowBox[{"x", " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "x", " ", 
         RowBox[{"h1", "[", "x", "]"}]}], "-", 
        RowBox[{"2", " ", "x", " ", 
         RowBox[{"h2", "[", "y", "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["h1", "\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}]}], 
       RowBox[{"2", " ", "r0", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"h1", "[", "x", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"m", " ", "x", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{
          SuperscriptBox["h2", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], 
        RowBox[{
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "y", " ", 
         RowBox[{"h1", "[", "x", "]"}]}], "+", 
        RowBox[{"2", " ", "y", " ", 
         RowBox[{"h2", "[", "y", "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["h2", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], 
       RowBox[{"2", " ", "r0", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"h2", "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"h1", "[", "x", "]"}]}], "+", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[
     xAct`AVF`\[CapitalGamma], 1, 1, 
      2] -> (((-1)/$CellContext`r0) $CellContext`y) ((($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-3, 2]/$CellContext`h2[$CellContext`y]), 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 1, 3, 
      4] -> ((((((-$CellContext`m) $CellContext`r0^(-2)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[
          1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) (-$CellContext`h1[$CellContext`x] + \
$CellContext`h2[$CellContext`y] + $CellContext`x 
       Derivative[1][$CellContext`h1][$CellContext`x]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 1, 
      2] -> ($CellContext`r0^(-1) $CellContext`x) ((($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
       Rational[-3, 2]/$CellContext`h1[$CellContext`x]), 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 3, 
      4] -> (((((($CellContext`m $CellContext`r0^(-2)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
     Derivative[1][$CellContext`h2][$CellContext`y], 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 1, 
      3] -> ((((
         Rational[-1, 
           2]/$CellContext`r0) ($CellContext`x^2 + $CellContext`y^2)^(-2)) \
(($CellContext`x^2 + $CellContext`y^2)/$CellContext`h1[$CellContext`x])^
        Rational[
         1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (((-2) $CellContext`x) \
$CellContext`h1[$CellContext`x]^2 + ((
         2 $CellContext`x) $CellContext`h1[$CellContext`x]) \
$CellContext`h2[$CellContext`y] + (($CellContext`x^2 + $CellContext`y^2) \
$CellContext`h2[$CellContext`y]) 
       Derivative[1][$CellContext`h1][$CellContext`x]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 1, 
      4] -> ((((($CellContext`m $CellContext`r0^(-2)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[
          1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) (-$CellContext`h1[$CellContext`x] + \
$CellContext`h2[$CellContext`y] + $CellContext`x 
       Derivative[1][$CellContext`h1][$CellContext`x]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 2, 
      3] -> ((((
         Rational[
          1, 2]/$CellContext`r0) ($CellContext`x^2 + \
$CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) (((-2) $CellContext`y) $CellContext`h2[$CellContext`y]^2 + \
$CellContext`h1[$CellContext`x] ((
          2 $CellContext`y) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 2, 
      4] -> (((((((-$CellContext`m) $CellContext`r0^(-2)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
     Derivative[1][$CellContext`h2][$CellContext`y], 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 1, 
      3] -> ((((($CellContext`m $CellContext`r0^(-2)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[
          1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) (-$CellContext`h1[$CellContext`x] + \
$CellContext`h2[$CellContext`y] + $CellContext`x 
       Derivative[1][$CellContext`h1][$CellContext`x]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 1, 
      4] -> ((((
         Rational[
          1, 2]/$CellContext`r0) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-3, 
           2])/$CellContext`h1[$CellContext`x])/($CellContext`h1[$CellContext`\
x] - $CellContext`h2[$CellContext`y])) ((
        2 $CellContext`x) $CellContext`h1[$CellContext`x] - (
       2 $CellContext`x) $CellContext`h2[$CellContext`y] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h1][$CellContext`x]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 2, 
      3] -> (((((((-$CellContext`m) $CellContext`r0^(-2)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
     Derivative[1][$CellContext`h2][$CellContext`y], 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 2, 
      4] -> ((((
         Rational[
          1, 2]/$CellContext`r0) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
         Rational[-3, 
           2])/$CellContext`h2[$CellContext`y])/(-$CellContext`h1[$\
CellContext`x] + $CellContext`h2[$CellContext`y])) (((-2) $CellContext`y) \
$CellContext`h1[$CellContext`x] + (
        2 $CellContext`y) $CellContext`h2[$CellContext`y] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y]), 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"y", " ", 
          SubscriptBox["\[Theta]", "1"]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"]}], 
             RowBox[{"h2", "[", "y", "]"}]], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], "-", 
        FractionBox[
         RowBox[{"x", " ", 
          SubscriptBox["\[Theta]", "2"]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"]}], 
             RowBox[{"h1", "[", "x", "]"}]], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"h1", "[", "x", "]"}]}]]}], "r0"]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "r0", " ", "x", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
            SubscriptBox["\[Theta]", "3"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r0", " ", "x", " ", 
               RowBox[{"h2", "[", "y", "]"}], " ", 
               SubscriptBox["\[Theta]", "3"]}], "-", 
              RowBox[{"m", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"h1", "[", "x", "]"}], " ", 
                 RowBox[{"h2", "[", "y", "]"}]}]], " ", 
               SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "m", " ", "x", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"h1", "[", "x", "]"}], " ", 
              RowBox[{"h2", "[", "y", "]"}]}]], " ", 
            SubscriptBox["\[Theta]", "4"], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "m", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"h1", "[", "x", "]"}], " ", 
                 RowBox[{"h2", "[", "y", "]"}]}]], " ", 
               SubscriptBox["\[Theta]", "4"]}], "+", 
              RowBox[{"r0", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               SubscriptBox["\[Theta]", "3"], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r0", " ", "x", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          SubscriptBox["\[Theta]", "4"]}], "-", 
         RowBox[{"2", " ", "m", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h2", "[", "y", "]"}], "+", 
            RowBox[{"x", " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "m", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "x", "]"}], " ", 
               RowBox[{"h2", "[", "y", "]"}]}]], " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"r0", " ", 
             SubscriptBox["\[Theta]", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h1", "[", "x", "]"}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         SuperscriptBox[
          RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "r0", " ", "y", " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"], " ", 
             SubscriptBox["\[Theta]", "3"]}], "+", 
            RowBox[{"2", " ", "m", " ", "x", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "x", "]"}], " ", 
               RowBox[{"h2", "[", "y", "]"}]}]], " ", 
             SubscriptBox["\[Theta]", "4"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{"r0", " ", 
             RowBox[{"h1", "[", "x", "]"}], " ", 
             SubscriptBox["\[Theta]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "y", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "r0", " ", "y", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          SubscriptBox["\[Theta]", "4"]}], "+", 
         RowBox[{"2", " ", "r0", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"], " ", 
          SubscriptBox["\[Theta]", "4"]}], "-", 
         RowBox[{"2", " ", "m", " ", "x", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"r0", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         SuperscriptBox[
          RowBox[{"h2", "[", "y", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"h1", "[", "x", "]"}]}], "+", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SqrtBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"]}], 
             RowBox[{"h1", "[", "x", "]"}]]], " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"h1", "[", "x", "]"}]}], "+", 
             RowBox[{"h2", "[", "y", "]"}], "+", 
             RowBox[{"x", " ", 
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], "-", 
          RowBox[{"x", " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"]}], 
             RowBox[{"h2", "[", "y", "]"}]]], " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 
      2] -> $CellContext`r0^(-1) ((($CellContext`y (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
          Rational[-3, 2])/$CellContext`h2[$CellContext`y]) 
       Subscript[
        xAct`AVF`\[Theta], 
         1] - (($CellContext`x (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-3, 2])/$CellContext`h1[$CellContext`x]) 
      Subscript[xAct`AVF`\[Theta], 2]), 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      3] -> ((((
         Rational[
          1, 2] $CellContext`r0^(-2)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
        Rational[
         1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (((((-2) $CellContext`r0) $CellContext`x) \
$CellContext`h1[$CellContext`x]^2) 
       Subscript[xAct`AVF`\[Theta], 3] + (
        2 $CellContext`h1[$CellContext`x]) ((($CellContext`r0 $CellContext`x) \
$CellContext`h2[$CellContext`y]) 
         Subscript[
          xAct`AVF`\[Theta], 
           3] - ($CellContext`m ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
        Subscript[
         xAct`AVF`\[Theta], 
          4]) + ((((
           2 $CellContext`m) $CellContext`x) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
        Subscript[xAct`AVF`\[Theta], 4]) 
       Derivative[
        1][$CellContext`h1][$CellContext`x] + $CellContext`h2[$CellContext`y] \
(((2 $CellContext`m) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
         Subscript[
          xAct`AVF`\[Theta], 
           4] + (($CellContext`r0 ($CellContext`x^2 + $CellContext`y^2)) 
          Subscript[xAct`AVF`\[Theta], 3]) 
         Derivative[1][$CellContext`h1][$CellContext`x])), 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      4] -> ((((
         Rational[
          1, 2] $CellContext`r0^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-3, 
           2]) $CellContext`h1[$CellContext`x]^(-2))/($CellContext`h1[$\
CellContext`x] - $CellContext`h2[$CellContext`y])) ((((
          2 $CellContext`r0) $CellContext`x) \
$CellContext`h1[$CellContext`x]^2) 
       Subscript[
        xAct`AVF`\[Theta], 4] - (((
         2 $CellContext`m) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
       Subscript[
        xAct`AVF`\[Theta], 
         3]) ($CellContext`h2[$CellContext`y] + $CellContext`x 
        Derivative[
         1][$CellContext`h1][$CellContext`x]) + \
$CellContext`h1[$CellContext`x] (((
           2 $CellContext`m) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
         Subscript[xAct`AVF`\[Theta], 3] - ($CellContext`r0 
         Subscript[
          xAct`AVF`\[Theta], 4]) ((
           2 $CellContext`x) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) 
          Derivative[1][$CellContext`h1][$CellContext`x]))), 
    Subscript[
     xAct`AVF`\[Omega], 2, 
      3] -> ((((
         Rational[-1, 
           2] $CellContext`r0^(-2)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) (((((-2) $CellContext`r0) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2) 
       Subscript[
        xAct`AVF`\[Theta], 
         3] + ((((
           2 $CellContext`m) $CellContext`x) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
        Subscript[xAct`AVF`\[Theta], 4]) 
       Derivative[
        1][$CellContext`h2][$CellContext`y] + (($CellContext`r0 \
$CellContext`h1[$CellContext`x]) 
        Subscript[
         xAct`AVF`\[Theta], 3]) ((
          2 $CellContext`y) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`\[Omega], 2, 
      4] -> ((((
         Rational[
          1, 2] $CellContext`r0^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
         Rational[-3, 
           2]) $CellContext`h2[$CellContext`y]^(-2))/(-$CellContext`h1[$\
CellContext`x] + $CellContext`h2[$CellContext`y])) ((((((-2) $CellContext`r0) \
$CellContext`y) $CellContext`h1[$CellContext`x]) \
$CellContext`h2[$CellContext`y]) 
       Subscript[
        xAct`AVF`\[Theta], 
         4] + (((2 $CellContext`r0) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2) 
       Subscript[
        xAct`AVF`\[Theta], 
         4] - ((((
          2 $CellContext`m) $CellContext`x) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) 
       Subscript[xAct`AVF`\[Theta], 3]) 
      Derivative[
       1][$CellContext`h2][$CellContext`y] - ((($CellContext`r0 \
($CellContext`x^2 + $CellContext`y^2)) $CellContext`h2[$CellContext`y]) 
       Subscript[xAct`AVF`\[Theta], 4]) 
      Derivative[1][$CellContext`h2][$CellContext`y]), 
    Subscript[
     xAct`AVF`\[Omega], 3, 
      4] -> (((($CellContext`m $CellContext`r0^(-2)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) (((($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^Rational[1, 2] 
        Subscript[
         xAct`AVF`\[Theta], 
          1]) (-$CellContext`h1[$CellContext`x] + \
$CellContext`h2[$CellContext`y] + $CellContext`x 
         Derivative[
          1][$CellContext`h1][$CellContext`x]) - (($CellContext`x \
(($CellContext`x^2 + $CellContext`y^2)/$CellContext`h2[$CellContext`y])^
         Rational[1, 2]) Subscript[xAct`AVF`\[Theta], 2]) 
      Derivative[1][$CellContext`h2][$CellContext`y])}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          RowBox[{"h1", "[", "x", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"y", " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h1", "[", "x", "]"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", 
                  SuperscriptBox["x", "2"]}], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", "x", " ", "y", " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{"3", " ", "x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["m", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", "x", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "5"}], " ", 
           RowBox[{"h1", "[", "x", "]"}]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"h2", "[", "y", "]"}]}], "+", 
          RowBox[{"5", " ", "x", " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}], "+", 
          RowBox[{"y", " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "x", "]"}], "2"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "y", "]"}], "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["m", "2"], " ", "x", " ", 
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox["m", "2"], " ", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["m", "2"], " ", "x", " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", 
                  SuperscriptBox["x", "2"]}], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", "x", " ", "y", " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", "x", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "5"}], " ", 
           RowBox[{"h1", "[", "x", "]"}]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"h2", "[", "y", "]"}]}], "+", 
          RowBox[{"5", " ", "x", " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}], "+", 
          RowBox[{"y", " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x", "2"]}], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", " ", 
                   SuperscriptBox["m", "2"]}], "-", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", "y", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "-", 
               RowBox[{"5", " ", 
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h1", "[", "x", "]"}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"h1", "[", "x", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "y", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "y", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "-", 
               RowBox[{"4", " ", "x", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"20", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"]}], "+", 
         RowBox[{"20", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox["m", "2"], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["r0", "2"]}], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "10"}], " ", 
             SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "x", "]"}], "2"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "y", "]"}], "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["m", "2"], " ", "x", " ", 
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox["m", "2"], " ", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["m", "2"], " ", "x", " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h1", "[", "x", "]"}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"h1", "[", "x", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "y", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "y", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "-", 
               RowBox[{"4", " ", "x", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "-", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{"2", " ", "y", " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"3", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", "x", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}], "-", 
          RowBox[{"x", " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}], "-", 
          RowBox[{"5", " ", "y", " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", 
                  SuperscriptBox["x", "2"]}], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", "x", " ", "y", " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"20", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"]}], "+", 
         RowBox[{"20", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox["m", "2"], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["r0", "2"]}], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "10"}], " ", 
             SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"m", " ", "x", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}], "-", 
          RowBox[{"x", " ", 
           RowBox[{
            SuperscriptBox["h1", "\[Prime]",
             MultilineFunction->None], "[", "x", "]"}]}], "-", 
          RowBox[{"5", " ", "y", " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           RowBox[{
            SuperscriptBox["h2", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r0", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], "-", 
          RowBox[{"h2", "[", "y", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{"y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "-", 
               RowBox[{"6", " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{"5", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "-", 
               RowBox[{"3", " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h1", "[", "x", "]"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", 
                  SuperscriptBox["x", "2"]}], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", "x", " ", "y", " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "-", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["m", "2"], " ", "x", " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
         "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{"y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", " ", 
                   SuperscriptBox["m", "2"]}], "-", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", "y", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], 
    "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[
     xAct`AVF`R, 1, 2, 1, 
      2] -> ((Rational[-1, 
         2] $CellContext`r0^(-2)) ($CellContext`x^2 + $CellContext`y^2)^(-3)) \
(((-2) ($CellContext`x^2 - $CellContext`y^2)) $CellContext`h1[$CellContext`x] + \
(2 ($CellContext`x^2 - $CellContext`y^2)) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) ($CellContext`x 
         Derivative[1][$CellContext`h1][$CellContext`x] + $CellContext`y 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[xAct`AVF`R, 1, 2, 1, 3] -> 0, Subscript[xAct`AVF`R, 1, 2, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 2, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 2, 3, 
      4] -> (((((((
            Rational[
             1, 2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ((-$CellContext`h1[$CellContext`x]) ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((-3) \
$CellContext`x^2 + $CellContext`y^2) 
         Derivative[
          1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h2[$CellContext`y] ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((
           4 $CellContext`x) $CellContext`y) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[xAct`AVF`R, 1, 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 3, 1, 
      3] -> (((Rational[
         1, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((
         4 $CellContext`r0^2) ($CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + (
        2 $CellContext`h1[$CellContext`x]^2) ((
          2 (3 $CellContext`m^2 + $CellContext`r0^2 ((-2) $CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ($CellContext`x 
          Derivative[1][$CellContext`h1][$CellContext`x] + $CellContext`y 
          Derivative[1][$CellContext`h2][$CellContext`y])) + ((
         2 $CellContext`h1[$CellContext`x]) $CellContext`h2[$CellContext`y]) \
((2 ((-6) $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y] + ((
           3 $CellContext`x) ((-4) $CellContext`m^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2))) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ($CellContext`y 
           Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
           Derivative[
            2][$CellContext`h1][$CellContext`x])) + \
$CellContext`h2[$CellContext`y] ((
          4 (3 $CellContext`m^2 - $CellContext`r0^2 $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]^2 + (
          3 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] ((((-4) $CellContext`x) ((-6) \
$CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[1][$CellContext`h1][$CellContext`x] - ((
            2 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2)^2) 
          Derivative[2][$CellContext`h1][$CellContext`x]))), 
    Subscript[
     xAct`AVF`R, 1, 3, 1, 
      4] -> ((((($CellContext`m $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[1, 2]) ((-5) $CellContext`h1[$CellContext`x] + 
      5 $CellContext`h2[$CellContext`y] + (5 $CellContext`x) 
       Derivative[1][$CellContext`h1][$CellContext`x] + $CellContext`y 
       Derivative[1][$CellContext`h2][$CellContext`y] - $CellContext`x^2 
      Derivative[2][$CellContext`h1][$CellContext`x] - $CellContext`y^2 
      Derivative[2][$CellContext`h1][$CellContext`x]), 
    Subscript[
     xAct`AVF`R, 1, 3, 2, 
      3] -> (((((
          Rational[
           3, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) ((((4 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h1[$CellContext`x]^2 + (((
          4 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2 - (((
         4 $CellContext`m^2) $CellContext`x) $CellContext`h2[$CellContext`y]) 
      Derivative[
       1][$CellContext`h2][$CellContext`y] + ((((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h1][$CellContext`x]) 
       Derivative[
        1][$CellContext`h2][$CellContext`y] + $CellContext`h1[$CellContext`x] \
(((((-8) $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y] + ((4 $CellContext`m^2) $CellContext`x) 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`R, 1, 3, 2, 
      4] -> (((((((
            Rational[
             1, 2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] (((-8) $CellContext`y) \
$CellContext`h2[$CellContext`y] + ((-3) $CellContext`x^2 + $CellContext`y^2) 
         Derivative[1][$CellContext`h2][$CellContext`y]) + (
        2 $CellContext`h2[$CellContext`y]) ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((
           4 $CellContext`x) $CellContext`y) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[xAct`AVF`R, 1, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 1, 4, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 1, 4, 1, 
      3] -> ((((($CellContext`m $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[1, 2]) ((-5) $CellContext`h1[$CellContext`x] + 
      5 $CellContext`h2[$CellContext`y] + (5 $CellContext`x) 
       Derivative[1][$CellContext`h1][$CellContext`x] + $CellContext`y 
       Derivative[1][$CellContext`h2][$CellContext`y] - $CellContext`x^2 
      Derivative[2][$CellContext`h1][$CellContext`x] - $CellContext`y^2 
      Derivative[2][$CellContext`h1][$CellContext`x]), 
    Subscript[
     xAct`AVF`R, 1, 4, 1, 
      4] -> (((Rational[
         1, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((4 $CellContext`r0^2) (
         3 $CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + $CellContext`h2[$CellContext`y] ((
          4 ($CellContext`m^2 - $CellContext`r0^2 $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[1][$CellContext`h1][$CellContext`x]^2 + (
          2 $CellContext`h2[$CellContext`y]) (($CellContext`x (
             4 $CellContext`m^2 - $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + (($CellContext`r0^2 \
$CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
           Derivative[1][$CellContext`h2][$CellContext`y])) + (
        2 $CellContext`h1[$CellContext`x]^2) ((
          2 ($CellContext`m^2 + $CellContext`r0^2 ((-6) $CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-4) $CellContext`x) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[2][$CellContext`h1][$CellContext`x])) - ((
        2 $CellContext`h1[$CellContext`x]) $CellContext`h2[$CellContext`y]) ((
         4 $CellContext`m^2 - (2 $CellContext`r0^2) (
          3 $CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y] + ($CellContext`x (
          4 $CellContext`m^2 - (
           5 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2))) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ($CellContext`y 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[2][$CellContext`h1][$CellContext`x]))), 
    Subscript[
     xAct`AVF`R, 1, 4, 2, 
      3] -> (((((((
            Rational[-1, 
              2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + (
          2 (3 $CellContext`x^2 - $CellContext`y^2)) 
         Derivative[
          1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h2[$CellContext`y] (((-4) $CellContext`y) \
$CellContext`h2[$CellContext`y] - ((4 $CellContext`x) $CellContext`y) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`R, 1, 4, 2, 
      4] -> (((((
          Rational[
           1, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) ((((20 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h1[$CellContext`x]^2 + (((
          20 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2 + ((((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h1][$CellContext`x]) 
       Derivative[1][$CellContext`h2][$CellContext`y] - (
       4 $CellContext`h2[$CellContext`y]) ((((-$CellContext`r0^2) \
$CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x \
($CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
        Derivative[1][$CellContext`h2][$CellContext`y]) + (
        4 $CellContext`h1[$CellContext`x]) (((((-10) $CellContext`r0^2) \
$CellContext`x) $CellContext`y) $CellContext`h2[$CellContext`y] - \
(($CellContext`r0^2 $CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x \
($CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[xAct`AVF`R, 1, 4, 3, 4] -> 0, Subscript[xAct`AVF`R, 2, 3, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 2, 3, 1, 
      3] -> (((((
          Rational[
           3, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) ((((4 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h1[$CellContext`x]^2 + (((
          4 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2 - (((
         4 $CellContext`m^2) $CellContext`x) $CellContext`h2[$CellContext`y]) 
      Derivative[
       1][$CellContext`h2][$CellContext`y] + ((((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h1][$CellContext`x]) 
       Derivative[
        1][$CellContext`h2][$CellContext`y] + $CellContext`h1[$CellContext`x] \
(((((-8) $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y] + ((4 $CellContext`m^2) $CellContext`x) 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`R, 2, 3, 1, 
      4] -> (((((((
            Rational[-1, 
              2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + (
          2 (3 $CellContext`x^2 - $CellContext`y^2)) 
         Derivative[
          1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h2[$CellContext`y] (((-4) $CellContext`y) \
$CellContext`h2[$CellContext`y] - ((4 $CellContext`x) $CellContext`y) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 
      3] -> (((Rational[
         1, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) ((((-4) $CellContext`r0^2) \
$CellContext`x^2) $CellContext`h1[$CellContext`x]^3 - ((
        2 $CellContext`r0^2) $CellContext`h2[$CellContext`y]^2) ((
         2 ($CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h2[$CellContext`y] + ($CellContext`x^2 + $CellContext`y^2) \
($CellContext`x 
          Derivative[1][$CellContext`h1][$CellContext`x] + $CellContext`y 
          Derivative[1][$CellContext`h2][$CellContext`y])) - (((
         2 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^2) ((-2) $CellContext`h2[$CellContext`y] + (
         2 $CellContext`y) 
        Derivative[
         1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
        Derivative[
         2][$CellContext`h2][$CellContext`y]) + \
$CellContext`h1[$CellContext`x] (((4 $CellContext`r0^2) ($CellContext`x^2 - 
           2 $CellContext`y^2)) $CellContext`h2[$CellContext`y]^2 + (
          3 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h2][$CellContext`y]^2 + (((
            2 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]) ($CellContext`x 
           Derivative[1][$CellContext`h1][$CellContext`x] + (3 $CellContext`y)
             Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[2][$CellContext`h2][$CellContext`y]))), 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 
      4] -> ((((($CellContext`m $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y] - $CellContext`x 
      Derivative[1][$CellContext`h1][$CellContext`x] - (5 $CellContext`y) 
      Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
       Derivative[2][$CellContext`h2][$CellContext`y] + $CellContext`y^2 
       Derivative[2][$CellContext`h2][$CellContext`y]), 
    Subscript[xAct`AVF`R, 2, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 2, 4, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 2, 4, 1, 
      3] -> (((((((
            Rational[
             1, 2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] (((-8) $CellContext`y) \
$CellContext`h2[$CellContext`y] + ((-3) $CellContext`x^2 + $CellContext`y^2) 
         Derivative[1][$CellContext`h2][$CellContext`y]) + (
        2 $CellContext`h2[$CellContext`y]) ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((
           4 $CellContext`x) $CellContext`y) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`R, 2, 4, 1, 
      4] -> (((((
          Rational[
           1, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) ((((20 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h1[$CellContext`x]^2 + (((
          20 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2 + ((((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h1][$CellContext`x]) 
       Derivative[1][$CellContext`h2][$CellContext`y] - (
       4 $CellContext`h2[$CellContext`y]) ((((-$CellContext`r0^2) \
$CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x \
($CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
        Derivative[1][$CellContext`h2][$CellContext`y]) + (
        4 $CellContext`h1[$CellContext`x]) (((((-10) $CellContext`r0^2) \
$CellContext`x) $CellContext`y) $CellContext`h2[$CellContext`y] - \
(($CellContext`r0^2 $CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x \
($CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     xAct`AVF`R, 2, 4, 2, 
      3] -> ((((($CellContext`m $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y] - $CellContext`x 
      Derivative[1][$CellContext`h1][$CellContext`x] - (5 $CellContext`y) 
      Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
       Derivative[2][$CellContext`h2][$CellContext`y] + $CellContext`y^2 
       Derivative[2][$CellContext`h2][$CellContext`y]), 
    Subscript[
     xAct`AVF`R, 2, 4, 2, 
      4] -> (((Rational[
         1, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) ((((-4) $CellContext`r0^2) \
$CellContext`x^2) $CellContext`h1[$CellContext`x]^3 + ((
         2 $CellContext`r0^2) $CellContext`h1[$CellContext`x]^2) ((
          2 ($CellContext`x^2 + 
           3 $CellContext`y^2)) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) ($CellContext`x 
           Derivative[1][$CellContext`h1][$CellContext`x] - $CellContext`y 
          Derivative[
           1][$CellContext`h2][$CellContext`y])) - \
$CellContext`h1[$CellContext`x] ((((-4) $CellContext`r0^2) ($CellContext`x^2 - 
          6 $CellContext`y^2)) $CellContext`h2[$CellContext`y]^2 + (((-4) \
$CellContext`m^2) $CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2)^2) 
        Derivative[
          1][$CellContext`h2][$CellContext`y]^2 + (((
           2 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]) ($CellContext`x 
          Derivative[1][$CellContext`h1][$CellContext`x] - (5 $CellContext`y) 
         Derivative[
          1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[2][$CellContext`h2][$CellContext`y])) + ((
         2 $CellContext`r0^2) $CellContext`h2[$CellContext`y]^2) (((-2) \
($CellContext`x^2 - 
           3 $CellContext`y^2)) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) (((-4) $CellContext`y) 
           Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[2][$CellContext`h2][$CellContext`y]))), 
    Subscript[xAct`AVF`R, 2, 4, 3, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 4, 1, 
      2] -> (((((((
            Rational[
             1, 2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ((-$CellContext`h1[$CellContext`x]) ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((-3) \
$CellContext`x^2 + $CellContext`y^2) 
         Derivative[
          1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h2[$CellContext`y] ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((
           4 $CellContext`x) $CellContext`y) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[xAct`AVF`R, 3, 4, 1, 3] -> 0, Subscript[xAct`AVF`R, 3, 4, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 4, 3, 
      4] -> (((Rational[
         1, 4] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) ((((-4) $CellContext`r0^2) \
$CellContext`x^2) $CellContext`h1[$CellContext`x]^3 - \
$CellContext`h1[$CellContext`x] ((
         4 (2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
            2 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (((
           8 $CellContext`m^2) $CellContext`x) \
$CellContext`h2[$CellContext`y]) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + (((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h2][$CellContext`y]^2) + (
        2 $CellContext`h1[$CellContext`x]^2) ((
          2 ($CellContext`m^2 + $CellContext`r0^2 (
             2 $CellContext`x^2 - $CellContext`y^2))) \
$CellContext`h2[$CellContext`y] + ($CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2)) ($CellContext`x 
           Derivative[1][$CellContext`h1][$CellContext`x] - $CellContext`y 
          Derivative[
           1][$CellContext`h2][$CellContext`y])) + \
$CellContext`h2[$CellContext`y] ((
          4 ($CellContext`m^2 - $CellContext`r0^2 $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[1][$CellContext`h1][$CellContext`x]^2 + (
          2 $CellContext`h2[$CellContext`y]) (($CellContext`x (
             4 $CellContext`m^2 - $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + (($CellContext`r0^2 \
$CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
           Derivative[1][$CellContext`h2][$CellContext`y])))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["m", "2"], " ", "x", " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", 
                   SuperscriptBox["m", "2"], " ", "x"}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r0", "2"], " ", "x", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox["m", "2"], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["r0", "2"]}], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "-", 
         RowBox[{
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{"2", " ", "x", " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{"2", " ", "y", " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["y", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["x", "2"]}], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["r0", "2"], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["y", "2"]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", 
                   SuperscriptBox["m", "2"], " ", "x"}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r0", "2"], " ", "x", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", " ", "x", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"h1", "[", "x", "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{"4", " ", "x", " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"4", " ", "y", " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["y", "2"], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["y", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r0", "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"4", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", 
                   SuperscriptBox["m", "2"], " ", "x"}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r0", "2"], " ", "x", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", 
                   SuperscriptBox["m", "2"], " ", "x"}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["r0", "2"], " ", "x", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], 
    "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[
     xAct`AVF`R, 1, 
      1] -> (((Rational[
         1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) ((((-2) $CellContext`r0^2) \
($CellContext`x^2 + $CellContext`y^2)) $CellContext`h1[$CellContext`x]^3 + ((
         2 $CellContext`h1[$CellContext`x]) $CellContext`h2[$CellContext`y]) \
(((-4) $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
            3 $CellContext`y^2)) $CellContext`h2[$CellContext`y] - ((
          4 $CellContext`m^2) $CellContext`x) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ((2 $CellContext`y) 
           Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
           Derivative[
            2][$CellContext`h1][$CellContext`x])) + \
$CellContext`h1[$CellContext`x]^2 ((
          2 (2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + 
             3 $CellContext`y^2))) $CellContext`h2[$CellContext`y] - \
($CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)) (((-2) \
$CellContext`x) 
          Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y) 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
          Derivative[
           2][$CellContext`h1][$CellContext`x])) + \
$CellContext`h2[$CellContext`y] ((
          2 (2 $CellContext`m^2 + $CellContext`r0^2 (-$CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] (((8 $CellContext`m^2) $CellContext`x - ((
              2 $CellContext`r0^2) $CellContext`x) ($CellContext`x^2 + \
$CellContext`y^2)) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ((2 $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[2][$CellContext`h1][$CellContext`x])))), 
    Subscript[
     xAct`AVF`R, 1, 
      2] -> (((((
          Rational[
           1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) (((((-4) $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h1[$CellContext`x]^2 - (((
         4 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2 + ((((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h1][$CellContext`x]) 
       Derivative[1][$CellContext`h2][$CellContext`y] + (
        2 $CellContext`h1[$CellContext`x]) ((((
            4 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y] + (($CellContext`r0^2 $CellContext`y) \
($CellContext`x^2 + $CellContext`y^2)) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ($CellContext`x ((-2) \
$CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
        Derivative[1][$CellContext`h2][$CellContext`y]) + (
        2 $CellContext`h2[$CellContext`y]) ((((-$CellContext`r0^2) \
$CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] + ($CellContext`x ((-2) \
$CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
         Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[xAct`AVF`R, 1, 3] -> 0, Subscript[xAct`AVF`R, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 
      2] -> (((Rational[
         1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((
         2 $CellContext`r0^2) ($CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 - (($CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2)) $CellContext`h2[$CellContext`y]^2) (
       2 $CellContext`h2[$CellContext`y] + (2 $CellContext`x) 
        Derivative[1][$CellContext`h1][$CellContext`x] - (2 $CellContext`y) 
       Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
        Derivative[2][$CellContext`h2][$CellContext`y] + $CellContext`y^2 
        Derivative[
         2][$CellContext`h2][$CellContext`y]) + \
$CellContext`h1[$CellContext`x] (((2 $CellContext`r0^2) (
           3 $CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[
           1][$CellContext`h2][$CellContext`y]^2 + (((
            2 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]) ((2 $CellContext`x) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`x^2 + \
$CellContext`y^2) 
           Derivative[
            2][$CellContext`h2][$CellContext`y])) - ($CellContext`r0^2 \
$CellContext`h1[$CellContext`x]^2) ((6 $CellContext`x^2 - 
         2 $CellContext`y^2) $CellContext`h2[$CellContext`y] + \
($CellContext`x^2 + $CellContext`y^2) ((2 $CellContext`x) 
          Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y) 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[2][$CellContext`h2][$CellContext`y]))), 
    Subscript[xAct`AVF`R, 2, 3] -> 0, Subscript[xAct`AVF`R, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 
      3] -> (((Rational[
         1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((
         2 $CellContext`r0^2) ($CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + $CellContext`h2[$CellContext`y] ((
          2 (2 $CellContext`m^2 + $CellContext`r0^2 (-$CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] (((8 $CellContext`m^2) $CellContext`x - ((
              2 $CellContext`r0^2) $CellContext`x) ($CellContext`x^2 + \
$CellContext`y^2)) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ((2 $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
            Derivative[
             2][$CellContext`h1][$CellContext`x]))) + \
$CellContext`h1[$CellContext`x]^2 ((
          4 $CellContext`m^2 + (
            6 $CellContext`r0^2) (-$CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y] - ($CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2)) ((2 $CellContext`x) 
          Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y) 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
          Derivative[
           2][$CellContext`h2][$CellContext`y])) + \
$CellContext`h1[$CellContext`x] (((-8) $CellContext`m^2 + (
            6 $CellContext`r0^2) ($CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[
           1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] (((
             4 $CellContext`x) ((-2) $CellContext`m^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ((4 $CellContext`y) 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
              Derivative[2][$CellContext`h2][$CellContext`y]))))), 
    Subscript[
     xAct`AVF`R, 3, 
      4] -> ((((((-$CellContext`m) $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) (
      4 $CellContext`h1[$CellContext`x] - 
      4 $CellContext`h2[$CellContext`y] - (4 $CellContext`x) 
      Derivative[1][$CellContext`h1][$CellContext`x] + (4 $CellContext`y) 
       Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`y^2 
       Derivative[2][$CellContext`h1][$CellContext`x] - $CellContext`x^2 
      Derivative[2][$CellContext`h2][$CellContext`y] - $CellContext`y^2 
      Derivative[2][$CellContext`h2][$CellContext`y]), 
    Subscript[
     xAct`AVF`R, 4, 
      4] -> (((Rational[
         1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((
         2 $CellContext`r0^2) ($CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + $CellContext`h1[$CellContext`x]^2 ((
          4 $CellContext`m^2 + (
            6 $CellContext`r0^2) (-$CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y] + ($CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2)) (((-2) $CellContext`x) 
           Derivative[1][$CellContext`h1][$CellContext`x] - (2 $CellContext`y)
            Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
           Derivative[
            2][$CellContext`h1][$CellContext`x])) + \
$CellContext`h2[$CellContext`y] ((
          2 (2 $CellContext`m^2 + $CellContext`r0^2 (-$CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] (((8 $CellContext`m^2) $CellContext`x - ((
              2 $CellContext`r0^2) $CellContext`x) ($CellContext`x^2 + \
$CellContext`y^2)) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-2) $CellContext`y) 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) 
             Derivative[
              2][$CellContext`h2][$CellContext`y]))) - \
$CellContext`h1[$CellContext`x] ((
         8 $CellContext`m^2 + (
           6 $CellContext`r0^2) (-$CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h2[$CellContext`y]^2 + (((-4) $CellContext`m^2) $CellContext`x^2 + \
$CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[
          1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] (((8 $CellContext`m^2) $CellContext`x - ((
             4 $CellContext`r0^2) $CellContext`x) ($CellContext`x^2 + \
$CellContext`y^2)) 
          Derivative[
           1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-4) $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
             Derivative[2][$CellContext`h2][$CellContext`y])))))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SuperscriptBox["r0", "2"], " ", 
         SuperscriptBox["y", "2"], " ", 
         SuperscriptBox[
          RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["m", "2"], "-", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["r0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "y", " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["h1", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "x", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"h2", "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["m", "2"], "-", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               SuperscriptBox["x", "2"]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["m", "2"], " ", 
               SuperscriptBox["x", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"8", " ", 
                  SuperscriptBox["m", "2"], " ", "x"}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["r0", "2"], " ", "x", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r0", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["h1", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "x", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"h1", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["m", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["x", "2"]}], "+", 
                 SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["m", "2"], " ", 
               SuperscriptBox["x", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["m", "2"], " ", "x"}], "+", 
                 RowBox[{
                  SuperscriptBox["r0", "2"], " ", "x", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["r0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"y", " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        SuperscriptBox["r0", "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], "}"}]}],
  
  SequenceForm[
  "ricciscalar = ", {
   Subscript[
     xAct`AVF`R, 
      "s"] -> (((
        Rational[
         1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) ((((-4) $CellContext`r0^2) \
$CellContext`y^2) $CellContext`h1[$CellContext`x]^3 + \
$CellContext`h1[$CellContext`x]^2 ((
          4 ($CellContext`m^2 - $CellContext`r0^2 ($CellContext`x^2 - 
            2 $CellContext`y^2))) $CellContext`h2[$CellContext`y] - ((
          2 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2)) ((
           2 $CellContext`y) 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
           Derivative[
            2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h2[$CellContext`y] ((
          4 ($CellContext`m^2 - $CellContext`r0^2 $CellContext`x^2)) \
$CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] (((8 $CellContext`m^2) $CellContext`x - ((
              4 $CellContext`r0^2) $CellContext`x) ($CellContext`x^2 + \
$CellContext`y^2)) 
           Derivative[1][$CellContext`h1][$CellContext`x] - ((
            2 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2)^2) (
           Derivative[2][$CellContext`h1][$CellContext`x] + 
           Derivative[
            2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h1[$CellContext`x] (((-4) (
           2 $CellContext`m^2 + $CellContext`r0^2 ((-2) $CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + ((
            4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2) 
         Derivative[1][$CellContext`h2][$CellContext`y]^2 + (
          4 $CellContext`h2[$CellContext`y]) ((((-2) $CellContext`m^2) \
$CellContext`x + ($CellContext`r0^2 $CellContext`x) ($CellContext`x^2 + \
$CellContext`y^2)) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ($CellContext`y 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
              Derivative[2][$CellContext`h2][$CellContext`y])))))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Weyl \
tensor:'weylcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"weylcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x", "2"]}], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"7", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  RowBox[{"5", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  RowBox[{"7", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h1", "[", "x", "]"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", 
                  SuperscriptBox["x", "2"]}], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", "x", " ", "y", " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x", "2"]}], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"11", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "16"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{"5", " ", 
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "14"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", " ", "x", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             RowBox[{"h1", "[", "x", "]"}]}], "-", 
            RowBox[{"6", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{"6", " ", "x", " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{"6", " ", "y", " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["y", "2"], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["y", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"]}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox["m", "2"], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["r0", "2"], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "16"}], " ", 
             SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", 
                  SuperscriptBox["x", "2"]}], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "y", " ", 
               RowBox[{"h2", "[", "y", "]"}]}], "+", 
              RowBox[{"4", " ", "x", " ", "y", " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", " ", "x", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             RowBox[{"h1", "[", "x", "]"}]}], "-", 
            RowBox[{"6", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{"6", " ", "x", " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{"6", " ", "y", " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["y", "2"], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["y", "2"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["x", "2"]}], "-", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "11"}], " ", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{"7", " ", 
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"10", " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h1", "[", "x", "]"}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"h2", "[", "y", "]"}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], " ", 
            RowBox[{"h2", "[", "y", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"h1", "[", "x", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "y", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "y", " ", 
                RowBox[{"h2", "[", "y", "]"}]}], "-", 
               RowBox[{"4", " ", "x", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["r0", "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"]}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox["m", "2"], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["r0", "2"], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "16"}], " ", 
             SuperscriptBox["r0", "2"], " ", "x", " ", "y", " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", "y", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h1", "[", "x", "]"}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], 
           RowBox[{"h2", "[", "y", "]"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "11"}], " ", 
                   SuperscriptBox["x", "2"]}], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{"7", " ", 
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"10", " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", "x", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"h1", "[", "x", "]"}]}], "-", 
           RowBox[{"6", " ", 
            RowBox[{"h2", "[", "y", "]"}]}], "-", 
           RowBox[{"6", " ", "x", " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "-", 
           RowBox[{"6", " ", "y", " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["x", "2"], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["y", "2"], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["x", "2"], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["y", "2"], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", "x", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], " ", 
           RowBox[{"h2", "[", "y", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"h1", "[", "x", "]"}]}], "-", 
           RowBox[{"6", " ", 
            RowBox[{"h2", "[", "y", "]"}]}], "-", 
           RowBox[{"6", " ", "x", " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "-", 
           RowBox[{"6", " ", "y", " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["x", "2"], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["y", "2"], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["x", "2"], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["y", "2"], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["r0", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "x", "]"}], "-", 
           RowBox[{"h2", "[", "y", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"11", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "16"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{"5", " ", 
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "14"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["x", "2"]}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "3"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h1", "[", "x", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"7", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  RowBox[{"5", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"h2", "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["r0", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", "x", " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
               RowBox[{"2", " ", "y", " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"h2", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "8"}], " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"h1", "[", "x", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["m", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", " ", 
                   SuperscriptBox["x", "2"]}], "-", 
                  RowBox[{"7", " ", 
                   SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox["m", "2"], " ", 
                SuperscriptBox["x", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["x", "2"], "+", 
                   SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h2", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "x", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", " ", 
                   SuperscriptBox["m", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["r0", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["x", "2"], "+", 
                  SuperscriptBox["y", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "y", " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["x", "2"], "+", 
                    SuperscriptBox["y", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox["r0", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "x", "]"}], "-", 
            RowBox[{"h2", "[", "y", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], 
    "}"}]}],
  SequenceForm[
  "weylcomps = ", {
   Subscript[
     C, 1, 2, 1, 
      2] -> (((Rational[
         1, 12] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((4 $CellContext`r0^2) (
         3 $CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + $CellContext`h1[$CellContext`x]^2 (((-4) (
           2 $CellContext`m^2 + $CellContext`r0^2 (7 $CellContext`x^2 - 
             5 $CellContext`y^2))) $CellContext`h2[$CellContext`y] + \
($CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)) (((-6) \
$CellContext`x) 
           Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y)
             Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
            Derivative[
             2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h2[$CellContext`y] (((-4) (
           2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             3 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 (((-4) $CellContext`m^2) $CellContext`x^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] (((
             2 $CellContext`x) ((-8) $CellContext`m^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`y) 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
              Derivative[2][$CellContext`h2][$CellContext`y])))) + (
        2 $CellContext`h1[$CellContext`x]) ((
          2 (4 $CellContext`m^2 + $CellContext`r0^2 (5 $CellContext`x^2 - 
             7 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (((-4) \
$CellContext`m^2) $CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2)^2) 
         Derivative[
           1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] (((2 $CellContext`x) (
             4 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-2) $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
             Derivative[2][$CellContext`h2][$CellContext`y]))))), 
    Subscript[C, 1, 2, 1, 3] -> 0, Subscript[C, 1, 2, 1, 4] -> 0, 
    Subscript[C, 1, 2, 2, 3] -> 0, Subscript[C, 1, 2, 2, 4] -> 0, 
    Subscript[
     C, 1, 2, 3, 
      4] -> (((((((
            Rational[
             1, 2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ((-$CellContext`h1[$CellContext`x]) ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((-3) \
$CellContext`x^2 + $CellContext`y^2) 
         Derivative[
          1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h2[$CellContext`y] ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((
           4 $CellContext`x) $CellContext`y) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[C, 1, 3, 1, 2] -> 0, 
    Subscript[
     C, 1, 3, 1, 
      3] -> (((Rational[
         1, 
          12] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((4 $CellContext`r0^2) (
         3 $CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + $CellContext`h1[$CellContext`x]^2 ((
          16 ($CellContext`m^2 - $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`x) 
           Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y)
             Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
            Derivative[
             2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h1[$CellContext`x] (((-4) (
           8 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             11 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 (((-4) $CellContext`m^2) $CellContext`x^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] (((
             2 $CellContext`x) ((-16) $CellContext`m^2 + (
               5 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-14) $CellContext`y) 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
              Derivative[2][$CellContext`h2][$CellContext`y])))) + (
        2 $CellContext`h2[$CellContext`y]) ((
          4 (2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             3 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] ((((-2) $CellContext`x) ((-8) \
$CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
             Derivative[2][$CellContext`h2][$CellContext`y]))))), 
    Subscript[
     C, 1, 3, 1, 
      4] -> ((((((
           Rational[-1, 
             2] $CellContext`m) $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) (
      6 $CellContext`h1[$CellContext`x] - 
      6 $CellContext`h2[$CellContext`y] - (6 $CellContext`x) 
      Derivative[1][$CellContext`h1][$CellContext`x] - (6 $CellContext`y) 
      Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`y^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`x^2 
       Derivative[2][$CellContext`h2][$CellContext`y] + $CellContext`y^2 
       Derivative[2][$CellContext`h2][$CellContext`y]), 
    Subscript[
     C, 1, 3, 2, 
      3] -> (((((
          Rational[
           1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) ((((8 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h1[$CellContext`x]^2 + (((
          8 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2 + ((((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h1][$CellContext`x]) 
       Derivative[
        1][$CellContext`h2][$CellContext`y] + $CellContext`h2[$CellContext`y] \
((($CellContext`r0^2 $CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
         Derivative[1][$CellContext`h1][$CellContext`x] - ($CellContext`x (
          4 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) 
        Derivative[
         1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h1[$CellContext`x] (((((-16) $CellContext`r0^2) $CellContext`x) \
$CellContext`y) $CellContext`h2[$CellContext`y] - (($CellContext`r0^2 \
$CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x (
           4 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     C, 1, 3, 2, 
      4] -> (((((((
            Rational[
             1, 2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] (((-8) $CellContext`y) \
$CellContext`h2[$CellContext`y] + ((-3) $CellContext`x^2 + $CellContext`y^2) 
         Derivative[1][$CellContext`h2][$CellContext`y]) + (
        2 $CellContext`h2[$CellContext`y]) ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + ((
           4 $CellContext`x) $CellContext`y) 
         Derivative[
          1][$CellContext`h1][$CellContext`x] - ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[C, 1, 3, 3, 4] -> 0, Subscript[C, 1, 4, 1, 2] -> 0, 
    Subscript[
     C, 1, 4, 1, 
      3] -> ((((((
           Rational[-1, 
             2] $CellContext`m) $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) (
      6 $CellContext`h1[$CellContext`x] - 
      6 $CellContext`h2[$CellContext`y] - (6 $CellContext`x) 
      Derivative[1][$CellContext`h1][$CellContext`x] - (6 $CellContext`y) 
      Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`y^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`x^2 
       Derivative[2][$CellContext`h2][$CellContext`y] + $CellContext`y^2 
       Derivative[2][$CellContext`h2][$CellContext`y]), 
    Subscript[
     C, 1, 4, 1, 
      4] -> (((Rational[
         1, 12] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((8 $CellContext`r0^2) (
         3 $CellContext`x^2 - $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + (
        2 $CellContext`h1[$CellContext`x]^2) ((
          2 (2 $CellContext`m^2 + $CellContext`r0^2 ((-11) $CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`x) 
           Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y)
             Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
            Derivative[
             2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h2[$CellContext`y] ((
          4 (2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             3 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] ((((-2) $CellContext`x) ((-8) \
$CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
             Derivative[
              2][$CellContext`h2][$CellContext`y])))) - \
$CellContext`h1[$CellContext`x] ((
         16 ($CellContext`m^2 - $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
         4 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
        Derivative[
          1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] ((((-2) $CellContext`x) ((-8) \
$CellContext`m^2 + (
              7 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2))) 
          Derivative[
           1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ((10 $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
             Derivative[2][$CellContext`h2][$CellContext`y]))))), 
    Subscript[
     C, 1, 4, 2, 
      3] -> (((((((
            Rational[-1, 
              2] $CellContext`m) $CellContext`r0^(-3)) ($CellContext`x^2 + \
$CellContext`y^2)^(-4)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
          Rational[
           1, 2])/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^
       Rational[
        1, 2]) ($CellContext`h1[$CellContext`x] ((
          4 $CellContext`y) $CellContext`h2[$CellContext`y] + (
          2 (3 $CellContext`x^2 - $CellContext`y^2)) 
         Derivative[
          1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h2[$CellContext`y] (((-4) $CellContext`y) \
$CellContext`h2[$CellContext`y] - ((4 $CellContext`x) $CellContext`y) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x^2 + \
$CellContext`y^2) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[
     C, 1, 4, 2, 
      4] -> (((((
          Rational[
           1, 2] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h1[$CellContext`x])^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (($CellContext`x^2 + \
$CellContext`y^2)/$CellContext`h2[$CellContext`y])^
       Rational[-1, 
         2]) ((((8 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h1[$CellContext`x]^2 + (((
          8 $CellContext`r0^2) $CellContext`x) $CellContext`y) \
$CellContext`h2[$CellContext`y]^2 + ((((-4) $CellContext`m^2) \
$CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)^2) 
        Derivative[1][$CellContext`h1][$CellContext`x]) 
       Derivative[
        1][$CellContext`h2][$CellContext`y] + $CellContext`h2[$CellContext`y] \
((($CellContext`r0^2 $CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
         Derivative[1][$CellContext`h1][$CellContext`x] - ($CellContext`x (
          4 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) 
        Derivative[
         1][$CellContext`h2][$CellContext`y]) + \
$CellContext`h1[$CellContext`x] (((((-16) $CellContext`r0^2) $CellContext`x) \
$CellContext`y) $CellContext`h2[$CellContext`y] - (($CellContext`r0^2 \
$CellContext`y) ($CellContext`x^2 + $CellContext`y^2)) 
        Derivative[
         1][$CellContext`h1][$CellContext`x] + ($CellContext`x (
           4 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) Derivative[1][$CellContext`h2][$CellContext`y])), 
    Subscript[C, 1, 4, 3, 4] -> 0, 
    Subscript[
     C, 2, 3, 2, 
      3] -> (((Rational[
         1, 12] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((
         8 $CellContext`r0^2) ((-3) $CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 - (
       2 $CellContext`h1[$CellContext`x]^2) ((
         2 (
          2 $CellContext`m^2 + $CellContext`r0^2 ((-11) $CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`x) 
          Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y) 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
           Derivative[
            2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h2[$CellContext`y] (((-4) (
           2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             3 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 (((-4) $CellContext`m^2) $CellContext`x^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] (((
             2 $CellContext`x) ((-8) $CellContext`m^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`y) 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
              Derivative[
               2][$CellContext`h2][$CellContext`y])))) + \
$CellContext`h1[$CellContext`x] ((
          16 ($CellContext`m^2 - $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          4 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] ((((-2) $CellContext`x) ((-8) \
$CellContext`m^2 + (
               7 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) ((10 $CellContext`y) 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
              Derivative[2][$CellContext`h2][$CellContext`y]))))), 
    Subscript[
     C, 2, 3, 2, 
      4] -> ((((((
           Rational[
            1, 2] $CellContext`m) $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) (
      6 $CellContext`h1[$CellContext`x] - 
      6 $CellContext`h2[$CellContext`y] - (6 $CellContext`x) 
      Derivative[1][$CellContext`h1][$CellContext`x] - (6 $CellContext`y) 
      Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`y^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`x^2 
       Derivative[2][$CellContext`h2][$CellContext`y] + $CellContext`y^2 
       Derivative[2][$CellContext`h2][$CellContext`y]), 
    Subscript[C, 2, 3, 3, 4] -> 0, 
    Subscript[
     C, 2, 4, 2, 
      3] -> ((((((
           Rational[
            1, 2] $CellContext`m) $CellContext`r0^(-3)) $CellContext`x) \
($CellContext`x^2 + $CellContext`y^2)^(-3))/($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])) ($CellContext`h1[$CellContext`x] \
$CellContext`h2[$CellContext`y])^Rational[1, 2]) (
      6 $CellContext`h1[$CellContext`x] - 
      6 $CellContext`h2[$CellContext`y] - (6 $CellContext`x) 
      Derivative[1][$CellContext`h1][$CellContext`x] - (6 $CellContext`y) 
      Derivative[1][$CellContext`h2][$CellContext`y] + $CellContext`x^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`y^2 
       Derivative[2][$CellContext`h1][$CellContext`x] + $CellContext`x^2 
       Derivative[2][$CellContext`h2][$CellContext`y] + $CellContext`y^2 
       Derivative[2][$CellContext`h2][$CellContext`y]), 
    Subscript[
     C, 2, 4, 2, 
      4] -> (((Rational[
         1, 12] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((
         4 $CellContext`r0^2) ((-3) $CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 - $CellContext`h1[$CellContext`x]^2 ((
         16 ($CellContext`m^2 - $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) $CellContext`h2[$CellContext`y] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`x) 
          Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y) 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
           Derivative[
            2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h1[$CellContext`x] ((
          4 (8 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             11 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] ((((-2) $CellContext`x) ((-16) \
$CellContext`m^2 + (
               5 $CellContext`r0^2) ($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-14) $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
             Derivative[2][$CellContext`h2][$CellContext`y])))) + (
        2 $CellContext`h2[$CellContext`y]) (((-4) (
           2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             3 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 (((-4) $CellContext`m^2) $CellContext`x^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] (((
             2 $CellContext`x) ((-8) $CellContext`m^2 + $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] + ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`y) 
             Derivative[
              1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
              Derivative[2][$CellContext`h2][$CellContext`y]))))), 
    Subscript[C, 2, 4, 3, 4] -> 0, 
    Subscript[
     C, 3, 4, 3, 
      4] -> (((Rational[
         1, 12] $CellContext`r0^(-4)) ($CellContext`x^2 + \
$CellContext`y^2)^(-3)) ($CellContext`h1[$CellContext`x] - \
$CellContext`h2[$CellContext`y])^(-2)) (((
         4 $CellContext`r0^2) ((-3) $CellContext`x^2 + $CellContext`y^2)) \
$CellContext`h1[$CellContext`x]^3 + $CellContext`h1[$CellContext`x]^2 ((
          4 (2 $CellContext`m^2 + $CellContext`r0^2 (7 $CellContext`x^2 - 
             5 $CellContext`y^2))) $CellContext`h2[$CellContext`y] - \
($CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2)) (((-6) \
$CellContext`x) 
          Derivative[1][$CellContext`h1][$CellContext`x] + (2 $CellContext`y) 
          Derivative[
           1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
           Derivative[
            2][$CellContext`h2][$CellContext`y]))) + \
$CellContext`h2[$CellContext`y] ((
          4 (2 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 - 
             3 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (
          2 ((4 $CellContext`m^2) $CellContext`x^2 - $CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)^2)) 
         Derivative[
           1][$CellContext`h1][$CellContext`x]^2 + \
$CellContext`h2[$CellContext`y] ((((-2) $CellContext`x) ((-8) \
$CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + $CellContext`y^2))) 
           Derivative[
            1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-6) $CellContext`y) 
            Derivative[
             1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
             Derivative[2][$CellContext`h2][$CellContext`y])))) - (
       2 $CellContext`h1[$CellContext`x]) ((
         2 (
          4 $CellContext`m^2 + $CellContext`r0^2 (5 $CellContext`x^2 - 
            7 $CellContext`y^2))) $CellContext`h2[$CellContext`y]^2 + (((-4) \
$CellContext`m^2) $CellContext`x^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2)^2) 
        Derivative[
          1][$CellContext`h2][$CellContext`y]^2 + \
$CellContext`h2[$CellContext`y] (((2 $CellContext`x) (
            4 $CellContext`m^2 + $CellContext`r0^2 ($CellContext`x^2 + \
$CellContext`y^2))) 
          Derivative[
           1][$CellContext`h1][$CellContext`x] - ($CellContext`r0^2 \
($CellContext`x^2 + $CellContext`y^2)) (((-2) $CellContext`y) 
           Derivative[
            1][$CellContext`h2][$CellContext`y] + ($CellContext`x^2 + \
$CellContext`y^2) (Derivative[2][$CellContext`h1][$CellContext`x] + 
            Derivative[2][$CellContext`h2][$CellContext`y])))))}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.8. Solution for a rigidly rotating fluid body", "Subsubsection"],

Cell[TextData[{
 "The following is a case in which ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Simplify", "Input",
  FontWeight->"Plain"],
 " command will not achieve a useful result in a reasonable time, unless the \
option ",
 StyleBox["Trig->False", "Input",
  FontWeight->"Plain"],
 " is included, and even then may take quite a while. This option is usually \
used inside the  calculation procedure to avoid wasting time, since \
simplifying with the default ",
 StyleBox["Trig", "Input",
  FontWeight->"Plain"],
 " option (i.e., ",
 StyleBox["True", "Input",
  FontWeight->"Plain"],
 ") can always be tried later. After waiting several minutes without success, \
one may want to Abort the calculation, and try something else. ",
 StyleBox["Simplify", "Input",
  FontWeight->"Plain"],
 " does succeed on the matter tensor components, as illustrated by the ",
 StyleBox["riccicomps", "Input",
  FontWeight->"Plain"],
 " command."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"signature", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makecoords", "[", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "\[Phi]", ",", "t"}], "}"}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"2", "u"}], "]"}], "+", 
    RowBox[{"Cosh", "[", 
     RowBox[{"2", "v"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "=", 
   SqrtBox[
    RowBox[{"\[Kappa]", " ", 
     RowBox[{"g", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"h1", "[", "u", "]"}], "-", 
        RowBox[{"h2", "[", "v", "]"}]}], ")"}]}]}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"radius", "=", 
   RowBox[{"2", " ", "r0", " ", "\[CapitalPhi]", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"h1", "[", "u", "]"}], " ", 
      RowBox[{"h2", "[", "v", "]"}]}]]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"twist", "=", 
   RowBox[{"2", "\[Kappa]", " ", "r0", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"h1", "[", "u", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "v"}], "]"}], "-", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "vA"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"h2", "[", "v", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"2", "u"}], "]"}], "+", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "vA"}], "]"}]}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"h1", "[", "u", "]"}], "-", 
       RowBox[{"h2", "[", "v", "]"}]}], ")"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tocoords", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "->", 
      RowBox[{
       SqrtBox[
        RowBox[{
         RowBox[{"g", "/", 
          RowBox[{"h1", "[", "u", "]"}]}], "/", "\[Mu]0"}]], "du"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], "->", 
      RowBox[{
       SqrtBox[
        RowBox[{
         RowBox[{"g", "/", 
          RowBox[{"h2", "[", "v", "]"}]}], "/", "\[Mu]0"}]], "dv"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "3"], "->", 
      RowBox[{"radius", " ", "d\[Phi]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Theta]", "4"], "->", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{"dt", "-", 
         RowBox[{"twist", " ", "d\[Phi]"}]}], ")"}], "/", 
       "\[CapitalPhi]"}]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h1", "->", 
      RowBox[{"Function", "[", 
       RowBox[{"u", ",", 
        RowBox[{"h0", "+", 
         RowBox[{"e0", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "u"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"u", "+", "u0"}], ")"}], 
          RowBox[{"Sin", "[", 
           RowBox[{"2", "u"}], "]"}]}]}]}], "]"}]}], ",", 
     RowBox[{"h2", "->", 
      RowBox[{"Function", "[", 
       RowBox[{"v", ",", 
        RowBox[{"h0", "-", 
         RowBox[{"e0", " ", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "v0"}], ")"}], 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "v"}], "]"}]}]}]}], "]"}]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"du", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "1"], 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "u"}], "]"}], "+", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"h1", "[", "u", "]"}]}]]]]}], ",", 
     RowBox[{"dv", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "2"], 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "u"}], "]"}], "+", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"h2", "[", "v", "]"}]}]]]]}], ",", 
     RowBox[{"d\[Phi]", "\[Rule]", 
      FractionBox[
       SubscriptBox["\[Theta]", "3"], 
       RowBox[{"2", " ", "r0", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"\[Kappa]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}]}], 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"h1", "[", "u", "]"}], " ", 
          RowBox[{"h2", "[", "v", "]"}]}]]}]]}], ",", 
     RowBox[{"dt", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          FractionBox[
           RowBox[{"\[Kappa]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}]}], 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}], "-", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "vA"}], "]"}]}], ")"}], " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            SubscriptBox["\[Theta]", "3"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "vA"}], "]"}]}], ")"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            SubscriptBox["\[Theta]", "3"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"h1", "[", "u", "]"}], " ", 
              RowBox[{"h2", "[", "v", "]"}]}]], " ", 
            SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "u"}], "]"}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {$CellContext`du -> ($CellContext`\[Mu]0^(-1) ((
         Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
      Rational[-1, 2] 
     Subscript[
      xAct`AVF`\[Theta], 
       1], $CellContext`dv -> ($CellContext`\[Mu]0^(-1) ((
         Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
      Rational[-1, 2] 
     Subscript[
      xAct`AVF`\[Theta], 
       2], $CellContext`d\[Phi] -> (((
        Rational[
         1, 2]/$CellContext`r0) ($CellContext`\[Kappa] ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])))^
        Rational[-1, 
          2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[-1, 2]) 
     Subscript[
      xAct`AVF`\[Theta], 
       3], $CellContext`dt -> (((Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])^(-1) ($CellContext`\[Kappa] ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((Cosh[2 $CellContext`v] - Cosh[
         2 $CellContext`vA]) $CellContext`h1[$CellContext`u]) 
       Subscript[
        xAct`AVF`\[Theta], 3] + ((Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`vA]) $CellContext`h2[$CellContext`v]) 
       Subscript[
        xAct`AVF`\[Theta], 3] + ((Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) 
       Subscript[xAct`AVF`\[Theta], 4])}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"Sinh", "[", 
          RowBox[{"2", " ", "v"}], "]"}], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "2"]}]}], 
        RowBox[{"\[Mu]0", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"h2", "[", "v", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "u"}], "]"}], " ", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
          SubscriptBox["\[Theta]", "2"]}]}], 
        RowBox[{"\[Mu]0", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"h1", "[", "u", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "3"], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], 
              RowBox[{"\[Mu]0", " ", 
               RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
             SubscriptBox["\[Theta]", "3"]}]}], "-", 
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}]}], "+", 
              RowBox[{"\[Mu]0", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], 
                  RowBox[{"\[Mu]0", " ", 
                   RowBox[{"h1", "[", "u", "]"}]}]], ")"}], 
                RowBox[{"3", "/", "2"}]], " ", 
               RowBox[{"h1", "[", "u", "]"}], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}]}], "+", 
              RowBox[{
               FractionBox["1", 
                RowBox[{"h2", "[", "v", "]"}]], 
               RowBox[{
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], 
                  RowBox[{"\[Mu]0", " ", 
                   RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
                RowBox[{
                 SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                 SubscriptBox["\[Theta]", "3"]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"h2", "[", "v", "]"}], " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], 
                 ")"}]}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "4"], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], 
              RowBox[{"\[Mu]0", " ", 
               RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
             SubscriptBox["\[Theta]", "4"]}]}], "+", 
           RowBox[{"2", " ", 
            SqrtBox[
             FractionBox[
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], 
              RowBox[{"\[Mu]0", " ", 
               RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
             SubscriptBox["\[Theta]", "4"]}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"h1", "[", "u", "]"}], " ", 
                 RowBox[{"h2", "[", "v", "]"}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}]}], "-", 
              RowBox[{"4", " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"h1", "[", "u", "]"}], " ", 
                 RowBox[{"h2", "[", "v", "]"}]}]], " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], 
                    RowBox[{"\[Mu]0", " ", 
                    RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                   SubscriptBox["\[Theta]", "4"]}]}], "+", 
                 RowBox[{
                  SqrtBox[
                   FractionBox[
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], 
                    RowBox[{"\[Mu]0", " ", 
                    RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                   SubscriptBox["\[Theta]", "4"]}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "4"]}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "4"]}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"h1", "[", "u", "]"}], " ", 
              RowBox[{"h2", "[", "v", "]"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}], "-", 
              RowBox[{
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "-", 
           
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"h1", "[", "u", "]"}], " ", 
                 RowBox[{"h2", "[", "v", "]"}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
                SubscriptBox["\[Theta]", "3"]}]}], "+", 
              RowBox[{
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], 
                 RowBox[{"\[Mu]0", " ", 
                  RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"h1", "[", "u", "]"}], " ", 
                    RowBox[{"h2", "[", "v", "]"}]}]], " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                   SubscriptBox["\[Theta]", "3"]}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
                   SubscriptBox["\[Theta]", "4"]}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[
     xAct`AVF`d\[Theta], 
      1] -> (((((-1)/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
         Rational[-3, 2])/$CellContext`h2[$CellContext`v]) 
      Sinh[2 $CellContext`v]) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 2]], 
    Subscript[
     xAct`AVF`d\[Theta], 
      2] -> (((((-1)/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-3, 2])/$CellContext`h1[$CellContext`u]) 
      Sin[2 $CellContext`u]) Wedge[
       Subscript[xAct`AVF`\[Theta], 1], 
       Subscript[xAct`AVF`\[Theta], 2]], 
    Subscript[
     xAct`AVF`d\[Theta], 
      3] -> (((Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) (((((-2) ($CellContext`\[Mu]0^(-1) ((
              Cos[2 $CellContext`u] + 
              Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
           Rational[1, 2]) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[
         xAct`AVF`\[Theta], 
          3]] - $CellContext`h2[$CellContext`v] ((((
           2 ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
            Rational[1, 2]) $CellContext`h2[$CellContext`v]) 
         Sinh[2 $CellContext`v]) Wedge[
          Subscript[xAct`AVF`\[Theta], 2], 
          Subscript[
          xAct`AVF`\[Theta], 
           3]] + ((($CellContext`\[Mu]0 ($CellContext`\[Mu]0^(-1) ((
               Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
            Rational[3, 2]) $CellContext`h1[$CellContext`u]) Wedge[
           Subscript[xAct`AVF`\[Theta], 1], 
           Subscript[xAct`AVF`\[Theta], 3]]) 
        Derivative[
         1][$CellContext`h1][$CellContext`u]) + \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) (((
           2 ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
            Rational[1, 2]) Sin[2 $CellContext`u]) Wedge[
           Subscript[xAct`AVF`\[Theta], 1], 
           Subscript[
           xAct`AVF`\[Theta], 
            3]] + ((($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
            Rational[1, 2]/$CellContext`h2[$CellContext`v]) Wedge[
            Subscript[xAct`AVF`\[Theta], 2], 
            Subscript[xAct`AVF`\[Theta], 3]]) ((
            2 $CellContext`h2[$CellContext`v]) 
           Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) 
           Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`d\[Theta], 
      4] -> (((Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ((((
          2 ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
              Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
           Rational[1, 2]) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[
         xAct`AVF`\[Theta], 4]] + (((
          2 ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
              Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
           Rational[1, 2]) $CellContext`h2[$CellContext`v]^2) 
        Sinh[2 $CellContext`v]) Wedge[
         Subscript[xAct`AVF`\[Theta], 2], 
         Subscript[
         xAct`AVF`\[Theta], 
          4]] + $CellContext`h1[$CellContext`u] ((((
            4 ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
                Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
             Rational[
              1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) Sin[2 $CellContext`u]) 
         Wedge[
           Subscript[xAct`AVF`\[Theta], 1], 
           Subscript[xAct`AVF`\[Theta], 3]] - (((
           4 ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
            Rational[
             1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) Sinh[2 $CellContext`v]) Wedge[
          Subscript[xAct`AVF`\[Theta], 2], 
          Subscript[xAct`AVF`\[Theta], 3]] - (
         2 $CellContext`h2[$CellContext`v]) ((($CellContext`\[Mu]0^(-1) ((
               Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
            Rational[1, 2] Sin[2 $CellContext`u]) Wedge[
            Subscript[xAct`AVF`\[Theta], 1], 
            Subscript[
            xAct`AVF`\[Theta], 
             4]] + (($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
            Rational[1, 2] Sinh[2 $CellContext`v]) Wedge[
            Subscript[xAct`AVF`\[Theta], 2], 
            Subscript[xAct`AVF`\[Theta], 4]]) + ((
           Cos[2 $CellContext`u] ($CellContext`\[Mu]0^(-1) ((
               Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
            Rational[1, 2]) Wedge[
            Subscript[xAct`AVF`\[Theta], 1], 
            Subscript[xAct`AVF`\[Theta], 4]]) 
         Derivative[
          1][$CellContext`h1][$CellContext`u] + ((
           Cosh[2 $CellContext`v] ($CellContext`\[Mu]0^(-1) ((
               Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
            Rational[1, 2]) Wedge[
            Subscript[xAct`AVF`\[Theta], 1], 
            Subscript[xAct`AVF`\[Theta], 4]]) 
         Derivative[1][$CellContext`h1][$CellContext`u]) + ((
         2 (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
         Rational[
          1, 2]) ((($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
              Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
           Rational[1, 2] Wedge[
            Subscript[xAct`AVF`\[Theta], 1], 
            Subscript[xAct`AVF`\[Theta], 3]]) 
         Derivative[
          1][$CellContext`h1][$CellContext`u] - (($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
          Rational[1, 2] Wedge[
           Subscript[xAct`AVF`\[Theta], 2], 
           Subscript[xAct`AVF`\[Theta], 3]]) 
        Derivative[
         1][$CellContext`h2][$CellContext`v]) - \
$CellContext`h2[$CellContext`v] ((((
           4 ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
               Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
            Rational[
             1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) Sin[2 $CellContext`u]) 
        Wedge[
          Subscript[xAct`AVF`\[Theta], 1], 
          Subscript[
          xAct`AVF`\[Theta], 
           3]] + ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
         Rational[
          1, 2] ((((-4) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) Sinh[2 $CellContext`v]) Wedge[
            Subscript[xAct`AVF`\[Theta], 2], 
            Subscript[xAct`AVF`\[Theta], 3]] + ((Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) Wedge[
             Subscript[xAct`AVF`\[Theta], 2], 
             Subscript[xAct`AVF`\[Theta], 4]]) 
          Derivative[1][$CellContext`h2][$CellContext`v])))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "2"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "3", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "3", ",", "4"}]]}]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4], 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3], 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4], 
    Subscript[
     xAct`AVF`\[Omega], 3, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sinh", "[", 
         RowBox[{"2", " ", "v"}], "]"}], 
        RowBox[{"\[Mu]0", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"h2", "[", "v", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "u"}], "]"}], 
        RowBox[{"\[Mu]0", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"h1", "[", "u", "]"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "u"}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"h2", "[", "v", "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "u"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "u"}], "]"}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["h1", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], 
       RowBox[{"2", " ", "\[Mu]0", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"h1", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", "[", "u", "]"}], "-", 
          RowBox[{"h2", "[", "v", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", 
          RowBox[{"2", " ", "v"}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"h2", "[", "v", "]"}], " ", 
         RowBox[{"Sinh", "[", 
          RowBox[{"2", " ", "v"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "u"}], "]"}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["h2", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}]}]}], 
       RowBox[{"2", " ", "\[Mu]0", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"h2", "[", "v", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"h1", "[", "u", "]"}]}], "+", 
          RowBox[{"h2", "[", "v", "]"}]}], ")"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[
     xAct`AVF`\[CapitalGamma], 1, 1, 
      2] -> ((((-1)/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[-3, 2])/$CellContext`h2[$CellContext`v]) 
     Sinh[2 $CellContext`v], Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] -> 
    0, Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 1, 3, 
      4] -> (((((
          Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[
          1, 2])/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((2 $CellContext`h1[$CellContext`u]) 
       Sin[2 $CellContext`u] - (2 $CellContext`h2[$CellContext`v]) 
      Sin[2 $CellContext`u] + (Cos[2 $CellContext`u] + Cosh[2 $CellContext`v])
         Derivative[1][$CellContext`h1][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 1, 
      2] -> ((((-1)/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
        Rational[-3, 2])/$CellContext`h1[$CellContext`u]) 
     Sin[2 $CellContext`u], Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] -> 0,
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 2, 3, 
      4] -> (((((
          Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((2 $CellContext`h1[$CellContext`u]) 
       Sinh[2 $CellContext`v] - (2 $CellContext`h2[$CellContext`v]) 
      Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) 
       Derivative[1][$CellContext`h2][$CellContext`v]), 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 1, 
      3] -> ((((
         Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
        Rational[
         1, 2])/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ((2 $CellContext`h1[$CellContext`u]^2) 
       Sin[2 $CellContext`u] - ((
        2 $CellContext`h1[$CellContext`u]) $CellContext`h2[$CellContext`v]) 
      Sin[2 $CellContext`u] + ((Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) 
       Derivative[1][$CellContext`h1][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 1, 
      4] -> (((((
          Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[
          1, 2])/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((2 $CellContext`h1[$CellContext`u]) 
       Sin[2 $CellContext`u] - (2 $CellContext`h2[$CellContext`v]) 
      Sin[2 $CellContext`u] + (Cos[2 $CellContext`u] + Cosh[2 $CellContext`v])
         Derivative[1][$CellContext`h1][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 2, 
      3] -> ((((
         Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[1, 2]) (((-2) $CellContext`h2[$CellContext`v]^2) 
       Sinh[2 $CellContext`v] + $CellContext`h1[$CellContext`u] ((
          2 $CellContext`h2[$CellContext`v]) 
         Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) 
         Derivative[1][$CellContext`h2][$CellContext`v])), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 3, 2, 
      4] -> (((((
          Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((2 $CellContext`h1[$CellContext`u]) 
       Sinh[2 $CellContext`v] - (2 $CellContext`h2[$CellContext`v]) 
      Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) 
       Derivative[1][$CellContext`h2][$CellContext`v]), 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 1, 
      3] -> (((((
          Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[
          1, 2])/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((2 $CellContext`h1[$CellContext`u]) 
       Sin[2 $CellContext`u] - (2 $CellContext`h2[$CellContext`v]) 
      Sin[2 $CellContext`u] + (Cos[2 $CellContext`u] + Cosh[2 $CellContext`v])
         Derivative[1][$CellContext`h1][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 1, 
      4] -> ((((
         Rational[
          1, 2]/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-3, 
           2])/$CellContext`h1[$CellContext`u])/($CellContext`h1[$CellContext`\
u] - $CellContext`h2[$CellContext`v])) (((-2) $CellContext`h1[$CellContext`u])
         Sin[2 $CellContext`u] + (2 $CellContext`h2[$CellContext`v]) 
       Sin[2 $CellContext`u] - (Cos[2 $CellContext`u] + 
       Cosh[2 $CellContext`v]) 
      Derivative[1][$CellContext`h1][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 2, 
      3] -> (((((
          Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((2 $CellContext`h1[$CellContext`u]) 
       Sinh[2 $CellContext`v] - (2 $CellContext`h2[$CellContext`v]) 
      Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) 
       Derivative[1][$CellContext`h2][$CellContext`v]), 
    Subscript[
     xAct`AVF`\[CapitalGamma], 4, 2, 
      4] -> ((((
         Rational[
          1, 2]/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
         Rational[-3, 
           2])/$CellContext`h2[$CellContext`v])/(-$CellContext`h1[$\
CellContext`u] + $CellContext`h2[$CellContext`v])) (((-2) \
$CellContext`h1[$CellContext`u]) 
       Sinh[2 $CellContext`v] + (2 $CellContext`h2[$CellContext`v]) 
       Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
       Cosh[2 $CellContext`v]) 
      Derivative[1][$CellContext`h2][$CellContext`v]), 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}], " ", 
          SubscriptBox["\[Theta]", "1"]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], 
             RowBox[{"\[Mu]0", " ", 
              RowBox[{"h2", "[", "v", "]"}]}]], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"h2", "[", "v", "]"}]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          SubscriptBox["\[Theta]", "2"]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], 
             RowBox[{"\[Mu]0", " ", 
              RowBox[{"h1", "[", "u", "]"}]}]], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"h1", "[", "u", "]"}]}]]}], "\[Mu]0"]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            SubscriptBox["\[Theta]", "3"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"h2", "[", "v", "]"}], " ", 
               SubscriptBox["\[Theta]", "3"]}], "-", 
              RowBox[{
               SqrtBox[
                RowBox[{
                 RowBox[{"h1", "[", "u", "]"}], " ", 
                 RowBox[{"h2", "[", "v", "]"}]}]], " ", 
               SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"h1", "[", "u", "]"}], " ", 
              RowBox[{"h2", "[", "v", "]"}]}]], " ", 
            SubscriptBox["\[Theta]", "4"], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"h1", "[", "u", "]"}], " ", 
                 RowBox[{"h2", "[", "v", "]"}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               SubscriptBox["\[Theta]", "4"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               SubscriptBox["\[Theta]", "3"], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "u", "]"}], " ", 
               RowBox[{"h2", "[", "v", "]"}]}]], " ", 
             SubscriptBox["\[Theta]", "3"]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", "\[Mu]0", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], 
             RowBox[{"\[Mu]0", " ", 
              RowBox[{"h1", "[", "u", "]"}]}]], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}], " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "u", "]"}], " ", 
               RowBox[{"h2", "[", "v", "]"}]}]], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}], " ", 
             SubscriptBox["\[Theta]", "4"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "u", "]"}], " ", 
               RowBox[{"h2", "[", "v", "]"}]}]], " ", 
             SubscriptBox["\[Theta]", "4"], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                SubscriptBox["\[Theta]", "3"]}], "+", 
               RowBox[{"2", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"h1", "[", "u", "]"}], " ", 
                  RowBox[{"h2", "[", "v", "]"}]}]], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                SubscriptBox["\[Theta]", "4"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                SubscriptBox["\[Theta]", "3"], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox[
              RowBox[{
               RowBox[{"h1", "[", "u", "]"}], " ", 
               RowBox[{"h2", "[", "v", "]"}]}]], " ", 
             SubscriptBox["\[Theta]", "3"]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "v", "]"}], " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", "\[Mu]0", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], 
             RowBox[{"\[Mu]0", " ", 
              RowBox[{"h2", "[", "v", "]"}]}]], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"h1", "[", "u", "]"}]}], "+", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox[
             FractionBox[
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], 
              RowBox[{"\[Mu]0", " ", 
               RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
            SubscriptBox["\[Theta]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"h1", "[", "u", "]"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "-", 
           
           RowBox[{
            SqrtBox[
             FractionBox[
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], 
              RowBox[{"\[Mu]0", " ", 
               RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
            SubscriptBox["\[Theta]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"h1", "[", "u", "]"}], " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}]}], ")"}]}]}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 
      2] -> $CellContext`\[Mu]0^(-1) (((($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
          Rational[-3, 2]/$CellContext`h2[$CellContext`v]) 
        Sinh[2 $CellContext`v]) 
       Subscript[
        xAct`AVF`\[Theta], 
         1] + ((($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
          Rational[-3, 2]/$CellContext`h1[$CellContext`u]) 
        Sin[2 $CellContext`u]) Subscript[xAct`AVF`\[Theta], 2]), 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      3] -> ((((
         Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
        Rational[
         1, 2])/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) (((2 $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) 
       Subscript[xAct`AVF`\[Theta], 3] - ((2 $CellContext`h1[$CellContext`u]) 
       Sin[2 $CellContext`u]) ($CellContext`h2[$CellContext`v] 
        Subscript[
         xAct`AVF`\[Theta], 
          3] - ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2] 
       Subscript[
        xAct`AVF`\[Theta], 
         4]) + (((Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) 
        Subscript[xAct`AVF`\[Theta], 4]) 
       Derivative[
        1][$CellContext`h1][$CellContext`u] + $CellContext`h2[$CellContext`v] \
((((-2) ($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v])^
            Rational[1, 2]) Sin[2 $CellContext`u]) 
         Subscript[
          xAct`AVF`\[Theta], 4] + ((Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) Subscript[xAct`AVF`\[Theta], 3]) 
         Derivative[1][$CellContext`h1][$CellContext`u])), 
    Subscript[
     xAct`AVF`\[Omega], 1, 
      4] -> (((((
          Rational[-1, 
            2]/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
          Rational[-3, 
            2]) $CellContext`h1[$CellContext`u]^(-2))/($CellContext`h1[$\
CellContext`u] - $CellContext`h2[$CellContext`v])) \
(($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v])^
         Rational[1, 2] 
        Subscript[xAct`AVF`\[Theta], 3] + $CellContext`h1[$CellContext`u] 
        Subscript[xAct`AVF`\[Theta], 4])) ((2 $CellContext`h1[$CellContext`u])
         Sin[2 $CellContext`u] - (2 $CellContext`h2[$CellContext`v]) 
      Sin[2 $CellContext`u] + (Cos[2 $CellContext`u] + Cosh[2 $CellContext`v])
         Derivative[1][$CellContext`h1][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[Omega], 2, 
      3] -> ((((
         Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[1, 2]) ((((-2) $CellContext`h2[$CellContext`v]^2) 
        Sinh[2 $CellContext`v]) 
       Subscript[
        xAct`AVF`\[Theta], 3] - (((
         2 $CellContext`h2[$CellContext`v]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) Sinh[2 $CellContext`v]) 
      Subscript[
       xAct`AVF`\[Theta], 
        4] + (((Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) 
        Subscript[xAct`AVF`\[Theta], 4]) 
       Derivative[
        1][$CellContext`h2][$CellContext`v] + $CellContext`h1[$CellContext`u] \
(((2 $CellContext`h2[$CellContext`v]) Sinh[2 $CellContext`v]) 
         Subscript[
          xAct`AVF`\[Theta], 3] + ((
           2 ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^Rational[1, 2]) Sinh[2 $CellContext`v]) 
         Subscript[
          xAct`AVF`\[Theta], 4] + ((Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) Subscript[xAct`AVF`\[Theta], 3]) 
         Derivative[1][$CellContext`h2][$CellContext`v])), 
    Subscript[
     xAct`AVF`\[Omega], 2, 
      4] -> (((((
          Rational[-1, 
            2]/$CellContext`\[Mu]0) ($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
          Rational[-3, 
            2]) $CellContext`h2[$CellContext`v]^(-2))/(-$CellContext`h1[$\
CellContext`u] + $CellContext`h2[$CellContext`v])) \
(($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v])^
         Rational[1, 2] 
        Subscript[xAct`AVF`\[Theta], 3] + $CellContext`h2[$CellContext`v] 
        Subscript[xAct`AVF`\[Theta], 4])) ((2 $CellContext`h1[$CellContext`u])
         Sinh[2 $CellContext`v] - (2 $CellContext`h2[$CellContext`v]) 
      Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) 
       Derivative[1][$CellContext`h2][$CellContext`v]), 
    Subscript[
     xAct`AVF`\[Omega], 3, 
      4] -> ((((
         Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-2))/($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[
        1, 2]) ((($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[1, 2] 
        Subscript[xAct`AVF`\[Theta], 1]) ((2 $CellContext`h1[$CellContext`u]) 
         Sin[2 $CellContext`u] - (2 $CellContext`h2[$CellContext`v]) 
        Sin[2 $CellContext`u] + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h1][$CellContext`u]) - (($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[1, 2] 
       Subscript[xAct`AVF`\[Theta], 2]) ((2 $CellContext`h1[$CellContext`u]) 
        Sinh[2 $CellContext`v] - (2 $CellContext`h2[$CellContext`v]) 
       Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) 
        Derivative[1][$CellContext`h2][$CellContext`v]))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"h1", "[", "u", "]"}]}], "-", 
           RowBox[{"4", " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}], "-", 
              RowBox[{
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"]}], ")"}]}]}], ",", 
     
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"]}], ")"}]}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"h2", "[", "v", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
              SuperscriptBox[
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
          RowBox[{"h2", "[", "v", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"24", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "16"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"h2", "[", "v", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
              SuperscriptBox[
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"7", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "16"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
          RowBox[{"h2", "[", "v", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], "-", 
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "16"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "2"]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}]}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"3", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
              RowBox[{"5", " ", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"5", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"5", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Mu]0", "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "u"}], "]"}], " ", 
            RowBox[{"Sinh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], " ", 
            RowBox[{
             SuperscriptBox["h2", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
          RowBox[{"h2", "[", "v", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
              RowBox[{"5", " ", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"5", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"5", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  RowBox[{"7", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}]}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"3", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"]}], ")"}]}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "-", 
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"]}], ")"}]}]}]}]}], 
    "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[
     xAct`AVF`R, 1, 2, 1, 
      2] -> ((Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v])^(-3)) ((
        4 (1 + 
         Cos[2 $CellContext`u] 
          Cosh[2 $CellContext`v])) $CellContext`h1[$CellContext`u] - (
       4 $CellContext`h2[$CellContext`v]) (
       Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
       Cosh[2 $CellContext`v]^2 - 
       Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) (
        Sin[2 $CellContext`u] Derivative[1][$CellContext`h1][$CellContext`u] - 
        Sinh[2 $CellContext`v] 
        Derivative[1][$CellContext`h2][$CellContext`v])), 
    Subscript[xAct`AVF`R, 1, 2, 1, 3] -> 0, Subscript[xAct`AVF`R, 1, 2, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 2, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 2, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 2, 3, 
      4] -> (((((
          Rational[-1, 2] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[
          1, 2]) ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) (((4 $CellContext`h1[$CellContext`u]) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((4 $CellContext`h2[$CellContext`v]) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v])), 
    Subscript[xAct`AVF`R, 1, 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 3, 1, 
      3] -> ((((
         Rational[1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        8 $CellContext`h1[$CellContext`u]^4) (Cos[2 $CellContext`u]^2 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
        Sin[2 $CellContext`u]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[1][$CellContext`h1][$CellContext`u]^2 - (
       2 $CellContext`h1[$CellContext`u]^3) ((
         2 $CellContext`h2[$CellContext`v]) (
         4 Cos[2 $CellContext`u]^2 + (4 Cos[2 $CellContext`u]) 
          Cosh[2 $CellContext`v] + Sin[2 $CellContext`u]^2 + 
         Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) (
        Sin[2 $CellContext`u] Derivative[1][$CellContext`h1][$CellContext`u] - 
        Sinh[2 $CellContext`v] 
        Derivative[1][$CellContext`h2][$CellContext`v])) + ((
         2 $CellContext`h1[$CellContext`u]) $CellContext`h2[$CellContext`v]) \
($CellContext`h2[$CellContext`v]^2 (6 Sin[2 $CellContext`u]^2 - 2 
          Sinh[2 $CellContext`v]^2) - (-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]^2 - ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((4 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] + (
           Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
          Derivative[2][$CellContext`h1][$CellContext`u])) + ((
         2 $CellContext`h1[$CellContext`u]^2) \
$CellContext`h2[$CellContext`v]) ((4 $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u]^2 + 
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] - 2 
          Sin[2 $CellContext`u]^2 + Sinh[2 $CellContext`v]^2) + (
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((3 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h2][$CellContext`v] + (
            Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h1][$CellContext`u]))), 
    Subscript[
     xAct`AVF`R, 1, 3, 1, 
      4] -> (((((
          Rational[1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) $CellContext`h2[$CellContext`v]) \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((-4) $CellContext`h1[$CellContext`u]^3) (
        2 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 
        Sinh[2 $CellContext`v]^2) + ($CellContext`h2[$CellContext`v] (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
       Derivative[1][$CellContext`h1][$CellContext`u]^2 + (
        2 $CellContext`h1[$CellContext`u]^2) ((
          4 $CellContext`h2[$CellContext`v]) (
          2 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) ((5 Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - 
         Sinh[2 $CellContext`v] 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) 
          Derivative[
           2][$CellContext`h1][$CellContext`u])) + \
$CellContext`h1[$CellContext`u] (((-4) $CellContext`h2[$CellContext`v]^2) (
          2 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) + (-1 + Cos[2 $CellContext`u]^2 + 
          Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((5 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - 
          Sinh[2 $CellContext`v] 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h1][$CellContext`u]))), 
    Subscript[
     xAct`AVF`R, 1, 3, 2, 
      3] -> ((((
         Rational[
          1, 2] (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[-1, 2]) ((((-12) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((12 $CellContext`h2[$CellContext`v]^2) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]) 
       Derivative[
        1][$CellContext`h2][$CellContext`v] + ((
         3 (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v]) + (
        3 $CellContext`h1[$CellContext`u]) (((
           8 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 1, 3, 2, 
      4] -> ((((((
           Rational[-1, 4] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
          Rational[
           1, 2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((((-8) $CellContext`h1[$CellContext`u]^3) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((
        2 (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])) $CellContext`h1[$CellContext`u]^2) (
       Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
       Sin[2 $CellContext`u] 
        Derivative[
         1][$CellContext`h2][$CellContext`v]) + \
$CellContext`h1[$CellContext`u] (((24 $CellContext`h2[$CellContext`v]^2) 
          Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[1][$CellContext`h2][$CellContext`v] - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[
           1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h2[$CellContext`v] ((((-16) $CellContext`h2[$CellContext`v]^2) 
          Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           4 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[xAct`AVF`R, 1, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 1, 4, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 1, 4, 1, 
      3] -> (((((
          Rational[1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) $CellContext`h2[$CellContext`v]) \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((-4) $CellContext`h1[$CellContext`u]^3) (
        2 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 
        Sinh[2 $CellContext`v]^2) + ((2 $CellContext`h2[$CellContext`v]) (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
       Derivative[1][$CellContext`h1][$CellContext`u]^2 + (
        2 $CellContext`h1[$CellContext`u]^2) ((
          4 $CellContext`h2[$CellContext`v]) (
          2 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) ((5 Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - 
         Sinh[2 $CellContext`v] 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) 
          Derivative[
           2][$CellContext`h1][$CellContext`u])) + \
$CellContext`h1[$CellContext`u] (((-4) $CellContext`h2[$CellContext`v]^2) (
          2 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) + (-1 + Cos[2 $CellContext`u]^2 + 
          Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((5 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - 
          Sinh[2 $CellContext`v] 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h1][$CellContext`u]))), 
    Subscript[
     xAct`AVF`R, 1, 4, 1, 
      4] -> (((Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ((
        4 $CellContext`h1[$CellContext`u]^3) (Cos[2 $CellContext`u]^2 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
        2 Sin[2 $CellContext`u]^2) + $CellContext`h2[$CellContext`v] ((
          2 $CellContext`h2[$CellContext`v]^2) (Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) - (-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]^2 - ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) (
         Sin[2 $CellContext`u] Derivative[1][$CellContext`h1][$CellContext`u] - 
         Sinh[2 $CellContext`v] 
         Derivative[
          1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u]^2 (((-2) $CellContext`h2[$CellContext`v]) (
          4 Cos[2 $CellContext`u]^2 + (4 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 7 Sin[2 $CellContext`u]^2 + 
          Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((4 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] + (
            Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
           Derivative[
            2][$CellContext`h1][$CellContext`u])) + \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) ((
          4 $CellContext`h2[$CellContext`v]) (Cos[2 $CellContext`u]^2 + 
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Sin[2 $CellContext`u]^2 + Sinh[2 $CellContext`v]^2) - (
         Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) ((3 Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h2][$CellContext`v] + (
           Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
          Derivative[2][$CellContext`h1][$CellContext`u]))), 
    Subscript[
     xAct`AVF`R, 1, 4, 2, 
      3] -> ((((((
           Rational[-1, 4] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
          Rational[
           1, 2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((((-16) $CellContext`h1[$CellContext`u]^3) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] + (
        4 $CellContext`h1[$CellContext`u]^2) (((
           6 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[
           1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u] (((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[
            1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h2[$CellContext`v] ((((-8) $CellContext`h2[$CellContext`v]^2) 
          Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 1, 4, 2, 
      4] -> ((((
         Rational[
          1, 2] (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[-1, 2]) ((((-12) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((12 $CellContext`h2[$CellContext`v]^2) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]) 
       Derivative[
        1][$CellContext`h2][$CellContext`v] + ((
         3 (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v]) + (
        3 $CellContext`h1[$CellContext`u]) (((
           8 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[xAct`AVF`R, 1, 4, 3, 4] -> 0, Subscript[xAct`AVF`R, 2, 3, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 2, 3, 1, 
      3] -> ((((
         Rational[
          3, 4] (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[-1, 2]) ((((-8) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((8 $CellContext`h2[$CellContext`v]^2) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]) 
       Derivative[
        1][$CellContext`h2][$CellContext`v] + ((
         2 (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v]) + (
        2 $CellContext`h1[$CellContext`u]) (((
           8 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 2, 3, 1, 
      4] -> ((((((
           Rational[-1, 4] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
          Rational[
           1, 2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((((-16) $CellContext`h1[$CellContext`u]^3) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] + (
        4 $CellContext`h1[$CellContext`u]^2) (((
           6 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[
           1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u] (((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[
            1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h2[$CellContext`v] ((((-8) $CellContext`h2[$CellContext`v]^2) 
          Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 
      3] -> (((Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
         Cosh[
          2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ((
        2 $CellContext`h1[$CellContext`u]^3) (Sin[2 $CellContext`u]^2 - 3 
        Sinh[2 $CellContext`v]^2) + $CellContext`h2[$CellContext`v]^2 ((
          4 $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 - Sinh[2 $CellContext`v]^2) - (
         Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) (
         Sin[2 $CellContext`u] Derivative[1][$CellContext`h1][$CellContext`u] - 
         Sinh[2 $CellContext`v] 
         Derivative[
          1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u]^2 ((4 $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 - Sin[2 $CellContext`u]^2 + 
          2 Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) (((-4) Sinh[2 $CellContext`v]) 
           Derivative[1][$CellContext`h2][$CellContext`v] + (
            Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
           Derivative[
            2][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u] ((
          2 $CellContext`h2[$CellContext`v]^2) (((-4) Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] - 4 Cosh[2 $CellContext`v]^2 + 
          Sin[2 $CellContext`u]^2 + Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 - ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((-
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (3 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) 
          Derivative[2][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 
      4] -> (((((
          Rational[1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-3)) $CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((
         4 $CellContext`h1[$CellContext`u]^2) \
$CellContext`h2[$CellContext`v]) ((2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 2 Cosh[2 $CellContext`v]^2 + 
        Sin[2 $CellContext`u]^2 - 5 
        Sinh[2 $CellContext`v]^2) + $CellContext`h2[$CellContext`v] ((
          4 $CellContext`h2[$CellContext`v]^2) ((2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 2 Cosh[2 $CellContext`v]^2 + 
          Sin[2 $CellContext`u]^2 - 5 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h1][$CellContext`u] - (5 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) 
          Derivative[
           2][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u] (((-8) $CellContext`h2[$CellContext`v]^2) ((2 
            Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
          2 Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 5 
          Sinh[2 $CellContext`v]^2) + (-1 + Cos[2 $CellContext`u]^2 + 
          Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h1][$CellContext`u] - (5 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h2][$CellContext`v]))), 
    Subscript[xAct`AVF`R, 2, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 2, 4, 1, 2] -> 
    0, Subscript[
     xAct`AVF`R, 2, 4, 1, 
      3] -> (((((((
            Rational[1, 4] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
              Cos[2 $CellContext`u] + 
              Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
           Rational[
            1, 2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
         Rational[
          1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
        Rational[1, 2]) ($CellContext`h1[$CellContext`u] + 
       2 $CellContext`h2[$CellContext`v])) (((
         8 $CellContext`h1[$CellContext`u]^2) Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] + ((8 $CellContext`h2[$CellContext`v]^2) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((-1 + Cos[2 $CellContext`u]^2 + 
        Sin[2 $CellContext`u]^2) 
       Derivative[1][$CellContext`h1][$CellContext`u]) 
      Derivative[
       1][$CellContext`h2][$CellContext`v] - ((
        2 (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
       Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
       Sin[2 $CellContext`u] 
        Derivative[1][$CellContext`h2][$CellContext`v]) + (
        2 $CellContext`h1[$CellContext`u]) ((((-8) \
$CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 2, 4, 1, 
      4] -> ((((
         Rational[
          1, 2] (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[-1, 2]) ((((-12) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((12 $CellContext`h2[$CellContext`v]^2) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]) 
       Derivative[
        1][$CellContext`h2][$CellContext`v] + ((
         3 (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v]) + (
        3 $CellContext`h1[$CellContext`u]) (((
           8 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 2, 4, 2, 
      3] -> (((((
          Rational[1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-3)) $CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((
         4 $CellContext`h1[$CellContext`u]^2) \
$CellContext`h2[$CellContext`v]) ((2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 2 Cosh[2 $CellContext`v]^2 + 
        Sin[2 $CellContext`u]^2 - 5 
        Sinh[2 $CellContext`v]^2) + $CellContext`h2[$CellContext`v] ((
          4 $CellContext`h2[$CellContext`v]^2) ((2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 2 Cosh[2 $CellContext`v]^2 + 
          Sin[2 $CellContext`u]^2 - 5 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h1][$CellContext`u] - (5 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) 
          Derivative[
           2][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u] (((-8) $CellContext`h2[$CellContext`v]^2) ((2 
            Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
          2 Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 5 
          Sinh[2 $CellContext`v]^2) + (-1 + Cos[2 $CellContext`u]^2 + 
          Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h1][$CellContext`u] - (5 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 2, 4, 2, 
      4] -> (((Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ((
        2 $CellContext`h1[$CellContext`u]^3) (Sin[2 $CellContext`u]^2 - 
        Sinh[2 $CellContext`v]^2) + $CellContext`h1[$CellContext`u]^2 ((
          4 $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 - Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) (
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h1][$CellContext`u] - 
          Sinh[2 $CellContext`v] 
          Derivative[
           1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h2[$CellContext`v]^2 ((4 $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 - 2 Sinh[2 $CellContext`v]^2) - (
         Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (((-4) Sinh[2 $CellContext`v]) 
          Derivative[1][$CellContext`h2][$CellContext`v] + (
           Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
          Derivative[
           2][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u] ((
          2 $CellContext`h2[$CellContext`v]^2) (((-4) Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] - 4 Cosh[2 $CellContext`v]^2 + 
          Sin[2 $CellContext`u]^2 + 7 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((-
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (3 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h2][$CellContext`v]))), 
    Subscript[xAct`AVF`R, 2, 4, 3, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 4, 1, 
      2] -> (((((
          Rational[-1, 2] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[
          1, 2]) ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) (((4 $CellContext`h1[$CellContext`u]) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((4 $CellContext`h2[$CellContext`v]) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v])), 
    Subscript[xAct`AVF`R, 3, 4, 1, 3] -> 0, Subscript[xAct`AVF`R, 3, 4, 1, 4] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 4, 3, 
      4] -> ((Rational[-1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v])^(-3)) ((2 $CellContext`h1[$CellContext`u]) (
        Sin[2 $CellContext`u]^2 - Sinh[2 $CellContext`v]^2) - (
       2 $CellContext`h2[$CellContext`v]) (Sin[2 $CellContext`u]^2 - 
       Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) (
        Sin[2 $CellContext`u] Derivative[1][$CellContext`h1][$CellContext`u] - 
        Sinh[2 $CellContext`v] 
        Derivative[1][$CellContext`h2][$CellContext`v]))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "-", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"6", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                  RowBox[{"6", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{"h2", "[", "v", "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h1", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox["h2", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
          ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"]}], ")"}]}]}], ",", 
     
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["h1", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
             ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"16", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "-", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "2"]}], 
                ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "-", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"4", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["h1", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], 
    "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[
     xAct`AVF`R, 1, 
      1] -> ((((
         Rational[-1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) \
(((-8) $CellContext`h1[$CellContext`u]^4) (1 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] - 
        Sin[2 $CellContext`u]^2) + ($CellContext`h2[$CellContext`v]^2 (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
       Derivative[1][$CellContext`h1][$CellContext`u]^2 - ((
        4 $CellContext`h1[$CellContext`u]^2) $CellContext`h2[$CellContext`v]) \
($CellContext`h2[$CellContext`v] (
         2 + (6 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
         4 Cosh[2 $CellContext`v]^2 - 6 Sin[2 $CellContext`u]^2 - 4 
         Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) ((2 Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] + (2 
           Sinh[2 $CellContext`v]) 
          Derivative[1][$CellContext`h2][$CellContext`v] + (
           Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
          Derivative[2][$CellContext`h1][$CellContext`u])) + (
        2 $CellContext`h1[$CellContext`u]^3) ((
          4 $CellContext`h2[$CellContext`v]) (
          2 + (3 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 - 3 Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((2 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] + (2 
            Sinh[2 $CellContext`v]) 
           Derivative[1][$CellContext`h2][$CellContext`v] + (
            Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h1][$CellContext`u])) + ((
         2 $CellContext`h1[$CellContext`u]) \
$CellContext`h2[$CellContext`v]^2) ((4 $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 - Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((2 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] + (2 
            Sinh[2 $CellContext`v]) 
           Derivative[1][$CellContext`h2][$CellContext`v] + (
            Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h1][$CellContext`u]))), 
    Subscript[xAct`AVF`R, 1, 2] -> 0, Subscript[xAct`AVF`R, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 
      2] -> ((Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v])^(-3)) ((4 $CellContext`h1[$CellContext`u]) (1 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
        Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
       Cosh[2 $CellContext`v]) ((4 
         Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v] - (2 
        Sin[2 $CellContext`u]) 
       Derivative[1][$CellContext`h1][$CellContext`u] - (2 
        Sinh[2 $CellContext`v]) 
       Derivative[1][$CellContext`h2][$CellContext`v] + 
       Cos[2 $CellContext`u] Derivative[2][$CellContext`h2][$CellContext`v] + 
       Cosh[2 $CellContext`v] 
        Derivative[2][$CellContext`h2][$CellContext`v])), 
    Subscript[xAct`AVF`R, 2, 3] -> 0, Subscript[xAct`AVF`R, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 
      3] -> ((((
         Rational[1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        8 $CellContext`h1[$CellContext`u]^4) (Cos[2 $CellContext`u]^2 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
        Sin[2 $CellContext`u]^2 + 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[1][$CellContext`h1][$CellContext`u]^2 - ((
        2 $CellContext`h1[$CellContext`u]) $CellContext`h2[$CellContext`v]) ((
         4 $CellContext`h2[$CellContext`v]^2) (
         Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
         Cosh[2 $CellContext`v]^2 - Sin[2 $CellContext`u]^2 - 
         Sinh[2 $CellContext`v]^2) + (-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((2 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] + (2 
           Sinh[2 $CellContext`v]) 
          Derivative[1][$CellContext`h2][$CellContext`v] + (
           Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
          Derivative[2][$CellContext`h1][$CellContext`u])) + (
        2 $CellContext`h1[$CellContext`u]^2) ((
          4 $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (3 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 2 Cosh[2 $CellContext`v]^2 - 
          Sin[2 $CellContext`u]^2 - Sinh[2 $CellContext`v]^2) - (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
        Derivative[
          1][$CellContext`h2][$CellContext`v]^2 + ((Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])^2 $CellContext`h2[$CellContext`v]) (
          Derivative[2][$CellContext`h1][$CellContext`u] + 
          Derivative[2][$CellContext`h2][$CellContext`v])) - (
       2 $CellContext`h1[$CellContext`u]^3) ((
         4 $CellContext`h2[$CellContext`v]) (
         2 Cos[2 $CellContext`u]^2 + (3 Cos[2 $CellContext`u]) 
          Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
         Sin[2 $CellContext`u]^2 + Sinh[2 $CellContext`v]^2) + (
         Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (((-2) Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (2 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) 
          Derivative[2][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     xAct`AVF`R, 3, 
      4] -> ((((
         Rational[1, 4] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[-1, 
         2]) ((((-8) $CellContext`h1[$CellContext`u]^3) \
$CellContext`h2[$CellContext`v]) (Cos[2 $CellContext`u]^2 - 
        Cosh[2 $CellContext`v]^2 + 2 Sin[2 $CellContext`u]^2 + 
        2 Sinh[2 $CellContext`v]^2) + ($CellContext`h2[$CellContext`v]^2 (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
       Derivative[
         1][$CellContext`h1][$CellContext`u]^2 + \
$CellContext`h1[$CellContext`u]^2 ((16 $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 - Cosh[2 $CellContext`v]^2 + 
          2 Sin[2 $CellContext`u]^2 + 2 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((4 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] + (4 
           Sinh[2 $CellContext`v]) 
          Derivative[1][$CellContext`h2][$CellContext`v] + (
           Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] - Derivative[
           2][$CellContext`h2][$CellContext`v]))) + \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) (((-8) \
$CellContext`h2[$CellContext`v]^2) (Cos[2 $CellContext`u]^2 - 
          Cosh[2 $CellContext`v]^2 + 2 Sin[2 $CellContext`u]^2 + 
          2 Sinh[2 $CellContext`v]^2) + (-1 + Cos[2 $CellContext`u]^2 + 
          Sin[2 $CellContext`u]^2) (
          Derivative[1][$CellContext`h1][$CellContext`u]^2 + 
          Derivative[1][$CellContext`h2][$CellContext`v]^2) + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((4 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] + (4 
            Sinh[2 $CellContext`v]) 
           Derivative[1][$CellContext`h2][$CellContext`v] + (
            Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] - Derivative[
            2][$CellContext`h2][$CellContext`v])))), 
    Subscript[
     xAct`AVF`R, 4, 
      4] -> (((Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ((
        4 $CellContext`h1[$CellContext`u]^3) (Cos[2 $CellContext`u]^2 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
        Sin[2 $CellContext`u]^2 + 
        Sinh[2 $CellContext`v]^2) + $CellContext`h1[$CellContext`u]^2 (((-4) \
$CellContext`h2[$CellContext`v]) (
          2 Cos[2 $CellContext`u]^2 + (3 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          Sin[2 $CellContext`u]^2 + Sinh[2 $CellContext`v]^2) + (
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((2 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] + (2 
            Sinh[2 $CellContext`v]) 
           Derivative[1][$CellContext`h2][$CellContext`v] + (
            Cos[2 $CellContext`u] + Cosh[2 $CellContext`v]) 
           Derivative[
            2][$CellContext`h1][$CellContext`u])) + \
$CellContext`h1[$CellContext`u] ((4 $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (3 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + 2 Cosh[2 $CellContext`v]^2 - 
          Sin[2 $CellContext`u]^2 - Sinh[2 $CellContext`v]^2) - (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
        Derivative[
          1][$CellContext`h2][$CellContext`v]^2 - ((Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^2 $CellContext`h2[$CellContext`v]) (
         Derivative[2][$CellContext`h1][$CellContext`u] + 
         Derivative[
          2][$CellContext`h2][$CellContext`v])) + \
$CellContext`h2[$CellContext`v] (((-4) $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 - Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) - (-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[
          1][$CellContext`h1][$CellContext`u]^2 + ((Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) (((-2) 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (2 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) 
           Derivative[2][$CellContext`h2][$CellContext`v])))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Mu]0", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], " ", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "v"}], "]"}]}], "-", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"Sinh", "[", 
               RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["h1", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
           RowBox[{"h2", "[", "v", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"h2", "[", "v", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                RowBox[{"6", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], " ", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                RowBox[{"3", " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "+", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
            ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"h2", "[", "v", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", 
                RowBox[{"6", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], " ", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                RowBox[{"3", " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "+", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
            ")"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"h1", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"h2", "[", "v", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], " ", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}]}], 
               ")"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "+", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "u"}], "]"}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
        RowBox[{"h1", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], "-", 
           RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], "}"}]}],
  
  SequenceForm[
  "ricciscalar = ", {
   Subscript[
     xAct`AVF`R, 
      "s"] -> ((((
         Rational[1, 2] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[
           2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        4 $CellContext`h1[$CellContext`u]^4) (
        2 + (2 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] - 
        Sin[2 $CellContext`u]^2 + 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[
        1][$CellContext`h1][$CellContext`u]^2 + ((
         4 $CellContext`h1[$CellContext`u]^2) \
$CellContext`h2[$CellContext`v]) ($CellContext`h2[$CellContext`v] (
          2 + (6 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
          4 Cosh[2 $CellContext`v]^2 - 3 Sin[2 $CellContext`u]^2 - 
          Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^2 (
          Derivative[2][$CellContext`h1][$CellContext`u] + 
          Derivative[2][$CellContext`h2][$CellContext`v])) - (
       2 $CellContext`h1[$CellContext`u]^3) ((
         2 $CellContext`h2[$CellContext`v]) (
         4 + (6 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
         2 Cosh[2 $CellContext`v]^2 - 3 Sin[2 $CellContext`u]^2 + 
         Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^2 (
         Derivative[2][$CellContext`h1][$CellContext`u] + 
         Derivative[2][$CellContext`h2][$CellContext`v])) - ((
        2 $CellContext`h1[$CellContext`u]) $CellContext`h2[$CellContext`v]^2) \
($CellContext`h2[$CellContext`v] ((4 Cos[2 $CellContext`u]) 
          Cosh[2 $CellContext`v] + 4 Cosh[2 $CellContext`v]^2 - 
         2 (Sin[2 $CellContext`u]^2 + Sinh[2 $CellContext`v]^2)) + (
          Cos[2 $CellContext`u] + Cosh[2 $CellContext`v])^2 (
         Derivative[2][$CellContext`h1][$CellContext`u] + 
         Derivative[2][$CellContext`h2][$CellContext`v])))}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Weyl \
tensor:'weylcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"weylcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"16", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"Sinh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"24", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"]}], ")"}]}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "-", 
                 RowBox[{"8", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"14", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "16"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "2"]}], 
                 ")"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "16"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
          RowBox[{"h2", "[", "v", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"24", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "16"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "2"], "-", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "2"]}], 
                 ")"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "16"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
              RowBox[{"4", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              RowBox[{"7", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "-", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"6", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                 RowBox[{"4", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"24", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         RowBox[{"h1", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Mu]0", "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], 
            RowBox[{"\[Mu]0", " ", 
             RowBox[{"h2", "[", "v", "]"}]}]]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "16"}], " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox[
           RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "u"}], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", " ", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["h1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["h2", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
          RowBox[{"h2", "[", "v", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}]}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["h2", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "u"}], "]"}], " ", 
             RowBox[{"Sinh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h1", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h1", "[", "u", "]"}]}]]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], 
           RowBox[{"\[Mu]0", " ", 
            RowBox[{"h2", "[", "v", "]"}]}]]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
               RowBox[{"4", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{"7", " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  RowBox[{"6", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "2"]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h1", "\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"24", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "2"]}], 
                ")"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "16"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}]}], "+", 
              SuperscriptBox[
               RowBox[{"Cosh", "[", 
                RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["h1", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], " ", 
            RowBox[{"h2", "[", "v", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "2"], "-", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "2"]}], 
                ")"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "16"}], " ", 
               SuperscriptBox[
                RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["h2", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
               RowBox[{"h2", "[", "v", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sinh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "u"}], "]"}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h1", "[", "u", "]"}], "-", 
            RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"h1", "[", "u", "]"}], " ", 
           RowBox[{"h2", "[", "v", "]"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               RowBox[{"5", " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Sinh", "[", 
                  RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "-", 
                  RowBox[{"8", " ", 
                   SuperscriptBox[
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "+", 
                  RowBox[{"14", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h2", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "16"}], " ", 
                SuperscriptBox[
                 RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["h1", "\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "4"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], " ", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}]}], "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
               SuperscriptBox[
                RowBox[{"Sinh", "[", 
                 RowBox[{"2", " ", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "u"}], "]"}], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["h1", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "2"], " ", 
             RowBox[{"h2", "[", "v", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"5", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"h1", "[", "u", "]"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"h1", "[", "u", "]"}], " ", 
             SuperscriptBox[
              RowBox[{"h2", "[", "v", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                RowBox[{"h2", "[", "v", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], "+", 
                  SuperscriptBox[
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "2"], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "u"}], "]"}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h1", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}]}], "-", 
                  RowBox[{"6", " ", 
                   RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["h2", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "u"}], "]"}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "v"}], "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["h1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["h2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"24", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "u"}], "]"}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", " ", "v"}], "]"}]}], ")"}], "3"], " ", 
          RowBox[{"h1", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h1", "[", "u", "]"}], "-", 
             RowBox[{"h2", "[", "v", "]"}]}], ")"}], "2"]}], ")"}]}]}]}]}], 
    "}"}]}],
  SequenceForm[
  "weylcomps = ", {
   Subscript[
     C, 1, 2, 1, 
      2] -> ((((
         Rational[1, 24] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        16 $CellContext`h1[$CellContext`u]^4) (1 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
        Sin[2 $CellContext`u]^2 - 
        Sinh[2 $CellContext`v]^2) + ($CellContext`h2[$CellContext`v]^2 (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
       Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
         4 $CellContext`h1[$CellContext`u]^2) \
$CellContext`h2[$CellContext`v]) ((4 $CellContext`h2[$CellContext`v]) (
          1 + (3 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
          2 Cosh[2 $CellContext`v]^2 + 3 Sin[2 $CellContext`u]^2 - 5 
          Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v]))) - (
       2 $CellContext`h1[$CellContext`u]^3) ((
         8 $CellContext`h2[$CellContext`v]) (
         2 + (3 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
         Cosh[2 $CellContext`v]^2 + 3 Sin[2 $CellContext`u]^2 - 4 
         Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
         Derivative[1][$CellContext`h1][$CellContext`u] - (6 
         Sinh[2 $CellContext`v]) 
        Derivative[
         1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) (
          Derivative[2][$CellContext`h1][$CellContext`u] + 
          Derivative[2][$CellContext`h2][$CellContext`v]))) + ((
         2 $CellContext`h1[$CellContext`u]) \
$CellContext`h2[$CellContext`v]^2) (((-8) $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 2 
          Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[C, 1, 2, 1, 3] -> 0, Subscript[C, 1, 2, 1, 4] -> 0, 
    Subscript[C, 1, 2, 2, 3] -> 0, Subscript[C, 1, 2, 2, 4] -> 0, 
    Subscript[
     C, 1, 2, 3, 
      4] -> (((((
          Rational[-1, 2] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[
          1, 2]) ($CellContext`\[Mu]0^(-1) ((Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) (((4 $CellContext`h1[$CellContext`u]) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((4 $CellContext`h2[$CellContext`v]) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v])), 
    Subscript[C, 1, 3, 1, 2] -> 0, 
    Subscript[
     C, 1, 3, 1, 
      3] -> ((((
         Rational[1, 12] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        4 $CellContext`h1[$CellContext`u]^4) (-1 + 
        3 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 2 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[
        1][$CellContext`h1][$CellContext`u]^2 + \
$CellContext`h1[$CellContext`u]^3 (((-8) $CellContext`h2[$CellContext`v]) (-1 + 
          3 Cos[2 $CellContext`u]^2 - 2 Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 + 2 Sinh[2 $CellContext`v]^2) + (
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[
             2][$CellContext`h2][$CellContext`v]))) + \
$CellContext`h1[$CellContext`u]^2 ((4 $CellContext`h2[$CellContext`v]^2) (-1 + 
          3 Cos[2 $CellContext`u]^2 - (6 Cos[2 $CellContext`u]) 
          Cosh[2 $CellContext`v] - 8 Cosh[2 $CellContext`v]^2 - 3 
          Sin[2 $CellContext`u]^2 + 14 Sinh[2 $CellContext`v]^2) + (
          3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((6 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[
             2][$CellContext`h2][$CellContext`v]))) - \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) (((-16) \
$CellContext`h2[$CellContext`v]^2) (
         Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
         Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 2 
         Sinh[2 $CellContext`v]^2) + (
         3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
        Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[
     C, 1, 3, 1, 
      4] -> ((((
         Rational[-1, 8] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((
         8 $CellContext`h1[$CellContext`u]^3) \
$CellContext`h2[$CellContext`v]) (
        Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
        3 Sin[2 $CellContext`u]^2 - 3 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[
        1][$CellContext`h1][$CellContext`u]^2 + \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) ((
          8 $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) - (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) (
         Derivative[1][$CellContext`h1][$CellContext`u]^2 - 
         Derivative[1][$CellContext`h2][$CellContext`v]^2) - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[
            2][$CellContext`h2][$CellContext`v]))) + \
$CellContext`h1[$CellContext`u]^2 (((-16) $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[
     C, 1, 3, 2, 
      3] -> ((((
         Rational[
          1, 2] (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[-1, 2]) ((((-12) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((12 $CellContext`h2[$CellContext`v]^2) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]) 
       Derivative[
        1][$CellContext`h2][$CellContext`v] + ((
         3 (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v]) + (
        3 $CellContext`h1[$CellContext`u]) (((
           8 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     C, 1, 3, 2, 
      4] -> ((((((
           Rational[-1, 4] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
          Rational[
           1, 2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((((-8) $CellContext`h1[$CellContext`u]^3) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((
        2 (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v])) $CellContext`h1[$CellContext`u]^2) (
       Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
       Sin[2 $CellContext`u] 
        Derivative[
         1][$CellContext`h2][$CellContext`v]) + \
$CellContext`h1[$CellContext`u] (((24 $CellContext`h2[$CellContext`v]^2) 
          Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[1][$CellContext`h2][$CellContext`v] - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[
           1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h2[$CellContext`v] ((((-16) $CellContext`h2[$CellContext`v]^2) 
          Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           4 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[C, 1, 3, 3, 4] -> 0, Subscript[C, 1, 4, 1, 2] -> 0, 
    Subscript[
     C, 1, 4, 1, 
      3] -> ((((
         Rational[-1, 8] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((
         8 $CellContext`h1[$CellContext`u]^3) \
$CellContext`h2[$CellContext`v]) (
        Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
        3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) - ((
        3 $CellContext`h2[$CellContext`v]^2) (-1 + Cos[2 $CellContext`u]^2 + 
        Sin[2 $CellContext`u]^2)) 
      Derivative[
        1][$CellContext`h1][$CellContext`u]^2 + \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) ((
          8 $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) - (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) (
         Derivative[1][$CellContext`h1][$CellContext`u]^2 - 
         Derivative[1][$CellContext`h2][$CellContext`v]^2) - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[
            2][$CellContext`h2][$CellContext`v]))) + \
$CellContext`h1[$CellContext`u]^2 (((-16) $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[
     C, 1, 4, 1, 
      4] -> ((((
         Rational[1, 24] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        8 $CellContext`h1[$CellContext`u]^4) (1 + 
        3 Cos[2 $CellContext`u]^2 + (4 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 7 Sin[2 $CellContext`u]^2 - 4 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[1][$CellContext`h1][$CellContext`u]^2 - (
       4 $CellContext`h1[$CellContext`u]^3) ((
         4 $CellContext`h2[$CellContext`v]) (1 + 
         3 Cos[2 $CellContext`u]^2 + (3 Cos[2 $CellContext`u]) 
          Cosh[2 $CellContext`v] - Cosh[2 $CellContext`v]^2 + 
         6 Sin[2 $CellContext`u]^2 - 2 Sinh[2 $CellContext`v]^2) - (
        Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
         Derivative[1][$CellContext`h1][$CellContext`u] - (6 
         Sinh[2 $CellContext`v]) 
        Derivative[
         1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) (
          Derivative[2][$CellContext`h1][$CellContext`u] + 
          Derivative[2][$CellContext`h2][$CellContext`v]))) + (
        2 $CellContext`h1[$CellContext`u]^2) ((
          4 $CellContext`h2[$CellContext`v]^2) (1 + 3 Cos[2 $CellContext`u]^2 - 
          4 Cosh[2 $CellContext`v]^2 + 3 Sin[2 $CellContext`u]^2 + 
          4 Sinh[2 $CellContext`v]^2) + (
          3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 - ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v]))) - ((
        2 $CellContext`h1[$CellContext`u]) $CellContext`h2[$CellContext`v]) \
(((-8) $CellContext`h2[$CellContext`v]^2) (
         Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
         Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 2 
         Sinh[2 $CellContext`v]^2) + (
         3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
        Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[
     C, 1, 4, 2, 
      3] -> ((((((
           Rational[-1, 4] $CellContext`\[Mu]0^2) (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])^(-4)) ($CellContext`\[Mu]0^(-1) ((
             Cos[2 $CellContext`u] + 
             Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
          Rational[
           1, 2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
        Rational[
         1, 2]) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[1, 2]) ((((-16) $CellContext`h1[$CellContext`u]^3) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] + (
        4 $CellContext`h1[$CellContext`u]^2) (((
           6 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[
           1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h1[$CellContext`u] (((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[
            1][$CellContext`h2][$CellContext`v])) + \
$CellContext`h2[$CellContext`v] ((((-8) $CellContext`h2[$CellContext`v]^2) 
          Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
           Sin[2 $CellContext`u]^2) 
          Derivative[1][$CellContext`h1][$CellContext`u]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
          Sinh[2 $CellContext`v] 
           Derivative[1][$CellContext`h1][$CellContext`u] + 
          Sin[2 $CellContext`u] 
           Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[
     C, 1, 4, 2, 
      4] -> ((((
         Rational[
          1, 2] (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
            Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])/$CellContext`h1[$CellContext`u]))^
         Rational[-1, 
           2]) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`\[Mu]0^(-1) ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])/$CellContext`h2[$CellContext`v]))^
       Rational[-1, 2]) ((((-12) $CellContext`h1[$CellContext`u]^2) 
        Sin[2 $CellContext`u]) 
       Sinh[2 $CellContext`v] - ((12 $CellContext`h2[$CellContext`v]^2) 
       Sin[2 $CellContext`u]) 
      Sinh[2 $CellContext`v] + ((-1 + Cos[2 $CellContext`u]^2 + 
         Sin[2 $CellContext`u]^2) 
        Derivative[1][$CellContext`h1][$CellContext`u]) 
       Derivative[
        1][$CellContext`h2][$CellContext`v] + ((
         3 (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) (
        Sinh[2 $CellContext`v] Derivative[1][$CellContext`h1][$CellContext`u] + 
        Sin[2 $CellContext`u] 
         Derivative[1][$CellContext`h2][$CellContext`v]) + (
        3 $CellContext`h1[$CellContext`u]) (((
           8 $CellContext`h2[$CellContext`v]) Sin[2 $CellContext`u]) 
         Sinh[2 $CellContext`v] - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) (
         Sinh[2 $CellContext`v] 
          Derivative[1][$CellContext`h1][$CellContext`u] + 
         Sin[2 $CellContext`u] 
          Derivative[1][$CellContext`h2][$CellContext`v]))), 
    Subscript[C, 1, 4, 3, 4] -> 0, 
    Subscript[
     C, 2, 3, 2, 
      3] -> ((((
         Rational[-1, 24] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        8 $CellContext`h1[$CellContext`u]^4) (1 + 
        3 Cos[2 $CellContext`u]^2 + (4 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 7 Sin[2 $CellContext`u]^2 - 4 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[1][$CellContext`h1][$CellContext`u]^2 - (
       4 $CellContext`h1[$CellContext`u]^3) ((
         4 $CellContext`h2[$CellContext`v]) (1 + 
         3 Cos[2 $CellContext`u]^2 + (3 Cos[2 $CellContext`u]) 
          Cosh[2 $CellContext`v] - Cosh[2 $CellContext`v]^2 + 
         6 Sin[2 $CellContext`u]^2 - 2 Sinh[2 $CellContext`v]^2) - (
        Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
         Derivative[1][$CellContext`h1][$CellContext`u] - (6 
         Sinh[2 $CellContext`v]) 
        Derivative[
         1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) (
          Derivative[2][$CellContext`h1][$CellContext`u] + 
          Derivative[2][$CellContext`h2][$CellContext`v]))) + (
        2 $CellContext`h1[$CellContext`u]^2) ((
          4 $CellContext`h2[$CellContext`v]^2) (1 + 3 Cos[2 $CellContext`u]^2 - 
          4 Cosh[2 $CellContext`v]^2 + 3 Sin[2 $CellContext`u]^2 + 
          4 Sinh[2 $CellContext`v]^2) + (
          3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 - ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v]))) - ((
        2 $CellContext`h1[$CellContext`u]) $CellContext`h2[$CellContext`v]) \
(((-8) $CellContext`h2[$CellContext`v]^2) (
         Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
         Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 2 
         Sinh[2 $CellContext`v]^2) + (
         3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
        Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[
     C, 2, 3, 2, 
      4] -> ((((
         Rational[1, 8] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((
         8 $CellContext`h1[$CellContext`u]^3) \
$CellContext`h2[$CellContext`v]) (
        Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
        3 Sin[2 $CellContext`u]^2 - 3 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[
        1][$CellContext`h1][$CellContext`u]^2 + \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) ((
          8 $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) - (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) (
         Derivative[1][$CellContext`h1][$CellContext`u]^2 - 
         Derivative[1][$CellContext`h2][$CellContext`v]^2) - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[
            2][$CellContext`h2][$CellContext`v]))) + \
$CellContext`h1[$CellContext`u]^2 (((-16) $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[C, 2, 3, 3, 4] -> 0, 
    Subscript[
     C, 2, 4, 2, 
      3] -> ((((
         Rational[1, 8] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3)) ($CellContext`h1[$CellContext`u] - \
$CellContext`h2[$CellContext`v])^(-2)) ($CellContext`h1[$CellContext`u] \
$CellContext`h2[$CellContext`v])^
       Rational[-1, 2]) (((
         8 $CellContext`h1[$CellContext`u]^3) \
$CellContext`h2[$CellContext`v]) (
        Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
        3 Sin[2 $CellContext`u]^2 - 3 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[
        1][$CellContext`h1][$CellContext`u]^2 + \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) ((
          8 $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) - (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) (
         Derivative[1][$CellContext`h1][$CellContext`u]^2 - 
         Derivative[1][$CellContext`h2][$CellContext`v]^2) - ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[
            2][$CellContext`h2][$CellContext`v]))) + \
$CellContext`h1[$CellContext`u]^2 (((-16) $CellContext`h2[$CellContext`v]^2) (
          Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
           Cosh[2 $CellContext`v] + Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 - 3 Sinh[2 $CellContext`v]^2) + (-1 + 
          Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           2 (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[
     C, 2, 4, 2, 
      4] -> ((((
         Rational[-1, 12] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        4 $CellContext`h1[$CellContext`u]^4) (-1 + 
        3 Cos[2 $CellContext`u]^2 + (2 Cos[2 $CellContext`u]) 
         Cosh[2 $CellContext`v] + 5 Sin[2 $CellContext`u]^2 - 2 
        Sinh[2 $CellContext`v]^2) - ($CellContext`h2[$CellContext`v]^2 (-1 + 
        Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
      Derivative[
        1][$CellContext`h1][$CellContext`u]^2 + \
$CellContext`h1[$CellContext`u]^3 (((-8) $CellContext`h2[$CellContext`v]) (-1 + 
          3 Cos[2 $CellContext`u]^2 - 2 Cosh[2 $CellContext`v]^2 + 
          3 Sin[2 $CellContext`u]^2 + 2 Sinh[2 $CellContext`v]^2) + (
          Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[
             2][$CellContext`h2][$CellContext`v]))) + \
$CellContext`h1[$CellContext`u]^2 ((4 $CellContext`h2[$CellContext`v]^2) (-1 + 
          3 Cos[2 $CellContext`u]^2 - (6 Cos[2 $CellContext`u]) 
          Cosh[2 $CellContext`v] - 8 Cosh[2 $CellContext`v]^2 - 3 
          Sin[2 $CellContext`u]^2 + 14 Sinh[2 $CellContext`v]^2) + (
          3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
         Derivative[1][$CellContext`h2][$CellContext`v]^2 + ((
           Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) $CellContext`h2[$CellContext`v]) ((6 
            Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[
             2][$CellContext`h2][$CellContext`v]))) - \
($CellContext`h1[$CellContext`u] $CellContext`h2[$CellContext`v]) (((-16) \
$CellContext`h2[$CellContext`v]^2) (
         Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
         Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 2 
         Sinh[2 $CellContext`v]^2) + (
         3 (-1 + Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
        Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
          2 (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v])) $CellContext`h2[$CellContext`v]) ((6 
           Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v])))), 
    Subscript[C, 2, 4, 3, 4] -> 0, 
    Subscript[
     C, 3, 4, 3, 
      4] -> ((((
         Rational[-1, 24] $CellContext`\[Mu]0) (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v])^(-3))/$CellContext`h1[$CellContext`u]) \
($CellContext`h1[$CellContext`u] - $CellContext`h2[$CellContext`v])^(-2)) ((
        16 $CellContext`h1[$CellContext`u]^4) (1 + 
        Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
        Sin[2 $CellContext`u]^2 - 
        Sinh[2 $CellContext`v]^2) + ($CellContext`h2[$CellContext`v]^2 (-1 + 
         Cos[2 $CellContext`u]^2 + Sin[2 $CellContext`u]^2)) 
       Derivative[1][$CellContext`h1][$CellContext`u]^2 + ((
         4 $CellContext`h1[$CellContext`u]^2) \
$CellContext`h2[$CellContext`v]) ((4 $CellContext`h2[$CellContext`v]) (
          1 + (3 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
          2 Cosh[2 $CellContext`v]^2 + 3 Sin[2 $CellContext`u]^2 - 5 
          Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
         Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
          Derivative[1][$CellContext`h1][$CellContext`u] - (6 
          Sinh[2 $CellContext`v]) 
         Derivative[
          1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
           Cosh[2 $CellContext`v]) (
           Derivative[2][$CellContext`h1][$CellContext`u] + 
           Derivative[2][$CellContext`h2][$CellContext`v]))) - (
       2 $CellContext`h1[$CellContext`u]^3) ((
         8 $CellContext`h2[$CellContext`v]) (
         2 + (3 Cos[2 $CellContext`u]) Cosh[2 $CellContext`v] + 
         Cosh[2 $CellContext`v]^2 + 3 Sin[2 $CellContext`u]^2 - 4 
         Sinh[2 $CellContext`v]^2) - (Cos[2 $CellContext`u] + 
        Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
         Derivative[1][$CellContext`h1][$CellContext`u] - (6 
         Sinh[2 $CellContext`v]) 
        Derivative[
         1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) (
          Derivative[2][$CellContext`h1][$CellContext`u] + 
          Derivative[2][$CellContext`h2][$CellContext`v]))) + ((
         2 $CellContext`h1[$CellContext`u]) \
$CellContext`h2[$CellContext`v]^2) (((-8) $CellContext`h2[$CellContext`v]) (
          Cos[2 $CellContext`u] Cosh[2 $CellContext`v] + 
          Cosh[2 $CellContext`v]^2 + Sin[2 $CellContext`u]^2 - 2 
          Sinh[2 $CellContext`v]^2) + (Cos[2 $CellContext`u] + 
          Cosh[2 $CellContext`v]) ((6 Sin[2 $CellContext`u]) 
           Derivative[1][$CellContext`h1][$CellContext`u] - (6 
           Sinh[2 $CellContext`v]) 
          Derivative[
           1][$CellContext`h2][$CellContext`v] + (Cos[2 $CellContext`u] + 
            Cosh[2 $CellContext`v]) (
            Derivative[2][$CellContext`h1][$CellContext`u] + 
            Derivative[2][$CellContext`h2][$CellContext`v]))))}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.9. P-P gravity wave", "Subsubsection"],

Cell["Null coordinates {u, v} defined by u = t - z, v = t + z.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"signature", "=", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1", ",", "1", ",", 
    RowBox[{"-", "1"}]}], "}"}]}], "\n", 
 RowBox[{"makescalars", "[", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", "x", ",", "y"}], "}"}], "]"}], "\n", 
 RowBox[{"tocoords", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Rule]", 
     RowBox[{
      RowBox[{"L", "[", "u", "]"}], 
      SuperscriptBox["E", 
       RowBox[{"\[Beta]", "[", "u", "]"}]], "dx"}]}], ",", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "->", 
     RowBox[{
      RowBox[{"L", "[", "u", "]"}], 
      SuperscriptBox["E", 
       RowBox[{"-", 
        RowBox[{"\[Beta]", "[", "u", "]"}]}]], "dy"}]}], ",", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Rule]", 
     RowBox[{
      RowBox[{"dv", "/", "2"}], "-", 
      RowBox[{"du", "/", "2"}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "->", 
     RowBox[{
      RowBox[{"dv", "/", "2"}], "+", 
      RowBox[{"du", "/", "2"}]}]}]}], "}"}]}], "\n", 
 RowBox[{"metric", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Theta]", "1"], "2"], "+", 
      SuperscriptBox[
       SubscriptBox["\[Theta]", "2"], "2"], "+", 
      SuperscriptBox[
       SubscriptBox["\[Theta]", "3"], "2"], "-", 
      SuperscriptBox[
       SubscriptBox["\[Theta]", "4"], "2"]}], ")"}], "/.", "tocoords"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"explicit", "=", 
   RowBox[{"{", 
    RowBox[{"dummy", "->", "dummy"}], "}"}]}], ";"}], "\n", 
 RowBox[{"makeorthonormalcurvature", "[", 
  RowBox[{"signature", ",", "tocoords", ",", "True"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", "x", ",", "y"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "\[Rule]", 
    RowBox[{"dx", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Beta]", "[", "u", "]"}]], " ", 
     RowBox[{"L", "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "2"], "\[Rule]", 
    RowBox[{"dy", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"\[Beta]", "[", "u", "]"}]}]], " ", 
     RowBox[{"L", "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "3"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["du", "2"]}], "+", 
     FractionBox["dv", "2"]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "4"], "\[Rule]", 
    RowBox[{
     FractionBox["du", "2"], "+", 
     FractionBox["dv", "2"]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "du"}], " ", "dv"}], "+", 
  RowBox[{
   SuperscriptBox["dy", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"\[Beta]", "[", "u", "]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"L", "[", "u", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["dx", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"2", " ", 
     RowBox[{"\[Beta]", "[", "u", "]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"L", "[", "u", "]"}], "2"]}]}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData["\<\"The inverse transformation back to \
orthoframe:'toortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"toortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"du", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Theta]", "3"]}], "+", 
       SubscriptBox["\[Theta]", "4"]}]}], ",", 
     RowBox[{"dv", "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Theta]", "3"], "+", 
       SubscriptBox["\[Theta]", "4"]}]}], ",", 
     RowBox[{"dx", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"\[Beta]", "[", "u", "]"}]}]], " ", 
        SubscriptBox["\[Theta]", "1"]}], 
       RowBox[{"L", "[", "u", "]"}]]}], ",", 
     RowBox[{"dy", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[Beta]", "[", "u", "]"}]], " ", 
        SubscriptBox["\[Theta]", "2"]}], 
       RowBox[{"L", "[", "u", "]"}]]}]}], "}"}]}],
  SequenceForm[
  "toortho = ", {$CellContext`du -> -Subscript[xAct`AVF`\[Theta], 3] + 
     Subscript[xAct`AVF`\[Theta], 4], $CellContext`dv -> 
    Subscript[xAct`AVF`\[Theta], 3] + 
     Subscript[xAct`AVF`\[Theta], 4], $CellContext`dx -> (
      E^(-$CellContext`\[Beta][$CellContext`u])/xAct`AVF`L[$CellContext`u]) 
     Subscript[xAct`AVF`\[Theta], 1], $CellContext`dy -> (
      E^$CellContext`\[Beta][$CellContext`u]/xAct`AVF`L[$CellContext`u]) 
     Subscript[xAct`AVF`\[Theta], 2]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Exterior derivatives of orthoframe:'dortho'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dortho = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d\[Theta]", "1"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "+", 
          RowBox[{
           RowBox[{"L", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "2"], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "-", 
          RowBox[{
           RowBox[{"L", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "3"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["d\[Theta]", "4"], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "dortho = ", {
   Subscript[xAct`AVF`d\[Theta], 1] -> (xAct`AVF`L[$CellContext`u]^(-1) (Wedge[
         Subscript[xAct`AVF`\[Theta], 1], 
         Subscript[xAct`AVF`\[Theta], 3]] - Wedge[
        Subscript[xAct`AVF`\[Theta], 1], 
        Subscript[xAct`AVF`\[Theta], 4]])) (
      Derivative[1][xAct`AVF`L][$CellContext`u] + 
      xAct`AVF`L[$CellContext`u] 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u]), 
    Subscript[
     xAct`AVF`d\[Theta], 2] -> (xAct`AVF`L[$CellContext`u]^(-1) (Wedge[
         Subscript[xAct`AVF`\[Theta], 2], 
         Subscript[xAct`AVF`\[Theta], 3]] - Wedge[
        Subscript[xAct`AVF`\[Theta], 2], 
        Subscript[xAct`AVF`\[Theta], 4]])) (
      Derivative[1][xAct`AVF`L][$CellContext`u] - xAct`AVF`L[$CellContext`u] 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u]), 
    Subscript[xAct`AVF`d\[Theta], 3] -> 0, Subscript[xAct`AVF`d\[Theta], 4] -> 
    0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The general matrix of connection \
1-forms:'generalomegas'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"generalomegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "2"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "2"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "1", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "1", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "1", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "3"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "3"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "3"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "2", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "2", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "2", ",", "4"}]]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Theta]", "1"]}], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"1", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"2", ",", "3", ",", "4"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"3", ",", "3", ",", "4"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        SubscriptBox["\[CapitalGamma]", 
         RowBox[{"4", ",", "3", ",", "4"}]]}]}]}]}], "}"}]}],
  SequenceForm[
  "generalomegas = ", {
   Subscript[
     xAct`AVF`\[Omega], 1, 2] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2], 
    Subscript[
     xAct`AVF`\[Omega], 1, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3], 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4], 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3], 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4], 
    Subscript[
     xAct`AVF`\[Omega], 3, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) 
      Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 2] 
     Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] - 
     Subscript[xAct`AVF`\[Theta], 3] 
     Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] + 
     Subscript[xAct`AVF`\[Theta], 4] 
      Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4]}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci rotation coefficients for \
orthoframe:'rotationcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rotationcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], 
        RowBox[{"L", "[", "u", "]"}]], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], 
        RowBox[{"L", "[", "u", "]"}]], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalGamma]", 
       RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "rotationcomps = ", {
   Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 3] -> 
    xAct`AVF`L[$CellContext`u]^(-1) Derivative[1][xAct`AVF`L][$CellContext`u] + 
     Derivative[1][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 1, 4] -> 
    xAct`AVF`L[$CellContext`u]^(-1) Derivative[1][xAct`AVF`L][$CellContext`u] + 
     Derivative[1][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 1, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 3] -> 
    xAct`AVF`L[$CellContext`u]^(-1) Derivative[1][xAct`AVF`L][$CellContext`u] - 
     Derivative[1][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 2, 4] -> 
    xAct`AVF`L[$CellContext`u]^(-1) Derivative[1][xAct`AVF`L][$CellContext`u] - 
     Derivative[1][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[xAct`AVF`\[CapitalGamma], 2, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 3, 3, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 2] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 1, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 3] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 2, 4] -> 0, 
    Subscript[xAct`AVF`\[CapitalGamma], 4, 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The solved matrix of connection 1-forms:'omegas'\"\>"], \
"Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"omegas = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Theta]", "1"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], 
          RowBox[{"L", "[", "u", "]"}]], "+", 
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Theta]", "1"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], 
          RowBox[{"L", "[", "u", "]"}]], "+", 
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox["L", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{"L", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox["L", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{"L", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]}],
  SequenceForm[
  "omegas = ", {
   Subscript[xAct`AVF`\[Omega], 1, 2] -> 0, 
    Subscript[
     xAct`AVF`\[Omega], 1, 3] -> (-Subscript[xAct`AVF`\[Theta], 1]) (
      xAct`AVF`L[$CellContext`u]^(-1) 
       Derivative[1][xAct`AVF`L][$CellContext`u] + 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[Omega], 1, 4] -> (-Subscript[xAct`AVF`\[Theta], 1]) (
      xAct`AVF`L[$CellContext`u]^(-1) 
       Derivative[1][xAct`AVF`L][$CellContext`u] + 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[Omega], 2, 3] -> (xAct`AVF`L[$CellContext`u]^(-1) 
      Subscript[xAct`AVF`\[Theta], 2]) (-
       Derivative[1][xAct`AVF`L][$CellContext`u] + 
      xAct`AVF`L[$CellContext`u] 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u]), 
    Subscript[
     xAct`AVF`\[Omega], 2, 4] -> (xAct`AVF`L[$CellContext`u]^(-1) 
      Subscript[xAct`AVF`\[Theta], 2]) (-
       Derivative[1][xAct`AVF`L][$CellContext`u] + 
      xAct`AVF`L[$CellContext`u] 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u]), 
    Subscript[xAct`AVF`\[Omega], 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Riemann tensor:'riemanncomps'\
\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riemanncomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "+", 
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
        RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "+", 
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
        RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "+", 
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
        RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "+", 
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
        RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], 
    "}"}]}],
  SequenceForm[
  "riemanncomps = ", {
   Subscript[xAct`AVF`R, 1, 2, 1, 2] -> 0, Subscript[xAct`AVF`R, 1, 2, 1, 3] -> 
    0, Subscript[xAct`AVF`R, 1, 2, 1, 4] -> 0, 
    Subscript[xAct`AVF`R, 1, 2, 2, 3] -> 0, Subscript[xAct`AVF`R, 1, 2, 2, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 2, 3, 4] -> 0, 
    Subscript[xAct`AVF`R, 1, 3, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 3, 1, 3] -> ((-1)/
      xAct`AVF`L[$CellContext`u]) ((2 
        Derivative[1][xAct`AVF`L][$CellContext`u]) 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
      Derivative[2][xAct`AVF`L][$CellContext`u] + 
      xAct`AVF`L[$CellContext`u] (
        Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
        Derivative[2][$CellContext`\[Beta]][$CellContext`u])), 
    Subscript[
     xAct`AVF`R, 1, 3, 1, 4] -> ((-1)/
      xAct`AVF`L[$CellContext`u]) ((2 
        Derivative[1][xAct`AVF`L][$CellContext`u]) 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
      Derivative[2][xAct`AVF`L][$CellContext`u] + 
      xAct`AVF`L[$CellContext`u] (
        Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
        Derivative[2][$CellContext`\[Beta]][$CellContext`u])), 
    Subscript[xAct`AVF`R, 1, 3, 2, 3] -> 0, Subscript[xAct`AVF`R, 1, 3, 2, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 3, 3, 4] -> 0, 
    Subscript[xAct`AVF`R, 1, 4, 1, 2] -> 0, 
    Subscript[
     xAct`AVF`R, 1, 4, 1, 3] -> ((-1)/
      xAct`AVF`L[$CellContext`u]) ((2 
        Derivative[1][xAct`AVF`L][$CellContext`u]) 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
      Derivative[2][xAct`AVF`L][$CellContext`u] + 
      xAct`AVF`L[$CellContext`u] (
        Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
        Derivative[2][$CellContext`\[Beta]][$CellContext`u])), 
    Subscript[
     xAct`AVF`R, 1, 4, 1, 4] -> ((-1)/
      xAct`AVF`L[$CellContext`u]) ((2 
        Derivative[1][xAct`AVF`L][$CellContext`u]) 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
      Derivative[2][xAct`AVF`L][$CellContext`u] + 
      xAct`AVF`L[$CellContext`u] (
        Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
        Derivative[2][$CellContext`\[Beta]][$CellContext`u])), 
    Subscript[xAct`AVF`R, 1, 4, 2, 3] -> 0, Subscript[xAct`AVF`R, 1, 4, 2, 4] -> 
    0, Subscript[xAct`AVF`R, 1, 4, 3, 4] -> 0, 
    Subscript[xAct`AVF`R, 2, 3, 1, 2] -> 0, Subscript[xAct`AVF`R, 2, 3, 1, 3] -> 
    0, Subscript[xAct`AVF`R, 2, 3, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 3] -> -
      Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
     xAct`AVF`L[$CellContext`u]^(-1) ((2 
         Derivative[1][xAct`AVF`L][$CellContext`u]) 
        Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[2][
       xAct`AVF`L][$CellContext`u]) + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[
     xAct`AVF`R, 2, 3, 2, 4] -> -
      Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
     xAct`AVF`L[$CellContext`u]^(-1) ((2 
         Derivative[1][xAct`AVF`L][$CellContext`u]) 
        Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[2][
       xAct`AVF`L][$CellContext`u]) + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[xAct`AVF`R, 2, 3, 3, 4] -> 0, Subscript[xAct`AVF`R, 2, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 2, 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 2, 4, 1, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 2, 4, 2, 3] -> -
      Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
     xAct`AVF`L[$CellContext`u]^(-1) ((2 
         Derivative[1][xAct`AVF`L][$CellContext`u]) 
        Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[2][
       xAct`AVF`L][$CellContext`u]) + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[
     xAct`AVF`R, 2, 4, 2, 4] -> -
      Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
     xAct`AVF`L[$CellContext`u]^(-1) ((2 
         Derivative[1][xAct`AVF`L][$CellContext`u]) 
        Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[2][
       xAct`AVF`L][$CellContext`u]) + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[xAct`AVF`R, 2, 4, 3, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 1, 2] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 1, 3] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 1, 4] -> 0, Subscript[xAct`AVF`R, 3, 4, 2, 3] -> 
    0, Subscript[xAct`AVF`R, 3, 4, 2, 4] -> 0, 
    Subscript[xAct`AVF`R, 3, 4, 3, 4] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Ricci \
tensor:'riccicomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"riccicomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"L", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["L", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
        RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"L", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["L", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
        RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["R", 
       RowBox[{"4", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"L", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["L", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
        RowBox[{"L", "[", "u", "]"}]]}]}]}], "}"}]}],
  SequenceForm[
  "riccicomps = ", {
   Subscript[xAct`AVF`R, 1, 1] -> 0, Subscript[xAct`AVF`R, 1, 2] -> 0, 
    Subscript[xAct`AVF`R, 1, 3] -> 0, Subscript[xAct`AVF`R, 1, 4] -> 0, 
    Subscript[xAct`AVF`R, 2, 2] -> 0, Subscript[xAct`AVF`R, 2, 3] -> 0, 
    Subscript[xAct`AVF`R, 2, 4] -> 0, 
    Subscript[
     xAct`AVF`R, 3, 3] -> ((-2)/xAct`AVF`L[$CellContext`u]) (
      xAct`AVF`L[$CellContext`u] 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
      Derivative[2][xAct`AVF`L][$CellContext`u]), 
    Subscript[
     xAct`AVF`R, 3, 4] -> ((-2)/xAct`AVF`L[$CellContext`u]) (
      xAct`AVF`L[$CellContext`u] 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
      Derivative[2][xAct`AVF`L][$CellContext`u]), 
    Subscript[
     xAct`AVF`R, 4, 4] -> ((-2)/xAct`AVF`L[$CellContext`u]) (
      xAct`AVF`L[$CellContext`u] 
       Derivative[1][$CellContext`\[Beta]][$CellContext`u]^2 + 
      Derivative[2][xAct`AVF`L][$CellContext`u])}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"The Ricci scalar:'ricciscalar'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ricciscalar = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", "0"}], "}"}]}],
  SequenceForm["ricciscalar = ", {Subscript[xAct`AVF`R, "s"] -> 0}],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Orthonormal components of the Weyl \
tensor:'weylcomps'\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"weylcomps = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], 
         RowBox[{"L", "[", "u", "]"}]]}], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], 
         RowBox[{"L", "[", "u", "]"}]]}], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], 
         RowBox[{"L", "[", "u", "]"}]]}], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], 
         RowBox[{"L", "[", "u", "]"}]]}], "-", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]], "+", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], 
    "}"}]}],
  SequenceForm[
  "weylcomps = ", {
   Subscript[C, 1, 2, 1, 2] -> 0, Subscript[C, 1, 2, 1, 3] -> 0, 
    Subscript[C, 1, 2, 1, 4] -> 0, Subscript[C, 1, 2, 2, 3] -> 0, 
    Subscript[C, 1, 2, 2, 4] -> 0, Subscript[C, 1, 2, 3, 4] -> 0, 
    Subscript[C, 1, 3, 1, 2] -> 0, 
    Subscript[
     C, 1, 3, 1, 
      3] -> (((-2)/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[
     2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[
     C, 1, 3, 1, 
      4] -> (((-2)/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[
     2][$CellContext`\[Beta]][$CellContext`u], Subscript[C, 1, 3, 2, 3] -> 0, 
    Subscript[C, 1, 3, 2, 4] -> 0, Subscript[C, 1, 3, 3, 4] -> 0, 
    Subscript[C, 1, 4, 1, 2] -> 0, 
    Subscript[
     C, 1, 4, 1, 
      3] -> (((-2)/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[
     2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[
     C, 1, 4, 1, 
      4] -> (((-2)/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] - Derivative[
     2][$CellContext`\[Beta]][$CellContext`u], Subscript[C, 1, 4, 2, 3] -> 0, 
    Subscript[C, 1, 4, 2, 4] -> 0, Subscript[C, 1, 4, 3, 4] -> 0, 
    Subscript[
     C, 2, 3, 2, 
      3] -> ((2/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[
     C, 2, 3, 2, 
      4] -> ((2/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[C, 2, 3, 3, 4] -> 0, 
    Subscript[
     C, 2, 4, 2, 
      3] -> ((2/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[
     C, 2, 4, 2, 
      4] -> ((2/xAct`AVF`L[$CellContext`u]) 
       Derivative[1][xAct`AVF`L][$CellContext`u]) 
      Derivative[1][$CellContext`\[Beta]][$CellContext`u] + 
     Derivative[2][$CellContext`\[Beta]][$CellContext`u], 
    Subscript[C, 2, 4, 3, 4] -> 0, Subscript[C, 3, 4, 3, 4] -> 0}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.10. Simplified results (for the P-P wave)", "Subsubsection"],

Cell[TextData[{
 "To display results execute the commands below. In complicated problems they \
may take a minute or two, even with the option ",
 StyleBox["Trig->False", "Input",
  FontWeight->"Plain"],
 ". Jose: To avoid a proliferation of new global symbols in the package, we \
have canverted them into the corresponding string names and wrapped them with \
the head ONFvalue (Ortho Normal Frame value)."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<rotationcomps\>\"", "]"}], "/.", 
    "explicit"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<rotationcomps\>\"", "]"}], "/.", 
    "explicit"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ONFvalue", "[", "\"\<rotationcomps\>\"", "]"}], "/.", 
     "explicit"}], ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"1", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", 
     RowBox[{"4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<riemanncomps\>\"", "]"}], "/.", 
    "explicit"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ONFvalue", "[", "\"\<riemanncomps\>\"", "]"}], "/.", 
     "explicit"}], ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "+", 
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res3", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<riccicomps\>\"", "]"}], "/.", "explicit"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"4", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res3", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ONFvalue", "[", "\"\<riccicomps\>\"", "]"}], "/.", "explicit"}],
     ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"3", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["R", 
     RowBox[{"4", ",", "4"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res4", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<ricciscalar\>\"", "]"}], "/.", "explicit"}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["R", "\<\"s\"\>"], "\[Rule]", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res5", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<weylcomps\>\"", "]"}], "/.", "explicit"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res5", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ONFvalue", "[", "\"\<weylcomps\>\"", "]"}], "/.", "explicit"}], 
    ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "1", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "1", ",", "3"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "1", ",", "4"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"1", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "3", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "3", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "3", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "4", ",", "2", ",", "3"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "4", ",", "2", ",", "4"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"2", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"3", ",", "4", ",", "3", ",", "4"}]], "\[Rule]", "0"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "In 4-dim. spacetimes, the timelike vector dual to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "4"], TraditionalForm]]],
 "is often a preferred vector field. The 3-space components of the \
acceleration, a , angular velocity, \[CapitalOmega] , and rate-of-strain, S , \
of this timelike congruence are given in the \"dyadics\" list."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res6", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<dyadics\>\"", "]"}], "/.", "res1"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\<\"a\"\>", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"a\"\>", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"a\"\>", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"\[CapitalOmega]\"\>", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"\[CapitalOmega]\"\>", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"\[CapitalOmega]\"\>", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"TrS\"\>", "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], 
     RowBox[{"L", "[", "u", "]"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res6", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ONFvalue", "[", "\"\<dyadics\>\"", "]"}], "/.", "res1"}], ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\<\"a\"\>", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"a\"\>", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"a\"\>", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"\[CapitalOmega]\"\>", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"\[CapitalOmega]\"\>", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"\[CapitalOmega]\"\>", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"L", "[", "u", "]"}]], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"S\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"TrS\"\>", "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["L", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], 
     RowBox[{"L", "[", "u", "]"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "In the local rest-frame of this congruence, the components of the \
stress-energy tensor are given in the \"stress\" list. The symbols are: \
\[Rho] = energy density, p = pressure, \[Mu] = \[Rho] + 3 p ,  t = momentum \
density 3-vector, and M = T +p I, the anisotropic stress dyadic with TrM = 0. \
Units are  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "\[Pi]", " ", 
    RowBox[{"G", "/", 
     SuperscriptBox["c", "2"]}]}], TraditionalForm]]],
 " = 1 ."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res7", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<stress\>\"", "]"}], "/.", "res3"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"\[Rho]\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{"\<\"p\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{"\<\"\[Mu]\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "3"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"L", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"L", "[", "u", "]"}]}]]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res7", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ONFvalue", "[", "\"\<stress\>\"", "]"}], "/.", "res3"}], ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"\[Rho]\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{"\<\"p\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{"\<\"\[Mu]\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "3"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"L", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"L", "[", "u", "]"}]}]]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"\[Rho]\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{"\<\"p\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{"\<\"\[Mu]\"\>", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"L", "[", "u", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"t\"\>", "3"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"3", " ", 
       RowBox[{"L", "[", "u", "]"}]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"L", "[", "u", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"L", "[", "u", "]"}]}]]}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"M\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The \"electric\", A , and \"magnetic\", B , components of the Weyl tensor in \
the same rest-frame are given in the \"AB\" list. Both A and B are symmetric, \
traceless, dyadics. The complex matrix, Q = A+i B.\
\>", "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res8", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"ONFvalue", "[", "\"\<AB\>\"", "]"}], "/.", "res5"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res8", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ONFvalue", "[", "\"\<AB\>\"", "]"}], "/.", "res5"}], ",", 
    RowBox[{"Trig", "->", "False"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"A\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"1", ",", "2"}]], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["L", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], 
      RowBox[{"L", "[", "u", "]"}]], "+", 
     RowBox[{
      SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\<\"B\"\>", 
     RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ONFvalue", "[", "\"\<Q\>\"", "]"}], "=", 
  RowBox[{
   RowBox[{"ONFvalue", "[", "\"\<Q\>\"", "]"}], "/.", "res8"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["L", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Beta]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], 
        RowBox[{"L", "[", "u", "]"}]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], ",", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], 
         RowBox[{"L", "[", "u", "]"}]], "+", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["L", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Beta]", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], 
         RowBox[{"L", "[", "u", "]"}]], "+", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["L", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Beta]", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], 
       RowBox[{"L", "[", "u", "]"}]], "+", 
      RowBox[{
       SuperscriptBox["\[Beta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lambdas", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Eigenvalues", "[", 
    RowBox[{"ONFvalue", "[", "\"\<Q\>\"", "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Some special massaging is required for the lambdas of the Kerr solution.\
\>", "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"kerrsimps1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "m", " ", "x"}], "r0"], "+", 
           SuperscriptBox["x", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["y", "2"]}], ")"}]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{"r0", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}]}], 
         RowBox[{"r0", "-", 
          RowBox[{"2", " ", "m", " ", "x"}], "+", 
          RowBox[{"r0", " ", 
           SuperscriptBox["x", "2"]}]}]]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], 
         RowBox[{"1", "-", 
          SuperscriptBox["y", "2"]}]]]}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r0", "-", 
             RowBox[{"2", " ", "m", " ", "x"}], "+", 
             RowBox[{"r0", " ", 
              SuperscriptBox["x", "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}]}], "r0"]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{"r0", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}]}], 
         RowBox[{"r0", "-", 
          RowBox[{"2", " ", "m", " ", "x"}], "+", 
          RowBox[{"r0", " ", 
           SuperscriptBox["x", "2"]}]}]]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["y", "2"]}]]]}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]}]}], "}"}]}], ";", 
  RowBox[{"kerrsimps2", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", 
         RowBox[{"I", " ", "y"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"I", " ", "y"}]}], ")"}]}]}], ",", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        SuperscriptBox["r0", "6"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", 
           RowBox[{"I", " ", "y"}]}], ")"}], "14"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"I", " ", "y"}]}], ")"}], "8"]}]], "\[Rule]", 
      RowBox[{"m", " ", 
       SuperscriptBox["r0", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{"I", " ", "y"}]}], ")"}], "7"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"I", " ", "y"}]}], ")"}], "4"]}]}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"lambdas", "/.", "kerrsimps1"}], "]"}], "//.", 
  "kerrsimps2"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.c.11. Clean up", "Subsubsection"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IV.d. Exterior differential systems and application to embedding\
\>", "Subsection"],

Cell["This is taken from the file CartanCharacters.nb.", "Text"],

Cell[CellGroupData[{

Cell["IV.d.1. General comments", "Subsubsection"],

Cell[TextData[{
 "This program calculates any number of Cartan characters, and solution \
vectors, for a closed ideal of forms comprising ",
 StyleBox["pforms[1]", "Input",
  FontWeight->"Plain"],
 ",..., ",
 StyleBox["pforms[maxnum]", "Input",
  FontWeight->"Plain"],
 ", for a specified value of ",
 StyleBox["maxnum", "Input",
  FontWeight->"Plain"],
 ". The separate lists of forms must be input with those names. The \
calculation uses random integers to construct the solution vectors, since in \
very large ideals symbolic vectors lead to overwhelming algebraic complexity. \
The parameter ",
 StyleBox["maxrandom", "Input",
  FontWeight->"Plain"],
 " specifies the absolute value of the largest integer which can be randomly \
selected. Positive or negative values are also chosen at random. The smallest \
allowed value of ",
 StyleBox["maxrandom", "Input",
  FontWeight->"Plain"],
 " is 3; if not specified it defaults to 3. The rational numbers generated \
during the calculation may become very large, so it is best to keep ",
 StyleBox["maxrandom", "Input",
  FontWeight->"Plain"],
 " small at first, except for very simple ideals. Generally, the correct \
answer for the characters will be obtained in every run. The calculation \
should be repeated for a few trials, however, to guard against the occasional \
degeneracy. If the results from several trials are inconsistent, the value of \
",
 StyleBox["maxrandom", "Input",
  FontWeight->"Plain"],
 " will have to be increased to avoid accidental degeneracies. Estabrook\
\[CloseCurlyQuote]s experience has been that with, say,  ",
 StyleBox["maxnum=9", "Input",
  FontWeight->"Plain"],
 " or larger the correct characters are always immediately found in exterior \
systems that can be of very high dimension."
}], "Text",
 FontFamily->"Times"],

Cell[TextData[{
 "Different subsections below are independent computations. The list of \
Cartan characters is output as it is generated. The  commands in section \
\"Detailed Results\" at the very end of the program can then be executed \
after each calculation to display the results in detail (as explained there) \
and to repeat the calculation possibly with some minor changes.\n\nA new \
problem can be inserted by copying one of these subsections and making the \
appropriate changes in the coordinates or basis forms, and in the input lists \
of forms of the ideal. There must be an input list for each degree of forms, \
up to the specified ",
 StyleBox["maxnum", "Input",
  FontWeight->"Plain"],
 ", even if just the null list, {}. Note: the ",
 StyleBox["characters", "Input",
  FontWeight->"Plain"],
 " program prunes the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list to the basis 1-forms actually present in the ideal of ",
 StyleBox["pforms[1]", "Input",
  FontWeight->"Plain"],
 ", ",
 StyleBox["pforms[2]", "Input",
  FontWeight->"Plain"],
 ", etc. This subset is called ",
 StyleBox["idealforms", "Input",
  FontWeight->"Plain"],
 ", and the remainder are in the List called ",
 StyleBox["absentforms", "Input",
  FontWeight->"Plain"],
 ".  Absentforms reflect the existence of Cauchy Characteristic Vectors in \
the solutions.  The complete ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list and any previously defined ",
 StyleBox["drules", "Input",
  FontWeight->"Plain"],
 " for them are saved in the variables, ",
 StyleBox["saveforms", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["savedrules", "Input",
  FontWeight->"Plain"],
 ", which can be used to be restore their original values when ",
 StyleBox["characters", "Input",
  FontWeight->"Plain"],
 " is done.\n\nThe characters are returned as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["s", "0"], ",", " ", 
     RowBox[{
      SubscriptBox["s", 
       RowBox[{"1", ",", " "}]], " ", 
      SubscriptBox["s", "2"]}], ",", " ", "...", ",", " "}]}], 
   TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["s", "n"], "}"}], ".", "  "}], TraditionalForm]]],
 " ",
 StyleBox["genus", "Input",
  FontWeight->"Plain"],
 " is the number of independent solution vectors found.   ",
 StyleBox["dimension", "Input",
  FontWeight->"Plain"],
 " is the number of ",
 StyleBox["idealforms", "Input",
  FontWeight->"Plain"],
 ".  "
}], "Text",
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.d.2. The KdV ideal with 3 2-forms in 5 dimensions", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", "t", ",", "u", ",", "p", ",", "z"}], "}"}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"maxnum", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "3", "]"}], "=", 
    RowBox[{
     RowBox[{"pforms", "[", "4", "]"}], "=", 
     RowBox[{
      RowBox[{"pforms", "[", "5", "]"}], "=", 
      RowBox[{"{", "}"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"du", "\[Wedge]", "dt"}], "-", 
     RowBox[{"z", " ", 
      RowBox[{"dx", "\[Wedge]", "dt"}]}]}], ",", 
    RowBox[{
     RowBox[{"dz", "\[Wedge]", "dx"}], "-", 
     RowBox[{"p", " ", 
      RowBox[{"dx", "\[Wedge]", "dt"}]}]}], ",", 
    RowBox[{
     RowBox[{"du", "\[Wedge]", "dx"}], "-", 
     RowBox[{"dp", "\[Wedge]", "dt"}], "-", 
     RowBox[{"12", " ", "u", " ", "z", " ", 
      RowBox[{"dx", "\[Wedge]", "dt"}]}]}]}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"maxrandom", "=", "11"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"du", "\[Wedge]", "dt"}], "-", 
    RowBox[{"z", " ", 
     RowBox[{"dx", "\[Wedge]", "dt"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p"}], " ", 
     RowBox[{"dx", "\[Wedge]", "dt"}]}], "+", 
    RowBox[{"dz", "\[Wedge]", "dx"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"dp", "\[Wedge]", "dt"}], ")"}]}], "+", 
    RowBox[{"du", "\[Wedge]", "dx"}], "-", 
    RowBox[{"12", " ", "u", " ", "z", " ", 
     RowBox[{"dx", "\[Wedge]", "dt"}]}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "3"}], "}"}]], "Print"],

Cell[BoxData["\<\"There are no more independent vectors.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["dimension = ", 5, "    genus = ", 2],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.d.3. A 2-dim string, embedded in flat 4-dim spacetime", \
"Subsubsection"],

Cell[TextData[{
 "The volume 2-form ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
   SubscriptBox["\[Theta]", "2"]}]]],
 " is the Cartan form for variation.  The subroutine ",
 StyleBox["embedsub", "Input",
  FontWeight->"Plain"],
 " constructs the necessary forms and bases."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"embedsub", "[", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"maxnum", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "4", "]"}], "=", 
    RowBox[{
     RowBox[{"pforms", "[", "5", "]"}], "=", 
     RowBox[{"{", "}"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"pforms", "[", "1", "]"}], "\n", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", 
  RowBox[{"Join", "[", 
   RowBox[{"embeddingforms", ",", 
    RowBox[{"fieldforms", "[", 
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
      SubscriptBox["\[Theta]", "2"]}], "]"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"maxrandom", "=", "27"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "3"], ",", 
   SubscriptBox["\[Theta]", "4"]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "3"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "3"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "4"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "4"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "3"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "3"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "4"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "4"}]]}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "2", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "4"}], "}"}]], "Print"],

Cell[BoxData["\<\"There are no more independent vectors.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["dimension = ", 8, "    genus = ", 2],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IV.d.4. The vacuum axi-stationary ideal with 6 2-forms in 6 dimensions\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "g", ",", "w", ",", "\[Phi]", ",", "\[Psi]"}],
     "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"maxnum", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "3", "]"}], "=", 
    RowBox[{
     RowBox[{"pforms", "[", "4", "]"}], "=", 
     RowBox[{
      RowBox[{"pforms", "[", "5", "]"}], "=", 
      RowBox[{"{", "}"}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"dg", "\[Wedge]", "d\[Psi]"}], ")"}]}], "-", 
     FractionBox[
      RowBox[{"dw", "\[Wedge]", "d\[Phi]"}], 
      SuperscriptBox["\[Phi]", "5"]]}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{"w", " ", 
       RowBox[{"dg", "\[Wedge]", "dw"}]}], "2"], "-", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["\[Phi]", "3"], " ", 
      RowBox[{"dg", "\[Wedge]", "d\[Phi]"}]}], "+", 
     RowBox[{"dw", "\[Wedge]", "d\[Psi]"}]}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{"w", " ", 
       RowBox[{"dg", "\[Wedge]", "dx"}]}], 
      RowBox[{"2", " ", "x"}]], "+", 
     FractionBox[
      RowBox[{"dx", "\[Wedge]", "d\[Psi]"}], "x"], "-", 
     FractionBox[
      RowBox[{"dy", "\[Wedge]", "d\[Phi]"}], "\[Phi]"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", "w", " ", 
      RowBox[{"dg", "\[Wedge]", "dy"}]}], "-", 
     FractionBox[
      RowBox[{"x", " ", 
       RowBox[{"dx", "\[Wedge]", "d\[Phi]"}]}], "\[Phi]"], "-", 
     RowBox[{"dy", "\[Wedge]", "d\[Psi]"}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "4"], " ", 
      RowBox[{"dg", "\[Wedge]", "dy"}]}], "-", 
     FractionBox[
      RowBox[{"dw", "\[Wedge]", "dx"}], "x"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "x"}], " ", 
      SuperscriptBox["\[Phi]", "4"], " ", 
      RowBox[{"dg", "\[Wedge]", "dx"}]}], "-", 
     RowBox[{"dw", "\[Wedge]", "dy"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxrandom", "=", "17"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"dg", "\[Wedge]", "d\[Psi]"}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"dw", "\[Wedge]", "d\[Phi]"}], 
     SuperscriptBox["\[Phi]", "5"]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"w", " ", 
      RowBox[{"dg", "\[Wedge]", "dw"}]}], "2"], "-", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["\[Phi]", "3"], " ", 
     RowBox[{"dg", "\[Wedge]", "d\[Phi]"}]}], "+", 
    RowBox[{"dw", "\[Wedge]", "d\[Psi]"}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"w", " ", 
      RowBox[{"dg", "\[Wedge]", "dx"}]}], 
     RowBox[{"2", " ", "x"}]], "+", 
    FractionBox[
     RowBox[{"dx", "\[Wedge]", "d\[Psi]"}], "x"], "-", 
    FractionBox[
     RowBox[{"dy", "\[Wedge]", "d\[Phi]"}], "\[Phi]"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "w", " ", 
     RowBox[{"dg", "\[Wedge]", "dy"}]}], "-", 
    FractionBox[
     RowBox[{"x", " ", 
      RowBox[{"dx", "\[Wedge]", "d\[Phi]"}]}], "\[Phi]"], "-", 
    RowBox[{"dy", "\[Wedge]", "d\[Psi]"}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "4"], " ", 
     RowBox[{"dg", "\[Wedge]", "dy"}]}], "-", 
    FractionBox[
     RowBox[{"dw", "\[Wedge]", "dx"}], "x"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "x"}], " ", 
     SuperscriptBox["\[Phi]", "4"], " ", 
     RowBox[{"dg", "\[Wedge]", "dx"}]}], "-", 
    RowBox[{"dw", "\[Wedge]", "dy"}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "4"}], "}"}]], "Print"],

Cell[BoxData["\<\"There are no more independent vectors.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["dimension = ", 6, "    genus = ", 2],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IV.d.5. A 4-dim Riemannian spacetime embedded in a flat 10-dim space\
\>", "Subsubsection"],

Cell[TextData[{
 "The subroutine ",
 StyleBox["embedsub", "Input",
  FontWeight->"Plain"],
 " constructs the embedding 2-forms and bases. In a problem such as this in \
which each 1-form consists only of a unique basis form, the ",
 StyleBox["oneforms", "Input",
  FontWeight->"Plain"],
 " can actually be omitted, so long as their closure 2-forms are included. \
Doing so will reduce the length of the solution vectors, and may lessen the \
execution time. The program will give the first character, ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SubscriptBox["s", "0"], "=", "0"}]}]]],
 ", but its actual value is clearly just the length of ",
 StyleBox["oneforms", "Input",
  FontWeight->"Plain"],
 ", since they are all independent"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"embedsub", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxnum", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "3", "]"}], "=", 
    RowBox[{
     RowBox[{"pforms", "[", "4", "]"}], "=", 
     RowBox[{
      RowBox[{"pforms", "[", "5", "]"}], "=", 
      RowBox[{"{", "}"}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", 
  "embeddingforms"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxrandom", "=", "9"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "5"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "6"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "6", ",", "6"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "6", ",", "6", ",", "6"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "6", ",", "6", ",", "6", ",", "6"}], "}"}]], "Print"],

Cell[BoxData["\<\"There are no more independent vectors.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["dimension = ", 28, "    genus = ", 4],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The result that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["s", "4"], "=", "6"}]]],
 " can be interpreted as 6 degrees of gauge freedom."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IV.d.6. A 4-dim Ricci-flat spacetime embedded in a flat 10-dim space\
\>", "Subsubsection"],

Cell[TextData[{
 "The subroutine ",
 StyleBox["embedsub", "Input",
  FontWeight->"Plain"],
 " constructs the Ricci 3-forms, ",
 StyleBox["subR\[Theta]", "Input",
  FontWeight->"Plain"],
 ", and bases. This time the ",
 StyleBox["oneforms", "Input",
  FontWeight->"Plain"],
 " are included, although again they could be omitted."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"embedsub", "[", 
  RowBox[{"4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"maxnum", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "5", "]"}], "=", 
    RowBox[{"{", "}"}]}]}], ";"}], "\n", 
 RowBox[{"pforms", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", "embeddingforms"}], "\n", 
 RowBox[{
  RowBox[{"pforms", "[", "3", "]"}], "=", 
  "subR\[Theta]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxrandom", "=", "5"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "5"], ",", 
   SubscriptBox["\[Theta]", "6"], ",", 
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "5"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"3", ",", "5"}]], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"4", ",", "5"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "5"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "5"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "5"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"2", ",", "5"}]], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"4", ",", "5"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "5"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "5"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "5"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "5"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "5"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "6"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "7"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "8"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "9"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"1", ",", "10"}]], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "6", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "6"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "6", ",", "10"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "6", ",", "10", ",", "8"}], "}"}]], "Print"],

Cell[BoxData["\<\"There are no more independent vectors.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["dimension = ", 34, "    genus = ", 4],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IV.d.7. A 5-dim Riemannian manifold embedded in a flat 15-dim space\
\>", "Subsubsection"],

Cell[TextData[{
 "The subroutine ",
 StyleBox["embedsub", "Input",
  FontWeight->"Plain"],
 " constructs the embedding 2-forms and bases."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"embedsub", "[", 
  RowBox[{"5", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
    "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"maxnum", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "4", "]"}], "=", 
    RowBox[{
     RowBox[{"pforms", "[", "5", "]"}], "=", 
     RowBox[{
      RowBox[{"pforms", "[", "6", "]"}], "=", 
      RowBox[{"{", "}"}]}]}]}]}], ";"}], "\n", 
 RowBox[{"pforms", "[", "1", "]"}], "\n", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", "embeddingforms"}], "\n", 
 RowBox[{
  RowBox[{"maxrandom", "=", "3"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "6"], ",", 
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"], ",", 
   SubscriptBox["\[Theta]", "11"], ",", 
   SubscriptBox["\[Theta]", "12"], ",", 
   SubscriptBox["\[Theta]", "13"], ",", 
   SubscriptBox["\[Theta]", "14"], ",", 
   SubscriptBox["\[Theta]", "15"]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "6"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "6"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "6"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "7"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "7"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "8"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "8"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "9"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "9"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "10"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "10"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "11"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "11"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "12"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "12"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "13"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "13"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "14"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "14"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "15"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "15"}]]}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "10", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "10"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "10", ",", "10"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "10", ",", "10", ",", "10"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "10", ",", "10", ",", "10", ",", "10"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "10", ",", "10", ",", "10", ",", "10", ",", "10"}], 
  "}"}]], "Print"],

Cell[BoxData["\<\"There are no more independent vectors.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["dimension = ", 65, "    genus = ", 5],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IV.d.8. A 6-dim Riemannian manifold embedded in a flat 21-dim space\
\>", "Subsubsection"],

Cell[TextData[{
 "The subroutine ",
 StyleBox["embedsub", "Input",
  FontWeight->"Plain"],
 " constructs the embedding 2-forms and bases. This problem is included \
simply to illustrate what happens for a case in which 6 characters are not \
sufficient to give a complete result. However, the final answer here is \
obvious, though it takes a while."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"embedsub", "[", 
  RowBox[{"6", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], 
  "]"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"maxnum", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "4", "]"}], "=", 
    RowBox[{
     RowBox[{"pforms", "[", "5", "]"}], "=", 
     RowBox[{"{", "}"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"pforms", "[", "1", "]"}], "\n", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", 
  "embeddingforms"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxrandom", "=", "3"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"], ",", 
   SubscriptBox["\[Theta]", "11"], ",", 
   SubscriptBox["\[Theta]", "12"], ",", 
   SubscriptBox["\[Theta]", "13"], ",", 
   SubscriptBox["\[Theta]", "14"], ",", 
   SubscriptBox["\[Theta]", "15"], ",", 
   SubscriptBox["\[Theta]", "16"], ",", 
   SubscriptBox["\[Theta]", "17"], ",", 
   SubscriptBox["\[Theta]", "18"], ",", 
   SubscriptBox["\[Theta]", "19"], ",", 
   SubscriptBox["\[Theta]", "20"], ",", 
   SubscriptBox["\[Theta]", "21"]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "7"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "7"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "8"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "8"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "9"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "9"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "10"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "10"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "11"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "11"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "12"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "12"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "13"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "13"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "14"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "14"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "15"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "15"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "16"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "16"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "17"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "17"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "18"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "18"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "19"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "19"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "20"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "20"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "21"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "21"}]]}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "15", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15", ",", "15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15", ",", "15", ",", "15", ",", "15"}], 
  "}"}]], "Print"],

Cell[BoxData["\<\"There may be more independent vectors, so the actual genus \
may be smaller than the printed value.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "21"}],
  SequenceForm["dimension = ", 111, "    genus = ", 21],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Indeed, by increasing ",
 StyleBox["maxnum", "Input",
  FontWeight->"Plain"],
 " we can see that the genus is smaller:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"embedsub", "[", 
  RowBox[{"6", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], 
  "]"}], "\n", 
 RowBox[{
  RowBox[{"makescalars", "[", 
   RowBox[{"{", "}"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"maxnum", "=", "7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pforms", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"pforms", "[", "4", "]"}], "=", 
    RowBox[{
     RowBox[{"pforms", "[", "5", "]"}], "=", 
     RowBox[{
      RowBox[{"pforms", "[", "6", "]"}], "=", 
      RowBox[{
       RowBox[{"pforms", "[", "7", "]"}], "=", 
       RowBox[{"{", "}"}]}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"pforms", "[", "1", "]"}], "\n", 
 RowBox[{
  RowBox[{"pforms", "[", "2", "]"}], "=", 
  "embeddingforms"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxrandom", "=", "3"}], 
  ";"}], "\[IndentingNewLine]", "characters"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"], ",", 
   SubscriptBox["\[Theta]", "11"], ",", 
   SubscriptBox["\[Theta]", "12"], ",", 
   SubscriptBox["\[Theta]", "13"], ",", 
   SubscriptBox["\[Theta]", "14"], ",", 
   SubscriptBox["\[Theta]", "15"], ",", 
   SubscriptBox["\[Theta]", "16"], ",", 
   SubscriptBox["\[Theta]", "17"], ",", 
   SubscriptBox["\[Theta]", "18"], ",", 
   SubscriptBox["\[Theta]", "19"], ",", 
   SubscriptBox["\[Theta]", "20"], ",", 
   SubscriptBox["\[Theta]", "21"]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "7"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "7"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "7"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "8"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "8"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "8"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "9"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "9"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "9"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "10"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "10"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "10"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "11"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "11"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "11"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "12"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "12"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "12"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "13"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "13"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "13"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "14"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "14"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "14"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "15"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "15"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "15"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "16"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "16"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "16"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "17"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "17"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "17"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "18"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "18"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "18"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "19"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "19"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "19"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "20"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "20"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "20"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
       SubscriptBox["\[Omega]", 
        RowBox[{"1", ",", "21"}]]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"3", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "4"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"4", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "5"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "21"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Theta]", "6"], "\[Wedge]", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "21"}]]}]}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", "15", "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15", ",", "15", ",", "15"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "15", ",", "15", ",", "15", ",", "15", ",", "15"}], 
  "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15", ",", "15", ",", "15", ",", "15", ",", "15", ",", "15", ",", "15"}], 
  "}"}]], "Print"],

Cell[BoxData["\<\"There are no more independent vectors.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"dimension = \"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\"    genus = \"\>", "\[InvisibleSpace]", "6"}],
  SequenceForm["dimension = ", 111, "    genus = ", 6],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "IV.d.9. Detailed results of IV.d.8 with ",
 StyleBox["maxnum=7", "Input",
  FontWeight->"Plain"],
 ".  Checking the results,  checking involutory vectors in solutions."
}], "Subsubsection"],

Cell[TextData[{
 "The variable ",
 StyleBox["solutionvectors", "Input",
  FontWeight->"Plain"],
 " contains the independent vectors, ",
 StyleBox["v[i]", "Input",
  FontWeight->"Plain"],
 ", found. In large ideals these vectors may be very long."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["solutionvectors"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "3", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "1", ",", "2", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "3", ",", 
     RowBox[{"-", "2"}], ",", "3", ",", "1", ",", "2", ",", "3", ",", "3", 
     ",", "1", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", "2", ",", 
     RowBox[{"-", "3"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2", ",", "1", ",", 
     RowBox[{"-", "3"}], ",", "2", ",", "3", ",", 
     RowBox[{"-", "2"}], ",", "3", ",", "2", ",", 
     RowBox[{"-", "2"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "3", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "2", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", "1", ",", "2", ",", 
     RowBox[{"-", "3"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", "3", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "3"}], ",", "1", ",", 
     RowBox[{"-", "3"}], ",", "1", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "1", ",", "2", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", "3", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "2", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "2", ",", 
     RowBox[{"-", "2"}], ",", "1", ",", "3", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["168", "31"], ",", 
     RowBox[{"-", 
      FractionBox["19", "31"]}], ",", 
     RowBox[{"-", 
      FractionBox["350", "31"]}], ",", 
     RowBox[{"-", 
      FractionBox["12", "31"]}], ",", 
     FractionBox["164", "31"], ",", 
     RowBox[{"-", 
      FractionBox["188", "31"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox["1832", "31"]}], ",", 
     RowBox[{"-", "3"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "3", ",", 
     RowBox[{"-", 
      FractionBox["301", "31"]}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     FractionBox["232", "31"], ",", "2", ",", 
     RowBox[{"-", "3"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     FractionBox["1768", "31"], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "1", ",", 
     RowBox[{"-", "3"}], ",", 
     FractionBox["1451", "31"], ",", 
     RowBox[{"-", "1"}], ",", "3", ",", "2", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      FractionBox["614", "31"]}], ",", "3", ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "1", ",", "2", ",", 
     FractionBox["1717", "31"], ",", 
     RowBox[{"-", "2"}], ",", "3", ",", "3", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      FractionBox["1403", "31"]}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", "1", ",", "1", ",", "2", ",", 
     FractionBox["975", "31"], ",", "3", ",", "3", ",", "1", ",", "1", ",", 
     "3", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "1", ",", 
     "3", ",", "2", ",", 
     RowBox[{"-", "3"}], ",", "2", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", "3", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "2", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", "2", ",", "2", ",", "1", ",", 
     RowBox[{"-", "3"}], ",", "2", ",", 
     RowBox[{"-", "2"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", "3", ",", "3", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "2", ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["389606", "5921"], ",", 
     FractionBox["741507", "11842"], ",", 
     FractionBox["442741", "5921"], ",", 
     RowBox[{"-", 
      FractionBox["628829", "11842"]}], ",", 
     FractionBox["290467", "11842"], ",", 
     FractionBox["138571", "11842"], ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox["2151838744", "2871685"]}], ",", 
     RowBox[{"-", 
      FractionBox["597300443", "2871685"]}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "3", ",", "1", ",", 
     RowBox[{"-", 
      FractionBox["94018772", "574337"]}], ",", 
     FractionBox["29837016", "574337"], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     FractionBox["102180707", "2871685"], ",", 
     RowBox[{"-", 
      FractionBox["1167527447", "5743370"]}], ",", 
     RowBox[{"-", "3"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "3", ",", 
     FractionBox["1803658392", "2871685"], ",", 
     FractionBox["637496009", "2871685"], ",", 
     RowBox[{"-", "3"}], ",", "3", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     FractionBox["1697295537", "2871685"], ",", 
     FractionBox["1399428353", "5743370"], ",", "3", ",", "2", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      FractionBox["1488498887", "5743370"]}], ",", 
     RowBox[{"-", 
      FractionBox["824558917", "2871685"]}], ",", "1", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     FractionBox["1973152007", "2871685"], ",", 
     FractionBox["902563119", "2871685"], ",", "3", ",", "2", ",", "3", ",", 
     "2", ",", 
     RowBox[{"-", 
      FractionBox["3718698263", "5743370"]}], ",", 
     RowBox[{"-", 
      FractionBox["1122686261", "5743370"]}], ",", "3", ",", "3", ",", "2", 
     ",", 
     RowBox[{"-", "3"}], ",", 
     FractionBox["2782758953", "5743370"], ",", 
     FractionBox["539458413", "2871685"], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", "3", ",", 
     FractionBox["309373197", "5743370"], ",", 
     RowBox[{"-", 
      FractionBox["1340221", "30070"]}], ",", "1", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", "3", ",", 
     RowBox[{"-", 
      FractionBox["257490263", "5743370"]}], ",", 
     RowBox[{"-", 
      FractionBox["503803673", "2871685"]}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      FractionBox["345190269", "5743370"]}], ",", 
     RowBox[{"-", 
      FractionBox["966642913", "5743370"]}], ",", "2", ",", "3", ",", "2", 
     ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "3", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "3", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "1", ",", "2", ",", "3", ",", "2", 
     ",", 
     RowBox[{"-", "2"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["2519269", "19835350"], ",", 
     RowBox[{"-", 
      FractionBox["74119593", "39670700"]}], ",", 
     FractionBox["255715863", "19835350"], ",", 
     RowBox[{"-", 
      FractionBox["326927741", "19835350"]}], ",", 
     RowBox[{"-", 
      FractionBox["1385045719", "39670700"]}], ",", 
     FractionBox["351716058", "9917675"], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     FractionBox["25077184247587310023", "548260313006840250"], ",", 
     RowBox[{"-", 
      FractionBox["33998512421586169259", "548260313006840250"]}], ",", 
     FractionBox["36451666939537117", "2260867270131300"], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     FractionBox["11357969230853603987", "526329900486566640"], ",", 
     RowBox[{"-", 
      FractionBox["6344245629961523153", "263164950243283320"]}], ",", 
     FractionBox["40021623464861941", "27130407241575600"], ",", "2", ",", 
     RowBox[{"-", "2"}], ",", "3", ",", 
     RowBox[{"-", 
      FractionBox["37172979990543126103", "6579123756082083000"]}], ",", 
     FractionBox["37520767112771584631", "1644780939020520750"], ",", 
     RowBox[{"-", 
      FractionBox["108989692767859451", "13565203620787800"]}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", "3", ",", 
     RowBox[{"-", 
      FractionBox["37741207070424435116", "822390469510260375"]}], ",", 
     FractionBox["38281832961896061313", "822390469510260375"], ",", 
     RowBox[{"-", 
      FractionBox["17374437552702019", "6782601810393900"]}], ",", "2", ",", 
     "2", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      FractionBox["22715318500991197087", "848919194333172000"]}], ",", 
     FractionBox["458792875083381393163", "13158247512164166000"], ",", 
     RowBox[{"-", 
      FractionBox["718402633556778311", "54260814483151200"]}], ",", 
     RowBox[{"-", "2"}], ",", "3", ",", 
     RowBox[{"-", "2"}], ",", 
     FractionBox["31315249022673978987", "1462027501351574000"], ",", 
     RowBox[{"-", 
      FractionBox["21572588446846038253", "731013750675787000"]}], ",", 
     FractionBox["8302699628304053", "602897938701680"], ",", "1", ",", "3", 
     ",", "2", ",", 
     RowBox[{"-", 
      FractionBox["568845773855755168511", "13158247512164166000"]}], ",", 
     FractionBox["391991556636621777569", "6579123756082083000"], ",", 
     RowBox[{"-", 
      FractionBox["530006399421567457", "27130407241575600"]}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     FractionBox["471034094734436409499", "26316495024328332000"], ",", 
     RowBox[{"-", 
      FractionBox["385318591607614853161", "13158247512164166000"]}], ",", 
     FractionBox["579396163534113437", "54260814483151200"], ",", "2", ",", 
     "1", ",", "3", ",", 
     RowBox[{"-", 
      FractionBox["24028507178731848139", "4386082504054722000"]}], ",", 
     FractionBox["48366250766914011841", "2193041252027361000"], ",", 
     RowBox[{"-", 
      FractionBox["118062946068217901", "9043469080525200"]}], ",", "2", ",", 
     
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", 
      FractionBox["74014195705436634481", "4386082504054722000"]}], ",", 
     FractionBox["70804531789168815529", "2193041252027361000"], ",", 
     RowBox[{"-", 
      FractionBox["62464524256696091", "9043469080525200"]}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     FractionBox["24575824122927674911", "2924055002703148000"], ",", 
     RowBox[{"-", 
      FractionBox["20310788723010578209", "1462027501351574000"]}], ",", 
     FractionBox["1139109193322329", "241159175480672"], ",", 
     RowBox[{"-", "3"}], ",", "2", ",", "3", ",", 
     FractionBox["15675289341352181297", "26316495024328332000"], ",", 
     RowBox[{"-", 
      FractionBox["38929176773020628723", "13158247512164166000"]}], ",", 
     FractionBox["258418907338099111", "54260814483151200"], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     FractionBox["317412642061839559", "10852162896630240"], ",", 
     RowBox[{"-", 
      FractionBox["21750717460036067", "875174427147600"]}], ",", 
     RowBox[{"-", 
      FractionBox["145171366700722159", "54260814483151200"]}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", 
     RowBox[{"-", "2"}], ",", "1", ",", "2", ",", 
     RowBox[{"-", "2"}], ",", "1", ",", 
     RowBox[{"-", "3"}], ",", "2", ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["541989215864135139526537", "22972926738610210987550"]}], 
     ",", 
     RowBox[{"-", 
      FractionBox["27264367993690754222250933", "712160728896916540614050"]}],
      ",", 
     FractionBox["10767874390348697153398131", "712160728896916540614050"], 
     ",", 
     FractionBox["7554184398282186878548679", "356080364448458270307025"], 
     ",", 
     RowBox[{"-", 
      FractionBox["21846991272386070866819407", "356080364448458270307025"]}],
      ",", 
     RowBox[{"-", 
      FractionBox["1528598533712637368054733", "712160728896916540614050"]}], 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", 
     FractionBox["13136388197371641210823301776353998633105056931179559", 
      "42482205707719849856582583142541078119743122616750"], ",", 
     RowBox[{"-", 
      FractionBox["248981141995847884584050685441683047042799398616149", 
       "14160735235906616618860861047513692706581040872250"]}], ",", 
     FractionBox["722467152334818929254591375924002956659270819681", 
      "29197392238982714678063631025801428260991836850"], ",", 
     RowBox[{"-", 
      FractionBox["75694335242971786818417974810784784759", 
       "965623874225234428389243981852024714"]}], ",", "3", ",", "3", ",", 
     FractionBox["101283989072755121696765341240340366614249482328789", 
      "1699288228308793994263303325701643124789724904670"], ",", 
     RowBox[{"-", 
      FractionBox["275024535429869062270809538426311610539013823381", 
       "4448398503426162288647390904978123363323887185"]}], ",", 
     FractionBox["349206468568759404840145087612462403664235846336", 
      "43796088358474072017095446538702142391487755275"], ",", 
     RowBox[{"-", 
      FractionBox["1433472003329760893292538181411380855", 
       "53645770790290801577180221214001373"]}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     FractionBox["27745681061424937861324123982295272272889215725311", 
      "2360122539317769436476810174585615451096840145375"], ",", 
     FractionBox["2415543267108167735193397501031405404727264210555383", 
      "21241102853859924928291291571270539059871561308375"], ",", 
     FractionBox["1496852058955021407102913621614638766578766827041", 
      "87592176716948144034190893077404284782975510550"], ",", 
     FractionBox["41952942309831559693837564324315031419", 
      "965623874225234428389243981852024714"], ",", "3", ",", "3", ",", 
     RowBox[{"-", 
      FractionBox["12532316737521244024322837171470781865614780790964327", 
       "42482205707719849856582583142541078119743122616750"]}], ",", 
     RowBox[{"-", 
      FractionBox["658167939378599600666647059174018525869448485435539", 
       "42482205707719849856582583142541078119743122616750"]}], ",", 
     RowBox[{"-", 
      FractionBox["1799697324412564981142642346054034342402634887667", 
       "87592176716948144034190893077404284782975510550"]}], ",", 
     FractionBox["7768615884367434026186320384005556843", 
      "321874624741744809463081327284008238"], ",", "2", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", 
      FractionBox["11380180559554509663476694066080459887518414042308387", 
       "42482205707719849856582583142541078119743122616750"]}], ",", 
     FractionBox["129302207417515307236722039306860593610514968714173", 
      "21241102853859924928291291571270539059871561308375"], ",", 
     RowBox[{"-", 
      FractionBox["5323472586392937326455167726018369046068521692631", 
       "87592176716948144034190893077404284782975510550"]}], ",", 
     FractionBox["21461575240360621917659998352241767243", 
      "965623874225234428389243981852024714"], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     FractionBox["137902574837664285620669652012365686090130715667691", 
      "1268125543514025368853211437090778451335615600500"], ",", 
     FractionBox["1492037051315967829880956720253076888744606170115869", 
      "14160735235906616618860861047513692706581040872250"], ",", 
     FractionBox["229914486776647033471181066580784073540600293351", 
      "11678956895593085871225452410320571304396734740"], ",", 
     RowBox[{"-", 
      FractionBox["34749770703934648897931203629239242247", 
       "965623874225234428389243981852024714"]}], ",", "3", ",", "3", ",", 
     RowBox[{"-", 
      FractionBox["8698074194913345192568056726266861064329531257856183", 
       "28321470471813233237721722095027385413162081744500"]}], ",", 
     RowBox[{"-", 
      FractionBox["499726894506585109615616378786470224046947526362602", 
       "21241102853859924928291291571270539059871561308375"]}], ",", 
     RowBox[{"-", 
      FractionBox["10291196365596862965583319563749768792135237295813", 
       "175184353433896288068381786154808569565951021100"]}], ",", 
     FractionBox["41498017746124918720474611353384045437", 
      "965623874225234428389243981852024714"], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     FractionBox["19660337122526492158525038266658972510272050602609583", 
      "84964411415439699713165166285082156239486245233500"], ",", 
     FractionBox["1223858285299907317630631432081410419243858881800244", 
      "21241102853859924928291291571270539059871561308375"], ",", 
     FractionBox["2619471065843567250722888772919599311705172038779", 
      "175184353433896288068381786154808569565951021100"], ",", 
     RowBox[{"-", 
      FractionBox["50451221573723355479699625278704104659", 
       "965623874225234428389243981852024714"]}], ",", "2", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", 
      FractionBox["4912636437826254882392142860949144414632068705636882", 
       "21241102853859924928291291571270539059871561308375"]}], ",", 
     FractionBox["1457958151870083788551770249630479721099077149274", 
      "2360122539317769436476810174585615451096840145375"], ",", 
     RowBox[{"-", 
      FractionBox["165421629416655265392477553160605681427089727157", 
       "4866232039830452446343938504300238043498639475"]}], ",", 
     FractionBox["206559336797938648866278841120699649", 
      "14412296630227379528197671370925742"], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", 
      FractionBox["2669282134599043823926801723849098074846129170852087", 
       "84964411415439699713165166285082156239486245233500"]}], ",", 
     FractionBox["165613798067419968140403277320653084727611609961656", 
      "2360122539317769436476810174585615451096840145375"], ",", 
     RowBox[{"-", 
      FractionBox["105412595732370382306164377747829435478872654373", 
       "19464928159321809785375754017200952173994557900"]}], ",", 
     FractionBox["27823335212427234795669203644057288609", 
      "965623874225234428389243981852024714"], ",", "3", ",", 
     RowBox[{"-", "2"}], ",", 
     FractionBox["692910526468050068326731982451317066353204350193637", 
      "9440490157271077745907240698342461804387360581500"], ",", 
     FractionBox["21316133678185002862499654820295223049689532726736", 
      "2360122539317769436476810174585615451096840145375"], ",", 
     FractionBox["26486279632323180070196439926613957223918385651", 
      "778597126372872391415030160688038086959782316"], ",", 
     FractionBox["138648910911648196738335306436311247", 
      "53645770790290801577180221214001373"], ",", "2", ",", 
     RowBox[{"-", "3"}], ",", 
     FractionBox["319867238361982990053534286695425514972150812424533", 
      "28321470471813233237721722095027385413162081744500"], ",", 
     FractionBox["2134838025373941392139048946947767150216621363698192", 
      "21241102853859924928291291571270539059871561308375"], ",", 
     RowBox[{"-", 
      FractionBox["2681245382714217957510801370174575334276174876213", 
       "175184353433896288068381786154808569565951021100"]}], ",", 
     RowBox[{"-", 
      FractionBox["36006289391744327990417682787239489797", 
       "965623874225234428389243981852024714"]}], ",", 
     RowBox[{"-", "2"}], ",", "1", ",", 
     FractionBox["924143399114040659844343776173074032436565604053", 
      "35036870686779257613676357230961713913190204220"], ",", 
     RowBox[{"-", 
      FractionBox["1990672090020284457199527167854892782119485861492", 
       "43796088358474072017095446538702142391487755275"]}], ",", 
     RowBox[{"-", 
      FractionBox["440020424594826158489010317573635569604404214853", 
       "175184353433896288068381786154808569565951021100"]}], ",", 
     RowBox[{"-", 
      FractionBox["8006722978239892876882631549697349969", 
       "321874624741744809463081327284008238"]}], ",", "2", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", 
      FractionBox["2620980599507535591", "71807225876721766"]}], ",", 
     FractionBox["1562142955905688948", "35903612938360883"], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", "3", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       "4748657623892575817997120047370739086176978276303498906218469773", 
       "237657319431286816275288677532089974406513496164975694641611477"]}], 
     ",", 
     RowBox[{"-", 
      FractionBox[
       "4295108485672579915654723944314572940558550690459089133362594971", 
       "237657319431286816275288677532089974406513496164975694641611477"]}], 
     ",", 
     RowBox[{"-", 
      FractionBox[
       "1987882814411166716131567132955222181284798959022542162615216335", 
       "237657319431286816275288677532089974406513496164975694641611477"]}], 
     ",", 
     FractionBox[
      "1979475491988901194906839137107405617058505767641371357684423315", 
      "237657319431286816275288677532089974406513496164975694641611477"], ",", 
     RowBox[{"-", 
      FractionBox[
       "5479269388163636820184852019402344966788417373015826570753227843", 
       "237657319431286816275288677532089974406513496164975694641611477"]}], 
     ",", 
     FractionBox[
      "3430555528508198913072810913956975766329368845156219241065422150", 
      "237657319431286816275288677532089974406513496164975694641611477"], ",",
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", 
     RowBox[{
     "223670984003003459253176642588723741532971985613193442303800700540134926\
01467681156131011630477558960671101259125718668752337334", "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}], ",", 
     RowBox[{
     "371014031300354104386393418121642569757129019739444781747430076634839216\
356333326940092461065032865275105009057336821292057728", "/", 
      "97885795108313374245250897358809625124708919058498650948085628535896705\
06135371114314002990923004407646742876458477633350995"}], ",", 
     RowBox[{
     "110292114349746235510213760537286660225002633725160070959039519257188956\
880617972345224269672112237646575407640098598416943", "/", 
      "20182638166662551390773380898723634046331735888350237308883634749669423\
723990455905802068022521658572467511085481397182167"}], ",", 
     RowBox[{
     "662974473215625054565045952572021021666119500857381757463934744411327264\
603770707377150756170741584770854570425284", "/", 
      "50061415842538097357742186501236190783022583116287242568344147139361955\
902156013282546362272518931083538937588761"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "28501380013833557917719622089852422539635355266408804470658731663136982\
05409023", "/", 
       "5184359788401538032260184517472189088760218647868610750345361676710000\
36715865"}]}], ",", "3", ",", 
     RowBox[{
     "126467287381973789351145296976471525218157574412265523863759947858091389\
942504491156706900924930237830149096408710923549951414", "/", 
      "23810058269589739681277245303494233138442710041256428608993801535758657\
98789684865643946673467757828887045564543954018923215"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "61755825814092351954462137239745183602707816639796733039918742253331609\
631115249152614393791867977585539804721150024695945513", "/", 
       "2381005826958973968127724530349423313844271004125642860899380153575865\
798789684865643946673467757828887045564543954018923215"}]}], ",", 
     RowBox[{
     "136740597597467128593116778097786631832729504159468732007106478526062010\
19988832718192382650199667391728724031700495408049", "/", 
      "49092903648638638518097412996895326058644762971662739399987219661358057\
70700381166276178708180943977086691885657637152419"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "72517780944626875080723125658462152650081424067454324100168067990752409\
7119491367502985062663348290105830094411", "/", 
       "1503345821097240160893158753790876600090768261750367644695019433614473\
15021489529377016102920477270521137950717"}]}], ",", 
     RowBox[{
     "148162208599275743198915940530735484195698260356849846432446678610958362\
62017", "/", 
      "14011783211896048735838336533708619158811401750996245271203680207324325\
316645"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10839891947694888627551448286723618864887553151762208215930921620483700\
90288212892937472955411217940979171948435130450703144949", "/", 
       "8809721559748203682072580762292866261223802715264878585327706568230703\
4555218340028826026918307039668820685888126298700158955"}]}], ",", 
     RowBox[{
     "572857231822191971859968593005710359777395386596566753094235166330205197\
2151885008908483452704962793446178917887319361234869433", "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "49444557227907362234065769041749811221606139195917838599760804814034344\
7831048753909500078267419381454572955219190460619", "/", 
       "2711100649253178545029260120724070245029636164106748295223174817119773\
336058419450033113614965595927644889548796008576709"}]}], ",", 
     RowBox[{
     "173518620612254612610565611033176541671903714671376074611354290665265363\
183147322911296987221225689248799113393094", "/", 
      "50061415842538097357742186501236190783022583116287242568344147139361955\
902156013282546362272518931083538937588761"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "28270813882795052178345603926333933625991621702268811247491726715268532\
3394497", "/", 
       "5184359788401538032260184517472189088760218647868610750345361676710000\
36715865"}]}], ",", "1", ",", 
     RowBox[{"-", 
      RowBox[{
      "19065359410220167920919248188200111138261282272151835743808378758942646\
251897001455589722397823520755092795507454393548366235343", "/", 
       "8809721559748203682072580762292866261223802715264878585327706568230703\
4555218340028826026918307039668820685888126298700158955"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "21394852928271320800271188349174603251342820620593869643632074807576815\
8265463840245484296585496756494955210257355661383527572", "/", 
       "5182189152793060989454459271936980153661060420744046226663356804841590\
267954020001695648642253355274636510934595664629421115"}]}], ",", 
     RowBox[{
     "153053988636625935185319432512801622976997265095256756516839311318139659\
515753903633797986219949701386041157116023381037884", "/", 
      "18164374349996296251696042808851270641698562299515213577995271274702481\
3515914103152218612202694927152207599769332574639503"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "75695899338792010833607932580440189350214065946824454868511487198157722\
091185743113398026444977830731570707059808", "/", 
       "1668713861417936578591406216707873026100752770542908085611471571312065\
1967385337760848787424172977027846312529587"}]}], ",", 
     RowBox[{
     "112029058133337002731456780105694450938632460601701895663338660389302921\
0969771", "/", 
      "51843597884015380322601845174721890887602186478686107503453616767100003\
6715865"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "37396609607162352667746651211658861061242839284770304584646104384581801\
60455899241896431843857921730070931090440826161427322659", "/", 
       "1957715902166267484905017947176192502494178381169973018961712570717934\
1012270742228628005981846008815293485752916955266701990"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "39971462867387610118935977117416077652528145479187538335813662436233944\
09836534106554318431305409825997417055883877199490277869", "/", 
       "8809721559748203682072580762292866261223802715264878585327706568230703\
4555218340028826026918307039668820685888126298700158955"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "36525790134428412795806082480870497654410222659143700460483429443921692\
65854090936948453009584019342115884887371611623459449", "/", 
       "3632874869999259250339208561770254128339712459903042715599054254940496\
27031828206304437224405389854304415199538665149279006"}]}], ",", 
     RowBox[{
     "145440063713011018115269597773797879297151018317682514014895174345715604\
966117550860728247963089758955422166241586", "/", 
      "50061415842538097357742186501236190783022583116287242568344147139361955\
902156013282546362272518931083538937588761"}], ",", 
     RowBox[{
     "131921559079428702124257835986189801701915756723070868833446467309518465\
5331156", "/", 
      "51843597884015380322601845174721890887602186478686107503453616767100003\
6715865"}], ",", "3", ",", 
     RowBox[{
     "790512059947699593991638904720525988598785659056400554713745734756443941\
2104396284988284292426577315900062253596720012143673862", "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}], ",", 
     RowBox[{
     "192067911834114550496079098636298807248678925099652770829907144292713444\
8121261246893355271887360425660471866074517346600677067", "/", 
      "29365738532494012273575269207642887537412675717549595284425688560769011\
518406113342942008972769013222940228629375432900052985"}], ",", 
     RowBox[{
     "362322898370632601661465397446653561063242727619470755146592412637561714\
398022755537087600670023429235395170402381278227519", "/", 
      "60547914499987654172320142696170902138995207665050711926650904249008271\
171971367717406204067564975717402533256444191546501"}], ",", 
     RowBox[{
     "106158695968649268262035310781374003768345952604078519185253425969955914\
423525209577518408294844197484552975152466", "/", 
      "50061415842538097357742186501236190783022583116287242568344147139361955\
902156013282546362272518931083538937588761"}], ",", 
     RowBox[{
     "655088896499174528269774415863585236780257430512695302494907818658692767\
356716", "/", 
      "51843597884015380322601845174721890887602186478686107503453616767100003\
6715865"}], ",", "2", ",", 
     RowBox[{"-", 
      RowBox[{
      "40914007298757915922350575045221087241712338248855652831324457676030901\
70432801316773604333209099303436196369073355024480046650", "/", 
       "1761944311949640736414516152458573252244760543052975717065541313646140\
6911043668005765205383661407933764137177625259740031791"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10930744740864569162961101085593026985635584968043552561854052139301634\
29225204906083022581447045546299122980145016589370356595", "/", 
       "1761944311949640736414516152458573252244760543052975717065541313646140\
6911043668005765205383661407933764137177625259740031791"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "19157712536283275936394116269033046005818296580287518138377965232863773\
74297224310853505114945694671946606576889795806926777", "/", 
       "1816437434999629625169604280885127064169856229951521357799527127470248\
13515914103152218612202694927152207599769332574639503"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "44783727934977490243150577568951098426853350498370491202422211618438494\
5467570570128279289940008744034625618016055", "/", 
       "5006141584253809735774218650123619078302258311628724256834414713936195\
5902156013282546362272518931083538937588761"}]}], ",", 
     RowBox[{
     "231617778940780205368335497334433150216890913153227857268105005755136476\
095869", "/", 
      "10368719576803076064520369034944378177520437295737221500690723353420000\
7343173"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{
     "237429042434738408900185847730476845452658791819360338603352245722466363\
9458207009755425372535924399182463689444215507651368235", "/", 
      "11746295412997604909430107683057155014965070287019838113770275424307604\
607362445337176803589107605289176091451750173160021194"}], ",", 
     RowBox[{
     "758749600806168683782780396358946752506630517008973759465844932303645586\
618959401059794967375929927997462794242206026901159536", "/", 
      "17619443119496407364145161524585732522447605430529757170655413136461406\
911043668005765205383661407933764137177625259740031791"}], ",", 
     RowBox[{
     "174534518022344133910075029635910697673682940821704865957507962640397128\
4362523102234943785238381451796330730354670477567247", "/", 
      "36328748699992592503392085617702541283397124599030427155990542549404962\
7031828206304437224405389854304415199538665149279006"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "23174857022885767625582546078247727884414329816558171879791656068559830\
869760972345736754430262074178840955924048", "/", 
       "5006141584253809735774218650123619078302258311628724256834414713936195\
5902156013282546362272518931083538937588761"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "99416397011492657371465821202965796100340759283123836651137187349105798\
512733", "/", 
       "1036871957680307606452036903494437817752043729573722150069072335342000\
07343173"}]}], ",", "2", ",", 
     RowBox[{"-", 
      RowBox[{
      "13204762921072144952323794257187984371847944433175904458130426518985771\
423118954969111715030041178935767456602059999803632085221", "/", 
       "8809721559748203682072580762292866261223802715264878585327706568230703\
4555218340028826026918307039668820685888126298700158955"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12735376535714920863250536385866732398277108374870653815653274891780531\
00385891830107632200968167489949907436118080529683330831", "/", 
       "2936573853249401227357526920764288753741267571754959528442568856076901\
1518406113342942008972769013222940228629375432900052985"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "43617861550157331420000776574383963344379226210447674655772111780427496\
7066861472880794333055929177238834352709125117510052", "/", 
       "6054791449998765417232014269617090213899520766505071192665090424900827\
1171971367717406204067564975717402533256444191546501"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22697233619387705984009458718418637037454594981256820939546002585735395\
86336684330314924191284893925846199108274", "/", 
       "7471853110826581695185400970333759818361579569595110831096141364083874\
01524716616157408392127148225127446829683"}]}], ",", 
     RowBox[{
     "572697825556995909276722370015213770618384421990401708636703587410041648\
452717", "/", 
      "51843597884015380322601845174721890887602186478686107503453616767100003\
6715865"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "17493105944996041351590507494844003541543864503525696408384052299505728\
53158507053094147294951535998720820202850312030524423034", "/", 
       "8809721559748203682072580762292866261223802715264878585327706568230703\
4555218340028826026918307039668820685888126298700158955"}]}], ",", 
     RowBox[{
     "804658749728426134446948445738175573054511015539772195705512059290636639\
475336131833815083086955293939893552313279352347521871", "/", 
      "29365738532494012273575269207642887537412675717549595284425688560769011\
518406113342942008972769013222940228629375432900052985"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "26349184689324165539450153681554969139033140004504177374573766538379716\
3754138517512995229723398063875084012472681198773768", "/", 
       "6054791449998765417232014269617090213899520766505071192665090424900827\
1171971367717406204067564975717402533256444191546501"}]}], ",", 
     RowBox[{
     "262002199481532610395930980738871405192591770787886026514991451541574040\
211054021167873417489164749052024401475711", "/", 
      "50061415842538097357742186501236190783022583116287242568344147139361955\
902156013282546362272518931083538937588761"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "67587870456161667833231349501043342810378920432996135554631570145661318\
4081767", "/", 
       "5184359788401538032260184517472189088760218647868610750345361676710000\
36715865"}]}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{
     "173408923037029194962895062105911541021963182672875471916693637483107654\
350796250145099857339361098208917413613733775572118491", "/", 
      "19577159021662674849050179471761925024941783811699730189617125707179341\
012270742228628005981846008815293485752916955266701990"}], ",", 
     RowBox[{
     "303733697056804861466032597617610075678821190306604037911688302948643735\
355496055244524969502713887516179118090966792558459614", "/", 
      "97885795108313374245250897358809625124708919058498650948085628535896705\
06135371114314002990923004407646742876458477633350995"}], ",", 
     RowBox[{
     "296471575573004374717596302427414817321477773795646217552685832801719779\
770429857317982434181677326184308227810641041441163", "/", 
      "40365276333325102781546761797447268092663471776700474617767269499338847\
447980911811604136045043317144935022170962794364334"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "94345436069250418916614025100409283611067876742327674752717290470323046\
045584215697277470314515485126120015683262", "/", 
       "5562379538059788595304687389026243420335842568476360285371571904373550\
655795112586949595808057659009282104176529"}]}], ",", 
     RowBox[{
     "289816659453127838347238515621452685477223543808900698498192570640044007\
7183111", "/", 
      "51843597884015380322601845174721890887602186478686107503453616767100003\
6715865"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{
     "183601410906765643096187865572530572137396505293871017121501467484466955\
6224139692359954731441528723625660968964917308378139849", "/", 
      "17619443119496407364145161524585732522447605430529757170655413136461406\
9110436680057652053836614079337641371776252597400317910"}], ",", 
     RowBox[{
     "354129607361864864115701297280560662526797217345834887100433565756661225\
5830163934361257000032101435752062448220273806479777586", "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}], ",", 
     RowBox[{
     "128287309847225268279431596840107174694570754050470015831589906437329025\
0964303947564008005421879817572275497531153538516385", "/", 
      "36328748699992592503392085617702541283397124599030427155990542549404962\
7031828206304437224405389854304415199538665149279006"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "62992816704394396411308856286216626225879510460072138719323910065145202\
8972461939966075783393379034740723907052721", "/", 
       "5006141584253809735774218650123619078302258311628724256834414713936195\
5902156013282546362272518931083538937588761"}]}], ",", 
     RowBox[{
     "141874177772780676285187282799319945283290129414450255873582811828823433\
1393891", "/", 
      "51843597884015380322601845174721890887602186478686107503453616767100003\
6715865"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{
     "286000009265659165376210903156488394640042891498476003142115626207267490\
82299072043436492484481668181470616163729454878473867", "/", 
      "18164374349996296251696042808851270641698562299515213577995271274702481\
35159141031522186122026949271522075997693325746395030"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "83270304343526736057915323570033728313828748498563646717207476269432621\
95628460660272189934622792940073080267403821424529812", "/", 
       "9082187174998148125848021404425635320849281149757606788997635637351240\
67579570515761093061013474635761037998846662873197515"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12173420691128478569827880262906508184388036854725011849910032607462255\
60600773409262565437643709790292099487216997116088789", "/", 
       "3632874869999259250339208561770254128339712459903042715599054254940496\
27031828206304437224405389854304415199538665149279006"}]}], ",", 
     RowBox[{
     "856123611608752222300420365626481611186954211322811375595627839889464938\
02857649291306897831672825725650055867620", "/", 
      "16687138614179365785914062167078730261007527705429080856114715713120651\
967385337760848787424172977027846312529587"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12070156095283208450354193155378522370676562804668326143144181903344387\
9890249", "/", 
       "5184359788401538032260184517472189088760218647868610750345361676710000\
36715865"}]}], ",", "2", ",", 
     FractionBox["1580099930280280389033998412890063686415524530222602455870",
       "599075185039051028278524647994842476705763942065493411111"], ",", 
     FractionBox["2455800677995987688781585355510669923876422406620898103161",
       "599075185039051028278524647994842476705763942065493411111"], ",", 
     FractionBox["9332171830671344038949541371901563104401", 
      "16685651833077074272130409245230517926717"], ",", 
     FractionBox["78147443830728476137017011219051786032917", 
      "16685651833077074272130409245230517926717"], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "2", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
 StyleBox["involutoryvectors", "Input",
  FontWeight->"Plain"],
 " will show a set of independent vectors with the leftmost components in \
involution. This shows which basis forms, pulled back into solutons, can be \
linked to independent variables in equivalent sets of partial differential \
equations."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["involutoryvectors"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
     "142657935466828590448852199245295494432489048851375460654238685033922068\
26416982691642175636537963336075890082764527094499959228446371333913569", "/",
       "2089727072555066084414105369586418465991024818497265568932936428829355\
091028559488901522915325013384879658883784310330378798593116551177353680"}], 
     ",", 
     RowBox[{
     "255519748170253162773853354227203828679007352461474508913447963001266678\
377615220677599966767460975084808155052221926368652417507289957658734", "/", 
      "14511993559410181141764620622127906013826561239564344228700947422426077\
021031663117371686911979259617219853359613266183186101341087160953845"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "52803444546168197402516357124638172810081412615315797283139284428003651\
0469223837816130447431646632524678596494835573439654727887926775033", "/", 
       "1196865448198777826124917164711579877428994741407368596181521436901119\
75431188974163890201335911419523462708120521782954112176008966275908"}]}], 
     ",", 
     RowBox[{
     "829436255961751697975280402958309036505893208844934072295655958064726206\
9746511074147204255006008694561463670803301958656800849634105", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "24708869196260093045838088389076356515550317723371140747584733334750504\
98326312624451797438468972835229950593343521", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
84283027612594107406465671496688984301168090"}]}], ",", 
     RowBox[{
     "112318496436335898829568138041865481455901850182279500798381293177749705\
1616491", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "29300014643788517113017959895829342199419693615123836882233059315780100\
6722472462871712630850017622007370046761329928394717638236897423210301", "/", 
       "2823955503452792005965007256197862791879763268239548066125589768688317\
6905791344444615174531419099795671065997085274734848629636710151045320"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "13845157989779270371261833842158104408876183188699783691169932364472947\
0396995342770889639925612657205548180155803224605120337192086690646529", "/", 
       "1411977751726396002982503628098931395939881634119774033062794884344158\
8452895672222307587265709549897835532998542637367424314818355075522660"}]}], 
     ",", 
     RowBox[{
     "102809455989821017940916556085311919415571523581445189732511501159463792\
327414798635218239427352366714487185325755447461572058601837416233", "/", 
      "58225886669129732081752726931914696739788933365763877652074015849243663\
723281122566216854703956906795198074220794380896595112653010620712"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "15832136731525364485131871687980944766399610619683557999932961017446814\
29007497747637567719850690794575620817774415884497212246547", "/", 
       "8513921894785754454901958770252772282274971699959210074384328875332396\
6865284370379199546579854304347296107931967330785151458314"}]}], ",", 
     RowBox[{
     "147802854728869907589992604773039112204655934192833393529863804206267924\
31455652204965432677415628325661347757402", "/", 
      "44160504666229862284378599464987222063456527305501397038020435621535443\
82203075845866316303590155360661950015785"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "61635636535283307154540352048864267950912176985631168646075199643256794\
188149", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "725701998491963479992056736249035303497556585706255423747927647371821661\
5247435380271710027717883942132344439276779099158627251624576326572447", "/", 
      "10448635362775330422070526847932092329955124092486327844664682144146775\
45514279744450761457662506692439829441892155165189399296558275588676840"}], 
     ",", 
     RowBox[{
     "152495300038981367369476792794120097154763109286778548929046894729980610\
556033667152049477917213599842225866281048142549527674862823094620343", "/", 
      "26121588406938326055176317119830230824887810231215819611661705360366938\
637856993611269036441562667310995736047303879129734982413956889716921"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "36927440126082730290082854542515599779982543865885035335170681963267980\
3579948963384014688194242242461555564733226662303272533180528300031", "/", 
       "2692947258447250108781063620601054724215238168166579341408423233027519\
44720175191868752953005800693927791093271174011646752396020174120793"}]}], 
     ",", 
     RowBox[{
     "141834012643183367932260583174313858105909894236477560722798728766673909\
3688138745310811328554972075943321706608516810482887750331943", "/", 
      "11340543963854624933929409081976692679990262304345667819079926061942752\
3864558781345093796044365933390598415765380484605821742474248"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "86671442743959122047790695442780694572079011617132998996626738263944134\
0400238044100100267250596382684475101943629", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
84283027612594107406465671496688984301168090"}]}], ",", 
     RowBox[{
     "160852703261628645043162916918615800160318438626321952521746603816640300\
633665", "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}], ",", 
     RowBox[{
     "976357281585204686017341928497845482937492910294668192664391102024511292\
6858833277334932125201019290135391466807093790663086263257015818341401", "/", 
      "20897270725550660844141053695864184659910248184972655689329364288293550\
91028559488901522915325013384879658883784310330378798593116551177353680"}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "63970352696289911561884292141579710216360891621537181389009490911035896\
0498734203601063804856956676344547988723070001787750411163665137510423", "/", 
       "2612158840693832605517631711983023082488781023121581961166170536036693\
86378569936112690364415626673109957360473038791297349824139568897169210"}]}], 
     ",", 
     RowBox[{
     "218304569332986867607607361923441078616907563505228619504825712788381950\
695353999267050421757592663707323499621463210547146073712146340713", "/", 
      "53858945168945002175621272412021094484304763363331586828168464660550388\
9440350383737505906011601387855582186542348023293504792040348241586"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "62406151815534212089395039313710760813683152040461959215640875606326275\
5232277142705657554462786886863521470951583355774858467396553", "/", 
       "7560362642569749955952939387984461786660174869563778546053284041295168\
2576372520896729197362910622260398943843586989737214494982832"}]}], ",", 
     RowBox[{
     "311980372772778207905356674893318762635557020339753818209308670823802618\
169652785203227072272041357894098190411576", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "29816903493537839549577901321834374353150283787139097260466095439011446\
5126937", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{
     "977726540438550498960525745794833542876614514849372201244012285210980404\
0287286650724361569949195994250542190415541527176883098313677075847067", "/", 
      "69657569085168869480470178986213948866367493949908852297764547627645169\
7009519829633840971775004461626552961261436776792932864372183725784560"}], 
     ",", 
     RowBox[{
     "115198643834722346802444254286595105675185184217860987079493656150412339\
74175404002316161588772686181826874137604662006395778951538025946041353", "/",
       "1044863536277533042207052684793209232995512409248632784466468214414677\
545514279744450761457662506692439829441892155165189399296558275588676840"}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "10630441588616907748666347304371252855424696161691311064503591900114616\
849965497816426895834383651080148588161561398207461644260051274517309", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{
     "214952623161528616825164598552887410486886429251763257787955299970225020\
855543794651992518961657549047218096527534306005296658102326", "/", 
      "14175679954818281167411761352470865849987827880432084773849907577428440\
483069847668136724505545741673824801970672560575727717809281"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22402179991189077657822741446353308773774382628298652360664159387332308\
85128595973253020279510172981823076565461611", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
68566055225188214812931342993377968602336180"}]}], ",", 
     RowBox[{
     "914157009959940039194410853507013478208170982783030470653137337696417343\
27101", "/", 
      "21035061547572380373414299102661085134058949909141801351097124945326986\
970244"}], ",", 
     RowBox[{
     "222408438593347447692847208332547738157284847638371098578267229930307917\
4824535189450371521371976289672026607423406559848718334897862540433123", "/", 
      "20897270725550660844141053695864184659910248184972655689329364288293550\
91028559488901522915325013384879658883784310330378798593116551177353680"}], 
     ",", 
     RowBox[{
     "329769918468839033980451772065864489567292426391210697071449695739359523\
76444931198334888556298309633472686658917064319966440384574420225184", "/", 
      "87071961356461086850587723732767436082959367437386065372205684534556462\
12618997870423012147187555770331912015767959709911660804652296572307"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "38456607705784302341873134780798964424947224164293286122466276515989095\
1048864999570973742063597934355092100937589869475441216260342495241", "/", 
       "3590596344596333478374751494134739632286984224222105788544564310703359\
26293566922491670604007734258570388124361565348862336528026898827724"}]}], 
     ",", 
     RowBox[{
     "207594412281944941640838913131284920891862618882235338602910973505665674\
0030216660665060025996069203072079787116604564847454523519487", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11590355533909125670934614031174919511058114563540011289250648532762748\
28172834717539680214933824211074548317487801", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
68566055225188214812931342993377968602336180"}]}], ",", 
     RowBox[{
     "311067504890742002964460146449517532884868734064710030147129776085081980\
852089", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "47185915886418848100302072159994332775393329522578709604003882419564310\
7194983377508038921682171421637318351295621657963388620546408263014769", "/", 
       "1044863536277533042207052684793209232995512409248632784466468214414677\
545514279744450761457662506692439829441892155165189399296558275588676840"}]}],
      ",", 
     RowBox[{"-", 
      RowBox[{
      "22679868032754165493059773969501869569689558884137996436956335547878475\
25804145425023256393504050819467968089740830545881437513143657012035387", "/",
        "261215884069383260551763171198302308248878102312158196116617053603669\
386378569936112690364415626673109957360473038791297349824139568897169210"}]}],
      ",", 
     RowBox[{
     "234923709157759910744889003885031799250944032797401303078236374306223424\
0771261135557972580541940490552909838224973308091909161454458540311", "/", 
      "10771789033789000435124254482404218896860952672666317365633692932110077\
78880700767475011812023202775711164373084696046587009584080696483172"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "23046479731101259233156018242555244819416372002900646459220370173696656\
12775936181445530135446339810924474774486644013845371072208029", "/", 
       "1134054396385462493392940908197669267999026230434566781907992606194275\
23864558781345093796044365933390598415765380484605821742474248"}]}], ",", 
     RowBox[{
     "571704676727701221643326643687487790937102638701508979953231136101148691\
221172100546774371935893625021941443393601", "/", 
      "13071509381204039236176065441636217730783132082428413523254048943974491\
3713211045037642962586268598675593720467236"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "32001825782032467465933741201846021707919938670998410719185831039153547\
0367009", "/", 
       "4207012309514476074682859820532217026811789981828360270219424989065397\
3940488"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "26644562233722920393630937449113890927770985152044278670278790987875902\
20206125628179796721120068013205561904599564097228478670580532701243719", "/",
        "348287845425844347402350894931069744331837469749544261488822738138225\
848504759914816920485887502230813276480630718388396466432186091862892280"}]}],
      ",", 
     RowBox[{"-", 
      RowBox[{
      "37975464551904460373733827059733385208595290498196015679849326289155870\
2503294027822670911467801676473196118791225896250528958363480008622969", "/", 
       "1044863536277533042207052684793209232995512409248632784466468214414677\
545514279744450761457662506692439829441892155165189399296558275588676840"}]}],
      ",", 
     RowBox[{"-", 
      RowBox[{
      "22283732129769799111200213060150358874814653559096702224765452689044116\
50591487084547346138141052357888521137171533878981459219950554316959", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{
     "404694977877015680162180063613519222852179477548860552069568052316656851\
620334935350856895926112842168555650040582539142826750710955", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "52751832471673182469854014604929150786404633976135425311783777259971293\
72864227867396954502957079259941420621768", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{
     "115382478004835736072012974868394987943164108192913609105508816807389905\
983953", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "424198354231466942903322754016881165698878468794146086761800339574867010\
30246075048492338509165309745282060519433546495277706354120504991", "/", 
      "31189956306792031110658289098304753223746639082048739834819946698945598\
373560589386589894258582289326562072892303139259385053628605241453040"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11896171597528203524980095982512729430532350520652345569400816324182310\
043905217913443354224754920054564173526333120650798099596553150136577", "/", 
       "2599163025566002592554857424858729435312219923504061652901662224912133\
197796715782215824521548524110546839407691928271615421135717103454420"}]}], 
     ",", 
     RowBox[{
     "133367026624092329647864457424084908874615206599613294291724256488704838\
64111697267348674647363810817067173379701399121076004685469347651", "/", 
      "10718198043571144711566422370551461588916370818573450115058400927472714\
217718415596766286686798037569265317145121353697383179941101457544"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "41666024622550659915038098067648864147211708403583757165468626095954575\
701516888253081077280091007124213883920520150314735529270307", "/", 
       "3385237004135708935501316143873639605967242478909154572859679421475448\
473568918846122202866995998011659654201951656256890201267888"}]}], ",", 
     RowBox[{
     "917884868980261443421959741268291164201889131285919388005339690495140211\
943172405672566192578506504910771779369429", "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
4283027612594107406465671496688984301168090"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "31998971285884759334694884824515504857927995039680230390505361217362706\
5768715", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{
     "296245295815004340741269935351926591084869092119453023920683657563769836\
1211153312336835171421773115078420209035303667955857914413536120788187", "/", 
      "52243176813876652110352634239660461649775620462431639223323410720733877\
2757139872225380728831253346219914720946077582594699648279137794338420"}], 
     ",", 
     RowBox[{
     "613579461902416139438620668272448783115931017210536279387660534521112753\
800250687208966237357666647079042365590946456653333740483359640650637", "/", 
      "87071961356461086850587723732767436082959367437386065372205684534556462\
126189978704230121471875557703319120157679597099116608046522965723070"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "46356191864490707780807132731155600872631993605370296100794778801363533\
8236620351194873565464316851880123372917278117969753145025954578391", "/", 
       "3590596344596333478374751494134739632286984224222105788544564310703359\
26293566922491670604007734258570388124361565348862336528026898827724"}]}], 
     ",", 
     RowBox[{
     "697605181397772693336237779455329138022523078901217535894441121584630188\
571954653635593379775261871937322181970208877029330061772763", "/", 
      "56702719819273124669647045409883463399951311521728339095399630309713761\
932279390672546898022182966695299207882690242302910871237124"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "14795438514387030257726413032737088531913874568950275224536454503278611\
26117079498613492670925969441630943541142143", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
68566055225188214812931342993377968602336180"}]}], ",", 
     RowBox[{
     "201603439989010868223980386145950712832782383904993755025393646493809771\
16096", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "40383869034593402286065089636316371441157528108874542502166685178352104\
2247506229530599753285173101802760935545353560805111486640269377163959", "/", 
       "2321918969505628982682339299540464962212249798330295076592151587588172\
3233650660987794699059166815387551765375381225893097762145739457526152"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "27134127697844580919702200777261171514039613787073642859068796909427429\
19494862206633570061539922239584214596157871325192174535610596736661517", "/",
        "116095948475281449134116964977023248110612489916514753829607579379408\
616168253304938973495295834076937758826876906129465488810728697287630760"}]}],
      ",", 
     RowBox[{
     "247330701299744316257167386868035005728254347983934455436824333997857150\
8229511586180017527538989890637849221132594850003603416005402696581", "/", 
      "47874617927951113044996686588463195097159789656294743847260857476044790\
1724755896655560805343645678093850832482087131816448704035865103632"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10185524811761375346698772357174450987848866373026912565306948878109581\
71038606277886977413651671428161517931953952594347801777946957", "/", 
       "2520120880856583318650979795994820595553391623187926182017761347098389\
4192124173632243065787636874086799647947862329912404831660944"}]}], ",", 
     RowBox[{
     "128399105391723031871059197689553338582306824790905252557017457916840243\
9011385818840029322042581473968617951716331", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11660054990935778810224382040501598102150624221557631348388382686209012\
71618271", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "26361818462727227908901432018244125329314184555172791225291525877605259\
449135458906682345156218502802056976327676510213395856303983485599739943", 
       "/", "20897270725550660844141053695864184659910248184972655689329364288\
29355091028559488901522915325013384879658883784310330378798593116551177353680"\
}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "16107044960104848564061472089143872988271455204593882811296914151467685\
048314997261164191641470205105657646511452483035617474320318475575039431", 
       "/", "10448635362775330422070526847932092329955124092486327844664682144\
14677545514279744450761457662506692439829441892155165189399296558275588676840"\
}]}], ",", 
     RowBox[{
     "130982817231817517145939543546711311706571123896025120508033223087664812\
75528529751484029520721363556289625428132137544369539313791627270275", "/", 
      "43087156135156001740497017929616875587443810690665269462534771728440311\
15522803069900047248092811102844657492338784186348038336322785932688"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "15726152142037152722894637449439679860238632955666685658835875408132803\
35736874620335506914458277316866812752226689768304061121822647", "/", 
       "5670271981927312466964704540988346339995131152172833909539963030971376\
1932279390672546898022182966695299207882690242302910871237124"}]}], ",", 
     RowBox[{
     "941538931746835654980148848275017325809236406933702134379978809438175873\
896273987341825493124747819234035985655021", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "19083248965441720448200481182500670009822836475043628005047985541794728\
6587123", "/", 
       "2103506154757238037341429910266108513405894990914180135109712494532698\
6970244"}]}], ",", 
     RowBox[{
     "906597332460900260986088999283075361237724858196315724097635603046691966\
0809868241558139832024566462057487398332638209819576053141461710167", "/", 
      "13464736292236250543905318103005273621076190840832896707042116165137597\
23600875959343764765029003469638955466355870058233761980100870603965"}], ",", 
     
     RowBox[{
     "792834689388787676911283273404060049228263895751630470316875187456694490\
08995431477858039796683552871326164108169094775285828342821642820943", "/", 
      "10771789033789000435124254482404218896860952672666317365633692932110077\
788807007674750118120232027757111643730846960465870095840806964831720"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "73672463431125565979665813871151779027868583937016673859079662454824955\
75961856877588306330865946815952661819589645531148099515214667417919", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{
     "107429415800259707600923349941047417907230716533307712097645663818114405\
1468031313827304010252299497690178147731752093999536393962855", "/", 
      "75603626425697499559529393879844617866601748695637785460532840412951682\
576372520896729197362910622260398943843586989737214494982832"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10785371032857510247043914113217539814429609400244372663379254872884360\
26030241264682315898856299492982415124348513", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
84283027612594107406465671496688984301168090"}]}], ",", 
     RowBox[{
     "434567428529199220029933012736084238440576117394782709078189250926097403\
016951", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "594430565320905461764068846342867956909944732192023783664813931292757744\
868249", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "526337887119368665378375098808830996993767356934199478675293912594441884\
72358", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "49316853515748626218182064587057343087616571464962309222111919258177508\
841449", "/", 
       "2103506154757238037341429910266108513405894990914180135109712494532698\
6970244"}]}], ",", 
     RowBox[{
     "144225977003090687260772943504482195701501583194997585609281238869748736\
1180125", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "33978249178693489575755681943903631020375076967425820574923119992942986\
732405", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "511900921428258491448076552394756151623711255431980554694551581739844819\
477879", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "286802125891616345419659359098725171576212920397778148369258276202632173\
94535", "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}], ",", 
     RowBox[{
     "166633274401644547895431282438145176065257335963052240712864194870586163\
11369", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "45590486421233224047645687183452367785437132171647321181049855256527974\
31685", "/", 
       "2103506154757238037341429910266108513405894990914180135109712494532698\
6970244"}]}], ",", 
     RowBox[{
     "953174785959229660425788646468873870405125701681696484006481984244709577\
99097", "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "62431291979872286794654645860228621855660163699776812525183191765417366\
89809", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "288107224990997173701859897769769196068219556582753655037421835429282590\
38079", "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
     "255519748170253162773853354227203828679007352461474508913447963001266678\
377615220677599966767460975084808155052221926368652417507289957658734", "/", 
      "14511993559410181141764620622127906013826561239564344228700947422426077\
021031663117371686911979259617219853359613266183186101341087160953845"}], ",", 
     RowBox[{
     "111605640131387850176824032418579941136353182279205789688213556903813623\
9211948034831808844179641327308587382308795167125153616279205076036092", "/", 
      "43535980678230543425293861866383718041479683718693032686102842267278231\
063094989352115060735937778851659560078839798549558304023261482861535"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11369061394690427069659685569831153208655641775224648533784963660285598\
00199712686529915305862876484944776088074612248305780222653969627991", "/", 
       "1795298172298166739187375747067369816143492112111052894272282155351679\
63146783461245835302003867129285194062180782674431168264013449413862"}]}], 
     ",", 
     RowBox[{
     "438767917744620903062537553198715886137134938419322224254402115723691560\
494223791746016873656197395953864084176009936236270025862951", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13909638427910533103412182185981754138399537535520213293327077361632396\
31102373713878860952774375911754890657803874", "/", 
       "1633938672650504904522008180204527216347891510303551690406756117996811\
42141513806297053703232835748344492150584045"}]}], ",", 
     RowBox[{
     "158163838633593660409888627248802372736777049695537170726477713505085747\
321329", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13845157989779270371261833842158104408876183188699783691169932364472947\
0396995342770889639925612657205548180155803224605120337192086690646529", "/", 
       "1411977751726396002982503628098931395939881634119774033062794884344158\
8452895672222307587265709549897835532998542637367424314818355075522660"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "71776543974867551608578522970033057070832009607804308667578700904209979\
369210916048904940835021394128787414485939416764083977319482628913111", "/", 
       "7059888758631980014912518140494656979699408170598870165313974421720794\
226447836111153793632854774948917766499271318683712157409177537761330"}]}], 
     ",", 
     RowBox[{
     "808114320838820355726356526080115410876878697700136928984714495998701761\
84832822869183104876273361131033548493688771511312044031644379785", "/", 
      "29112943334564866040876363465957348369894466682881938826037007924621831\
861640561283108427351978453397599037110397190448297556326505310356"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "26040759628346943733044590025590791169704063964636294778706455197842903\
82664989608895136163799593869105683782130000950856467839323", "/", 
       "1277088284217863168235293815537915842341245754993881511157649331299859\
50297926555568799319869781456520944161897950996177727187471"}]}], ",", 
     RowBox[{
     "661315607871830520590162509919792959293869044803027447816187999510314754\
74312360975607273707585094285771970168663", "/", 
      "13248151399868958685313579839496166619036958191650419111406130686460633\
146609227537598948910770466081985850047355"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10651899421646792712256679930501490436800141852258920239156102055015957\
0557507", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "152495300038981367369476792794120097154763109286778548929046894729980610\
556033667152049477917213599842225866281048142549527674862823094620343", "/", 
      "26121588406938326055176317119830230824887810231215819611661705360366938\
637856993611269036441562667310995736047303879129734982413956889716921"}], ",", 
     RowBox[{
     "826113002769718514542335973176080607849037299811280836344625863305923241\
566815126717538419051504142945773020835863068873589557481275170909926", "/", 
      "13060794203469163027588158559915115412443905115607909805830852680183469\
3189284968056345182207813336554978680236519395648674912069784448584605"}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "67686873093168815358909028728012599490054758799192390454124856599515639\
2727210749128621062990467140113938521011273918621968442818972134450", "/", 
       "2692947258447250108781063620601054724215238168166579341408423233027519\
44720175191868752953005800693927791093271174011646752396020174120793"}]}], 
     ",", 
     RowBox[{
     "670234846426733040332110225888618268070941666869587470902012956787231594\
60577609196877582324445174473012114255253648231020106734978", "/", 
      "47252266516060937224705871174902886166626092934773615912833025258094801\
61023282556045574835181913891274933990224186858575905936427"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "19219909189280270942798829931666706726259484773135216905187591805988391\
73762305859049062402839219149829300546643358", "/", 
       "4901816017951514713566024540613581649043674530910655071220268353990434\
26424541418891161109698507245033476451752135"}]}], ",", 
     RowBox[{
     "725927816462560414237007225976203149278512081582897442591843213635376882\
43255", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "63970352696289911561884292141579710216360891621537181389009490911035896\
0498734203601063804856956676344547988723070001787750411163665137510423", "/", 
       "2612158840693832605517631711983023082488781023121581961166170536036693\
86378569936112690364415626673109957360473038791297349824139568897169210"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "68169869984812838998396831533805265412374672256399779211461350580167952\
6757788723552794121861812549088876814353655081541808024303789724275041", "/", 
       "1306079420346916302758815855991511541244390511560790980583085268018346\
93189284968056345182207813336554978680236519395648674912069784448584605"}]}], 
     ",", 
     RowBox[{
     "531577022359958867025263579815111829225010079140170234015263057830935067\
612405001253838330386714127928848631183667634206083501763317656445", "/", 
      "26929472584472501087810636206010547242152381681665793414084232330275194\
4720175191868752953005800693927791093271174011646752396020174120793"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10104684882407097245180006245983164269715428575318552332831532837965702\
2206399230104431932402572888839835290416544120007030639914283", "/", 
       "9450453303212187444941174234980577233325218586954723182566605051618960\
322046565112091149670363827782549867980448373717151811872854"}]}], ",", 
     RowBox[{
     "664691635239659344300175499091708578777635644090862546782250426612722412\
199610936090930061800574312363078749789409", "/", 
      "49018160179515147135660245406135816490436745309106550712202683539904342\
6424541418891161109698507245033476451752135"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10429921895623848705895496980357111117598646719296216252538736782996040\
7015037", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "115198643834722346802444254286595105675185184217860987079493656150412339\
74175404002316161588772686181826874137604662006395778951538025946041353", "/",
       "1044863536277533042207052684793209232995512409248632784466468214414677\
545514279744450761457662506692439829441892155165189399296558275588676840"}], 
     ",", 
     RowBox[{
     "468829686893561524423796309182329211244542326639118278015848154668257561\
6160967915968824621523556524397380934059187774671569298025443802011801", "/", 
      "52243176813876652110352634239660461649775620462431639223323410720733877\
2757139872225380728831253346219914720946077582594699648279137794338420"}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "18160122893765932235562359086546528879814129929696337178047238965699613\
85710601159967988502747645452748287789818742882630852331076152717921", "/", 
       "2154357806757800087024850896480843779372190534533263473126738586422015\
557761401534950023624046405551422328746169392093174019168161392966344"}]}], 
     ",", 
     RowBox[{
     "561754099923951251570362712807815035893061705228499256139533994347762413\
26351129407947826424468996938087051997572098001640538258017", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "41038606545722111679229976712607111301835910720550501547210639180100767\
25473539982807647892788990262460525564828027", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
52849082837782322219397014490066952903504270"}]}], ",", 
     RowBox[{
     "929173457388279056474575247179322560550528728912027240715683262597449632\
86509", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{
     "329769918468839033980451772065864489567292426391210697071449695739359523\
76444931198334888556298309633472686658917064319966440384574420225184", "/", 
      "87071961356461086850587723732767436082959367437386065372205684534556462\
12618997870423012147187555770331912015767959709911660804652296572307"}], ",", 
     
     RowBox[{
     "230780999620039402990826830035820722132874954825289234915467083293929899\
600519880982013736880564080053782933754540757864675070490197166796844", "/", 
      "43535980678230543425293861866383718041479683718693032686102842267278231\
063094989352115060735937778851659560078839798549558304023261482861535"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "40915630040518985448836717182022035025438283114324028757622882195367095\
3839146205937426518533314351106396118808512935707077233691314976041", "/", 
       "1795298172298166739187375747067369816143492112111052894272282155351679\
63146783461245835302003867129285194062180782674431168264013449413862"}]}], 
     ",", 
     RowBox[{
     "198153414321277047732092216528405025132286371620032782290787895844239398\
55426188599689854662826252006796758085609233926453624916133", "/", 
      "15750755505353645741568623724967628722208697644924538637611008419364933\
87007760852015191611727304630424977996741395619525301978809"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "27546944525084543084743354705619151975744681190016216054180313519353155\
74610180145910323057163967420382259593720477", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
52849082837782322219397014490066952903504270"}]}], ",", 
     RowBox[{
     "105471726694458085324004527581202010386043473666858373767970477765474345\
944141", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22679868032754165493059773969501869569689558884137996436956335547878475\
25804145425023256393504050819467968089740830545881437513143657012035387", "/",
        "261215884069383260551763171198302308248878102312158196116617053603669\
386378569936112690364415626673109957360473038791297349824139568897169210"}]}],
      ",", 
     RowBox[{"-", 
      RowBox[{
      "18291709906819230371096139358406713282442744381973662995428481426596721\
55397619883103338839536216399431602850464414222049776538717956921939357", "/",
        "130607942034691630275881585599151154124439051156079098058308526801834\
693189284968056345182207813336554978680236519395648674912069784448584605"}]}],
      ",", 
     RowBox[{
     "237948381089509235928346187189778966229149586625476601209118663402157561\
0358476036582382383993817828760791637288219630356496217049042283819", "/", 
      "53858945168945002175621272412021094484304763363331586828168464660550388\
9440350383737505906011601387855582186542348023293504792040348241586"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25249468472539125324127601441030506197189292880483108086416962983302791\
1683789506578685032683982057355903500001672996700755492788647", "/", 
       "9450453303212187444941174234980577233325218586954723182566605051618960\
322046565112091149670363827782549867980448373717151811872854"}]}], ",", 
     RowBox[{
     "301247984272063148416332655668167855720197804481220746822751881552031016\
100372937805668228311406063195037897550997", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "44764448017676896803632183728143688492507396610196775919775447986244223\
521792", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "37975464551904460373733827059733385208595290498196015679849326289155870\
2503294027822670911467801676473196118791225896250528958363480008622969", "/", 
       "1044863536277533042207052684793209232995512409248632784466468214414677\
545514279744450761457662506692439829441892155165189399296558275588676840"}]}],
      ",", 
     RowBox[{
     "234927778075663861460692096978481530383150709905393102460445102610401201\
325450768284591219087245453690525913466596530589576731588648366841491", "/", 
      "52243176813876652110352634239660461649775620462431639223323410720733877\
2757139872225380728831253346219914720946077582594699648279137794338420"}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "10572433639942736877083732315891614409625008492896410882657323837422117\
76785641672758944193736547368359942264007979697856520279069009946747", "/", 
       "2154357806757800087024850896480843779372190534533263473126738586422015\
557761401534950023624046405551422328746169392093174019168161392966344"}]}], 
     ",", 
     RowBox[{
     "299473466083220643418044441337049237446307971297833212361935595977558027\
91828175393192992438532271343527624353777456324612246258121", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12784685296380364068772035555309446208261061536652613520738364161498838\
546295933470819791547032691841424084461809", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "227823909084107375810108571006011984889942815283797499927981971543405736\
64559", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11896171597528203524980095982512729430532350520652345569400816324182310\
043905217913443354224754920054564173526333120650798099596553150136577", "/", 
       "2599163025566002592554857424858729435312219923504061652901662224912133\
197796715782215824521548524110546839407691928271615421135717103454420"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "12282964101241151087634441360637311807635178761161987606997094572087181\
507938461385178391371418017526417474511233762935103261136826988564849", "/", 
       "1299581512783001296277428712429364717656109961752030826450831112456066\
598898357891107912260774262055273419703845964135807710567858551727210"}]}], 
     ",", 
     RowBox[{
     "156492583557099004562801132097903880197298887896923564990054435151289517\
81005251797532170320974770604957729080695654892750828738658836655", "/", 
      "53590990217855723557832111852757307944581854092867250575292004637363571\
08859207798383143343399018784632658572560676848691589970550728772"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22633919425106305098044647204686079113011438129390058177348021185248465\
75211798804692679232342755946002469165268120818974950004921", "/", 
       "1410515418389878723125548393280683169153017699545481072024866425614770\
19732038285255091786124833250485818925081319010703758386162"}]}], ",", 
     RowBox[{
     "491505837607312545873029010885860347050984934458222550142793931130598965\
313043162477322012423770882473097309448676", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "56979412642688316042876679777275063446273849582001390697334996653936845\
349845", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "613579461902416139438620668272448783115931017210536279387660534521112753\
800250687208966237357666647079042365590946456653333740483359640650637", "/", 
      "87071961356461086850587723732767436082959367437386065372205684534556462\
126189978704230121471875557703319120157679597099116608046522965723070"}], ",", 
     RowBox[{
     "293171524665685710861350145402794865301356488051050423033484814799888422\
134098799575287989771530069329037511606272702527959503614218231659784", "/", 
      "43535980678230543425293861866383718041479683718693032686102842267278231\
063094989352115060735937778851659560078839798549558304023261482861535"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "33989752192461698473686376235102129955646095773382832526198320542451137\
0981660210254341917720380578223122201859828331961642565261768801479", "/", 
       "1795298172298166739187375747067369816143492112111052894272282155351679\
63146783461245835302003867129285194062180782674431168264013449413862"}]}], 
     ",", 
     RowBox[{
     "133629448608361782263730774001690479982530248030981160751769171133298542\
270878396813504539640946900357165789596818778133173672233289", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "37245411693805851069281185778667929123491963766958355288289721143573547\
75598779347087743581415006419113244106971541", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
52849082837782322219397014490066952903504270"}]}], ",", 
     RowBox[{
     "750902046250496304778155068149238020190185920580139157463345182973370936\
47804", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "27134127697844580919702200777261171514039613787073642859068796909427429\
19494862206633570061539922239584214596157871325192174535610596736661517", "/",
        "116095948475281449134116964977023248110612489916514753829607579379408\
616168253304938973495295834076937758826876906129465488810728697287630760"}]}],
      ",", 
     RowBox[{"-", 
      RowBox[{
      "29737207546951272577447728621157020137947546569303419103929715893892224\
0908897576858374802254489537909524020033937009993029912491304992001289", "/", 
       "1160959484752814491341169649770232481106124899165147538296075793794086\
1616825330493897349529583407693775882687690612946548881072869728763076"}]}], 
     ",", 
     RowBox[{
     "115739941159799419407016644749467978246386152757828435982712776237971328\
5192749112443187753390811497018334847778073968420992421015510042177", "/", 
      "23937308963975556522498343294231597548579894828147371923630428738022395\
0862377948327780402671822839046925416241043565908224352017932551816"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "15098086957376085775251027399193726562944078476345177752994783736603083\
3848300961632591459172629956491941565590702810228349237898961", "/", 
       "3150151101070729148313724744993525744441739528984907727522201683872986\
774015521704030383223454609260849955993482791239050603957618"}]}], ",", 
     RowBox[{
     "163338676278972735260316609571075326710760031915729127315562287175834150\
1251936248427417994029212494480482753627203", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "16668949098372637316236934414013771350524529942476515591831512389433886\
9207135", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "16107044960104848564061472089143872988271455204593882811296914151467685\
048314997261164191641470205105657646511452483035617474320318475575039431", 
       "/", "10448635362775330422070526847932092329955124092486327844664682144\
14677545514279744450761457662506692439829441892155165189399296558275588676840"\
}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10164116068765562737380111665629970489641176964841160966184172919248723\
998690437071210549811072128879185708849029135437158826564309475448727143", 
       "/", "52243176813876652110352634239660461649775620462431639223323410720\
7338772757139872225380728831253346219914720946077582594699648279137794338420"}\
]}], ",", 
     RowBox[{
     "861333994881303353190834872040680521707494100344026327817260238212430216\
6800933109210256790230233386457940304620869773829137282125453374111", "/", 
      "21543578067578000870248508964808437793721905345332634731267385864220155\
57761401534950023624046405551422328746169392093174019168161392966344"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "51576032276782068054131351195698373030456635324472911394182904423039274\
589325071321257106320890738851438835833239434662885926546911", "/", 
       "1575075550535364574156862372496762872220869764492453863761100841936493\
387007760852015191611727304630424977996741395619525301978809"}]}], ",", 
     RowBox[{
     "318071961615185895309312594578004761656853674538560567356294373098796404\
4409186714047113853227913704549569408723099", "/", 
      "49018160179515147135660245406135816490436745309106550712202683539904342\
6424541418891161109698507245033476451752135"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "17885659070358154038288916426178687728072220489066978031407728146880231\
8671821", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "792834689388787676911283273404060049228263895751630470316875187456694490\
08995431477858039796683552871326164108169094775285828342821642820943", "/", 
      "10771789033789000435124254482404218896860952672666317365633692932110077\
788807007674750118120232027757111643730846960465870095840806964831720"}], ",", 
     RowBox[{
     "576348946777964848046010732346685243111971236777984526084095883043149523\
11365910988635284867050980828093650362886667350832665149749532091007", "/", 
      "53858945168945002175621272412021094484304763363331586828168464660550388\
94403503837375059060116013878555821865423480232935047920403482415860"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "54109681784346033774293107685561309441689265037082368477016829446925742\
65655643878534818708646130010808986508786794014794081105663837971291", "/", 
       "2154357806757800087024850896480843779372190534533263473126738586422015\
557761401534950023624046405551422328746169392093174019168161392966344"}]}], 
     ",", 
     RowBox[{
     "564514391089203828202732965564175215761293588569806135088850663448016769\
51485953771311274218407976030217193241131093321488965967097", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "55392593093606086092115464292854713929224628750268368136372845793274874\
3824444041846937303129572307992115622649362", "/", 
       "1633938672650504904522008180204527216347891510303551690406756117996811\
42141513806297053703232835748344492150584045"}]}], ",", 
     RowBox[{
     "603783329437877955957826298827408171131657498836060407443579115417721660\
24929", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{
     "526337887119368665378375098808830996993767356934199478675293912594441884\
72358", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{
     "575891940722125520217001063056554117949860068269667592674233451882289704\
76982", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "24875718793096222777466133258095046403003600185507607339053257154326070\
829387", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "222721885063301848750675519467390061009158475761779826873288855229397834\
389825", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25652498443561621346722306464385870100111304720277302475678743226170529\
697476", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "680337215202935227100053272908329209963194234973830699178315365555606126\
98849", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{
     "166633274401644547895431282438145176065257335963052240712864194870586163\
11369", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{
     "251875090959963432408913012237388458328191877305190823517375812077596679\
47643", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "74974560338560588987852301670854773122219044640533618909639982998842758\
61085", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "562751412199638741317279687480500385405643980829299506925051100911065983\
91540", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "73058989896798749457993968625679807223251355692105635449401328645516282\
48221", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "220069780906243196773791333577987768800287220267435859858810455816438541\
26911", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"-", 
      RowBox[{
      "52803444546168197402516357124638172810081412615315797283139284428003651\
0469223837816130447431646632524678596494835573439654727887926775033", "/", 
       "1196865448198777826124917164711579877428994741407368596181521436901119\
75431188974163890201335911419523462708120521782954112176008966275908"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "11369061394690427069659685569831153208655641775224648533784963660285598\
00199712686529915305862876484944776088074612248305780222653969627991", "/", 
       "1795298172298166739187375747067369816143492112111052894272282155351679\
63146783461245835302003867129285194062180782674431168264013449413862"}]}], 
     ",", 
     RowBox[{
     "469827385604374157801562442979502292622818817699174958317251712596854756\
479987026635651618442330880971642273847150099273167619678423130857", "/", 
      "35905963445963334783747514941347396322869842242221057885445643107033592\
6293566922491670604007734258570388124361565348862336528026898827724"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "51658409257766915057477779204508515552813270103155515638790304403884102\
231951574295959338625386319292440853579943947162335255251550", "/", 
       "4725226651606093722470587117490288616662609293477361591283302525809480\
161023282556045574835181913891274933990224186858575905936427"}]}], ",", 
     RowBox[{
     "124881248847131114108708756606758261739706077046820331080862360310957349\
823697173551434211572382527238589451703713", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "37218922930724221504899854540351977220756651481278501793832282098033298\
019527", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "102809455989821017940916556085311919415571523581445189732511501159463792\
327414798635218239427352366714487185325755447461572058601837416233", "/", 
      "58225886669129732081752726931914696739788933365763877652074015849243663\
723281122566216854703956906795198074220794380896595112653010620712"}], ",", 
     RowBox[{
     "808114320838820355726356526080115410876878697700136928984714495998701761\
84832822869183104876273361131033548493688771511312044031644379785", "/", 
      "29112943334564866040876363465957348369894466682881938826037007924621831\
861640561283108427351978453397599037110397190448297556326505310356"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "27368895572102234133185951976008269291583964461492236198372578519888697\
280901122250257253598064762438511744905195057381623275436352303453", "/", 
       "5822588666912973208175272693191469673978893336576387765207401584924366\
3723281122566216854703956906795198074220794380896595112653010620712"}]}], ",", 
     RowBox[{
     "589324187102251019405339422567538784812450855650523766206855848207215001\
872140170423261022173411645889760842221667601980380164274", "/", 
      "12770882842178631682352938155379158423412457549938815111576493312998595\
0297926555568799319869781456520944161897950996177727187471"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "29419087005876625219282370609305218795374693972994310973151052016866737\
28508157397521735827248048342516934672798", "/", 
       "2649630279973791737062715967899233323807391638330083822281226137292126\
629321845507519789782154093216397170009471"}]}], ",", 
     RowBox[{
     "221496008966425249698528641419349902230579063754106575776273788534131861\
56830", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "36927440126082730290082854542515599779982543865885035335170681963267980\
3579948963384014688194242242461555564733226662303272533180528300031", "/", 
       "2692947258447250108781063620601054724215238168166579341408423233027519\
44720175191868752953005800693927791093271174011646752396020174120793"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "67686873093168815358909028728012599490054758799192390454124856599515639\
2727210749128621062990467140113938521011273918621968442818972134450", "/", 
       "2692947258447250108781063620601054724215238168166579341408423233027519\
44720175191868752953005800693927791093271174011646752396020174120793"}]}], 
     ",", 
     RowBox[{
     "499181432317101494701492888530402572279102880566649351922959081230994773\
950864700145009198744614374646320133911640785117503666797267192537", "/", 
      "53858945168945002175621272412021094484304763363331586828168464660550388\
9440350383737505906011601387855582186542348023293504792040348241586"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "14532524008657467243708501825947742053605806438531259857385341419306754\
778405835628114586318826301642598591195830923052871992929975", "/", 
       "4725226651606093722470587117490288616662609293477361591283302525809480\
161023282556045574835181913891274933990224186858575905936427"}]}], ",", 
     RowBox[{
     "200212773643314724090593333974144571091464024994348174045762480203426218\
386692291340314917687520974604322983540409", "/", 
      "19607264071806058854264098162454326596174698123642620284881073415961737\
0569816567556464443879402898013390580700854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "35184159144287479998208956135487829036358691915499629662967567455240426\
797533", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "218304569332986867607607361923441078616907563505228619504825712788381950\
695353999267050421757592663707323499621463210547146073712146340713", "/", 
      "53858945168945002175621272412021094484304763363331586828168464660550388\
9440350383737505906011601387855582186542348023293504792040348241586"}], ",", 
     RowBox[{
     "531577022359958867025263579815111829225010079140170234015263057830935067\
612405001253838330386714127928848631183667634206083501763317656445", "/", 
      "26929472584472501087810636206010547242152381681665793414084232330275194\
4720175191868752953005800693927791093271174011646752396020174120793"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10531287229894956532071109561193095508581458511998916368729606105026626\
0808881269942208984543465697247810528166869778644982031123424630887", "/", 
       "2692947258447250108781063620601054724215238168166579341408423233027519\
44720175191868752953005800693927791093271174011646752396020174120793"}]}], 
     ",", 
     RowBox[{
     "224105352313000977844179211851649539773452455163295831263766276925046231\
61947554056157377085759405164715530122072356750419479151699", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "35416336514878723708466659987931118921455991644139559197269998251048342\
145917332305575673836164320459323168729800", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "289950152662132653043123649889612210357242453447318209662854620602624335\
32435", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10630441588616907748666347304371252855424696161691311064503591900114616\
849965497816426895834383651080148588161561398207461644260051274517309", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "18160122893765932235562359086546528879814129929696337178047238965699613\
85710601159967988502747645452748287789818742882630852331076152717921", "/", 
       "2154357806757800087024850896480843779372190534533263473126738586422015\
557761401534950023624046405551422328746169392093174019168161392966344"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "53730050084356489126910888724762689618332961911251808852154517596856895\
7342127489946325598960330233805158253468358841738921447637714142247", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "25497555171478981315323937632900241375278840579089356864680494622679745\
832271750128373997063510907339740823341348919610385770208545", "/", 
       "6300302202141458296627449489987051488883479057969815455044403367745973\
548031043408060766446909218521699911986965582478101207915236"}]}], ",", 
     RowBox[{
     "422187029028887118789909288994733676990940392843902259233717427281665053\
625465596504903497660118684233057798734481", "/", 
      "39214528143612117708528196324908653192349396247285240569762146831923474\
1139633135112928887758805796026781161401708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "18688128076607299686657924711794908401471779530295603092794504390594734\
112953", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "38456607705784302341873134780798964424947224164293286122466276515989095\
1048864999570973742063597934355092100937589869475441216260342495241", "/", 
       "3590596344596333478374751494134739632286984224222105788544564310703359\
26293566922491670604007734258570388124361565348862336528026898827724"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "40915630040518985448836717182022035025438283114324028757622882195367095\
3839146205937426518533314351106396118808512935707077233691314976041", "/", 
       "1795298172298166739187375747067369816143492112111052894272282155351679\
63146783461245835302003867129285194062180782674431168264013449413862"}]}], 
     ",", 
     RowBox[{
     "191630899315213257310058327793680765980969882476321964932429547833656438\
797793185029126082436796897188534183731767636412832579103640946719", "/", 
      "35905963445963334783747514941347396322869842242221057885445643107033592\
6293566922491670604007734258570388124361565348862336528026898827724"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "20225029588084714933849577870339813598946097150489778280103225669448858\
577928802108642588486478706470346335727188090836406915706309", "/", 
       "6300302202141458296627449489987051488883479057969815455044403367745973\
548031043408060766446909218521699911986965582478101207915236"}]}], ",", 
     RowBox[{
     "221409997505350460220426421806529363598260657151504927105414274596292046\
288735029811629875345355717270055401292387", "/", 
      "39214528143612117708528196324908653192349396247285240569762146831923474\
1139633135112928887758805796026781161401708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13536539507675291695948549100187137875479264102253069500962666662119893\
521390", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "234923709157759910744889003885031799250944032797401303078236374306223424\
0771261135557972580541940490552909838224973308091909161454458540311", "/", 
      "10771789033789000435124254482404218896860952672666317365633692932110077\
78880700767475011812023202775711164373084696046587009584080696483172"}], ",", 
     
     RowBox[{
     "237948381089509235928346187189778966229149586625476601209118663402157561\
0358476036582382383993817828760791637288219630356496217049042283819", "/", 
      "53858945168945002175621272412021094484304763363331586828168464660550388\
9440350383737505906011601387855582186542348023293504792040348241586"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13239164761970464139803552546570419892665147227333970547994848799566855\
65366011820806020905689825788662406287638156560580260618257266776817", "/", 
       "1077178903378900043512425448240421889686095267266631736563369293211007\
778880700767475011812023202775711164373084696046587009584080696483172"}]}], 
     ",", 
     RowBox[{
     "117035455939123224743257642274621399350482746101664591322850906709270076\
820279676313722363544668248228341758820725750768350741482911", "/", 
      "18900906606424374889882348469961154466650437173909446365133210103237920\
644093130224182299340727655565099735960896747434303623745708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11431277507732398252888160899630545576803959482113279562496832311057085\
9045494524909361147621683169409653064151025", "/", 
       "1307150938120403923617606544163621773078313208242841352325404894397449\
13713211045037642962586268598675593720467236"}]}], ",", 
     RowBox[{
     "112419275101184917699750912478546730734905332233308596714045967196532073\
38492", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22283732129769799111200213060150358874814653559096702224765452689044116\
50591487084547346138141052357888521137171533878981459219950554316959", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "10572433639942736877083732315891614409625008492896410882657323837422117\
76785641672758944193736547368359942264007979697856520279069009946747", "/", 
       "2154357806757800087024850896480843779372190534533263473126738586422015\
557761401534950023624046405551422328746169392093174019168161392966344"}]}], 
     ",", 
     RowBox[{
     "100783668442667836246714722970564458541760197311769082464254697399275298\
7062320819015635177609344677486248955040842570381608129950098578723", "/", 
      "43087156135156001740497017929616875587443810690665269462534771728440311\
15522803069900047248092811102844657492338784186348038336322785932688"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "48504305430912599465103693790041893362297954631526805430909493848077893\
41343337057303539180580984058671587103373631966682387794221", "/", 
       "4725226651606093722470587117490288616662609293477361591283302525809480\
161023282556045574835181913891274933990224186858575905936427"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "24589914305686673968389694429621201492352430378823615212577001852213517\
48867479536826805563074681053687163571413", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "97720015959799504292733114447150351208496209663146974133755243120978606\
30893", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "133367026624092329647864457424084908874615206599613294291724256488704838\
64111697267348674647363810817067173379701399121076004685469347651", "/", 
      "10718198043571144711566422370551461588916370818573450115058400927472714\
217718415596766286686798037569265317145121353697383179941101457544"}], ",", 
     RowBox[{
     "156492583557099004562801132097903880197298887896923564990054435151289517\
81005251797532170320974770604957729080695654892750828738658836655", "/", 
      "53590990217855723557832111852757307944581854092867250575292004637363571\
08859207798383143343399018784632658572560676848691589970550728772"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "94131381221566855583154409782900908774888118770398687526576747893881449\
95159732114969573389878201244143158714515233834710757968539477083", "/", 
       "1071819804357114471156642237055146158891637081857345011505840092747271\
4217718415596766286686798037569265317145121353697383179941101457544"}]}], ",", 
     RowBox[{
     "258677757091532713225540660407612051208912220400392968553983087022371820\
349163828101588942265343026535133895120208648914400351273", "/", 
      "70525770919493936156277419664034158457650884977274053601243321280738509\
866019142627545893062416625242909462540659505351879193081"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "47882553462818868556044272759141511102763726057050251945349584780780008\
954022012521099230359817888804702237743613", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
6856605522518821481293134299337796860233618"}]}], ",", 
     RowBox[{
     "114003156410307620821954632681192901057250950979170916045438508473775575\
01731", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "46356191864490707780807132731155600872631993605370296100794778801363533\
8236620351194873565464316851880123372917278117969753145025954578391", "/", 
       "3590596344596333478374751494134739632286984224222105788544564310703359\
26293566922491670604007734258570388124361565348862336528026898827724"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "33989752192461698473686376235102129955646095773382832526198320542451137\
0981660210254341917720380578223122201859828331961642565261768801479", "/", 
       "1795298172298166739187375747067369816143492112111052894272282155351679\
63146783461245835302003867129285194062180782674431168264013449413862"}]}], 
     ",", 
     RowBox[{
     "140444010284420887084284071399762929685702456374948868694017021954418810\
503041888200899289334247911261129017463982146114047066077359795411", "/", 
      "35905963445963334783747514941347396322869842242221057885445643107033592\
6293566922491670604007734258570388124361565348862336528026898827724"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "60014358140505079777510813680102086512171548867048617805097053392309219\
955937763672382734251907259375338985177849323494513868691863", "/", 
       "1890090660642437488988234846996115446665043717390944636513321010323792\
0644093130224182299340727655565099735960896747434303623745708"}]}], ",", 
     RowBox[{
     "315137129674340213851840197806195008256053338538927308355979906355553485\
604054443838849903971967693270476657446645", "/", 
      "39214528143612117708528196324908653192349396247285240569762146831923474\
1139633135112928887758805796026781161401708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "35232672015148909430879337254092423127788059679126267911799640901917892\
549763", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "247330701299744316257167386868035005728254347983934455436824333997857150\
8229511586180017527538989890637849221132594850003603416005402696581", "/", 
      "47874617927951113044996686588463195097159789656294743847260857476044790\
1724755896655560805343645678093850832482087131816448704035865103632"}], ",", 
     RowBox[{
     "115739941159799419407016644749467978246386152757828435982712776237971328\
5192749112443187753390811497018334847778073968420992421015510042177", "/", 
      "23937308963975556522498343294231597548579894828147371923630428738022395\
0862377948327780402671822839046925416241043565908224352017932551816"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "38987444690285129801977607663044044054826359937711437878012488834332129\
5058306530481850497734160620209610650438196163840649757646930570873", "/", 
       "4787461792795111304499668658846319509715978965629474384726085747604479\
01724755896655560805343645678093850832482087131816448704035865103632"}]}], 
     ",", 
     RowBox[{
     "340525614140265548743004469356909765493528540254768249510991143138215035\
31222034391462708932291383106732888953179371097044914085071", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "70131808279419422073011632121463058790690741291135468852796886144700844\
636394934287820130438650966958364127084470", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{
     "188086865394409210987827092780470183490641131896392737962296675937580073\
71745", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{
     "130982817231817517145939543546711311706571123896025120508033223087664812\
75528529751484029520721363556289625428132137544369539313791627270275", "/", 
      "43087156135156001740497017929616875587443810690665269462534771728440311\
15522803069900047248092811102844657492338784186348038336322785932688"}], ",", 
     
     RowBox[{
     "861333994881303353190834872040680521707494100344026327817260238212430216\
6800933109210256790230233386457940304620869773829137282125453374111", "/", 
      "21543578067578000870248508964808437793721905345332634731267385864220155\
57761401534950023624046405551422328746169392093174019168161392966344"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "39126473094116663384701056518935319815003290612317997483987345011282465\
62083302850347117918204737148635220620081729418342245368646413340415", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{
     "226953796348972663888802294931507144098177914214846218891326508611962976\
77572120916995283153561739517119678511935035673075584613711", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12199521294241003173119612694476121965511135307597353167910878998923788\
8964627445070238949633490804979018342416571", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "439756518643518984817444251873130503971439508033563219581599402921612719\
70280", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "73672463431125565979665813871151779027868583937016673859079662454824955\
75961856877588306330865946815952661819589645531148099515214667417919", "/", 
       "4308715613515600174049701792961687558744381069066526946253477172844031\
115522803069900047248092811102844657492338784186348038336322785932688"}]}], 
     ",", 
     RowBox[{"-", 
      RowBox[{
      "54109681784346033774293107685561309441689265037082368477016829446925742\
65655643878534818708646130010808986508786794014794081105663837971291", "/", 
       "2154357806757800087024850896480843779372190534533263473126738586422015\
557761401534950023624046405551422328746169392093174019168161392966344"}]}], 
     ",", 
     RowBox[{
     "219165841718322947867532889359504697979982406143031193997969105435365321\
0089301183647265284152862755116091398403888404411694281993843127227", "/", 
      "43087156135156001740497017929616875587443810690665269462534771728440311\
15522803069900047248092811102844657492338784186348038336322785932688"}], ",", 
     
     RowBox[{"-", 
      RowBox[{
      "67684948635129642791122735045396550575311805837796231178850349848353387\
81525912935958914627876700480168873292456218401934081678121", "/", 
       "1575075550535364574156862372496762872220869764492453863761100841936493\
387007760852015191611727304630424977996741395619525301978809"}]}], ",", 
     RowBox[{
     "624553063450788985880425148457947209198657187746925077912389335831907054\
08796619394152672450503518787512807472581", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "75882501183664951003710304911465586211425433512993649159220126980467885\
77208", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "49316853515748626218182064587057343087616571464962309222111919258177508\
841449", "/", 
       "2103506154757238037341429910266108513405894990914180135109712494532698\
6970244"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "24875718793096222777466133258095046403003600185507607339053257154326070\
829387", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "131935364922285113081777374760184260721687517924160664197691126825287848\
44439", "/", 
      "21035061547572380373414299102661085134058949909141801351097124945326986\
970244"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "24974156310912127781633761523791402945678242374829364037439463443581019\
932886", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "976885289101968559650588257800049104894570349898563820848625626435488533\
4897", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "16623869100160545491087886490248232225814119814851360711173829935595587\
634629", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "45590486421233224047645687183452367785437132171647321181049855256527974\
31685", "/", 
       "2103506154757238037341429910266108513405894990914180135109712494532698\
6970244"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "74974560338560588987852301670854773122219044640533618909639982998842758\
61085", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "18416293036758347044746757386160073663460571081642850519761335877466042\
41207", "/", 
       "6310518464271714112024289730798325540217684972742540405329137483598096\
0910732"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11571391067232006405391102222505139849441511172578777603169574686767972\
492412", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "317383979603844500112054251284901267570394827742591339989740315939200204\
07", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12539817585498410770409517888706699417249846543686527122013021772141614\
544047", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
     "829436255961751697975280402958309036505893208844934072295655958064726206\
9746511074147204255006008694561463670803301958656800849634105", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{
     "438767917744620903062537553198715886137134938419322224254402115723691560\
494223791746016873656197395953864084176009936236270025862951", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "51658409257766915057477779204508515552813270103155515638790304403884102\
231951574295959338625386319292440853579943947162335255251550", "/", 
       "4725226651606093722470587117490288616662609293477361591283302525809480\
161023282556045574835181913891274933990224186858575905936427"}]}], ",", 
     RowBox[{
     "189025083378504911310748194886806966224729355032483702544653711639633979\
68377595014003457081882649429800173872630556735678289598231049", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "54361368063265193788336341452123770536044621228668580398639711773597788\
7802605004606768647836281488949852610858496", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{
     "241261865632612050449966987794653304450733209595743739298914380315436078\
2452707", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "15832136731525364485131871687980944766399610619683557999932961017446814\
29007497747637567719850690794575620817774415884497212246547", "/", 
       "8513921894785754454901958770252772282274971699959210074384328875332396\
6865284370379199546579854304347296107931967330785151458314"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "26040759628346943733044590025590791169704063964636294778706455197842903\
82664989608895136163799593869105683782130000950856467839323", "/", 
       "1277088284217863168235293815537915842341245754993881511157649331299859\
50297926555568799319869781456520944161897950996177727187471"}]}], ",", 
     RowBox[{
     "589324187102251019405339422567538784812450855650523766206855848207215001\
872140170423261022173411645889760842221667601980380164274", "/", 
      "12770882842178631682352938155379158423412457549938815111576493312998595\
0297926555568799319869781456520944161897950996177727187471"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10120123007197056405737276185054156074840347921088638223255912414688028\
851496672560223706999232846298112695880139345535494188330047", "/", 
       "2554176568435726336470587631075831684682491509987763022315298662599719\
00595853111137598639739562913041888323795901992355454374942"}]}], ",", 
     RowBox[{
     "217275987731258401986954911239934630576767124872192278548917056151936704\
52880063324425026148222863097390804743311", "/", 
      "26496302799737917370627159678992333238073916383300838222812261372921266\
29321845507519789782154093216397170009471"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "40925065028125013340490112423266996726194429762747693441850921665845945\
0445481", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "141834012643183367932260583174313858105909894236477560722798728766673909\
3688138745310811328554972075943321706608516810482887750331943", "/", 
      "11340543963854624933929409081976692679990262304345667819079926061942752\
3864558781345093796044365933390598415765380484605821742474248"}], ",", 
     RowBox[{
     "670234846426733040332110225888618268070941666869587470902012956787231594\
60577609196877582324445174473012114255253648231020106734978", "/", 
      "47252266516060937224705871174902886166626092934773615912833025258094801\
61023282556045574835181913891274933990224186858575905936427"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "14532524008657467243708501825947742053605806438531259857385341419306754\
778405835628114586318826301642598591195830923052871992929975", "/", 
       "4725226651606093722470587117490288616662609293477361591283302525809480\
161023282556045574835181913891274933990224186858575905936427"}]}], ",", 
     RowBox[{
     "304616212146904302870884219844982856679856040711235616217293604338349543\
2234809436870791753948761729263591205297127135523328288981695", "/", 
      "11340543963854624933929409081976692679990262304345667819079926061942752\
3864558781345093796044365933390598415765380484605821742474248"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "60062883192535548673803530607259510478933137280864939794796778176336025\
3714671171651785116467063425793917334379755", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "104055391056878292507850034869188063856659531924964557206185578016390975\
0456303", "/", 
      "12621036928543428224048579461596651080435369945485080810658274967196192\
1821464"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "62406151815534212089395039313710760813683152040461959215640875606326275\
5232277142705657554462786886863521470951583355774858467396553", "/", 
       "7560362642569749955952939387984461786660174869563778546053284041295168\
2576372520896729197362910622260398943843586989737214494982832"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10104684882407097245180006245983164269715428575318552332831532837965702\
2206399230104431932402572888839835290416544120007030639914283", "/", 
       "9450453303212187444941174234980577233325218586954723182566605051618960\
322046565112091149670363827782549867980448373717151811872854"}]}], ",", 
     RowBox[{
     "224105352313000977844179211851649539773452455163295831263766276925046231\
61947554056157377085759405164715530122072356750419479151699", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "14682153534616391817924703634061479318525469701283620438928817696002769\
79948751917786790632260813728612584540845278825260587339988465", "/", 
       "7560362642569749955952939387984461786660174869563778546053284041295168\
2576372520896729197362910622260398943843586989737214494982832"}]}], ",", 
     RowBox[{
     "349192958266177414581904622441798031086345803950515868808964974819144982\
422528869741636291616551250693877496269813", "/", 
      "98036320359030294271320490812271632980873490618213101424405367079808685\
284908283778232221939701449006695290350427"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "17312001422958923630643751202781470248860744314791978406994295325071120\
01351651", "/", 
       "2524207385708685644809715892319330216087073989097016162131654993439238\
43642928"}]}], ",", 
     RowBox[{
     "214952623161528616825164598552887410486886429251763257787955299970225020\
855543794651992518961657549047218096527534306005296658102326", "/", 
      "14175679954818281167411761352470865849987827880432084773849907577428440\
483069847668136724505545741673824801970672560575727717809281"}], ",", 
     RowBox[{
     "561754099923951251570362712807815035893061705228499256139533994347762413\
26351129407947826424468996938087051997572098001640538258017", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25497555171478981315323937632900241375278840579089356864680494622679745\
832271750128373997063510907339740823341348919610385770208545", "/", 
       "6300302202141458296627449489987051488883479057969815455044403367745973\
548031043408060766446909218521699911986965582478101207915236"}]}], ",", 
     RowBox[{
     "187369637516090975262480951412783004326738190993273683330957628469130576\
2939683673660653700876209228560295086940414344825523003181493", "/", 
      "56702719819273124669647045409883463399951311521728339095399630309713761\
932279390672546898022182966695299207882690242302910871237124"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "14233843709551020992069649788359406022455377954297298614519005486827294\
85603407952913964462583812282240217378759937", "/", 
       "1960726407180605885426409816245432659617469812364262028488107341596173\
70569816567556464443879402898013390580700854"}]}], ",", 
     RowBox[{
     "663283647244248501154922972218222123458445826478905524584252490618171757\
713631", "/", 
      "63105184642717141120242897307983255402176849727425404053291374835980960\
910732"}], ",", 
     RowBox[{
     "207594412281944941640838913131284920891862618882235338602910973505665674\
0030216660665060025996069203072079787116604564847454523519487", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{
     "198153414321277047732092216528405025132286371620032782290787895844239398\
55426188599689854662826252006796758085609233926453624916133", "/", 
      "15750755505353645741568623724967628722208697644924538637611008419364933\
87007760852015191611727304630424977996741395619525301978809"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "20225029588084714933849577870339813598946097150489778280103225669448858\
577928802108642588486478706470346335727188090836406915706309", "/", 
       "6300302202141458296627449489987051488883479057969815455044403367745973\
548031043408060766446909218521699911986965582478101207915236"}]}], ",", 
     RowBox[{
     "481935059870112792680923781972241331940713114563558721653613710385283578\
8579883726676278100496349355658485273038209761951829869301491", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "87878714702136297166730776328656474331101713021729362697065049250586203\
0096338537324210889032036208194450403923695", "/", 
       "1960726407180605885426409816245432659617469812364262028488107341596173\
70569816567556464443879402898013390580700854"}]}], ",", 
     RowBox[{
     "183967939704950038189193458218326359813153126217699022771651568012426721\
6642779", "/", 
      "25242073857086856448097158923193302160870739890970161621316549934392384\
3642928"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "23046479731101259233156018242555244819416372002900646459220370173696656\
12775936181445530135446339810924474774486644013845371072208029", "/", 
       "1134054396385462493392940908197669267999026230434566781907992606194275\
23864558781345093796044365933390598415765380484605821742474248"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25249468472539125324127601441030506197189292880483108086416962983302791\
1683789506578685032683982057355903500001672996700755492788647", "/", 
       "9450453303212187444941174234980577233325218586954723182566605051618960\
322046565112091149670363827782549867980448373717151811872854"}]}], ",", 
     RowBox[{
     "117035455939123224743257642274621399350482746101664591322850906709270076\
820279676313722363544668248228341758820725750768350741482911", "/", 
      "18900906606424374889882348469961154466650437173909446365133210103237920\
644093130224182299340727655565099735960896747434303623745708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "53452230566426128138142926989531310520379032990787300456765724070197741\
11703100150700462393476144622388655758733000070135550500058487", "/", 
       "1134054396385462493392940908197669267999026230434566781907992606194275\
23864558781345093796044365933390598415765380484605821742474248"}]}], ",", 
     RowBox[{
     "625969718198165683141946313918858146264945209082347673620629350359192897\
004265383602190710524337754869734328627437", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "67812951350337826267985565422669798090753399952322817933906603048789501\
1649161", "/", 
       "4207012309514476074682859820532217026811789981828360270219424989065397\
3940488"}]}], ",", 
     RowBox[{
     "404694977877015680162180063613519222852179477548860552069568052316656851\
620334935350856895926112842168555650040582539142826750710955", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{
     "299473466083220643418044441337049237446307971297833212361935595977558027\
91828175393192992438532271343527624353777456324612246258121", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "48504305430912599465103693790041893362297954631526805430909493848077893\
41343337057303539180580984058671587103373631966682387794221", "/", 
       "4725226651606093722470587117490288616662609293477361591283302525809480\
161023282556045574835181913891274933990224186858575905936427"}]}], ",", 
     RowBox[{
     "106763813824603703700911990799108875659888885809188466880241045939010141\
3071442220099543739086800869557247417248617686228151626536619", "/", 
      "22681087927709249867858818163953385359980524608691335638159852123885504\
7729117562690187592088731866781196831530760969211643484948496"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "50645323100186055178500734141183091919500729171649280747393889333769457\
527716414433367124997942418047273812369002", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "572802818605046775784150868297104765783482746648073041895900974649648984\
205451", "/", 
      "25242073857086856448097158923193302160870739890970161621316549934392384\
3642928"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "41666024622550659915038098067648864147211708403583757165468626095954575\
701516888253081077280091007124213883920520150314735529270307", "/", 
       "3385237004135708935501316143873639605967242478909154572859679421475448\
473568918846122202866995998011659654201951656256890201267888"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22633919425106305098044647204686079113011438129390058177348021185248465\
75211798804692679232342755946002469165268120818974950004921", "/", 
       "1410515418389878723125548393280683169153017699545481072024866425614770\
19732038285255091786124833250485818925081319010703758386162"}]}], ",", 
     RowBox[{
     "258677757091532713225540660407612051208912220400392968553983087022371820\
349163828101588942265343026535133895120208648914400351273", "/", 
      "70525770919493936156277419664034158457650884977274053601243321280738509\
866019142627545893062416625242909462540659505351879193081"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "95809365111991308242756338416992550955858140163512818850372537323509602\
418953413815809354482295578366479496950918062992777254131523", "/", 
       "3385237004135708935501316143873639605967242478909154572859679421475448\
473568918846122202866995998011659654201951656256890201267888"}]}], ",", 
     RowBox[{
     "194681963550327712001565776586868794118690222258596495117367428958325770\
844919520096692006413219518579193217929938", "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
428302761259410740646567149668898430116809"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "78813716986211090063763289236815201034130208529529872869810031148108313\
4714787", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{
     "697605181397772693336237779455329138022523078901217535894441121584630188\
571954653635593379775261871937322181970208877029330061772763", "/", 
      "56702719819273124669647045409883463399951311521728339095399630309713761\
932279390672546898022182966695299207882690242302910871237124"}], ",", 
     RowBox[{
     "133629448608361782263730774001690479982530248030981160751769171133298542\
270878396813504539640946900357165789596818778133173672233289", "/", 
      "94504533032121874449411742349805772333252185869547231825666050516189603\
22046565112091149670363827782549867980448373717151811872854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "60014358140505079777510813680102086512171548867048617805097053392309219\
955937763672382734251907259375338985177849323494513868691863", "/", 
       "1890090660642437488988234846996115446665043717390944636513321010323792\
0644093130224182299340727655565099735960896747434303623745708"}]}], ",", 
     RowBox[{
     "377816725507247597889682750272733254425173021266923109952209324942249852\
167616386388691717849932386881515064095087690954991387547894", "/", 
      "14175679954818281167411761352470865849987827880432084773849907577428440\
483069847668136724505545741673824801970672560575727717809281"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11542352966806673912389180024266123717375251383573922685150759889153564\
18100708284869785295152521144197214725381307", "/", 
       "1960726407180605885426409816245432659617469812364262028488107341596173\
70569816567556464443879402898013390580700854"}]}], ",", 
     RowBox[{
     "267405260513251960398123929360979832901921022691979080229916364656767396\
818417", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10185524811761375346698772357174450987848866373026912565306948878109581\
71038606277886977413651671428161517931953952594347801777946957", "/", 
       "2520120880856583318650979795994820595553391623187926182017761347098389\
4192124173632243065787636874086799647947862329912404831660944"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "15098086957376085775251027399193726562944078476345177752994783736603083\
3848300961632591459172629956491941565590702810228349237898961", "/", 
       "3150151101070729148313724744993525744441739528984907727522201683872986\
774015521704030383223454609260849955993482791239050603957618"}]}], ",", 
     RowBox[{
     "340525614140265548743004469356909765493528540254768249510991143138215035\
31222034391462708932291383106732888953179371097044914085071", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22583123500245809368361007294639053320726844410182201739753857801753911\
24346700633573804890205407497751671201109699173777016204054549", "/", 
       "2520120880856583318650979795994820595553391623187926182017761347098389\
4192124173632243065787636874086799647947862329912404831660944"}]}], ",", 
     RowBox[{
     "592798745670280956511516072103553748264519636288996647403395871680334231\
847682692471982308356216628124881417560016", "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
428302761259410740646567149668898430116809"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25396487775616369090736871492585374035444833667254270210925714905960774\
47279055", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "15726152142037152722894637449439679860238632955666685658835875408132803\
35736874620335506914458277316866812752226689768304061121822647", "/", 
       "5670271981927312466964704540988346339995131152172833909539963030971376\
1932279390672546898022182966695299207882690242302910871237124"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "51576032276782068054131351195698373030456635324472911394182904423039274\
589325071321257106320890738851438835833239434662885926546911", "/", 
       "1575075550535364574156862372496762872220869764492453863761100841936493\
387007760852015191611727304630424977996741395619525301978809"}]}], ",", 
     RowBox[{
     "226953796348972663888802294931507144098177914214846218891326508611962976\
77572120916995283153561739517119678511935035673075584613711", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "34756238157415873296112196686998918315725891343406862845253408198868320\
91647518490413525620830641070188669472295821433669496305736393", "/", 
       "5670271981927312466964704540988346339995131152172833909539963030971376\
1932279390672546898022182966695299207882690242302910871237124"}]}], ",", 
     RowBox[{
     "127297263578553643381672401962710418942766809226010966930598286159186885\
2511181538746976075290376209195063380294275", "/", 
      "98036320359030294271320490812271632980873490618213101424405367079808685\
284908283778232221939701449006695290350427"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12606837655631737333067475408594613553453381489438090207914067507802958\
65350309", "/", 
       "6310518464271714112024289730798325540217684972742540405329137483598096\
0910732"}]}], ",", 
     RowBox[{
     "107429415800259707600923349941047417907230716533307712097645663818114405\
1468031313827304010252299497690178147731752093999536393962855", "/", 
      "75603626425697499559529393879844617866601748695637785460532840412951682\
576372520896729197362910622260398943843586989737214494982832"}], ",", 
     RowBox[{
     "564514391089203828202732965564175215761293588569806135088850663448016769\
51485953771311274218407976030217193241131093321488965967097", "/", 
      "31501511010707291483137247449935257444417395289849077275222016838729867\
74015521704030383223454609260849955993482791239050603957618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "67684948635129642791122735045396550575311805837796231178850349848353387\
81525912935958914627876700480168873292456218401934081678121", "/", 
       "1575075550535364574156862372496762872220869764492453863761100841936493\
387007760852015191611727304630424977996741395619525301978809"}]}], ",", 
     RowBox[{
     "242807919044234611474274996603120710326270626203246608188760805463892211\
0918029802050710704562552008889167918744707109012760901268903", "/", 
      "75603626425697499559529393879844617866601748695637785460532840412951682\
576372520896729197362910622260398943843586989737214494982832"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "21493242653414393896577956634954609270629744297076356176145425788228715\
7971568636877683849046074316063474245134712", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{
     "920046559369237615605694142006323377016978010267673153013091676007930221\
590151", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "144225977003090687260772943504482195701501583194997585609281238869748736\
1180125", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "222721885063301848750675519467390061009158475761779826873288855229397834\
389825", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "24974156310912127781633761523791402945678242374829364037439463443581019\
932886", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "324176734180214592038989511447605259577042031195679695543306962880925092\
7660253", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "42492405113766238126598518549642605911517499701258579265201796771863268\
732594", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "106653329089589895980093111543869043349194189138297530137746416919416721\
0495903", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "953174785959229660425788646468873870405125701681696484006481984244709577\
99097", "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}], ",", 
     RowBox[{
     "562751412199638741317279687480500385405643980829299506925051100911065983\
91540", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11571391067232006405391102222505139849441511172578777603169574686767972\
492412", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "713716124317858528883105127435661747508277790194654675522308658581674541\
033731", "/", 
      "12621036928543428224048579461596651080435369945485080810658274967196192\
1821464"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22012092760632247438873853174329885462674199545632238439463346076421164\
823765", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "204011409517260296359507901566426808119658827320573136648942423827774678\
666305", "/", 
      "12621036928543428224048579461596651080435369945485080810658274967196192\
1821464"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"-", 
      RowBox[{
      "24708869196260093045838088389076356515550317723371140747584733334750504\
98326312624451797438468972835229950593343521", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
84283027612594107406465671496688984301168090"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13909638427910533103412182185981754138399537535520213293327077361632396\
31102373713878860952774375911754890657803874", "/", 
       "1633938672650504904522008180204527216347891510303551690406756117996811\
42141513806297053703232835748344492150584045"}]}], ",", 
     RowBox[{
     "124881248847131114108708756606758261739706077046820331080862360310957349\
823697173551434211572382527238589451703713", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "54361368063265193788336341452123770536044621228668580398639711773597788\
7802605004606768647836281488949852610858496", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{
     "505591938087612848827613427271132213870869278044610142083375420975986798\
082476266986446095518220930149568995012432", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "30802812797464893677286469784490796091837207124839476577994610907760940\
771537", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "147802854728869907589992604773039112204655934192833393529863804206267924\
31455652204965432677415628325661347757402", "/", 
      "44160504666229862284378599464987222063456527305501397038020435621535443\
82203075845866316303590155360661950015785"}], ",", 
     RowBox[{
     "661315607871830520590162509919792959293869044803027447816187999510314754\
74312360975607273707585094285771970168663", "/", 
      "13248151399868958685313579839496166619036958191650419111406130686460633\
146609227537598948910770466081985850047355"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "29419087005876625219282370609305218795374693972994310973151052016866737\
28508157397521735827248048342516934672798", "/", 
       "2649630279973791737062715967899233323807391638330083822281226137292126\
629321845507519789782154093216397170009471"}]}], ",", 
     RowBox[{
     "217275987731258401986954911239934630576767124872192278548917056151936704\
52880063324425026148222863097390804743311", "/", 
      "26496302799737917370627159678992333238073916383300838222812261372921266\
29321845507519789782154093216397170009471"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25331230460072343980848689041346378301613677746046592355594816099076644\
554290909381672703956947909322717157622739", "/", 
       "1324815139986895868531357983949616661903695819165041911140613068646063\
3146609227537598948910770466081985850047355"}]}], ",", 
     RowBox[{
     "398663244410924556758151208617758724980565018615597208964882986871019761\
56247", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "86671442743959122047790695442780694572079011617132998996626738263944134\
0400238044100100267250596382684475101943629", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
84283027612594107406465671496688984301168090"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "19219909189280270942798829931666706726259484773135216905187591805988391\
73762305859049062402839219149829300546643358", "/", 
       "4901816017951514713566024540613581649043674530910655071220268353990434\
26424541418891161109698507245033476451752135"}]}], ",", 
     RowBox[{
     "200212773643314724090593333974144571091464024994348174045762480203426218\
386692291340314917687520974604322983540409", "/", 
      "19607264071806058854264098162454326596174698123642620284881073415961737\
0569816567556464443879402898013390580700854"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "60062883192535548673803530607259510478933137280864939794796778176336025\
3714671171651785116467063425793917334379755", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "792890325718567952652988664388846689403603554495723824770601899665898120\
940903604628328512766477621493467396276984", "/", 
      "49018160179515147135660245406135816490436745309106550712202683539904342\
6424541418891161109698507245033476451752135"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "30098247514386965070084487789554032368680694955488013062554448363161917\
492402", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "311980372772778207905356674893318762635557020339753818209308670823802618\
169652785203227072272041357894098190411576", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{
     "664691635239659344300175499091708578777635644090862546782250426612722412\
199610936090930061800574312363078749789409", "/", 
      "49018160179515147135660245406135816490436745309106550712202683539904342\
6424541418891161109698507245033476451752135"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "35416336514878723708466659987931118921455991644139559197269998251048342\
145917332305575673836164320459323168729800", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "349192958266177414581904622441798031086345803950515868808964974819144982\
422528869741636291616551250693877496269813", "/", 
      "98036320359030294271320490812271632980873490618213101424405367079808685\
284908283778232221939701449006695290350427"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25450881027476974182963639796565792904808645149752174536206249589765825\
4922771407188076184635178645273954153877237", "/", 
       "4901816017951514713566024540613581649043674530910655071220268353990434\
26424541418891161109698507245033476451752135"}]}], ",", 
     RowBox[{
     "220329064697342723563287557219792714113634615076255484809179380611095932\
52795", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22402179991189077657822741446353308773774382628298652360664159387332308\
85128595973253020279510172981823076565461611", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
68566055225188214812931342993377968602336180"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "41038606545722111679229976712607111301835910720550501547210639180100767\
25473539982807647892788990262460525564828027", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
52849082837782322219397014490066952903504270"}]}], ",", 
     RowBox[{
     "422187029028887118789909288994733676990940392843902259233717427281665053\
625465596504903497660118684233057798734481", "/", 
      "39214528143612117708528196324908653192349396247285240569762146831923474\
1139633135112928887758805796026781161401708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "14233843709551020992069649788359406022455377954297298614519005486827294\
85603407952913964462583812282240217378759937", "/", 
       "1960726407180605885426409816245432659617469812364262028488107341596173\
70569816567556464443879402898013390580700854"}]}], ",", 
     RowBox[{
     "177240653650724334640587636361156740882627011855109896524877105957289729\
4014191984457004208571352162846176463975181", "/", 
      "98036320359030294271320490812271632980873490618213101424405367079808685\
2849082837782322219397014490066952903504270"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "33273711199312519848001913190524474944894668947220801501034507314417174\
322631", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11590355533909125670934614031174919511058114563540011289250648532762748\
28172834717539680214933824211074548317487801", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
68566055225188214812931342993377968602336180"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "27546944525084543084743354705619151975744681190016216054180313519353155\
74610180145910323057163967420382259593720477", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
52849082837782322219397014490066952903504270"}]}], ",", 
     RowBox[{
     "221409997505350460220426421806529363598260657151504927105414274596292046\
288735029811629875345355717270055401292387", "/", 
      "39214528143612117708528196324908653192349396247285240569762146831923474\
1139633135112928887758805796026781161401708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "87878714702136297166730776328656474331101713021729362697065049250586203\
0096338537324210889032036208194450403923695", "/", 
       "1960726407180605885426409816245432659617469812364262028488107341596173\
70569816567556464443879402898013390580700854"}]}], ",", 
     RowBox[{
     "100247827662232750156819897044316564326091546145466791188598060771101938\
1184313105251684476338709834689206721913771", "/", 
      "98036320359030294271320490812271632980873490618213101424405367079808685\
2849082837782322219397014490066952903504270"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "21119351753934089435477252598760989758787703312927237681142829527353145\
325637", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "571704676727701221643326643687487790937102638701508979953231136101148691\
221172100546774371935893625021941443393601", "/", 
      "13071509381204039236176065441636217730783132082428413523254048943974491\
3713211045037642962586268598675593720467236"}], ",", 
     RowBox[{
     "301247984272063148416332655668167855720197804481220746822751881552031016\
100372937805668228311406063195037897550997", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11431277507732398252888160899630545576803959482113279562496832311057085\
9045494524909361147621683169409653064151025", "/", 
       "1307150938120403923617606544163621773078313208242841352325404894397449\
13713211045037642962586268598675593720467236"}]}], ",", 
     RowBox[{
     "625969718198165683141946313918858146264945209082347673620629350359192897\
004265383602190710524337754869734328627437", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10436314355499757699824507605306886930795909960857167392439480516528643\
6003940856330130926350647205179627371881823", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
6856605522518821481293134299337796860233618"}]}], ",", 
     RowBox[{
     "178595365265652823163236668794956172466677530787048459144534237360901046\
21739", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "52751832471673182469854014604929150786404633976135425311783777259971293\
72864227867396954502957079259941420621768", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12784685296380364068772035555309446208261061536652613520738364161498838\
546295933470819791547032691841424084461809", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "24589914305686673968389694429621201492352430378823615212577001852213517\
48867479536826805563074681053687163571413", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "50645323100186055178500734141183091919500729171649280747393889333769457\
527716414433367124997942418047273812369002", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "63162783083253761910818168351389971828062630441707289778603157015124182\
68021142779790086140600106146495838829195", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "42990298669427782812714407377405003744306127791264150006609699784878615\
71152", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "917884868980261443421959741268291164201889131285919388005339690495140211\
943172405672566192578506504910771779369429", "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
4283027612594107406465671496688984301168090"}], ",", 
     RowBox[{
     "491505837607312545873029010885860347050984934458222550142793931130598965\
313043162477322012423770882473097309448676", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "47882553462818868556044272759141511102763726057050251945349584780780008\
954022012521099230359817888804702237743613", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
6856605522518821481293134299337796860233618"}]}], ",", 
     RowBox[{
     "194681963550327712001565776586868794118690222258596495117367428958325770\
844919520096692006413219518579193217929938", "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
428302761259410740646567149668898430116809"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "19023467871714163114758072363275531559749572667508161157644116522235944\
4894667723292296863033503827727659186943998", "/", 
       "1633938672650504904522008180204527216347891510303551690406756117996811\
42141513806297053703232835748344492150584045"}]}], ",", 
     RowBox[{
     "105655069213187108651366883731069945268145299454027809242094347865319229\
64727", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "14795438514387030257726413032737088531913874568950275224536454503278611\
26117079498613492670925969441630943541142143", "/", 
       "6535754690602019618088032720818108865391566041214206761627024471987245\
68566055225188214812931342993377968602336180"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "37245411693805851069281185778667929123491963766958355288289721143573547\
75598779347087743581415006419113244106971541", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
52849082837782322219397014490066952903504270"}]}], ",", 
     RowBox[{
     "315137129674340213851840197806195008256053338538927308355979906355553485\
604054443838849903971967693270476657446645", "/", 
      "39214528143612117708528196324908653192349396247285240569762146831923474\
1139633135112928887758805796026781161401708"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11542352966806673912389180024266123717375251383573922685150759889153564\
18100708284869785295152521144197214725381307", "/", 
       "1960726407180605885426409816245432659617469812364262028488107341596173\
70569816567556464443879402898013390580700854"}]}], ",", 
     RowBox[{
     "139160867543612029600925073812256695452447641570783079240590890094571303\
3476804899409295985564977245834065608627823", "/", 
      "98036320359030294271320490812271632980873490618213101424405367079808685\
2849082837782322219397014490066952903504270"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "29199673357680490383866615261410513401040573380749875302768343030795781\
110334", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "128399105391723031871059197689553338582306824790905252557017457916840243\
9011385818840029322042581473968617951716331", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{
     "163338676278972735260316609571075326710760031915729127315562287175834150\
1251936248427417994029212494480482753627203", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "70131808279419422073011632121463058790690741291135468852796886144700844\
636394934287820130438650966958364127084470", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{
     "592798745670280956511516072103553748264519636288996647403395871680334231\
847682692471982308356216628124881417560016", "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
428302761259410740646567149668898430116809"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "61446411168228063061657190354175493259136379523164320936939683717393258\
0437130075267841579992730122108390964112639", "/", 
       "1633938672650504904522008180204527216347891510303551690406756117996811\
42141513806297053703232835748344492150584045"}]}], ",", 
     RowBox[{
     "318871274515517689287524125151632891004314923823219793541084847819418344\
41288", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{
     "941538931746835654980148848275017325809236406933702134379978809438175873\
896273987341825493124747819234035985655021", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{
     "318071961615185895309312594578004761656853674538560567356294373098796404\
4409186714047113853227913704549569408723099", "/", 
      "49018160179515147135660245406135816490436745309106550712202683539904342\
6424541418891161109698507245033476451752135"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12199521294241003173119612694476121965511135307597353167910878998923788\
8964627445070238949633490804979018342416571", "/", 
       "9803632035903029427132049081227163298087349061821310142440536707980868\
5284908283778232221939701449006695290350427"}]}], ",", 
     RowBox[{
     "127297263578553643381672401962710418942766809226010966930598286159186885\
2511181538746976075290376209195063380294275", "/", 
      "98036320359030294271320490812271632980873490618213101424405367079808685\
284908283778232221939701449006695290350427"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10824144093189234532625122670655946583670312298428641116081360904246282\
39802971264336894119051201175696416030052647", "/", 
       "4901816017951514713566024540613581649043674530910655071220268353990434\
26424541418891161109698507245033476451752135"}]}], ",", 
     RowBox[{
     "717795448688354852064543348641348149920822698677763842433786977785491351\
83115", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10785371032857510247043914113217539814429609400244372663379254872884360\
26030241264682315898856299492982415124348513", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
84283027612594107406465671496688984301168090"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "55392593093606086092115464292854713929224628750268368136372845793274874\
3824444041846937303129572307992115622649362", "/", 
       "1633938672650504904522008180204527216347891510303551690406756117996811\
42141513806297053703232835748344492150584045"}]}], ",", 
     RowBox[{
     "624553063450788985880425148457947209198657187746925077912389335831907054\
08796619394152672450503518787512807472581", "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
856605522518821481293134299337796860233618"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "21493242653414393896577956634954609270629744297076356176145425788228715\
7971568636877683849046074316063474245134712", "/", 
       "3267877345301009809044016360409054432695783020607103380813512235993622\
8428302761259410740646567149668898430116809"}]}], ",", 
     RowBox[{
     "227465666058635012989109838730893412392352194663988388250338779371225990\
382170977460237794916105514293303146889636", "/", 
      "16339386726505049045220081802045272163478915103035516904067561179968114\
2141513806297053703232835748344492150584045"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11868064580924479284317555240019245389470831993271458314569874218573538\
138433", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "33978249178693489575755681943903631020375076967425820574923119992942986\
732405", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25652498443561621346722306464385870100111304720277302475678743226170529\
697476", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "976885289101968559650588257800049104894570349898563820848625626435488533\
4897", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "42492405113766238126598518549642605911517499701258579265201796771863268\
732594", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "976423361461190918805729839267378518489695082553671190320959349238156823\
2926", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13053971932609240305774394716794242529151332135560691733217840773074424\
398639", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "62431291979872286794654645860228621855660163699776812525183191765417366\
89809", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "73058989896798749457993968625679807223251355692105635449401328645516282\
48221", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "317383979603844500112054251284901267570394827742591339989740315939200204\
07", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22012092760632247438873853174329885462674199545632238439463346076421164\
823765", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "176453796835870414678926964453196216184652440745914702506295403806833873\
927", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11303497462156261979239383684563367356108022525798123441872330183017568\
476564", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
     "112318496436335898829568138041865481455901850182279500798381293177749705\
1616491", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "158163838633593660409888627248802372736777049695537170726477713505085747\
321329", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "37218922930724221504899854540351977220756651481278501793832282098033298\
019527", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "241261865632612050449966987794653304450733209595743739298914380315436078\
2452707", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "30802812797464893677286469784490796091837207124839476577994610907760940\
771537", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "804596314864934262249920950880050081165451462163930484332184227770537385\
141105", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "61635636535283307154540352048864267950912176985631168646075199643256794\
188149", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10651899421646792712256679930501490436800141852258920239156102055015957\
0557507", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "221496008966425249698528641419349902230579063754106575776273788534131861\
56830", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "40925065028125013340490112423266996726194429762747693441850921665845945\
0445481", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "398663244410924556758151208617758724980565018615597208964882986871019761\
56247", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13570387129316788127109253049580176866831965291670724312147601477325177\
7707151", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "160852703261628645043162916918615800160318438626321952521746603816640300\
633665", "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}], ",", 
     RowBox[{
     "725927816462560414237007225976203149278512081582897442591843213635376882\
43255", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "35184159144287479998208956135487829036358691915499629662967567455240426\
797533", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "104055391056878292507850034869188063856659531924964557206185578016390975\
0456303", "/", 
      "12621036928543428224048579461596651080435369945485080810658274967196192\
1821464"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "30098247514386965070084487789554032368680694955488013062554448363161917\
492402", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "337262836819589546704767165343269234559713286242602709668090931167018128\
143437", "/", 
      "12621036928543428224048579461596651080435369945485080810658274967196192\
1821464"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "29816903493537839549577901321834374353150283787139097260466095439011446\
5126937", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "10429921895623848705895496980357111117598646719296216252538736782996040\
7015037", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "289950152662132653043123649889612210357242453447318209662854620602624335\
32435", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "17312001422958923630643751202781470248860744314791978406994295325071120\
01351651", "/", 
       "2524207385708685644809715892319330216087073989097016162131654993439238\
43642928"}]}], ",", 
     RowBox[{
     "220329064697342723563287557219792714113634615076255484809179380611095932\
52795", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "60396743670348610974721582427985485771007962748264806693799638069030153\
3394481", "/", 
       "2524207385708685644809715892319330216087073989097016162131654993439238\
43642928"}]}], ",", 
     RowBox[{
     "914157009959940039194410853507013478208170982783030470653137337696417343\
27101", "/", 
      "21035061547572380373414299102661085134058949909141801351097124945326986\
970244"}], ",", 
     RowBox[{
     "929173457388279056474575247179322560550528728912027240715683262597449632\
86509", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "18688128076607299686657924711794908401471779530295603092794504390594734\
112953", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "663283647244248501154922972218222123458445826478905524584252490618171757\
713631", "/", 
      "63105184642717141120242897307983255402176849727425404053291374835980960\
910732"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "33273711199312519848001913190524474944894668947220801501034507314417174\
322631", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "219452118038154126582696215237995858035204706449329912333285459282244396\
626101", "/", 
      "63105184642717141120242897307983255402176849727425404053291374835980960\
910732"}], ",", 
     RowBox[{
     "311067504890742002964460146449517532884868734064710030147129776085081980\
852089", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "105471726694458085324004527581202010386043473666858373767970477765474345\
944141", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13536539507675291695948549100187137875479264102253069500962666662119893\
521390", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "183967939704950038189193458218326359813153126217699022771651568012426721\
6642779", "/", 
      "25242073857086856448097158923193302160870739890970161621316549934392384\
3642928"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "21119351753934089435477252598760989758787703312927237681142829527353145\
325637", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "656422998361952488100719873625182209859584816873521898796168053371337676\
838729", "/", 
      "25242073857086856448097158923193302160870739890970161621316549934392384\
3642928"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "32001825782032467465933741201846021707919938670998410719185831039153547\
0367009", "/", 
       "4207012309514476074682859820532217026811789981828360270219424989065397\
3940488"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "44764448017676896803632183728143688492507396610196775919775447986244223\
521792", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "112419275101184917699750912478546730734905332233308596714045967196532073\
38492", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "67812951350337826267985565422669798090753399952322817933906603048789501\
1649161", "/", 
       "4207012309514476074682859820532217026811789981828360270219424989065397\
3940488"}]}], ",", 
     RowBox[{
     "178595365265652823163236668794956172466677530787048459144534237360901046\
21739", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "22848128037615309406338760828033496271683192016603168141076302829501085\
4330563", "/", 
       "4207012309514476074682859820532217026811789981828360270219424989065397\
3940488"}]}], ",", 
     RowBox[{
     "115382478004835736072012974868394987943164108192913609105508816807389905\
983953", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "227823909084107375810108571006011984889942815283797499927981971543405736\
64559", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "97720015959799504292733114447150351208496209663146974133755243120978606\
30893", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "572802818605046775784150868297104765783482746648073041895900974649648984\
205451", "/", 
      "25242073857086856448097158923193302160870739890970161621316549934392384\
3642928"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "42990298669427782812714407377405003744306127791264150006609699784878615\
71152", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "256633382870161582726914104530880917977441163925477659989474084567380533\
544521", "/", 
      "25242073857086856448097158923193302160870739890970161621316549934392384\
3642928"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "31998971285884759334694884824515504857927995039680230390505361217362706\
5768715", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "56979412642688316042876679777275063446273849582001390697334996653936845\
349845", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "114003156410307620821954632681192901057250950979170916045438508473775575\
01731", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "78813716986211090063763289236815201034130208529529872869810031148108313\
4714787", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{
     "105655069213187108651366883731069945268145299454027809242094347865319229\
64727", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25352016770901703646307075849209359957940771579939734242490552972583501\
7221937", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{
     "201603439989010868223980386145950712832782383904993755025393646493809771\
16096", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{
     "750902046250496304778155068149238020190185920580139157463345182973370936\
47804", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "35232672015148909430879337254092423127788059679126267911799640901917892\
549763", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "267405260513251960398123929360979832901921022691979080229916364656767396\
818417", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "29199673357680490383866615261410513401040573380749875302768343030795781\
110334", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "852933395266073819232898927506857905449440275273842215555096435479178080\
14353", "/", 
      "31552592321358570560121448653991627701088424863712702026645687417990480\
455366"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11660054990935778810224382040501598102150624221557631348388382686209012\
71618271", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "16668949098372637316236934414013771350524529942476515591831512389433886\
9207135", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "188086865394409210987827092780470183490641131896392737962296675937580073\
71745", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "25396487775616369090736871492585374035444833667254270210925714905960774\
47279055", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{
     "318871274515517689287524125151632891004314923823219793541084847819418344\
41288", "/", 
      "52587653868930950933535747756652712835147374772854503377742812363317467\
42561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "84640856618911368989382287557749108733724940995176731258723140092142498\
6534885", "/", 
       "8414024619028952149365719641064434053623579963656720540438849978130794\
7880976"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "19083248965441720448200481182500670009822836475043628005047985541794728\
6587123", "/", 
       "2103506154757238037341429910266108513405894990914180135109712494532698\
6970244"}]}], ",", 
     RowBox[{"-", 
      RowBox[{
      "17885659070358154038288916426178687728072220489066978031407728146880231\
8671821", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "439756518643518984817444251873130503971439508033563219581599402921612719\
70280", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12606837655631737333067475408594613553453381489438090207914067507802958\
65350309", "/", 
       "6310518464271714112024289730798325540217684972742540405329137483598096\
0910732"}]}], ",", 
     RowBox[{
     "717795448688354852064543348641348149920822698677763842433786977785491351\
83115", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "40461711547850997151582681025168844191926205075526730687705577412874587\
5267119", "/", 
       "6310518464271714112024289730798325540217684972742540405329137483598096\
0910732"}]}], ",", 
     RowBox[{
     "434567428529199220029933012736084238440576117394782709078189250926097403\
016951", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "603783329437877955957826298827408171131657498836060407443579115417721660\
24929", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "75882501183664951003710304911465586211425433512993649159220126980467885\
77208", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "920046559369237615605694142006323377016978010267673153013091676007930221\
590151", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11868064580924479284317555240019245389470831993271458314569874218573538\
138433", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "313430673466635432099059661258297588275489455618448240811149604586296760\
640813", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "511900921428258491448076552394756151623711255431980554694551581739844819\
477879", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "680337215202935227100053272908329209963194234973830699178315365555606126\
98849", "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "16623869100160545491087886490248232225814119814851360711173829935595587\
634629", "/", 
       "1051753077378619018670714955133054256702947495457090067554856247266349\
3485122"}]}], ",", 
     RowBox[{
     "106653329089589895980093111543869043349194189138297530137746416919416721\
0495903", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "13053971932609240305774394716794242529151332135560691733217840773074424\
398639", "/", 
       "5258765386893095093353574775665271283514737477285450337774281236331746\
742561"}]}], ",", 
     RowBox[{
     "358127648253712653763451217225984991730617800191737275134891921792433120\
309093", "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}], ",", 
     RowBox[{
     "288107224990997173701859897769769196068219556582753655037421835429282590\
38079", "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}], ",", 
     RowBox[{
     "220069780906243196773791333577987768800287220267435859858810455816438541\
26911", "/", 
      "15776296160679285280060724326995813850544212431856351013322843708995240\
227683"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "12539817585498410770409517888706699417249846543686527122013021772141614\
544047", "/", 
       "3155259232135857056012144865399162770108842486371270202664568741799048\
0455366"}]}], ",", 
     RowBox[{
     "204011409517260296359507901566426808119658827320573136648942423827774678\
666305", "/", 
      "12621036928543428224048579461596651080435369945485080810658274967196192\
1821464"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "11303497462156261979239383684563367356108022525798123441872330183017568\
476564", "/", 
       "1577629616067928528006072432699581385054421243185635101332284370899524\
0227683"}]}], ",", 
     RowBox[{
     "401087290269390107428415413583037823225483452131516301490558538954312315\
31139", "/", 
      "12621036928543428224048579461596651080435369945485080810658274967196192\
1821464"}]}], "}"}]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
 StyleBox["allones", "Input",
  FontWeight->"Plain"],
 " shows all 1-forms generated during the calculation."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["allones"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"], ",", 
   SubscriptBox["\[Theta]", "11"], ",", 
   SubscriptBox["\[Theta]", "12"], ",", 
   SubscriptBox["\[Theta]", "13"], ",", 
   SubscriptBox["\[Theta]", "14"], ",", 
   SubscriptBox["\[Theta]", "15"], ",", 
   SubscriptBox["\[Theta]", "16"], ",", 
   SubscriptBox["\[Theta]", "17"], ",", 
   SubscriptBox["\[Theta]", "18"], ",", 
   SubscriptBox["\[Theta]", "19"], ",", 
   SubscriptBox["\[Theta]", "20"], ",", 
   SubscriptBox["\[Theta]", "21"], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    SubscriptBox["\[Theta]", "3"], "+", 
    SubscriptBox["\[Theta]", "4"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "7"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "7"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "7"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "7"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "7"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "7"}]]}]}], ",", 
   RowBox[{
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "8"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "8"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "8"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "8"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "8"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "8"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    SubscriptBox["\[Theta]", "2"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "9"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "9"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "9"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "9"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "9"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "9"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "10"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "10"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "10"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "10"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "10"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "10"}]]}]}], ",", 
   RowBox[{
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "11"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "11"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "11"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "11"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "11"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "11"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    SubscriptBox["\[Theta]", "2"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "12"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "12"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "12"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "12"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "12"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "12"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "13"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "13"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "13"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "13"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "13"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "13"}]]}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    SubscriptBox["\[Theta]", "3"], "-", 
    SubscriptBox["\[Theta]", "4"], "+", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "14"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "14"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "14"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "14"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "14"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "14"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "15"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "15"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "15"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "15"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "15"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "15"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "-", 
    SubscriptBox["\[Theta]", "2"], "-", 
    SubscriptBox["\[Theta]", "3"], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "16"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "16"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "16"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "16"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "16"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "16"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    SubscriptBox["\[Theta]", "2"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "17"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "17"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "17"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "17"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "17"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "17"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    SubscriptBox["\[Theta]", "3"], "-", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "18"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "18"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "18"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "18"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "18"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "18"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    SubscriptBox["\[Theta]", "3"], "+", 
    SubscriptBox["\[Theta]", "4"], "+", 
    SubscriptBox["\[Theta]", "5"], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "19"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "19"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "19"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "19"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "19"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "19"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "+", 
    SubscriptBox["\[Theta]", "2"], "+", 
    SubscriptBox["\[Theta]", "3"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "20"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "20"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "20"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "20"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "20"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "20"}]]}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    SubscriptBox["\[Theta]", "3"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"1", ",", "21"}]], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"2", ",", "21"}]]}], "-", 
    SubscriptBox["\[Omega]", 
     RowBox[{"3", ",", "21"}]], "+", 
    SubscriptBox["\[Omega]", 
     RowBox[{"4", ",", "21"}]], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"5", ",", "21"}]]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", 
      RowBox[{"6", ",", "21"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"1832", " ", 
       SubscriptBox["\[Theta]", "1"]}], "31"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    SubscriptBox["\[Theta]", "3"], "-", 
    SubscriptBox["\[Theta]", "4"], "+", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "7"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "7"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "7"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "7"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "7"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "7"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"301", " ", 
       SubscriptBox["\[Theta]", "1"]}], "31"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    SubscriptBox["\[Theta]", "5"], "+", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "8"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "8"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "8"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "8"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "8"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "8"}]]}], "31"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"232", " ", 
      SubscriptBox["\[Theta]", "1"]}], "31"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    SubscriptBox["\[Theta]", "5"], "+", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "9"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "9"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "9"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "9"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "9"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "9"}]]}], "31"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"1768", " ", 
      SubscriptBox["\[Theta]", "1"]}], "31"], "-", 
    SubscriptBox["\[Theta]", "2"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "10"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "10"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "10"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "10"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "10"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "10"}]]}], "31"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"1451", " ", 
      SubscriptBox["\[Theta]", "1"]}], "31"], "-", 
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "11"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "11"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "11"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "11"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "11"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "11"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"614", " ", 
       SubscriptBox["\[Theta]", "1"]}], "31"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    SubscriptBox["\[Theta]", "3"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "12"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "12"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "12"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "12"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "12"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "12"}]]}], "31"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"1717", " ", 
      SubscriptBox["\[Theta]", "1"]}], "31"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "13"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "13"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "13"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "13"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "13"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "13"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"1403", " ", 
       SubscriptBox["\[Theta]", "1"]}], "31"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    SubscriptBox["\[Theta]", "4"], "+", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "14"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "14"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "14"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "14"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "14"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "14"}]]}], "31"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"975", " ", 
      SubscriptBox["\[Theta]", "1"]}], "31"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    SubscriptBox["\[Theta]", "4"], "+", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "15"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "15"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "15"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "15"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "15"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "15"}]]}], "31"]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "+", 
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    SubscriptBox["\[Theta]", "4"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "16"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "16"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "16"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "16"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "16"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "16"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "17"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "17"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "17"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "17"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "17"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "17"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    SubscriptBox["\[Theta]", "2"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "18"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "18"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "18"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "18"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "18"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "18"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "19"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "19"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "19"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "19"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "19"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "19"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    SubscriptBox["\[Theta]", "2"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    SubscriptBox["\[Theta]", "4"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "20"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "20"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "20"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "20"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "20"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "20"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    SubscriptBox["\[Theta]", "4"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"168", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "21"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"19", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "21"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"350", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "21"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"12", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "21"}]]}], "31"], "-", 
    FractionBox[
     RowBox[{"164", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "21"}]]}], "31"], "+", 
    FractionBox[
     RowBox[{"188", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "21"}]]}], "31"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2151838744", " ", 
       SubscriptBox["\[Theta]", "1"]}], "2871685"]}], "-", 
    FractionBox[
     RowBox[{"597300443", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2871685"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "7"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "7"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "7"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "7"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "7"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "7"}]]}], "11842"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"94018772", " ", 
       SubscriptBox["\[Theta]", "1"]}], "574337"]}], "+", 
    FractionBox[
     RowBox[{"29837016", " ", 
      SubscriptBox["\[Theta]", "2"]}], "574337"], "-", 
    SubscriptBox["\[Theta]", "3"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "8"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "8"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "8"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "8"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "8"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "8"}]]}], "11842"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"102180707", " ", 
      SubscriptBox["\[Theta]", "1"]}], "2871685"], "-", 
    FractionBox[
     RowBox[{"1167527447", " ", 
      SubscriptBox["\[Theta]", "2"]}], "5743370"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "9"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "9"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "9"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "9"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "9"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "9"}]]}], "11842"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"1803658392", " ", 
      SubscriptBox["\[Theta]", "1"]}], "2871685"], "+", 
    FractionBox[
     RowBox[{"637496009", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2871685"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "10"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "10"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "10"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "10"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "10"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "10"}]]}], "11842"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"1697295537", " ", 
      SubscriptBox["\[Theta]", "1"]}], "2871685"], "+", 
    FractionBox[
     RowBox[{"1399428353", " ", 
      SubscriptBox["\[Theta]", "2"]}], "5743370"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "11"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "11"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "11"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "11"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "11"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "11"}]]}], "11842"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"1488498887", " ", 
       SubscriptBox["\[Theta]", "1"]}], "5743370"]}], "-", 
    FractionBox[
     RowBox[{"824558917", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2871685"], "+", 
    SubscriptBox["\[Theta]", "3"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "12"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "12"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "12"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "12"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "12"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "12"}]]}], "11842"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"1973152007", " ", 
      SubscriptBox["\[Theta]", "1"]}], "2871685"], "+", 
    FractionBox[
     RowBox[{"902563119", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2871685"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "13"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "13"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "13"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "13"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "13"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "13"}]]}], "11842"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3718698263", " ", 
       SubscriptBox["\[Theta]", "1"]}], "5743370"]}], "-", 
    FractionBox[
     RowBox[{"1122686261", " ", 
      SubscriptBox["\[Theta]", "2"]}], "5743370"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "14"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "14"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "14"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "14"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "14"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "14"}]]}], "11842"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"2782758953", " ", 
      SubscriptBox["\[Theta]", "1"]}], "5743370"], "+", 
    FractionBox[
     RowBox[{"539458413", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2871685"], "-", 
    SubscriptBox["\[Theta]", "3"], "-", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "15"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "15"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "15"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "15"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "15"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "15"}]]}], "11842"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"309373197", " ", 
      SubscriptBox["\[Theta]", "1"]}], "5743370"], "-", 
    FractionBox[
     RowBox[{"1340221", " ", 
      SubscriptBox["\[Theta]", "2"]}], "30070"], "+", 
    SubscriptBox["\[Theta]", "3"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "16"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "16"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "16"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "16"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "16"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "16"}]]}], "11842"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"257490263", " ", 
       SubscriptBox["\[Theta]", "1"]}], "5743370"]}], "-", 
    FractionBox[
     RowBox[{"503803673", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2871685"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "17"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "17"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "17"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "17"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "17"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "17"}]]}], "11842"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"345190269", " ", 
       SubscriptBox["\[Theta]", "1"]}], "5743370"]}], "-", 
    FractionBox[
     RowBox[{"966642913", " ", 
      SubscriptBox["\[Theta]", "2"]}], "5743370"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "18"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "18"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "18"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "18"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "18"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "18"}]]}], "11842"]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "-", 
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    SubscriptBox["\[Theta]", "5"], "-", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "19"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "19"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "19"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "19"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "19"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "19"}]]}], "11842"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    SubscriptBox["\[Theta]", "2"], "+", 
    SubscriptBox["\[Theta]", "3"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "20"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "20"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "20"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "20"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "20"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "20"}]]}], "11842"]}], ",", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"389606", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "21"}]]}], "5921"], "-", 
    FractionBox[
     RowBox[{"741507", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "21"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"442741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "21"}]]}], "5921"], "+", 
    FractionBox[
     RowBox[{"628829", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "21"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"290467", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "21"}]]}], "11842"], "-", 
    FractionBox[
     RowBox[{"138571", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "21"}]]}], "11842"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"25077184247587310023", " ", 
      SubscriptBox["\[Theta]", "1"]}], "548260313006840250"], "-", 
    FractionBox[
     RowBox[{"33998512421586169259", " ", 
      SubscriptBox["\[Theta]", "2"]}], "548260313006840250"], "+", 
    FractionBox[
     RowBox[{"36451666939537117", " ", 
      SubscriptBox["\[Theta]", "3"]}], "2260867270131300"], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "7"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "7"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "7"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "7"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "7"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "7"}]]}], "9917675"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"11357969230853603987", " ", 
      SubscriptBox["\[Theta]", "1"]}], "526329900486566640"], "-", 
    FractionBox[
     RowBox[{"6344245629961523153", " ", 
      SubscriptBox["\[Theta]", "2"]}], "263164950243283320"], "+", 
    FractionBox[
     RowBox[{"40021623464861941", " ", 
      SubscriptBox["\[Theta]", "3"]}], "27130407241575600"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "8"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "8"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "8"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "8"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "8"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "8"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"37172979990543126103", " ", 
       SubscriptBox["\[Theta]", "1"]}], "6579123756082083000"]}], "+", 
    FractionBox[
     RowBox[{"37520767112771584631", " ", 
      SubscriptBox["\[Theta]", "2"]}], "1644780939020520750"], "-", 
    FractionBox[
     RowBox[{"108989692767859451", " ", 
      SubscriptBox["\[Theta]", "3"]}], "13565203620787800"], "-", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "9"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "9"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "9"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "9"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "9"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "9"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"37741207070424435116", " ", 
       SubscriptBox["\[Theta]", "1"]}], "822390469510260375"]}], "+", 
    FractionBox[
     RowBox[{"38281832961896061313", " ", 
      SubscriptBox["\[Theta]", "2"]}], "822390469510260375"], "-", 
    FractionBox[
     RowBox[{"17374437552702019", " ", 
      SubscriptBox["\[Theta]", "3"]}], "6782601810393900"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "10"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "10"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "10"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "10"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "10"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "10"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"22715318500991197087", " ", 
       SubscriptBox["\[Theta]", "1"]}], "848919194333172000"]}], "+", 
    FractionBox[
     RowBox[{"458792875083381393163", " ", 
      SubscriptBox["\[Theta]", "2"]}], "13158247512164166000"], "-", 
    FractionBox[
     RowBox[{"718402633556778311", " ", 
      SubscriptBox["\[Theta]", "3"]}], "54260814483151200"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "11"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "11"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "11"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "11"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "11"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "11"}]]}], "9917675"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"31315249022673978987", " ", 
      SubscriptBox["\[Theta]", "1"]}], "1462027501351574000"], "-", 
    FractionBox[
     RowBox[{"21572588446846038253", " ", 
      SubscriptBox["\[Theta]", "2"]}], "731013750675787000"], "+", 
    FractionBox[
     RowBox[{"8302699628304053", " ", 
      SubscriptBox["\[Theta]", "3"]}], "602897938701680"], "+", 
    SubscriptBox["\[Theta]", "4"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "12"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "12"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "12"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "12"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "12"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "12"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"568845773855755168511", " ", 
       SubscriptBox["\[Theta]", "1"]}], "13158247512164166000"]}], "+", 
    FractionBox[
     RowBox[{"391991556636621777569", " ", 
      SubscriptBox["\[Theta]", "2"]}], "6579123756082083000"], "-", 
    FractionBox[
     RowBox[{"530006399421567457", " ", 
      SubscriptBox["\[Theta]", "3"]}], "27130407241575600"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "13"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "13"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "13"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "13"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "13"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "13"}]]}], "9917675"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"471034094734436409499", " ", 
      SubscriptBox["\[Theta]", "1"]}], "26316495024328332000"], "-", 
    FractionBox[
     RowBox[{"385318591607614853161", " ", 
      SubscriptBox["\[Theta]", "2"]}], "13158247512164166000"], "+", 
    FractionBox[
     RowBox[{"579396163534113437", " ", 
      SubscriptBox["\[Theta]", "3"]}], "54260814483151200"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    SubscriptBox["\[Theta]", "5"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "14"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "14"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "14"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "14"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "14"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "14"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"24028507178731848139", " ", 
       SubscriptBox["\[Theta]", "1"]}], "4386082504054722000"]}], "+", 
    FractionBox[
     RowBox[{"48366250766914011841", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2193041252027361000"], "-", 
    FractionBox[
     RowBox[{"118062946068217901", " ", 
      SubscriptBox["\[Theta]", "3"]}], "9043469080525200"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    SubscriptBox["\[Theta]", "5"], "+", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "15"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "15"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "15"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "15"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "15"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "15"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"74014195705436634481", " ", 
       SubscriptBox["\[Theta]", "1"]}], "4386082504054722000"]}], "+", 
    FractionBox[
     RowBox[{"70804531789168815529", " ", 
      SubscriptBox["\[Theta]", "2"]}], "2193041252027361000"], "-", 
    FractionBox[
     RowBox[{"62464524256696091", " ", 
      SubscriptBox["\[Theta]", "3"]}], "9043469080525200"], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "16"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "16"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "16"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "16"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "16"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "16"}]]}], "9917675"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"24575824122927674911", " ", 
      SubscriptBox["\[Theta]", "1"]}], "2924055002703148000"], "-", 
    FractionBox[
     RowBox[{"20310788723010578209", " ", 
      SubscriptBox["\[Theta]", "2"]}], "1462027501351574000"], "+", 
    FractionBox[
     RowBox[{"1139109193322329", " ", 
      SubscriptBox["\[Theta]", "3"]}], "241159175480672"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "17"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "17"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "17"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "17"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "17"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "17"}]]}], "9917675"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"15675289341352181297", " ", 
      SubscriptBox["\[Theta]", "1"]}], "26316495024328332000"], "-", 
    FractionBox[
     RowBox[{"38929176773020628723", " ", 
      SubscriptBox["\[Theta]", "2"]}], "13158247512164166000"], "+", 
    FractionBox[
     RowBox[{"258418907338099111", " ", 
      SubscriptBox["\[Theta]", "3"]}], "54260814483151200"], "-", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "18"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "18"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "18"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "18"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "18"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "18"}]]}], "9917675"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"317412642061839559", " ", 
      SubscriptBox["\[Theta]", "1"]}], "10852162896630240"], "-", 
    FractionBox[
     RowBox[{"21750717460036067", " ", 
      SubscriptBox["\[Theta]", "2"]}], "875174427147600"], "-", 
    FractionBox[
     RowBox[{"145171366700722159", " ", 
      SubscriptBox["\[Theta]", "3"]}], "54260814483151200"], "+", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "19"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "19"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "19"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "19"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "19"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "19"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "4"]}], "+", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "20"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "20"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "20"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "20"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "20"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "20"}]]}], "9917675"]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    SubscriptBox["\[Theta]", "2"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "4"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "-", 
    FractionBox[
     RowBox[{"2519269", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "21"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"74119593", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "21"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"255715863", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "21"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"326927741", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "21"}]]}], "19835350"], "+", 
    FractionBox[
     RowBox[{"1385045719", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "21"}]]}], "39670700"], "-", 
    FractionBox[
     RowBox[{"351716058", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "21"}]]}], "9917675"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"13136388197371641210823301776353998633105056931179559", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "42482205707719849856582583142541078119743122616750"], "-", 
    FractionBox[
     RowBox[{"248981141995847884584050685441683047042799398616149", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "14160735235906616618860861047513692706581040872250"], "+", 
    FractionBox[
     RowBox[{"722467152334818929254591375924002956659270819681", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "29197392238982714678063631025801428260991836850"], "-", 
    FractionBox[
     RowBox[{"75694335242971786818417974810784784759", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "7"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "7"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "7"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "7"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "7"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "7"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"101283989072755121696765341240340366614249482328789", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "1699288228308793994263303325701643124789724904670"], "-", 
    FractionBox[
     RowBox[{"275024535429869062270809538426311610539013823381", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "4448398503426162288647390904978123363323887185"], "+", 
    FractionBox[
     RowBox[{"349206468568759404840145087612462403664235846336", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "43796088358474072017095446538702142391487755275"], "-", 
    FractionBox[
     RowBox[{"1433472003329760893292538181411380855", " ", 
      SubscriptBox["\[Theta]", "4"]}], "53645770790290801577180221214001373"],
     "-", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "8"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "8"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "8"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "8"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "8"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "8"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"27745681061424937861324123982295272272889215725311", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "2360122539317769436476810174585615451096840145375"], "+", 
    FractionBox[
     RowBox[{"2415543267108167735193397501031405404727264210555383", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "21241102853859924928291291571270539059871561308375"], "+", 
    FractionBox[
     RowBox[{"1496852058955021407102913621614638766578766827041", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "87592176716948144034190893077404284782975510550"], "+", 
    FractionBox[
     RowBox[{"41952942309831559693837564324315031419", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "9"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "9"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "9"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "9"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "9"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "9"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"12532316737521244024322837171470781865614780790964327", " ", 
       SubscriptBox["\[Theta]", "1"]}], 
      "42482205707719849856582583142541078119743122616750"]}], "-", 
    FractionBox[
     RowBox[{"658167939378599600666647059174018525869448485435539", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "42482205707719849856582583142541078119743122616750"], "-", 
    FractionBox[
     RowBox[{"1799697324412564981142642346054034342402634887667", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "87592176716948144034190893077404284782975510550"], "+", 
    FractionBox[
     RowBox[{"7768615884367434026186320384005556843", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "321874624741744809463081327284008238"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "10"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "10"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "10"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "10"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "10"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "10"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"11380180559554509663476694066080459887518414042308387", " ", 
       SubscriptBox["\[Theta]", "1"]}], 
      "42482205707719849856582583142541078119743122616750"]}], "+", 
    FractionBox[
     RowBox[{"129302207417515307236722039306860593610514968714173", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "21241102853859924928291291571270539059871561308375"], "-", 
    FractionBox[
     RowBox[{"5323472586392937326455167726018369046068521692631", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "87592176716948144034190893077404284782975510550"], "+", 
    FractionBox[
     RowBox[{"21461575240360621917659998352241767243", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "11"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "11"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "11"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "11"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "11"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "11"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"137902574837664285620669652012365686090130715667691", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "1268125543514025368853211437090778451335615600500"], "+", 
    FractionBox[
     RowBox[{"1492037051315967829880956720253076888744606170115869", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "14160735235906616618860861047513692706581040872250"], "+", 
    FractionBox[
     RowBox[{"229914486776647033471181066580784073540600293351", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "11678956895593085871225452410320571304396734740"], "-", 
    FractionBox[
     RowBox[{"34749770703934648897931203629239242247", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "12"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "12"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "12"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "12"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "12"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "12"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"8698074194913345192568056726266861064329531257856183", " ", 
       SubscriptBox["\[Theta]", "1"]}], 
      "28321470471813233237721722095027385413162081744500"]}], "-", 
    FractionBox[
     RowBox[{"499726894506585109615616378786470224046947526362602", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "21241102853859924928291291571270539059871561308375"], "-", 
    FractionBox[
     RowBox[{"10291196365596862965583319563749768792135237295813", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "175184353433896288068381786154808569565951021100"], "+", 
    FractionBox[
     RowBox[{"41498017746124918720474611353384045437", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "+", 
    SubscriptBox["\[Theta]", "5"], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "13"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "13"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "13"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "13"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "13"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "13"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"19660337122526492158525038266658972510272050602609583", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "84964411415439699713165166285082156239486245233500"], "+", 
    FractionBox[
     RowBox[{"1223858285299907317630631432081410419243858881800244", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "21241102853859924928291291571270539059871561308375"], "+", 
    FractionBox[
     RowBox[{"2619471065843567250722888772919599311705172038779", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "175184353433896288068381786154808569565951021100"], "-", 
    FractionBox[
     RowBox[{"50451221573723355479699625278704104659", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "14"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "14"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "14"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "14"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "14"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "14"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"4912636437826254882392142860949144414632068705636882", " ", 
       SubscriptBox["\[Theta]", "1"]}], 
      "21241102853859924928291291571270539059871561308375"]}], "+", 
    FractionBox[
     RowBox[{"1457958151870083788551770249630479721099077149274", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "2360122539317769436476810174585615451096840145375"], "-", 
    FractionBox[
     RowBox[{"165421629416655265392477553160605681427089727157", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "4866232039830452446343938504300238043498639475"], "+", 
    FractionBox[
     RowBox[{"206559336797938648866278841120699649", " ", 
      SubscriptBox["\[Theta]", "4"]}], "14412296630227379528197671370925742"],
     "+", 
    SubscriptBox["\[Theta]", "5"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "15"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "15"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "15"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "15"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "15"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "15"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2669282134599043823926801723849098074846129170852087", " ", 
       SubscriptBox["\[Theta]", "1"]}], 
      "84964411415439699713165166285082156239486245233500"]}], "+", 
    FractionBox[
     RowBox[{"165613798067419968140403277320653084727611609961656", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "2360122539317769436476810174585615451096840145375"], "-", 
    FractionBox[
     RowBox[{"105412595732370382306164377747829435478872654373", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "19464928159321809785375754017200952173994557900"], "+", 
    FractionBox[
     RowBox[{"27823335212427234795669203644057288609", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "16"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "16"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "16"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "16"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "16"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "16"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"692910526468050068326731982451317066353204350193637", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "9440490157271077745907240698342461804387360581500"], "+", 
    FractionBox[
     RowBox[{"21316133678185002862499654820295223049689532726736", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "2360122539317769436476810174585615451096840145375"], "+", 
    FractionBox[
     RowBox[{"26486279632323180070196439926613957223918385651", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "778597126372872391415030160688038086959782316"], "+", 
    FractionBox[
     RowBox[{"138648910911648196738335306436311247", " ", 
      SubscriptBox["\[Theta]", "4"]}], "53645770790290801577180221214001373"],
     "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "17"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "17"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "17"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "17"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "17"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "17"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"319867238361982990053534286695425514972150812424533", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "28321470471813233237721722095027385413162081744500"], "+", 
    FractionBox[
     RowBox[{"2134838025373941392139048946947767150216621363698192", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "21241102853859924928291291571270539059871561308375"], "-", 
    FractionBox[
     RowBox[{"2681245382714217957510801370174575334276174876213", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "175184353433896288068381786154808569565951021100"], "-", 
    FractionBox[
     RowBox[{"36006289391744327990417682787239489797", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "965623874225234428389243981852024714"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "18"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "18"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "18"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "18"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "18"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "18"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"924143399114040659844343776173074032436565604053", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "35036870686779257613676357230961713913190204220"], "-", 
    FractionBox[
     RowBox[{"1990672090020284457199527167854892782119485861492", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "43796088358474072017095446538702142391487755275"], "-", 
    FractionBox[
     RowBox[{"440020424594826158489010317573635569604404214853", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "175184353433896288068381786154808569565951021100"], "-", 
    FractionBox[
     RowBox[{"8006722978239892876882631549697349969", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "321874624741744809463081327284008238"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "19"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "19"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "19"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "19"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "19"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "19"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2620980599507535591", " ", 
       SubscriptBox["\[Theta]", "1"]}], "71807225876721766"]}], "+", 
    FractionBox[
     RowBox[{"1562142955905688948", " ", 
      SubscriptBox["\[Theta]", "2"]}], "35903612938360883"], "+", 
    SubscriptBox["\[Theta]", "3"], "-", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "20"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "20"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "20"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "20"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "20"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "20"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    SubscriptBox["\[Theta]", "2"], "-", 
    SubscriptBox["\[Theta]", "3"], "+", 
    SubscriptBox["\[Theta]", "4"], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "5"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{"541989215864135139526537", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "21"}]]}], "22972926738610210987550"], "+", 
    FractionBox[
     RowBox[{"27264367993690754222250933", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "21"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"10767874390348697153398131", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "21"}]]}], "712160728896916540614050"], "-", 
    FractionBox[
     RowBox[{"7554184398282186878548679", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "21"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"21846991272386070866819407", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "21"}]]}], "356080364448458270307025"], "+", 
    FractionBox[
     RowBox[{"1528598533712637368054733", " ", 
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "21"}]]}], "712160728896916540614050"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22367098400300345925317664258872374153297198561319344230380070054013492\
601467681156131011630477558960671101259125718668752337334", " ", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
     "880972155974820368207258076229286626122380271526487858532770656823070345\
55218340028826026918307039668820685888126298700158955"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "37101403130035410438639341812164256975712901973944478174743007663483921\
6356333326940092461065032865275105009057336821292057728", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "978857951083133742452508973588096251247089190584986509480856285358967050\
6135371114314002990923004407646742876458477633350995"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11029211434974623551021376053728666022500263372516007095903951925718895\
6880617972345224269672112237646575407640098598416943", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "201826381666625513907733808987236340463317358883502373088836347496694237\
23990455905802068022521658572467511085481397182167"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "66297447321562505456504595257202102166611950085738175746393474441132726\
4603770707377150756170741584770854570425284", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28501380013833557917719622089852422539635355266408804470658731663136982\
05409023", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "7"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "7"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "7"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "7"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "7"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "7"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12646728738197378935114529697647152521815757441226552386375994785809138\
9942504491156706900924930237830149096408710923549951414", " ", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
     "238100582695897396812772453034942331384427100412564286089938015357586579\
8789684865643946673467757828887045564543954018923215"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "61755825814092351954462137239745183602707816639796733039918742253331609\
631115249152614393791867977585539804721150024695945513", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "238100582695897396812772453034942331384427100412564286089938015357586579\
8789684865643946673467757828887045564543954018923215"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13674059759746712859311677809778663183272950415946873200710647852606201\
019988832718192382650199667391728724031700495408049", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "490929036486386385180974129968953260586447629716627393999872196613580577\
0700381166276178708180943977086691885657637152419"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "72517780944626875080723125658462152650081424067454324100168067990752409\
7119491367502985062663348290105830094411", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "150334582109724016089315875379087660009076826175036764469501943361447315\
021489529377016102920477270521137950717"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14816220859927574319891594053073548419569826035684984643244667861095836\
262017", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "140117832118960487358383365337086191588114017509962452712036802073243253\
16645"}], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "8"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "8"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "8"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "8"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "8"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "8"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1083989194769488862755144828672361886488755315176220821593092162048370\
090288212892937472955411217940979171948435130450703144949", " ", 
        SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57285723182219197185996859300571035977739538659656675309423516633020519\
72151885008908483452704962793446178917887319361234869433", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "880972155974820368207258076229286626122380271526487858532770656823070345\
55218340028826026918307039668820685888126298700158955"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "49444557227907362234065769041749811221606139195917838599760804814034344\
7831048753909500078267419381454572955219190460619", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "271110064925317854502926012072407024502963616410674829522317481711977333\
6058419450033113614965595927644889548796008576709"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17351862061225461261056561103317654167190371467137607461135429066526536\
3183147322911296987221225689248799113393094", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28270813882795052178345603926333933625991621702268811247491726715268532\
3394497", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "+", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "9"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "9"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "9"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "9"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "9"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "9"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1906535941022016792091924818820011113826128227215183574380837875894264\
6251897001455589722397823520755092795507454393548366235343", " ", 
        SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21394852928271320800271188349174603251342820620593869643632074807576815\
8265463840245484296585496756494955210257355661383527572", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "518218915279306098945445927193698015366106042074404622666335680484159026\
7954020001695648642253355274636510934595664629421115"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15305398863662593518531943251280162297699726509525675651683931131813965\
9515753903633797986219949701386041157116023381037884", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "181643743499962962516960428088512706416985622995152135779952712747024813\
515914103152218612202694927152207599769332574639503"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "75695899338792010833607932580440189350214065946824454868511487198157722\
091185743113398026444977830731570707059808", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "166871386141793657859140621670787302610075277054290808561147157131206519\
67385337760848787424172977027846312529587"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11202905813333700273145678010569445093863246060170189566333866038930292\
10969771", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "10"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "10"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "10"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "10"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "10"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "10"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "3739660960716235266774665121165886106124283928477030458464610438458180\
160455899241896431843857921730070931090440826161427322659", " ", 
        SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
      "19577159021662674849050179471761925024941783811699730189617125707179341\
012270742228628005981846008815293485752916955266701990"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "39971462867387610118935977117416077652528145479187538335813662436233944\
09836534106554318431305409825997417055883877199490277869", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "880972155974820368207258076229286626122380271526487858532770656823070345\
55218340028826026918307039668820685888126298700158955"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "36525790134428412795806082480870497654410222659143700460483429443921692\
65854090936948453009584019342115884887371611623459449", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "363287486999925925033920856177025412833971245990304271559905425494049627\
031828206304437224405389854304415199538665149279006"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14544006371301101811526959777379787929715101831768251401489517434571560\
4966117550860728247963089758955422166241586", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13192155907942870212425783598618980170191575672307086883344646730951846\
55331156", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "+", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "11"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "11"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "11"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "11"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "11"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "11"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "79051205994769959399163890472052598859878565905640055471374573475644394\
12104396284988284292426577315900062253596720012143673862", " ", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
     "880972155974820368207258076229286626122380271526487858532770656823070345\
55218340028826026918307039668820685888126298700158955"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19206791183411455049607909863629880724867892509965277082990714429271344\
48121261246893355271887360425660471866074517346600677067", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "293657385324940122735752692076428875374126757175495952844256885607690115\
18406113342942008972769013222940228629375432900052985"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "36232289837063260166146539744665356106324272761947075514659241263756171\
4398022755537087600670023429235395170402381278227519", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "605479144999876541723201426961709021389952076650507119266509042490082711\
71971367717406204067564975717402533256444191546501"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10615869596864926826203531078137400376834595260407851918525342596995591\
4423525209577518408294844197484552975152466", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "65508889649917452826977441586358523678025743051269530249490781865869276\
7356716", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "12"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "12"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "12"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "12"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "12"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "12"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "4091400729875791592235057504522108724171233824885565283132445767603090\
170432801316773604333209099303436196369073355024480046650", " ", 
        SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
      "17619443119496407364145161524585732522447605430529757170655413136461406\
911043668005765205383661407933764137177625259740031791"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10930744740864569162961101085593026985635584968043552561854052139301634\
29225204906083022581447045546299122980145016589370356595", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "176194431194964073641451615245857325224476054305297571706554131364614069\
11043668005765205383661407933764137177625259740031791"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19157712536283275936394116269033046005818296580287518138377965232863773\
74297224310853505114945694671946606576889795806926777", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "181643743499962962516960428088512706416985622995152135779952712747024813\
515914103152218612202694927152207599769332574639503"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "44783727934977490243150577568951098426853350498370491202422211618438494\
5467570570128279289940008744034625618016055", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23161777894078020536833549733443315021689091315322785726810500575513647\
6095869", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "103687195768030760645203690349443781775204372957372215006907233534200007\
343173"}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "13"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "13"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "13"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "13"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "13"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "13"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23742904243473840890018584773047684545265879181936033860335224572246636\
39458207009755425372535924399182463689444215507651368235", " ", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
     "117462954129976049094301076830571550149650702870198381137702754243076046\
07362445337176803589107605289176091451750173160021194"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "75874960080616868378278039635894675250663051700897375946584493230364558\
6618959401059794967375929927997462794242206026901159536", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "176194431194964073641451615245857325224476054305297571706554131364614069\
11043668005765205383661407933764137177625259740031791"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17453451802234413391007502963591069767368294082170486595750796264039712\
84362523102234943785238381451796330730354670477567247", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "363287486999925925033920856177025412833971245990304271559905425494049627\
031828206304437224405389854304415199538665149279006"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23174857022885767625582546078247727884414329816558171879791656068559830\
869760972345736754430262074178840955924048", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "99416397011492657371465821202965796100340759283123836651137187349105798\
512733", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "103687195768030760645203690349443781775204372957372215006907233534200007\
343173"}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "14"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "14"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "14"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "14"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "14"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "14"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1320476292107214495232379425718798437184794443317590445813042651898577\
1423118954969111715030041178935767456602059999803632085221", " ", 
        SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12735376535714920863250536385866732398277108374870653815653274891780531\
00385891830107632200968167489949907436118080529683330831", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "293657385324940122735752692076428875374126757175495952844256885607690115\
18406113342942008972769013222940228629375432900052985"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "43617861550157331420000776574383963344379226210447674655772111780427496\
7066861472880794333055929177238834352709125117510052", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "605479144999876541723201426961709021389952076650507119266509042490082711\
71971367717406204067564975717402533256444191546501"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22697233619387705984009458718418637037454594981256820939546002585735395\
86336684330314924191284893925846199108274", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "747185311082658169518540097033375981836157956959511083109614136408387401\
524716616157408392127148225127446829683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57269782555699590927672237001521377061838442199040170863670358741004164\
8452717", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "15"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "15"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "15"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "15"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "15"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "15"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1749310594499604135159050749484400354154386450352569640838405229950572\
853158507053094147294951535998720820202850312030524423034", " ", 
        SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
      "88097215597482036820725807622928662612238027152648785853277065682307034\
555218340028826026918307039668820685888126298700158955"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "80465874972842613444694844573817557305451101553977219570551205929063663\
9475336131833815083086955293939893552313279352347521871", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "293657385324940122735752692076428875374126757175495952844256885607690115\
18406113342942008972769013222940228629375432900052985"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "26349184689324165539450153681554969139033140004504177374573766538379716\
3754138517512995229723398063875084012472681198773768", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "605479144999876541723201426961709021389952076650507119266509042490082711\
71971367717406204067564975717402533256444191546501"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "26200219948153261039593098073887140519259177078788602651499145154157404\
0211054021167873417489164749052024401475711", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67587870456161667833231349501043342810378920432996135554631570145661318\
4081767", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "16"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "16"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "16"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "16"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "16"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "16"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17340892303702919496289506210591154102196318267287547191669363748310765\
4350796250145099857339361098208917413613733775572118491", " ", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
     "195771590216626748490501794717619250249417838116997301896171257071793410\
12270742228628005981846008815293485752916955266701990"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30373369705680486146603259761761007567882119030660403791168830294864373\
5355496055244524969502713887516179118090966792558459614", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "978857951083133742452508973588096251247089190584986509480856285358967050\
6135371114314002990923004407646742876458477633350995"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29647157557300437471759630242741481732147777379564621755268583280171977\
9770429857317982434181677326184308227810641041441163", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "403652763333251027815467617974472680926634717767004746177672694993388474\
47980911811604136045043317144935022170962794364334"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "94345436069250418916614025100409283611067876742327674752717290470323046\
045584215697277470314515485126120015683262", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "556237953805978859530468738902624342033584256847636028537157190437355065\
5795112586949595808057659009282104176529"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28981665945312783834723851562145268547722354380890069849819257064004400\
77183111", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "17"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "17"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "17"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "17"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "17"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "17"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18360141090676564309618786557253057213739650529387101712150146748446695\
56224139692359954731441528723625660968964917308378139849", " ", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
     "176194431194964073641451615245857325224476054305297571706554131364614069\
110436680057652053836614079337641371776252597400317910"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35412960736186486411570129728056066252679721734583488710043356575666122\
55830163934361257000032101435752062448220273806479777586", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "880972155974820368207258076229286626122380271526487858532770656823070345\
55218340028826026918307039668820685888126298700158955"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12828730984722526827943159684010717469457075405047001583158990643732902\
50964303947564008005421879817572275497531153538516385", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "363287486999925925033920856177025412833971245990304271559905425494049627\
031828206304437224405389854304415199538665149279006"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "62992816704394396411308856286216626225879510460072138719323910065145202\
8972461939966075783393379034740723907052721", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "500614158425380973577421865012361907830225831162872425683441471393619559\
02156013282546362272518931083538937588761"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14187417777278067628518728279931994528329012941445025587358281182882343\
31393891", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "18"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "18"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "18"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "18"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "18"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "18"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28600000926565916537621090315648839464004289149847600314211562620726749\
082299072043436492484481668181470616163729454878473867", " ", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], "/", 
     "181643743499962962516960428088512706416985622995152135779952712747024813\
5159141031522186122026949271522075997693325746395030"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "83270304343526736057915323570033728313828748498563646717207476269432621\
95628460660272189934622792940073080267403821424529812", " ", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], "/", 
     "908218717499814812584802140442563532084928114975760678899763563735124067\
579570515761093061013474635761037998846662873197515"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12173420691128478569827880262906508184388036854725011849910032607462255\
60600773409262565437643709790292099487216997116088789", " ", 
       SubscriptBox["\[Theta]", "3"]}], ")"}], "/", 
     "363287486999925925033920856177025412833971245990304271559905425494049627\
031828206304437224405389854304415199538665149279006"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "85612361160875222230042036562648161118695421132281137559562783988946493\
802857649291306897831672825725650055867620", " ", 
       SubscriptBox["\[Theta]", "4"]}], ")"}], "/", 
     "166871386141793657859140621670787302610075277054290808561147157131206519\
67385337760848787424172977027846312529587"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12070156095283208450354193155378522370676562804668326143144181903344387\
9890249", " ", 
       SubscriptBox["\[Theta]", "5"]}], ")"}], "/", 
     "518435978840153803226018451747218908876021864786861075034536167671000036\
715865"}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "6"]}], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "19"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "19"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "19"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "19"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "19"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "19"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    FractionBox[
     RowBox[{
     "1580099930280280389033998412890063686415524530222602455870", " ", 
      SubscriptBox["\[Theta]", "1"]}], 
     "599075185039051028278524647994842476705763942065493411111"], "+", 
    FractionBox[
     RowBox[{
     "2455800677995987688781585355510669923876422406620898103161", " ", 
      SubscriptBox["\[Theta]", "2"]}], 
     "599075185039051028278524647994842476705763942065493411111"], "+", 
    FractionBox[
     RowBox[{"9332171830671344038949541371901563104401", " ", 
      SubscriptBox["\[Theta]", "3"]}], 
     "16685651833077074272130409245230517926717"], "+", 
    FractionBox[
     RowBox[{"78147443830728476137017011219051786032917", " ", 
      SubscriptBox["\[Theta]", "4"]}], 
     "16685651833077074272130409245230517926717"], "-", 
    SubscriptBox["\[Theta]", "5"], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "20"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "20"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "20"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "20"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "20"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "20"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}], 
   ",", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "2"]}], "-", 
    RowBox[{"3", " ", 
     SubscriptBox["\[Theta]", "3"]}], "-", 
    SubscriptBox["\[Theta]", "4"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Theta]", "5"]}], "-", 
    SubscriptBox["\[Theta]", "6"], "+", 
    FractionBox[
     RowBox[{
     "4748657623892575817997120047370739086176978276303498906218469773", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"1", ",", "21"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "4295108485672579915654723944314572940558550690459089133362594971", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"2", ",", "21"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "1987882814411166716131567132955222181284798959022542162615216335", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"3", ",", "21"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "1979475491988901194906839137107405617058505767641371357684423315", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"4", ",", "21"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "+", 
    
    FractionBox[
     RowBox[{
     "5479269388163636820184852019402344966788417373015826570753227843", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"5", ",", "21"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"], "-", 
    
    FractionBox[
     RowBox[{
     "3430555528508198913072810913956975766329368845156219241065422150", " ", 
      
      SubscriptBox["\[Omega]", 
       RowBox[{"6", ",", "21"}]]}], 
     "237657319431286816275288677532089974406513496164975694641611477"]}]}], 
  "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "allones", "]"}]], "Input"],

Cell[BoxData["105"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The procedure ",
 StyleBox["check", "Input",
  FontWeight->"Plain"],
 " first constructs an arbitrary linear combination of ",
 StyleBox["involutoryvectors", "Input",
  FontWeight->"Plain"],
 ", called ",
 StyleBox["genvec", "Input",
  FontWeight->"Plain"],
 ". It then contracts ",
 StyleBox["genvec", "Input",
  FontWeight->"Plain"],
 " on ",
 StyleBox["allones", "Input",
  FontWeight->"Plain"],
 ", which must give zero for each of them. The list ",
 StyleBox["invset", "Input",
  FontWeight->"Plain"],
 " contains the involutory vector components; i.e., the leftmost non-zero \
components. Any of the original ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " which do not appear in the ideal are obviously either Cauchy \
characteristics or basis oneforms that were deliberately omitted. They are in \
the variable ",
 StyleBox["absentforms", "Input",
  FontWeight->"Plain"],
 ". The routine ",
 StyleBox["cauchys", "Input",
  FontWeight->"Plain"],
 " attempts to find other potential Cauchy characteristics which annul the ",
 StyleBox["oneforms", "Input",
  FontWeight->"Plain"],
 " and ",
 StyleBox["twoforms", "Input",
  FontWeight->"Plain"],
 ", but does not investigate any higher degree forms."
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["check"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["genvec"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["V", "1"], ",", 
   SubscriptBox["V", "2"], ",", 
   SubscriptBox["V", "3"], ",", 
   SubscriptBox["V", "4"], ",", 
   SubscriptBox["V", "5"], ",", 
   SubscriptBox["V", "6"], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14265793546682859044885219924529549443248904885137546065423868503392206\
826416982691642175636537963336075890082764527094499959228446371333913569", 
       " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "208972707255506608441410536958641846599102481849726556893293642882935509\
1028559488901522915325013384879658883784310330378798593116551177353680"}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25551974817025316277385335422720382867900735246147450891344796300126667\
8377615220677599966767460975084808155052221926368652417507289957658734", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "145119935594101811417646206221279060138265612395643442287009474224260770\
21031663117371686911979259617219853359613266183186101341087160953845"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "52803444546168197402516357124638172810081412615315797283139284428003651\
0469223837816130447431646632524678596494835573439654727887926775033", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "119686544819877782612491716471157987742899474140736859618152143690111975\
431188974163890201335911419523462708120521782954112176008966275908"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "82943625596175169797528040295830903650589320884493407229565595806472620\
69746511074147204255006008694561463670803301958656800849634105", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24708869196260093045838088389076356515550317723371140747584733334750504\
98326312624451797438468972835229950593343521", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
283027612594107406465671496688984301168090"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11231849643633589882956813804186548145590185018227950079838129317774970\
51616491", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25551974817025316277385335422720382867900735246147450891344796300126667\
8377615220677599966767460975084808155052221926368652417507289957658734", " ", 
       
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "145119935594101811417646206221279060138265612395643442287009474224260770\
21031663117371686911979259617219853359613266183186101341087160953845"}], "+", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11160564013138785017682403241857994113635318227920578968821355690381362\
39211948034831808844179641327308587382308795167125153616279205076036092", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "435359806782305434252938618663837180414796837186930326861028422672782310\
63094989352115060735937778851659560078839798549558304023261482861535"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11369061394690427069659685569831153208655641775224648533784963660285598\
00199712686529915305862876484944776088074612248305780222653969627991", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "179529817229816673918737574706736981614349211211105289427228215535167963\
146783461245835302003867129285194062180782674431168264013449413862"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "43876791774462090306253755319871588613713493841932222425440211572369156\
0494223791746016873656197395953864084176009936236270025862951", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13909638427910533103412182185981754138399537535520213293327077361632396\
31102373713878860952774375911754890657803874", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15816383863359366040988862724880237273677704969553717072647771350508574\
7321329", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "5280344454616819740251635712463817281008141261531579728313928442800365\
10469223837816130447431646632524678596494835573439654727887926775033", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "11968654481987778261249171647115798774289947414073685961815214369011197\
5431188974163890201335911419523462708120521782954112176008966275908"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11369061394690427069659685569831153208655641775224648533784963660285598\
00199712686529915305862876484944776088074612248305780222653969627991", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "179529817229816673918737574706736981614349211211105289427228215535167963\
146783461245835302003867129285194062180782674431168264013449413862"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "46982738560437415780156244297950229262281881769917495831725171259685475\
6479987026635651618442330880971642273847150099273167619678423130857", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "359059634459633347837475149413473963228698422422210578854456431070335926\
293566922491670604007734258570388124361565348862336528026898827724"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "51658409257766915057477779204508515552813270103155515638790304403884102\
231951574295959338625386319292440853579943947162335255251550", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12488124884713111410870875660675826173970607704682033108086236031095734\
9823697173551434211572382527238589451703713", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "37218922930724221504899854540351977220756651481278501793832282098033298\
019527", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "82943625596175169797528040295830903650589320884493407229565595806472620\
69746511074147204255006008694561463670803301958656800849634105", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "43876791774462090306253755319871588613713493841932222425440211572369156\
0494223791746016873656197395953864084176009936236270025862951", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "51658409257766915057477779204508515552813270103155515638790304403884102\
231951574295959338625386319292440853579943947162335255251550", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18902508337850491131074819488680696622472935503248370254465371163963397\
968377595014003457081882649429800173872630556735678289598231049", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "54361368063265193788336341452123770536044621228668580398639711773597788\
7802605004606768647836281488949852610858496", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24126186563261205044996698779465330445073320959574373929891438031543607\
82452707", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2470886919626009304583808838907635651555031772337114074758473333475050\
498326312624451797438468972835229950593343521", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
4283027612594107406465671496688984301168090"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13909638427910533103412182185981754138399537535520213293327077361632396\
31102373713878860952774375911754890657803874", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12488124884713111410870875660675826173970607704682033108086236031095734\
9823697173551434211572382527238589451703713", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "54361368063265193788336341452123770536044621228668580398639711773597788\
7802605004606768647836281488949852610858496", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "50559193808761284882761342727113221387086927804461014208337542097598679\
8082476266986446095518220930149568995012432", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30802812797464893677286469784490796091837207124839476577994610907760940\
771537", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11231849643633589882956813804186548145590185018227950079838129317774970\
51616491", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15816383863359366040988862724880237273677704969553717072647771350508574\
7321329", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "37218922930724221504899854540351977220756651481278501793832282098033298\
019527", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24126186563261205044996698779465330445073320959574373929891438031543607\
82452707", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30802812797464893677286469784490796091837207124839476577994610907760940\
771537", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "80459631486493426224992095088005008116545146216393048433218422777053738\
5141105", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2930001464378851711301795989582934219941969361512383688223305931578010\
06722472462871712630850017622007370046761329928394717638236897423210301", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "28239555034527920059650072561978627918797632682395480661255897686883176\
905791344444615174531419099795671065997085274734848629636710151045320"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13845157989779270371261833842158104408876183188699783691169932364472947\
0396995342770889639925612657205548180155803224605120337192086690646529", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "141197775172639600298250362809893139593988163411977403306279488434415884\
52895672222307587265709549897835532998542637367424314818355075522660"}], "+", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10280945598982101794091655608531191941557152358144518973251150115946379\
2327414798635218239427352366714487185325755447461572058601837416233", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "582258866691297320817527269319146967397889333657638776520740158492436637\
23281122566216854703956906795198074220794380896595112653010620712"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15832136731525364485131871687980944766399610619683557999932961017446814\
29007497747637567719850690794575620817774415884497212246547", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "851392189478575445490195877025277228227497169995921007438432887533239668\
65284370379199546579854304347296107931967330785151458314"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14780285472886990758999260477303911220465593419283339352986380420626792\
431455652204965432677415628325661347757402", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "441605046662298622843785994649872220634565273055013970380204356215354438\
2203075845866316303590155360661950015785"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "61635636535283307154540352048864267950912176985631168646075199643256794\
188149", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1384515798977927037126183384215810440887618318869978369116993236447294\
70396995342770889639925612657205548180155803224605120337192086690646529", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "14119777517263960029825036280989313959398816341197740330627948843441588\
452895672222307587265709549897835532998542637367424314818355075522660"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "71776543974867551608578522970033057070832009607804308667578700904209979\
369210916048904940835021394128787414485939416764083977319482628913111", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "705988875863198001491251814049465697969940817059887016531397442172079422\
6447836111153793632854774948917766499271318683712157409177537761330"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "80811432083882035572635652608011541087687869770013692898471449599870176\
184832822869183104876273361131033548493688771511312044031644379785", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "291129433345648660408763634659573483698944666828819388260370079246218318\
61640561283108427351978453397599037110397190448297556326505310356"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "26040759628346943733044590025590791169704063964636294778706455197842903\
82664989608895136163799593869105683782130000950856467839323", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "127708828421786316823529381553791584234124575499388151115764933129985950\
297926555568799319869781456520944161897950996177727187471"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "66131560787183052059016250991979295929386904480302744781618799951031475\
474312360975607273707585094285771970168663", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "132481513998689586853135798394961666190369581916504191114061306864606331\
46609227537598948910770466081985850047355"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10651899421646792712256679930501490436800141852258920239156102055015957\
0557507", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10280945598982101794091655608531191941557152358144518973251150115946379\
2327414798635218239427352366714487185325755447461572058601837416233", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "582258866691297320817527269319146967397889333657638776520740158492436637\
23281122566216854703956906795198074220794380896595112653010620712"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "80811432083882035572635652608011541087687869770013692898471449599870176\
184832822869183104876273361131033548493688771511312044031644379785", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "291129433345648660408763634659573483698944666828819388260370079246218318\
61640561283108427351978453397599037110397190448297556326505310356"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "27368895572102234133185951976008269291583964461492236198372578519888697\
280901122250257253598064762438511744905195057381623275436352303453", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "582258866691297320817527269319146967397889333657638776520740158492436637\
23281122566216854703956906795198074220794380896595112653010620712"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "58932418710225101940533942256753878481245085565052376620685584820721500\
1872140170423261022173411645889760842221667601980380164274", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "127708828421786316823529381553791584234124575499388151115764933129985950\
297926555568799319869781456520944161897950996177727187471"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29419087005876625219282370609305218795374693972994310973151052016866737\
28508157397521735827248048342516934672798", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "264963027997379173706271596789923332380739163833008382228122613729212662\
9321845507519789782154093216397170009471"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22149600896642524969852864141934990223057906375410657577627378853413186\
156830", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1583213673152536448513187168798094476639961061968355799993296101744681\
429007497747637567719850690794575620817774415884497212246547", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "85139218947857544549019587702527722822749716999592100743843288753323966\
865284370379199546579854304347296107931967330785151458314"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "26040759628346943733044590025590791169704063964636294778706455197842903\
82664989608895136163799593869105683782130000950856467839323", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "127708828421786316823529381553791584234124575499388151115764933129985950\
297926555568799319869781456520944161897950996177727187471"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "58932418710225101940533942256753878481245085565052376620685584820721500\
1872140170423261022173411645889760842221667601980380164274", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "127708828421786316823529381553791584234124575499388151115764933129985950\
297926555568799319869781456520944161897950996177727187471"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10120123007197056405737276185054156074840347921088638223255912414688028\
851496672560223706999232846298112695880139345535494188330047", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "255417656843572633647058763107583168468249150998776302231529866259971900\
595853111137598639739562913041888323795901992355454374942"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21727598773125840198695491123993463057676712487219227854891705615193670\
452880063324425026148222863097390804743311", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "264963027997379173706271596789923332380739163833008382228122613729212662\
9321845507519789782154093216397170009471"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40925065028125013340490112423266996726194429762747693441850921665845945\
0445481", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14780285472886990758999260477303911220465593419283339352986380420626792\
431455652204965432677415628325661347757402", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "441605046662298622843785994649872220634565273055013970380204356215354438\
2203075845866316303590155360661950015785"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "66131560787183052059016250991979295929386904480302744781618799951031475\
474312360975607273707585094285771970168663", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "132481513998689586853135798394961666190369581916504191114061306864606331\
46609227537598948910770466081985850047355"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29419087005876625219282370609305218795374693972994310973151052016866737\
28508157397521735827248048342516934672798", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "264963027997379173706271596789923332380739163833008382228122613729212662\
9321845507519789782154093216397170009471"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21727598773125840198695491123993463057676712487219227854891705615193670\
452880063324425026148222863097390804743311", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "264963027997379173706271596789923332380739163833008382228122613729212662\
9321845507519789782154093216397170009471"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25331230460072343980848689041346378301613677746046592355594816099076644\
554290909381672703956947909322717157622739", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "132481513998689586853135798394961666190369581916504191114061306864606331\
46609227537598948910770466081985850047355"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "39866324441092455675815120861775872498056501861559720896488298687101976\
156247", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "6163563653528330715454035204886426795091217698563116864607519964325679\
4188149", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10651899421646792712256679930501490436800141852258920239156102055015957\
0557507", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22149600896642524969852864141934990223057906375410657577627378853413186\
156830", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40925065028125013340490112423266996726194429762747693441850921665845945\
0445481", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "39866324441092455675815120861775872498056501861559720896488298687101976\
156247", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13570387129316788127109253049580176866831965291670724312147601477325177\
7707151", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "72570199849196347999205673624903530349755658570625542374792764737182166\
15247435380271710027717883942132344439276779099158627251624576326572447", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "104486353627753304220705268479320923299551240924863278446646821441467754\
5514279744450761457662506692439829441892155165189399296558275588676840"}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15249530003898136736947679279412009715476310928677854892904689472998061\
0556033667152049477917213599842225866281048142549527674862823094620343", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "261215884069383260551763171198302308248878102312158196116617053603669386\
37856993611269036441562667310995736047303879129734982413956889716921"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "36927440126082730290082854542515599779982543865885035335170681963267980\
3579948963384014688194242242461555564733226662303272533180528300031", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "269294725844725010878106362060105472421523816816657934140842323302751944\
720175191868752953005800693927791093271174011646752396020174120793"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14183401264318336793226058317431385810590989423647756072279872876667390\
93688138745310811328554972075943321706608516810482887750331943", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "113405439638546249339294090819766926799902623043456678190799260619427523\
864558781345093796044365933390598415765380484605821742474248"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "86671442743959122047790695442780694572079011617132998996626738263944134\
0400238044100100267250596382684475101943629", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
283027612594107406465671496688984301168090"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16085270326162864504316291691861580016031843862632195252174660381664030\
0633665", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15249530003898136736947679279412009715476310928677854892904689472998061\
0556033667152049477917213599842225866281048142549527674862823094620343", " ", 
       
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "261215884069383260551763171198302308248878102312158196116617053603669386\
37856993611269036441562667310995736047303879129734982413956889716921"}], "+", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "82611300276971851454233597317608060784903729981128083634462586330592324\
1566815126717538419051504142945773020835863068873589557481275170909926", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "130607942034691630275881585599151154124439051156079098058308526801834693\
189284968056345182207813336554978680236519395648674912069784448584605"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67686873093168815358909028728012599490054758799192390454124856599515639\
2727210749128621062990467140113938521011273918621968442818972134450", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "269294725844725010878106362060105472421523816816657934140842323302751944\
720175191868752953005800693927791093271174011646752396020174120793"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67023484642673304033211022588861826807094166686958747090201295678723159\
460577609196877582324445174473012114255253648231020106734978", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19219909189280270942798829931666706726259484773135216905187591805988391\
73762305859049062402839219149829300546643358", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "72592781646256041423700722597620314927851208158289744259184321363537688\
243255", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "3692744012608273029008285454251559977998254386588503533517068196326798\
03579948963384014688194242242461555564733226662303272533180528300031", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "26929472584472501087810636206010547242152381681665793414084232330275194\
4720175191868752953005800693927791093271174011646752396020174120793"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67686873093168815358909028728012599490054758799192390454124856599515639\
2727210749128621062990467140113938521011273918621968442818972134450", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "269294725844725010878106362060105472421523816816657934140842323302751944\
720175191868752953005800693927791093271174011646752396020174120793"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "49918143231710149470149288853040257227910288056664935192295908123099477\
3950864700145009198744614374646320133911640785117503666797267192537", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "538589451689450021756212724120210944843047633633315868281684646605503889\
440350383737505906011601387855582186542348023293504792040348241586"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14532524008657467243708501825947742053605806438531259857385341419306754\
778405835628114586318826301642598591195830923052871992929975", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20021277364331472409059333397414457109146402499434817404576248020342621\
8386692291340314917687520974604322983540409", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35184159144287479998208956135487829036358691915499629662967567455240426\
797533", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14183401264318336793226058317431385810590989423647756072279872876667390\
93688138745310811328554972075943321706608516810482887750331943", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "113405439638546249339294090819766926799902623043456678190799260619427523\
864558781345093796044365933390598415765380484605821742474248"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67023484642673304033211022588861826807094166686958747090201295678723159\
460577609196877582324445174473012114255253648231020106734978", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14532524008657467243708501825947742053605806438531259857385341419306754\
778405835628114586318826301642598591195830923052871992929975", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30461621214690430287088421984498285667985604071123561621729360433834954\
32234809436870791753948761729263591205297127135523328288981695", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "113405439638546249339294090819766926799902623043456678190799260619427523\
864558781345093796044365933390598415765380484605821742474248"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "60062883192535548673803530607259510478933137280864939794796778176336025\
3714671171651785116467063425793917334379755", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10405539105687829250785003486918806385665953192496455720618557801639097\
50456303", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "126210369285434282240485794615966510804353699454850808106582749671961921\
821464"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "8667144274395912204779069544278069457207901161713299899662673826394413\
40400238044100100267250596382684475101943629", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
4283027612594107406465671496688984301168090"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19219909189280270942798829931666706726259484773135216905187591805988391\
73762305859049062402839219149829300546643358", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20021277364331472409059333397414457109146402499434817404576248020342621\
8386692291340314917687520974604322983540409", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "60062883192535548673803530607259510478933137280864939794796778176336025\
3714671171651785116467063425793917334379755", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "79289032571856795265298866438884668940360355449572382477060189966589812\
0940903604628328512766477621493467396276984", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30098247514386965070084487789554032368680694955488013062554448363161917\
492402", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16085270326162864504316291691861580016031843862632195252174660381664030\
0633665", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "72592781646256041423700722597620314927851208158289744259184321363537688\
243255", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35184159144287479998208956135487829036358691915499629662967567455240426\
797533", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10405539105687829250785003486918806385665953192496455720618557801639097\
50456303", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "126210369285434282240485794615966510804353699454850808106582749671961921\
821464"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30098247514386965070084487789554032368680694955488013062554448363161917\
492402", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "33726283681958954670476716534326923455971328624260270966809093116701812\
8143437", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "126210369285434282240485794615966510804353699454850808106582749671961921\
821464"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "97635728158520468601734192849784548293749291029466819266439110202451129\
26858833277334932125201019290135391466807093790663086263257015818341401", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "208972707255506608441410536958641846599102481849726556893293642882935509\
1028559488901522915325013384879658883784310330378798593116551177353680"}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "63970352696289911561884292141579710216360891621537181389009490911035896\
0498734203601063804856956676344547988723070001787750411163665137510423", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "261215884069383260551763171198302308248878102312158196116617053603669386\
378569936112690364415626673109957360473038791297349824139568897169210"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21830456933298686760760736192344107861690756350522861950482571278838195\
0695353999267050421757592663707323499621463210547146073712146340713", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "538589451689450021756212724120210944843047633633315868281684646605503889\
440350383737505906011601387855582186542348023293504792040348241586"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "62406151815534212089395039313710760813683152040461959215640875606326275\
5232277142705657554462786886863521470951583355774858467396553", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "756036264256974995595293938798446178666017486956377854605328404129516825\
76372520896729197362910622260398943843586989737214494982832"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31198037277277820790535667489331876263555702033975381820930867082380261\
8169652785203227072272041357894098190411576", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29816903493537839549577901321834374353150283787139097260466095439011446\
5126937", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "6397035269628991156188429214157971021636089162153718138900949091103589\
60498734203601063804856956676344547988723070001787750411163665137510423", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "26121588406938326055176317119830230824887810231215819611661705360366938\
6378569936112690364415626673109957360473038791297349824139568897169210"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "68169869984812838998396831533805265412374672256399779211461350580167952\
6757788723552794121861812549088876814353655081541808024303789724275041", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "130607942034691630275881585599151154124439051156079098058308526801834693\
189284968056345182207813336554978680236519395648674912069784448584605"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "53157702235995886702526357981511182922501007914017023401526305783093506\
7612405001253838330386714127928848631183667634206083501763317656445", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "269294725844725010878106362060105472421523816816657934140842323302751944\
720175191868752953005800693927791093271174011646752396020174120793"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10104684882407097245180006245983164269715428575318552332831532837965702\
2206399230104431932402572888839835290416544120007030639914283", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "66469163523965934430017549909170857877763564409086254678225042661272241\
2199610936090930061800574312363078749789409", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10429921895623848705895496980357111117598646719296216252538736782996040\
7015037", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21830456933298686760760736192344107861690756350522861950482571278838195\
0695353999267050421757592663707323499621463210547146073712146340713", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "538589451689450021756212724120210944843047633633315868281684646605503889\
440350383737505906011601387855582186542348023293504792040348241586"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "53157702235995886702526357981511182922501007914017023401526305783093506\
7612405001253838330386714127928848631183667634206083501763317656445", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "269294725844725010878106362060105472421523816816657934140842323302751944\
720175191868752953005800693927791093271174011646752396020174120793"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10531287229894956532071109561193095508581458511998916368729606105026626\
0808881269942208984543465697247810528166869778644982031123424630887", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "269294725844725010878106362060105472421523816816657934140842323302751944\
720175191868752953005800693927791093271174011646752396020174120793"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22410535231300097784417921185164953977345245516329583126376627692504623\
161947554056157377085759405164715530122072356750419479151699", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35416336514878723708466659987931118921455991644139559197269998251048342\
145917332305575673836164320459323168729800", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28995015266213265304312364988961221035724245344731820966285462060262433\
532435", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "6240615181553421208939503931371076081368315204046195921564087560632627\
55232277142705657554462786886863521470951583355774858467396553", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "75603626425697499559529393879844617866601748695637785460532840412951682\
576372520896729197362910622260398943843586989737214494982832"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10104684882407097245180006245983164269715428575318552332831532837965702\
2206399230104431932402572888839835290416544120007030639914283", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22410535231300097784417921185164953977345245516329583126376627692504623\
161947554056157377085759405164715530122072356750419479151699", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14682153534616391817924703634061479318525469701283620438928817696002769\
79948751917786790632260813728612584540845278825260587339988465", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "756036264256974995595293938798446178666017486956377854605328404129516825\
76372520896729197362910622260398943843586989737214494982832"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "34919295826617741458190462244179803108634580395051586880896497481914498\
2422528869741636291616551250693877496269813", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17312001422958923630643751202781470248860744314791978406994295325071120\
01351651", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31198037277277820790535667489331876263555702033975381820930867082380261\
8169652785203227072272041357894098190411576", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "66469163523965934430017549909170857877763564409086254678225042661272241\
2199610936090930061800574312363078749789409", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35416336514878723708466659987931118921455991644139559197269998251048342\
145917332305575673836164320459323168729800", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "34919295826617741458190462244179803108634580395051586880896497481914498\
2422528869741636291616551250693877496269813", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25450881027476974182963639796565792904808645149752174536206249589765825\
4922771407188076184635178645273954153877237", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22032906469734272356328755721979271411363461507625548480917938061109593\
252795", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2981690349353783954957790132183437435315028378713909726046609543901144\
65126937", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10429921895623848705895496980357111117598646719296216252538736782996040\
7015037", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28995015266213265304312364988961221035724245344731820966285462060262433\
532435", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17312001422958923630643751202781470248860744314791978406994295325071120\
01351651", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22032906469734272356328755721979271411363461507625548480917938061109593\
252795", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "60396743670348610974721582427985485771007962748264806693799638069030153\
3394481", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "97772654043855049896052574579483354287661451484937220124401228521098040\
40287286650724361569949195994250542190415541527176883098313677075847067", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "696575690851688694804701789862139488663674939499088522977645476276451697\
009519829633840971775004461626552961261436776792932864372183725784560"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11519864383472234680244425428659510567518518421786098707949365615041233\
974175404002316161588772686181826874137604662006395778951538025946041353", 
       " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "104486353627753304220705268479320923299551240924863278446646821441467754\
5514279744450761457662506692439829441892155165189399296558275588676840"}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10630441588616907748666347304371252855424696161691311064503591900114616\
849965497816426895834383651080148588161561398207461644260051274517309", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21495262316152861682516459855288741048688642925176325778795529997022502\
0855543794651992518961657549047218096527534306005296658102326", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "141756799548182811674117613524708658499878278804320847738499075774284404\
83069847668136724505545741673824801970672560575727717809281"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22402179991189077657822741446353308773774382628298652360664159387332308\
85128595973253020279510172981823076565461611", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
566055225188214812931342993377968602336180"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "91415700995994003919441085350701347820817098278303047065313733769641734\
327101", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "210350615475723803734142991026610851340589499091418013510971249453269869\
70244"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11519864383472234680244425428659510567518518421786098707949365615041233\
974175404002316161588772686181826874137604662006395778951538025946041353", 
       " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "104486353627753304220705268479320923299551240924863278446646821441467754\
5514279744450761457662506692439829441892155165189399296558275588676840"}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "46882968689356152442379630918232921124454232663911827801584815466825756\
16160967915968824621523556524397380934059187774671569298025443802011801", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "522431768138766521103526342396604616497756204624316392233234107207338772\
757139872225380728831253346219914720946077582594699648279137794338420"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18160122893765932235562359086546528879814129929696337178047238965699613\
85710601159967988502747645452748287789818742882630852331076152717921", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56175409992395125157036271280781503589306170522849925613953399434776241\
326351129407947826424468996938087051997572098001640538258017", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "41038606545722111679229976712607111301835910720550501547210639180100767\
25473539982807647892788990262460525564828027", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "92917345738827905647457524717932256055052872891202724071568326259744963\
286509", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1063044158861690774866634730437125285542469616169131106450359190011461\
6849965497816426895834383651080148588161561398207461644260051274517309", " ", 
        
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "43087156135156001740497017929616875587443810690665269462534771728440311\
15522803069900047248092811102844657492338784186348038336322785932688"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18160122893765932235562359086546528879814129929696337178047238965699613\
85710601159967988502747645452748287789818742882630852331076152717921", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "53730050084356489126910888724762689618332961911251808852154517596856895\
7342127489946325598960330233805158253468358841738921447637714142247", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25497555171478981315323937632900241375278840579089356864680494622679745\
832271750128373997063510907339740823341348919610385770208545", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "630030220214145829662744948998705148888347905796981545504440336774597354\
8031043408060766446909218521699911986965582478101207915236"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "42218702902888711878990928899473367699094039284390225923371742728166505\
3625465596504903497660118684233057798734481", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "392145281436121177085281963249086531923493962472852405697621468319234741\
139633135112928887758805796026781161401708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18688128076607299686657924711794908401471779530295603092794504390594734\
112953", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21495262316152861682516459855288741048688642925176325778795529997022502\
0855543794651992518961657549047218096527534306005296658102326", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "141756799548182811674117613524708658499878278804320847738499075774284404\
83069847668136724505545741673824801970672560575727717809281"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56175409992395125157036271280781503589306170522849925613953399434776241\
326351129407947826424468996938087051997572098001640538258017", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25497555171478981315323937632900241375278840579089356864680494622679745\
832271750128373997063510907339740823341348919610385770208545", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "630030220214145829662744948998705148888347905796981545504440336774597354\
8031043408060766446909218521699911986965582478101207915236"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18736963751609097526248095141278300432673819099327368333095762846913057\
62939683673660653700876209228560295086940414344825523003181493", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "567027198192731246696470454098834633999513115217283390953996303097137619\
32279390672546898022182966695299207882690242302910871237124"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14233843709551020992069649788359406022455377954297298614519005486827294\
85603407952913964462583812282240217378759937", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "66328364724424850115492297221822212345844582647890552458425249061817175\
7713631", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "631051846427171411202428973079832554021768497274254040532913748359809609\
10732"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2240217999118907765782274144635330877377438262829865236066415938733230\
885128595973253020279510172981823076565461611", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
8566055225188214812931342993377968602336180"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "41038606545722111679229976712607111301835910720550501547210639180100767\
25473539982807647892788990262460525564828027", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "42218702902888711878990928899473367699094039284390225923371742728166505\
3625465596504903497660118684233057798734481", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "392145281436121177085281963249086531923493962472852405697621468319234741\
139633135112928887758805796026781161401708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14233843709551020992069649788359406022455377954297298614519005486827294\
85603407952913964462583812282240217378759937", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17724065365072433464058763636115674088262701185510989652487710595728972\
94014191984457004208571352162846176463975181", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "33273711199312519848001913190524474944894668947220801501034507314417174\
322631", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "91415700995994003919441085350701347820817098278303047065313733769641734\
327101", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "210350615475723803734142991026610851340589499091418013510971249453269869\
70244"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "92917345738827905647457524717932256055052872891202724071568326259744963\
286509", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18688128076607299686657924711794908401471779530295603092794504390594734\
112953", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "66328364724424850115492297221822212345844582647890552458425249061817175\
7713631", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "631051846427171411202428973079832554021768497274254040532913748359809609\
10732"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "33273711199312519848001913190524474944894668947220801501034507314417174\
322631", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21945211803815412658269621523799585803520470644932991233328545928224439\
6626101", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "631051846427171411202428973079832554021768497274254040532913748359809609\
10732"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22240843859334744769284720833254773815728484763837109857826722993030791\
74824535189450371521371976289672026607423406559848718334897862540433123", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "208972707255506608441410536958641846599102481849726556893293642882935509\
1028559488901522915325013384879658883784310330378798593116551177353680"}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "32976991846883903398045177206586448956729242639121069707144969573935952\
376444931198334888556298309633472686658917064319966440384574420225184", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "870719613564610868505877237327674360829593674373860653722056845345564621\
2618997870423012147187555770331912015767959709911660804652296572307"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "38456607705784302341873134780798964424947224164293286122466276515989095\
1048864999570973742063597934355092100937589869475441216260342495241", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "359059634459633347837475149413473963228698422422210578854456431070335926\
293566922491670604007734258570388124361565348862336528026898827724"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20759441228194494164083891313128492089186261888223533860291097350566567\
40030216660665060025996069203072079787116604564847454523519487", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11590355533909125670934614031174919511058114563540011289250648532762748\
28172834717539680214933824211074548317487801", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
566055225188214812931342993377968602336180"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31106750489074200296446014644951753288486873406471003014712977608508198\
0852089", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "32976991846883903398045177206586448956729242639121069707144969573935952\
376444931198334888556298309633472686658917064319966440384574420225184", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "870719613564610868505877237327674360829593674373860653722056845345564621\
2618997870423012147187555770331912015767959709911660804652296572307"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23078099962003940299082683003582072213287495482528923491546708329392989\
9600519880982013736880564080053782933754540757864675070490197166796844", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "435359806782305434252938618663837180414796837186930326861028422672782310\
63094989352115060735937778851659560078839798549558304023261482861535"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40915630040518985448836717182022035025438283114324028757622882195367095\
3839146205937426518533314351106396118808512935707077233691314976041", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "179529817229816673918737574706736981614349211211105289427228215535167963\
146783461245835302003867129285194062180782674431168264013449413862"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19815341432127704773209221652840502513228637162003278229078789584423939\
855426188599689854662826252006796758085609233926453624916133", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "157507555053536457415686237249676287222086976449245386376110084193649338\
7007760852015191611727304630424977996741395619525301978809"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "27546944525084543084743354705619151975744681190016216054180313519353155\
74610180145910323057163967420382259593720477", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10547172669445808532400452758120201038604347366685837376797047776547434\
5944141", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "3845660770578430234187313478079896442494722416429328612246627651598909\
51048864999570973742063597934355092100937589869475441216260342495241", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "35905963445963334783747514941347396322869842242221057885445643107033592\
6293566922491670604007734258570388124361565348862336528026898827724"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40915630040518985448836717182022035025438283114324028757622882195367095\
3839146205937426518533314351106396118808512935707077233691314976041", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "179529817229816673918737574706736981614349211211105289427228215535167963\
146783461245835302003867129285194062180782674431168264013449413862"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19163089931521325731005832779368076598096988247632196493242954783365643\
8797793185029126082436796897188534183731767636412832579103640946719", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "359059634459633347837475149413473963228698422422210578854456431070335926\
293566922491670604007734258570388124361565348862336528026898827724"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20225029588084714933849577870339813598946097150489778280103225669448858\
577928802108642588486478706470346335727188090836406915706309", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "630030220214145829662744948998705148888347905796981545504440336774597354\
8031043408060766446909218521699911986965582478101207915236"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22140999750535046022042642180652936359826065715150492710541427459629204\
6288735029811629875345355717270055401292387", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "392145281436121177085281963249086531923493962472852405697621468319234741\
139633135112928887758805796026781161401708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13536539507675291695948549100187137875479264102253069500962666662119893\
521390", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20759441228194494164083891313128492089186261888223533860291097350566567\
40030216660665060025996069203072079787116604564847454523519487", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19815341432127704773209221652840502513228637162003278229078789584423939\
855426188599689854662826252006796758085609233926453624916133", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157507555053536457415686237249676287222086976449245386376110084193649338\
7007760852015191611727304630424977996741395619525301978809"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20225029588084714933849577870339813598946097150489778280103225669448858\
577928802108642588486478706470346335727188090836406915706309", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "630030220214145829662744948998705148888347905796981545504440336774597354\
8031043408060766446909218521699911986965582478101207915236"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "48193505987011279268092378197224133194071311456355872165361371038528357\
88579883726676278100496349355658485273038209761951829869301491", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "87878714702136297166730776328656474331101713021729362697065049250586203\
0096338537324210889032036208194450403923695", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18396793970495003818919345821832635981315312621769902277165156801242672\
16642779", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1159035553390912567093461403117491951105811456354001128925064853276274\
828172834717539680214933824211074548317487801", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
8566055225188214812931342993377968602336180"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "27546944525084543084743354705619151975744681190016216054180313519353155\
74610180145910323057163967420382259593720477", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22140999750535046022042642180652936359826065715150492710541427459629204\
6288735029811629875345355717270055401292387", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "392145281436121177085281963249086531923493962472852405697621468319234741\
139633135112928887758805796026781161401708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "87878714702136297166730776328656474331101713021729362697065049250586203\
0096338537324210889032036208194450403923695", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10024782766223275015681989704431656432609154614546679118859806077110193\
81184313105251684476338709834689206721913771", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21119351753934089435477252598760989758787703312927237681142829527353145\
325637", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31106750489074200296446014644951753288486873406471003014712977608508198\
0852089", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10547172669445808532400452758120201038604347366685837376797047776547434\
5944141", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13536539507675291695948549100187137875479264102253069500962666662119893\
521390", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18396793970495003818919345821832635981315312621769902277165156801242672\
16642779", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21119351753934089435477252598760989758787703312927237681142829527353145\
325637", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "65642299836195248810071987362518220985958481687352189879616805337133767\
6838729", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "4718591588641884810030207215999433277539332952257870960400388241956431\
07194983377508038921682171421637318351295621657963388620546408263014769", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "10448635362775330422070526847932092329955124092486327844664682144146775\
45514279744450761457662506692439829441892155165189399296558275588676840"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22679868032754165493059773969501869569689558884137996436956335547878475\
25804145425023256393504050819467968089740830545881437513143657012035387", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "261215884069383260551763171198302308248878102312158196116617053603669386\
378569936112690364415626673109957360473038791297349824139568897169210"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23492370915775991074488900388503179925094403279740130307823637430622342\
40771261135557972580541940490552909838224973308091909161454458540311", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "107717890337890004351242544824042188968609526726663173656336929321100777\
8880700767475011812023202775711164373084696046587009584080696483172"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23046479731101259233156018242555244819416372002900646459220370173696656\
12775936181445530135446339810924474774486644013845371072208029", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "113405439638546249339294090819766926799902623043456678190799260619427523\
864558781345093796044365933390598415765380484605821742474248"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57170467672770122164332664368748779093710263870150897995323113610114869\
1221172100546774371935893625021941443393601", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "130715093812040392361760654416362177307831320824284135232540489439744913\
713211045037642962586268598675593720467236"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "32001825782032467465933741201846021707919938670998410719185831039153547\
0367009", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2267986803275416549305977396950186956968955888413799643695633554787847\
525804145425023256393504050819467968089740830545881437513143657012035387", 
        " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "26121588406938326055176317119830230824887810231215819611661705360366938\
6378569936112690364415626673109957360473038791297349824139568897169210"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18291709906819230371096139358406713282442744381973662995428481426596721\
55397619883103338839536216399431602850464414222049776538717956921939357", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "130607942034691630275881585599151154124439051156079098058308526801834693\
189284968056345182207813336554978680236519395648674912069784448584605"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23794838108950923592834618718977896622914958662547660120911866340215756\
10358476036582382383993817828760791637288219630356496217049042283819", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "538589451689450021756212724120210944843047633633315868281684646605503889\
440350383737505906011601387855582186542348023293504792040348241586"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25249468472539125324127601441030506197189292880483108086416962983302791\
1683789506578685032683982057355903500001672996700755492788647", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30124798427206314841633265566816785572019780448122074682275188155203101\
6100372937805668228311406063195037897550997", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "44764448017676896803632183728143688492507396610196775919775447986244223\
521792", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23492370915775991074488900388503179925094403279740130307823637430622342\
40771261135557972580541940490552909838224973308091909161454458540311", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "107717890337890004351242544824042188968609526726663173656336929321100777\
8880700767475011812023202775711164373084696046587009584080696483172"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23794838108950923592834618718977896622914958662547660120911866340215756\
10358476036582382383993817828760791637288219630356496217049042283819", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "538589451689450021756212724120210944843047633633315868281684646605503889\
440350383737505906011601387855582186542348023293504792040348241586"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13239164761970464139803552546570419892665147227333970547994848799566855\
65366011820806020905689825788662406287638156560580260618257266776817", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "107717890337890004351242544824042188968609526726663173656336929321100777\
8880700767475011812023202775711164373084696046587009584080696483172"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11703545593912322474325764227462139935048274610166459132285090670927007\
6820279676313722363544668248228341758820725750768350741482911", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "189009066064243748898823484699611544666504371739094463651332101032379206\
44093130224182299340727655565099735960896747434303623745708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11431277507732398252888160899630545576803959482113279562496832311057085\
9045494524909361147621683169409653064151025", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "130715093812040392361760654416362177307831320824284135232540489439744913\
713211045037642962586268598675593720467236"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11241927510118491769975091247854673073490533223330859671404596719653207\
338492", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2304647973110125923315601824255524481941637200290064645922037017369665\
612775936181445530135446339810924474774486644013845371072208029", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "11340543963854624933929409081976692679990262304345667819079926061942752\
3864558781345093796044365933390598415765380484605821742474248"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25249468472539125324127601441030506197189292880483108086416962983302791\
1683789506578685032683982057355903500001672996700755492788647", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11703545593912322474325764227462139935048274610166459132285090670927007\
6820279676313722363544668248228341758820725750768350741482911", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "189009066064243748898823484699611544666504371739094463651332101032379206\
44093130224182299340727655565099735960896747434303623745708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "53452230566426128138142926989531310520379032990787300456765724070197741\
11703100150700462393476144622388655758733000070135550500058487", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "113405439638546249339294090819766926799902623043456678190799260619427523\
864558781345093796044365933390598415765380484605821742474248"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "62596971819816568314194631391885814626494520908234767362062935035919289\
7004265383602190710524337754869734328627437", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67812951350337826267985565422669798090753399952322817933906603048789501\
1649161", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57170467672770122164332664368748779093710263870150897995323113610114869\
1221172100546774371935893625021941443393601", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "130715093812040392361760654416362177307831320824284135232540489439744913\
713211045037642962586268598675593720467236"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "30124798427206314841633265566816785572019780448122074682275188155203101\
6100372937805668228311406063195037897550997", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11431277507732398252888160899630545576803959482113279562496832311057085\
9045494524909361147621683169409653064151025", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "130715093812040392361760654416362177307831320824284135232540489439744913\
713211045037642962586268598675593720467236"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "62596971819816568314194631391885814626494520908234767362062935035919289\
7004265383602190710524337754869734328627437", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10436314355499757699824507605306886930795909960857167392439480516528643\
6003940856330130926350647205179627371881823", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17859536526565282316323666879495617246667753078704845914453423736090104\
621739", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "3200182578203246746593374120184602170791993867099841071918583103915354\
70367009", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "42070123095144760746828598205322170268117899818283602702194249890653973\
940488"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "44764448017676896803632183728143688492507396610196775919775447986244223\
521792", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11241927510118491769975091247854673073490533223330859671404596719653207\
338492", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67812951350337826267985565422669798090753399952322817933906603048789501\
1649161", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17859536526565282316323666879495617246667753078704845914453423736090104\
621739", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22848128037615309406338760828033496271683192016603168141076302829501085\
4330563", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2664456223372292039363093744911389092777098515204427867027879098787590\
220206125628179796721120068013205561904599564097228478670580532701243719", 
        " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "34828784542584434740235089493106974433183746974954426148882273813822584\
8504759914816920485887502230813276480630718388396466432186091862892280"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "37975464551904460373733827059733385208595290498196015679849326289155870\
2503294027822670911467801676473196118791225896250528958363480008622969", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "104486353627753304220705268479320923299551240924863278446646821441467754\
5514279744450761457662506692439829441892155165189399296558275588676840"}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22283732129769799111200213060150358874814653559096702224765452689044116\
50591487084547346138141052357888521137171533878981459219950554316959", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40469497787701568016218006361351922285217947754886055206956805231665685\
1620334935350856895926112842168555650040582539142826750710955", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "52751832471673182469854014604929150786404633976135425311783777259971293\
72864227867396954502957079259941420621768", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11538247800483573607201297486839498794316410819291360910550881680738990\
5983953", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "3797546455190446037373382705973338520859529049819601567984932628915587\
02503294027822670911467801676473196118791225896250528958363480008622969", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "10448635362775330422070526847932092329955124092486327844664682144146775\
45514279744450761457662506692439829441892155165189399296558275588676840"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "23492777807566386146069209697848153038315070990539310246044510261040120\
1325450768284591219087245453690525913466596530589576731588648366841491", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "522431768138766521103526342396604616497756204624316392233234107207338772\
757139872225380728831253346219914720946077582594699648279137794338420"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10572433639942736877083732315891614409625008492896410882657323837422117\
76785641672758944193736547368359942264007979697856520279069009946747", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29947346608322064341804444133704923744630797129783321236193559597755802\
791828175393192992438532271343527624353777456324612246258121", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12784685296380364068772035555309446208261061536652613520738364161498838\
546295933470819791547032691841424084461809", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22782390908410737581010857100601198488994281528379749992798197154340573\
664559", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2228373212976979911120021306015035887481465355909670222476545268904411\
650591487084547346138141052357888521137171533878981459219950554316959", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "43087156135156001740497017929616875587443810690665269462534771728440311\
15522803069900047248092811102844657492338784186348038336322785932688"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10572433639942736877083732315891614409625008492896410882657323837422117\
76785641672758944193736547368359942264007979697856520279069009946747", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10078366844266783624671472297056445854176019731176908246425469739927529\
87062320819015635177609344677486248955040842570381608129950098578723", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "48504305430912599465103693790041893362297954631526805430909493848077893\
41343337057303539180580984058671587103373631966682387794221", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24589914305686673968389694429621201492352430378823615212577001852213517\
48867479536826805563074681053687163571413", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "97720015959799504292733114447150351208496209663146974133755243120978606\
30893", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40469497787701568016218006361351922285217947754886055206956805231665685\
1620334935350856895926112842168555650040582539142826750710955", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29947346608322064341804444133704923744630797129783321236193559597755802\
791828175393192992438532271343527624353777456324612246258121", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "48504305430912599465103693790041893362297954631526805430909493848077893\
41343337057303539180580984058671587103373631966682387794221", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "472522665160609372247058711749028861666260929347736159128330252580948016\
1023282556045574835181913891274933990224186858575905936427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10676381382460370370091199079910887565988888580918846688024104593901014\
13071442220099543739086800869557247417248617686228151626536619", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "226810879277092498678588181639533853599805246086913356381598521238855047\
729117562690187592088731866781196831530760969211643484948496"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "50645323100186055178500734141183091919500729171649280747393889333769457\
527716414433367124997942418047273812369002", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57280281860504677578415086829710476578348274664807304189590097464964898\
4205451", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "5275183247167318246985401460492915078640463397613542531178377725997129\
372864227867396954502957079259941420621768", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
428302761259410740646567149668898430116809"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12784685296380364068772035555309446208261061536652613520738364161498838\
546295933470819791547032691841424084461809", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24589914305686673968389694429621201492352430378823615212577001852213517\
48867479536826805563074681053687163571413", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "50645323100186055178500734141183091919500729171649280747393889333769457\
527716414433367124997942418047273812369002", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "63162783083253761910818168351389971828062630441707289778603157015124182\
68021142779790086140600106146495838829195", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "42990298669427782812714407377405003744306127791264150006609699784878615\
71152", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11538247800483573607201297486839498794316410819291360910550881680738990\
5983953", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22782390908410737581010857100601198488994281528379749992798197154340573\
664559", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "97720015959799504292733114447150351208496209663146974133755243120978606\
30893", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57280281860504677578415086829710476578348274664807304189590097464964898\
4205451", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "42990298669427782812714407377405003744306127791264150006609699784878615\
71152", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25663338287016158272691410453088091797744116392547765998947408456738053\
3544521", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "252420738570868564480971589231933021608707398909701616213165499343923843\
642928"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "42419835423146694290332275401688116569887846879414608676180033957486701\
030246075048492338509165309745282060519433546495277706354120504991", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "311899563067920311106582890983047532237466390820487398348199466989455983\
73560589386589894258582289326562072892303139259385053628605241453040"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11896171597528203524980095982512729430532350520652345569400816324182310\
043905217913443354224754920054564173526333120650798099596553150136577", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "259916302556600259255485742485872943531221992350406165290166222491213319\
7796715782215824521548524110546839407691928271615421135717103454420"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13336702662409232964786445742408490887461520659961329429172425648870483\
864111697267348674647363810817067173379701399121076004685469347651", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "107181980435711447115664223705514615889163708185734501150584009274727142\
17718415596766286686798037569265317145121353697383179941101457544"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "41666024622550659915038098067648864147211708403583757165468626095954575\
701516888253081077280091007124213883920520150314735529270307", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "338523700413570893550131614387363960596724247890915457285967942147544847\
3568918846122202866995998011659654201951656256890201267888"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "91788486898026144342195974126829116420188913128591938800533969049514021\
1943172405672566192578506504910771779369429", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
283027612594107406465671496688984301168090"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31998971285884759334694884824515504857927995039680230390505361217362706\
5768715", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1189617159752820352498009598251272943053235052065234556940081632418231\
0043905217913443354224754920054564173526333120650798099596553150136577", " ", 
        
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "25991630255660025925548574248587294353122199235040616529016622249121331\
97796715782215824521548524110546839407691928271615421135717103454420"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12282964101241151087634441360637311807635178761161987606997094572087181\
507938461385178391371418017526417474511233762935103261136826988564849", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "129958151278300129627742871242936471765610996175203082645083111245606659\
8898357891107912260774262055273419703845964135807710567858551727210"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15649258355709900456280113209790388019729888789692356499005443515128951\
781005251797532170320974770604957729080695654892750828738658836655", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "535909902178557235578321118527573079445818540928672505752920046373635710\
8859207798383143343399018784632658572560676848691589970550728772"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22633919425106305098044647204686079113011438129390058177348021185248465\
75211798804692679232342755946002469165268120818974950004921", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "141051541838987872312554839328068316915301769954548107202486642561477019\
732038285255091786124833250485818925081319010703758386162"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "49150583760731254587302901088586034705098493445822255014279393113059896\
5313043162477322012423770882473097309448676", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56979412642688316042876679777275063446273849582001390697334996653936845\
349845", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13336702662409232964786445742408490887461520659961329429172425648870483\
864111697267348674647363810817067173379701399121076004685469347651", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "107181980435711447115664223705514615889163708185734501150584009274727142\
17718415596766286686798037569265317145121353697383179941101457544"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15649258355709900456280113209790388019729888789692356499005443515128951\
781005251797532170320974770604957729080695654892750828738658836655", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "535909902178557235578321118527573079445818540928672505752920046373635710\
8859207798383143343399018784632658572560676848691589970550728772"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "94131381221566855583154409782900908774888118770398687526576747893881449\
95159732114969573389878201244143158714515233834710757968539477083", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "107181980435711447115664223705514615889163708185734501150584009274727142\
17718415596766286686798037569265317145121353697383179941101457544"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25867775709153271322554066040761205120891222040039296855398308702237182\
0349163828101588942265343026535133895120208648914400351273", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "705257709194939361562774196640341584576508849772740536012433212807385098\
66019142627545893062416625242909462540659505351879193081"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "47882553462818868556044272759141511102763726057050251945349584780780008\
954022012521099230359817888804702237743613", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11400315641030762082195463268119290105725095097917091604543850847377557\
501731", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "4166602462255065991503809806764886414721170840358375716546862609595457\
5701516888253081077280091007124213883920520150314735529270307", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "33852370041357089355013161438736396059672424789091545728596794214754484\
73568918846122202866995998011659654201951656256890201267888"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22633919425106305098044647204686079113011438129390058177348021185248465\
75211798804692679232342755946002469165268120818974950004921", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "141051541838987872312554839328068316915301769954548107202486642561477019\
732038285255091786124833250485818925081319010703758386162"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25867775709153271322554066040761205120891222040039296855398308702237182\
0349163828101588942265343026535133895120208648914400351273", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "705257709194939361562774196640341584576508849772740536012433212807385098\
66019142627545893062416625242909462540659505351879193081"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "95809365111991308242756338416992550955858140163512818850372537323509602\
418953413815809354482295578366479496950918062992777254131523", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "338523700413570893550131614387363960596724247890915457285967942147544847\
3568918846122202866995998011659654201951656256890201267888"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19468196355032771200156577658686879411869022225859649511736742895832577\
0844919520096692006413219518579193217929938", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "78813716986211090063763289236815201034130208529529872869810031148108313\
4714787", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "91788486898026144342195974126829116420188913128591938800533969049514021\
1943172405672566192578506504910771779369429", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
283027612594107406465671496688984301168090"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "49150583760731254587302901088586034705098493445822255014279393113059896\
5313043162477322012423770882473097309448676", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "47882553462818868556044272759141511102763726057050251945349584780780008\
954022012521099230359817888804702237743613", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19468196355032771200156577658686879411869022225859649511736742895832577\
0844919520096692006413219518579193217929938", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19023467871714163114758072363275531559749572667508161157644116522235944\
4894667723292296863033503827727659186943998", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10565506921318710865136688373106994526814529945402780924209434786531922\
964727", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "3199897128588475933469488482451550485792799503968023039050536121736270\
65768715", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56979412642688316042876679777275063446273849582001390697334996653936845\
349845", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11400315641030762082195463268119290105725095097917091604543850847377557\
501731", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "78813716986211090063763289236815201034130208529529872869810031148108313\
4714787", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10565506921318710865136688373106994526814529945402780924209434786531922\
964727", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25352016770901703646307075849209359957940771579939734242490552972583501\
7221937", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29624529581500434074126993535192659108486909211945302392068365756376983\
61211153312336835171421773115078420209035303667955857914413536120788187", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "522431768138766521103526342396604616497756204624316392233234107207338772\
757139872225380728831253346219914720946077582594699648279137794338420"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "61357946190241613943862066827244878311593101721053627938766053452111275\
3800250687208966237357666647079042365590946456653333740483359640650637", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "870719613564610868505877237327674360829593674373860653722056845345564621\
26189978704230121471875557703319120157679597099116608046522965723070"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "46356191864490707780807132731155600872631993605370296100794778801363533\
8236620351194873565464316851880123372917278117969753145025954578391", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "359059634459633347837475149413473963228698422422210578854456431070335926\
293566922491670604007734258570388124361565348862336528026898827724"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "69760518139777269333623777945532913802252307890121753589444112158463018\
8571954653635593379775261871937322181970208877029330061772763", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "567027198192731246696470454098834633999513115217283390953996303097137619\
32279390672546898022182966695299207882690242302910871237124"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14795438514387030257726413032737088531913874568950275224536454503278611\
26117079498613492670925969441630943541142143", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
566055225188214812931342993377968602336180"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20160343998901086822398038614595071283278238390499375502539364649380977\
116096", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "61357946190241613943862066827244878311593101721053627938766053452111275\
3800250687208966237357666647079042365590946456653333740483359640650637", " ", 
       
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "870719613564610868505877237327674360829593674373860653722056845345564621\
26189978704230121471875557703319120157679597099116608046522965723070"}], "+", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29317152466568571086135014540279486530135648805105042303348481479988842\
2134098799575287989771530069329037511606272702527959503614218231659784", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "435359806782305434252938618663837180414796837186930326861028422672782310\
63094989352115060735937778851659560078839798549558304023261482861535"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "33989752192461698473686376235102129955646095773382832526198320542451137\
0981660210254341917720380578223122201859828331961642565261768801479", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "179529817229816673918737574706736981614349211211105289427228215535167963\
146783461245835302003867129285194062180782674431168264013449413862"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13362944860836178226373077400169047998253024803098116075176917113329854\
2270878396813504539640946900357165789596818778133173672233289", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "37245411693805851069281185778667929123491963766958355288289721143573547\
75598779347087743581415006419113244106971541", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "75090204625049630477815506814923802019018592058013915746334518297337093\
647804", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "4635619186449070778080713273115560087263199360537029610079477880136353\
38236620351194873565464316851880123372917278117969753145025954578391", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "35905963445963334783747514941347396322869842242221057885445643107033592\
6293566922491670604007734258570388124361565348862336528026898827724"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "33989752192461698473686376235102129955646095773382832526198320542451137\
0981660210254341917720380578223122201859828331961642565261768801479", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "179529817229816673918737574706736981614349211211105289427228215535167963\
146783461245835302003867129285194062180782674431168264013449413862"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14044401028442088708428407139976292968570245637494886869401702195441881\
0503041888200899289334247911261129017463982146114047066077359795411", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "359059634459633347837475149413473963228698422422210578854456431070335926\
293566922491670604007734258570388124361565348862336528026898827724"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "60014358140505079777510813680102086512171548867048617805097053392309219\
955937763672382734251907259375338985177849323494513868691863", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "189009066064243748898823484699611544666504371739094463651332101032379206\
44093130224182299340727655565099735960896747434303623745708"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31513712967434021385184019780619500825605333853892730835597990635555348\
5604054443838849903971967693270476657446645", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "392145281436121177085281963249086531923493962472852405697621468319234741\
139633135112928887758805796026781161401708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35232672015148909430879337254092423127788059679126267911799640901917892\
549763", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "69760518139777269333623777945532913802252307890121753589444112158463018\
8571954653635593379775261871937322181970208877029330061772763", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "567027198192731246696470454098834633999513115217283390953996303097137619\
32279390672546898022182966695299207882690242302910871237124"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13362944860836178226373077400169047998253024803098116075176917113329854\
2270878396813504539640946900357165789596818778133173672233289", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "945045330321218744494117423498057723332521858695472318256660505161896032\
2046565112091149670363827782549867980448373717151811872854"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "60014358140505079777510813680102086512171548867048617805097053392309219\
955937763672382734251907259375338985177849323494513868691863", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "189009066064243748898823484699611544666504371739094463651332101032379206\
44093130224182299340727655565099735960896747434303623745708"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "37781672550724759788968275027273325442517302126692310995220932494224985\
2167616386388691717849932386881515064095087690954991387547894", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "141756799548182811674117613524708658499878278804320847738499075774284404\
83069847668136724505545741673824801970672560575727717809281"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11542352966806673912389180024266123717375251383573922685150759889153564\
18100708284869785295152521144197214725381307", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "26740526051325196039812392936097983290192102269197908022991636465676739\
6818417", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1479543851438703025772641303273708853191387456895027522453645450327861\
126117079498613492670925969441630943541142143", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "65357546906020196180880327208181088653915660412142067616270244719872456\
8566055225188214812931342993377968602336180"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "37245411693805851069281185778667929123491963766958355288289721143573547\
75598779347087743581415006419113244106971541", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31513712967434021385184019780619500825605333853892730835597990635555348\
5604054443838849903971967693270476657446645", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "392145281436121177085281963249086531923493962472852405697621468319234741\
139633135112928887758805796026781161401708"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11542352966806673912389180024266123717375251383573922685150759889153564\
18100708284869785295152521144197214725381307", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "196072640718060588542640981624543265961746981236426202848810734159617370\
569816567556464443879402898013390580700854"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13916086754361202960092507381225669545244764157078307924059089009457130\
33476804899409295985564977245834065608627823", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
849082837782322219397014490066952903504270"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29199673357680490383866615261410513401040573380749875302768343030795781\
110334", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20160343998901086822398038614595071283278238390499375502539364649380977\
116096", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "75090204625049630477815506814923802019018592058013915746334518297337093\
647804", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35232672015148909430879337254092423127788059679126267911799640901917892\
549763", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "26740526051325196039812392936097983290192102269197908022991636465676739\
6818417", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29199673357680490383866615261410513401040573380749875302768343030795781\
110334", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "85293339526607381923289892750685790544944027527384221555509643547917808\
014353", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "4038386903459340228606508963631637144115752810887454250216668517835210\
42247506229530599753285173101802760935545353560805111486640269377163959", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "23219189695056289826823392995404649622122497983302950765921515875881723\
233650660987794699059166815387551765375381225893097762145739457526152"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "27134127697844580919702200777261171514039613787073642859068796909427429\
19494862206633570061539922239584214596157871325192174535610596736661517", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "116095948475281449134116964977023248110612489916514753829607579379408616\
168253304938973495295834076937758826876906129465488810728697287630760"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24733070129974431625716738686803500572825434798393445543682433399785715\
08229511586180017527538989890637849221132594850003603416005402696581", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "478746179279511130449966865884631950971597896562947438472608574760447901\
724755896655560805343645678093850832482087131816448704035865103632"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10185524811761375346698772357174450987848866373026912565306948878109581\
71038606277886977413651671428161517931953952594347801777946957", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "252012088085658331865097979599482059555339162318792618201776134709838941\
92124173632243065787636874086799647947862329912404831660944"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12839910539172303187105919768955333858230682479090525255701745791684024\
39011385818840029322042581473968617951716331", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11660054990935778810224382040501598102150624221557631348388382686209012\
71618271", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2713412769784458091970220077726117151403961378707364285906879690942742\
919494862206633570061539922239584214596157871325192174535610596736661517", 
        " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "11609594847528144913411696497702324811061248991651475382960757937940861\
6168253304938973495295834076937758826876906129465488810728697287630760"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "29737207546951272577447728621157020137947546569303419103929715893892224\
0908897576858374802254489537909524020033937009993029912491304992001289", " ", 
       
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "116095948475281449134116964977023248110612489916514753829607579379408616\
16825330493897349529583407693775882687690612946548881072869728763076"}], "+", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11573994115979941940701664474946797824638615275782843598271277623797132\
85192749112443187753390811497018334847778073968420992421015510042177", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "239373089639755565224983432942315975485798948281473719236304287380223950\
862377948327780402671822839046925416241043565908224352017932551816"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15098086957376085775251027399193726562944078476345177752994783736603083\
3848300961632591459172629956491941565590702810228349237898961", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16333867627897273526031660957107532671076003191572912731556228717583415\
01251936248427417994029212494480482753627203", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16668949098372637316236934414013771350524529942476515591831512389433886\
9207135", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24733070129974431625716738686803500572825434798393445543682433399785715\
08229511586180017527538989890637849221132594850003603416005402696581", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "478746179279511130449966865884631950971597896562947438472608574760447901\
724755896655560805343645678093850832482087131816448704035865103632"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11573994115979941940701664474946797824638615275782843598271277623797132\
85192749112443187753390811497018334847778073968420992421015510042177", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "239373089639755565224983432942315975485798948281473719236304287380223950\
862377948327780402671822839046925416241043565908224352017932551816"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "38987444690285129801977607663044044054826359937711437878012488834332129\
5058306530481850497734160620209610650438196163840649757646930570873", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "478746179279511130449966865884631950971597896562947438472608574760447901\
724755896655560805343645678093850832482087131816448704035865103632"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "34052561414026554874300446935690976549352854025476824951099114313821503\
531222034391462708932291383106732888953179371097044914085071", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "70131808279419422073011632121463058790690741291135468852796886144700844\
636394934287820130438650966958364127084470", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18808686539440921098782709278047018349064113189639273796229667593758007\
371745", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1018552481176137534669877235717445098784886637302691256530694887810958\
171038606277886977413651671428161517931953952594347801777946957", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "25201208808565833186509797959948205955533916231879261820177613470983894\
192124173632243065787636874086799647947862329912404831660944"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15098086957376085775251027399193726562944078476345177752994783736603083\
3848300961632591459172629956491941565590702810228349237898961", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "34052561414026554874300446935690976549352854025476824951099114313821503\
531222034391462708932291383106732888953179371097044914085071", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22583123500245809368361007294639053320726844410182201739753857801753911\
24346700633573804890205407497751671201109699173777016204054549", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "252012088085658331865097979599482059555339162318792618201776134709838941\
92124173632243065787636874086799647947862329912404831660944"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "59279874567028095651151607210355374826451963628899664740339587168033423\
1847682692471982308356216628124881417560016", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25396487775616369090736871492585374035444833667254270210925714905960774\
47279055", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12839910539172303187105919768955333858230682479090525255701745791684024\
39011385818840029322042581473968617951716331", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16333867627897273526031660957107532671076003191572912731556228717583415\
01251936248427417994029212494480482753627203", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "70131808279419422073011632121463058790690741291135468852796886144700844\
636394934287820130438650966958364127084470", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "59279874567028095651151607210355374826451963628899664740339587168033423\
1847682692471982308356216628124881417560016", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "61446411168228063061657190354175493259136379523164320936939683717393258\
0437130075267841579992730122108390964112639", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31887127451551768928752412515163289100431492382321979354108484781941834\
441288", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1166005499093577881022438204050159810215062422155763134838838268620901\
271618271", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "84140246190289521493657196410644340536235799636567205404388499781307947\
880976"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16668949098372637316236934414013771350524529942476515591831512389433886\
9207135", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18808686539440921098782709278047018349064113189639273796229667593758007\
371745", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25396487775616369090736871492585374035444833667254270210925714905960774\
47279055", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31887127451551768928752412515163289100431492382321979354108484781941834\
441288", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "84640856618911368989382287557749108733724940995176731258723140092142498\
6534885", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "2636181846272722790890143201824412532931418455517279122529152587760525\
9449135458906682345156218502802056976327676510213395856303983485599739943", 
        " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "20897270725550660844141053695864184659910248184972655689329364288293550\
91028559488901522915325013384879658883784310330378798593116551177353680"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16107044960104848564061472089143872988271455204593882811296914151467685\
048314997261164191641470205105657646511452483035617474320318475575039431", 
       " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "104486353627753304220705268479320923299551240924863278446646821441467754\
5514279744450761457662506692439829441892155165189399296558275588676840"}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13098281723181751714593954354671131170657112389602512050803322308766481\
275528529751484029520721363556289625428132137544369539313791627270275", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "15726152142037152722894637449439679860238632955666685658835875408132803\
35736874620335506914458277316866812752226689768304061121822647", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "567027198192731246696470454098834633999513115217283390953996303097137619\
32279390672546898022182966695299207882690242302910871237124"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "94153893174683565498014884827501732580923640693370213437997880943817587\
3896273987341825493124747819234035985655021", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "19083248965441720448200481182500670009822836475043628005047985541794728\
6587123", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "210350615475723803734142991026610851340589499091418013510971249453269869\
70244"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1610704496010484856406147208914387298827145520459388281129691415146768\
5048314997261164191641470205105657646511452483035617474320318475575039431", 
        " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "10448635362775330422070526847932092329955124092486327844664682144146775\
45514279744450761457662506692439829441892155165189399296558275588676840"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10164116068765562737380111665629970489641176964841160966184172919248723\
998690437071210549811072128879185708849029135437158826564309475448727143", 
       " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "522431768138766521103526342396604616497756204624316392233234107207338772\
757139872225380728831253346219914720946077582594699648279137794338420"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "86133399488130335319083487204068052170749410034402632781726023821243021\
66800933109210256790230233386457940304620869773829137282125453374111", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "51576032276782068054131351195698373030456635324472911394182904423039274\
589325071321257106320890738851438835833239434662885926546911", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "157507555053536457415686237249676287222086976449245386376110084193649338\
7007760852015191611727304630424977996741395619525301978809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31807196161518589530931259457800476165685367453856056735629437309879640\
44409186714047113853227913704549569408723099", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17885659070358154038288916426178687728072220489066978031407728146880231\
8671821", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13098281723181751714593954354671131170657112389602512050803322308766481\
275528529751484029520721363556289625428132137544369539313791627270275", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "86133399488130335319083487204068052170749410034402632781726023821243021\
66800933109210256790230233386457940304620869773829137282125453374111", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "39126473094116663384701056518935319815003290612317997483987345011282465\
62083302850347117918204737148635220620081729418342245368646413340415", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22695379634897266388880229493150714409817791421484621889132650861196297\
677572120916995283153561739517119678511935035673075584613711", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12199521294241003173119612694476121965511135307597353167910878998923788\
8964627445070238949633490804979018342416571", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "43975651864351898481744425187313050397143950803356321958159940292161271\
970280", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1572615214203715272289463744943967986023863295566668565883587540813280\
335736874620335506914458277316866812752226689768304061121822647", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "56702719819273124669647045409883463399951311521728339095399630309713761\
932279390672546898022182966695299207882690242302910871237124"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "51576032276782068054131351195698373030456635324472911394182904423039274\
589325071321257106320890738851438835833239434662885926546911", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157507555053536457415686237249676287222086976449245386376110084193649338\
7007760852015191611727304630424977996741395619525301978809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22695379634897266388880229493150714409817791421484621889132650861196297\
677572120916995283153561739517119678511935035673075584613711", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "34756238157415873296112196686998918315725891343406862845253408198868320\
91647518490413525620830641070188669472295821433669496305736393", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "567027198192731246696470454098834633999513115217283390953996303097137619\
32279390672546898022182966695299207882690242302910871237124"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12729726357855364338167240196271041894276680922601096693059828615918688\
52511181538746976075290376209195063380294275", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12606837655631737333067475408594613553453381489438090207914067507802958\
65350309", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "631051846427171411202428973079832554021768497274254040532913748359809609\
10732"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "94153893174683565498014884827501732580923640693370213437997880943817587\
3896273987341825493124747819234035985655021", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31807196161518589530931259457800476165685367453856056735629437309879640\
44409186714047113853227913704549569408723099", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12199521294241003173119612694476121965511135307597353167910878998923788\
8964627445070238949633490804979018342416571", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12729726357855364338167240196271041894276680922601096693059828615918688\
52511181538746976075290376209195063380294275", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "980363203590302942713204908122716329808734906182131014244053670798086852\
84908283778232221939701449006695290350427"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10824144093189234532625122670655946583670312298428641116081360904246282\
39802971264336894119051201175696416030052647", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "490181601795151471356602454061358164904367453091065507122026835399043426\
424541418891161109698507245033476451752135"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "71779544868835485206454334864134814992082269867776384243378697778549135\
183115", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1908324896544172044820048118250067000982283647504362800504798554179472\
86587123", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "21035061547572380373414299102661085134058949909141801351097124945326986\
970244"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17885659070358154038288916426178687728072220489066978031407728146880231\
8671821", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "43975651864351898481744425187313050397143950803356321958159940292161271\
970280", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12606837655631737333067475408594613553453381489438090207914067507802958\
65350309", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "631051846427171411202428973079832554021768497274254040532913748359809609\
10732"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "71779544868835485206454334864134814992082269867776384243378697778549135\
183115", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40461711547850997151582681025168844191926205075526730687705577412874587\
5267119", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "631051846427171411202428973079832554021768497274254040532913748359809609\
10732"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "90659733246090026098608899928307536123772485819631572409763560304669196\
60809868241558139832024566462057487398332638209819576053141461710167", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "134647362922362505439053181030052736210761908408328967070421161651375972\
3600875959343764765029003469638955466355870058233761980100870603965"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "79283468938878767691128327340406004922826389575163047031687518745669449\
008995431477858039796683552871326164108169094775285828342821642820943", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "107717890337890004351242544824042188968609526726663173656336929321100777\
88807007674750118120232027757111643730846960465870095840806964831720"}], "-", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "73672463431125565979665813871151779027868583937016673859079662454824955\
75961856877588306330865946815952661819589645531148099515214667417919", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10742941580025970760092334994104741790723071653330771209764566381811440\
51468031313827304010252299497690178147731752093999536393962855", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "756036264256974995595293938798446178666017486956377854605328404129516825\
76372520896729197362910622260398943843586989737214494982832"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10785371032857510247043914113217539814429609400244372663379254872884360\
26030241264682315898856299492982415124348513", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
283027612594107406465671496688984301168090"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "43456742852919922002993301273608423844057611739478270907818925092609740\
3016951", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "79283468938878767691128327340406004922826389575163047031687518745669449\
008995431477858039796683552871326164108169094775285828342821642820943", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "107717890337890004351242544824042188968609526726663173656336929321100777\
88807007674750118120232027757111643730846960465870095840806964831720"}], "+", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57634894677796484804601073234668524311197123677798452608409588304314952\
311365910988635284867050980828093650362886667350832665149749532091007", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "538589451689450021756212724120210944843047633633315868281684646605503889\
4403503837375059060116013878555821865423480232935047920403482415860"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "54109681784346033774293107685561309441689265037082368477016829446925742\
65655643878534818708646130010808986508786794014794081105663837971291", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56451439108920382820273296556417521576129358856980613508885066344801676\
951485953771311274218407976030217193241131093321488965967097", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "55392593093606086092115464292854713929224628750268368136372845793274874\
3824444041846937303129572307992115622649362", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "60378332943787795595782629882740817113165749883606040744357911541772166\
024929", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "7367246343112556597966581387115177902786858393701667385907966245482495\
575961856877588306330865946815952661819589645531148099515214667417919", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "43087156135156001740497017929616875587443810690665269462534771728440311\
15522803069900047248092811102844657492338784186348038336322785932688"}]}], 
    "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "54109681784346033774293107685561309441689265037082368477016829446925742\
65655643878534818708646130010808986508786794014794081105663837971291", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "215435780675780008702485089648084377937219053453326347312673858642201555\
7761401534950023624046405551422328746169392093174019168161392966344"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21916584171832294786753288935950469797998240614303119399796910543536532\
10089301183647265284152862755116091398403888404411694281993843127227", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "430871561351560017404970179296168755874438106906652694625347717284403111\
5522803069900047248092811102844657492338784186348038336322785932688"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67684948635129642791122735045396550575311805837796231178850349848353387\
81525912935958914627876700480168873292456218401934081678121", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "157507555053536457415686237249676287222086976449245386376110084193649338\
7007760852015191611727304630424977996741395619525301978809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "62455306345078898588042514845794720919865718774692507791238933583190705\
408796619394152672450503518787512807472581", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "75882501183664951003710304911465586211425433512993649159220126980467885\
77208", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10742941580025970760092334994104741790723071653330771209764566381811440\
51468031313827304010252299497690178147731752093999536393962855", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "756036264256974995595293938798446178666017486956377854605328404129516825\
76372520896729197362910622260398943843586989737214494982832"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56451439108920382820273296556417521576129358856980613508885066344801676\
951485953771311274218407976030217193241131093321488965967097", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "315015110107072914831372474499352574444173952898490772752220168387298677\
4015521704030383223454609260849955993482791239050603957618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "67684948635129642791122735045396550575311805837796231178850349848353387\
81525912935958914627876700480168873292456218401934081678121", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "157507555053536457415686237249676287222086976449245386376110084193649338\
7007760852015191611727304630424977996741395619525301978809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24280791904423461147427499660312071032627062620324660818876080546389221\
10918029802050710704562552008889167918744707109012760901268903", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "756036264256974995595293938798446178666017486956377854605328404129516825\
76372520896729197362910622260398943843586989737214494982832"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21493242653414393896577956634954609270629744297076356176145425788228715\
7971568636877683849046074316063474245134712", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "92004655936923761560569414200632337701697801026767315301309167600793022\
1590151", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "1078537103285751024704391411321753981442960940024437266337925487288436\
026030241264682315898856299492982415124348513", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "32678773453010098090440163604090544326957830206071033808135122359936228\
4283027612594107406465671496688984301168090"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "55392593093606086092115464292854713929224628750268368136372845793274874\
3824444041846937303129572307992115622649362", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "62455306345078898588042514845794720919865718774692507791238933583190705\
408796619394152672450503518787512807472581", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "653575469060201961808803272081810886539156604121420676162702447198724568\
56605522518821481293134299337796860233618"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "21493242653414393896577956634954609270629744297076356176145425788228715\
7971568636877683849046074316063474245134712", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "326787734530100980904401636040905443269578302060710338081351223599362284\
28302761259410740646567149668898430116809"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22746566605863501298910983873089341239235219466398838825033877937122599\
0382170977460237794916105514293303146889636", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "163393867265050490452200818020452721634789151030355169040675611799681142\
141513806297053703232835748344492150584045"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11868064580924479284317555240019245389470831993271458314569874218573538\
138433", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "43456742852919922002993301273608423844057611739478270907818925092609740\
3016951", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "60378332943787795595782629882740817113165749883606040744357911541772166\
024929", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "75882501183664951003710304911465586211425433512993649159220126980467885\
77208", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "92004655936923761560569414200632337701697801026767315301309167600793022\
1590151", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11868064580924479284317555240019245389470831993271458314569874218573538\
138433", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31343067346663543209905966125829758827548945561844824081114960458629676\
0640813", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "59443056532090546176406884634286795690994473219202378366481393129275774\
4868249", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "52633788711936866537837509880883099699376735693419947867529391259444188\
472358", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "49316853515748626218182064587057343087616571464962309222111919258177508\
841449", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "210350615475723803734142991026610851340589499091418013510971249453269869\
70244"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14422597700309068726077294350448219570150158319499758560928123886974873\
61180125", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "33978249178693489575755681943903631020375076967425820574923119992942986\
732405", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "51190092142825849144807655239475615162371125543198055469455158173984481\
9477879", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "52633788711936866537837509880883099699376735693419947867529391259444188\
472358", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "57589194072212552021700106305655411794986006826966759267423345188228970\
476982", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24875718793096222777466133258095046403003600185507607339053257154326070\
829387", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22272188506330184875067551946739006100915847576177982687328885522939783\
4389825", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25652498443561621346722306464385870100111304720277302475678743226170529\
697476", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "68033721520293522710005327290832920996319423497383069917831536555560612\
698849", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "4931685351574862621818206458705734308761657146496230922211191925817750\
8841449", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "21035061547572380373414299102661085134058949909141801351097124945326986\
970244"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24875718793096222777466133258095046403003600185507607339053257154326070\
829387", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13193536492228511308177737476018426072168751792416066419769112682528784\
844439", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "210350615475723803734142991026610851340589499091418013510971249453269869\
70244"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24974156310912127781633761523791402945678242374829364037439463443581019\
932886", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "97688528910196855965058825780004910489457034989856382084862562643548853\
34897", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16623869100160545491087886490248232225814119814851360711173829935595587\
634629", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "14422597700309068726077294350448219570150158319499758560928123886974873\
61180125", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22272188506330184875067551946739006100915847576177982687328885522939783\
4389825", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "24974156310912127781633761523791402945678242374829364037439463443581019\
932886", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "32417673418021459203898951144760525957704203119567969554330696288092509\
27660253", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "42492405113766238126598518549642605911517499701258579265201796771863268\
732594", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10665332908958989598009311154386904334919418913829753013774641691941672\
10495903", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "3397824917869348957575568194390363102037507696742582057492311999294298\
6732405", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25652498443561621346722306464385870100111304720277302475678743226170529\
697476", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "97688528910196855965058825780004910489457034989856382084862562643548853\
34897", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "42492405113766238126598518549642605911517499701258579265201796771863268\
732594", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "97642336146119091880572983926737851848969508255367119032095934923815682\
32926", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13053971932609240305774394716794242529151332135560691733217840773074424\
398639", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "51190092142825849144807655239475615162371125543198055469455158173984481\
9477879", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "68033721520293522710005327290832920996319423497383069917831536555560612\
698849", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16623869100160545491087886490248232225814119814851360711173829935595587\
634629", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "10665332908958989598009311154386904334919418913829753013774641691941672\
10495903", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "13053971932609240305774394716794242529151332135560691733217840773074424\
398639", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "525876538689309509335357477566527128351473747728545033777428123633174674\
2561"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "35812764825371265376345121722598499173061780019173727513489192179243312\
0309093", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "841402461902895214936571964106443405362357996365672054043884997813079478\
80976"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28680212589161634541965935909872517157621292039777814836925827620263217\
394535", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16663327440164454789543128243814517606525733596305224071286419487058616\
311369", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "45590486421233224047645687183452367785437132171647321181049855256527974\
31685", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "210350615475723803734142991026610851340589499091418013510971249453269869\
70244"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "95317478595922966042578864646887387040512570168169648400648198424470957\
799097", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "62431291979872286794654645860228621855660163699776812525183191765417366\
89809", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28810722499099717370185989776976919606821955658275365503742183542928259\
038079", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "16663327440164454789543128243814517606525733596305224071286419487058616\
311369", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "105175307737861901867071495513305425670294749545709006755485624726634934\
85122"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "25187509095996343240891301223738845832819187730519082351737581207759667\
947643", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "74974560338560588987852301670854773122219044640533618909639982998842758\
61085", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56275141219963874131727968748050038540564398082929950692505110091106598\
391540", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "73058989896798749457993968625679807223251355692105635449401328645516282\
48221", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22006978090624319677379133357798776880028722026743585985881045581643854\
126911", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "4559048642123322404764568718345236778543713217164732118104985525652797\
431685", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "21035061547572380373414299102661085134058949909141801351097124945326986\
970244"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "74974560338560588987852301670854773122219044640533618909639982998842758\
61085", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "18416293036758347044746757386160073663460571081642850519761335877466042\
41207", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "631051846427171411202428973079832554021768497274254040532913748359809609\
10732"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11571391067232006405391102222505139849441511172578777603169574686767972\
492412", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31738397960384450011205425128490126757039482774259133998974031593920020\
407", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12539817585498410770409517888706699417249846543686527122013021772141614\
544047", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "95317478595922966042578864646887387040512570168169648400648198424470957\
799097", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "56275141219963874131727968748050038540564398082929950692505110091106598\
391540", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11571391067232006405391102222505139849441511172578777603169574686767972\
492412", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "71371612431785852888310512743566174750827779019465467552230865858167454\
1033731", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "126210369285434282240485794615966510804353699454850808106582749671961921\
821464"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22012092760632247438873853174329885462674199545632238439463346076421164\
823765", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20401140951726029635950790156642680811965882732057313664894242382777467\
8666305", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "126210369285434282240485794615966510804353699454850808106582749671961921\
821464"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "6243129197987228679465464586022862185566016369977681252518319176541736\
689809", " ", 
        SubscriptBox["V", "1"]}], ")"}], "/", 
      "10517530773786190186707149551330542567029474954570900675548562472663493\
485122"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "73058989896798749457993968625679807223251355692105635449401328645516282\
48221", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "31738397960384450011205425128490126757039482774259133998974031593920020\
407", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22012092760632247438873853174329885462674199545632238439463346076421164\
823765", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "17645379683587041467892696445319621618465244074591470250629540380683387\
3927", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11303497462156261979239383684563367356108022525798123441872330183017568\
476564", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "28810722499099717370185989776976919606821955658275365503742183542928259\
038079", " ", 
       SubscriptBox["V", "1"]}], ")"}], "/", 
     "420701230951447607468285982053221702681178998182836027021942498906539739\
40488"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "22006978090624319677379133357798776880028722026743585985881045581643854\
126911", " ", 
       SubscriptBox["V", "2"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "12539817585498410770409517888706699417249846543686527122013021772141614\
544047", " ", 
       SubscriptBox["V", "3"]}], ")"}], "/", 
     "315525923213585705601214486539916277010884248637127020266456874179904804\
55366"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "20401140951726029635950790156642680811965882732057313664894242382777467\
8666305", " ", 
       SubscriptBox["V", "4"]}], ")"}], "/", 
     "126210369285434282240485794615966510804353699454850808106582749671961921\
821464"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "11303497462156261979239383684563367356108022525798123441872330183017568\
476564", " ", 
       SubscriptBox["V", "5"]}], ")"}], "/", 
     "157762961606792852800607243269958138505442124318563510133228437089952402\
27683"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "40108729026939010742841541358303782322548345213151630149055853895431231\
531139", " ", 
       SubscriptBox["V", "6"]}], ")"}], "/", 
     "126210369285434282240485794615966510804353699454850808106582749671961921\
821464"}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["invset"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["V", "1"], ",", 
   SubscriptBox["V", "2"], ",", 
   SubscriptBox["V", "3"], ",", 
   SubscriptBox["V", "4"], ",", 
   SubscriptBox["V", "5"], ",", 
   SubscriptBox["V", "6"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["idealforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "1"], ",", 
   SubscriptBox["\[Theta]", "2"], ",", 
   SubscriptBox["\[Theta]", "3"], ",", 
   SubscriptBox["\[Theta]", "4"], ",", 
   SubscriptBox["\[Theta]", "5"], ",", 
   SubscriptBox["\[Theta]", "6"], ",", 
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"], ",", 
   SubscriptBox["\[Theta]", "11"], ",", 
   SubscriptBox["\[Theta]", "12"], ",", 
   SubscriptBox["\[Theta]", "13"], ",", 
   SubscriptBox["\[Theta]", "14"], ",", 
   SubscriptBox["\[Theta]", "15"], ",", 
   SubscriptBox["\[Theta]", "16"], ",", 
   SubscriptBox["\[Theta]", "17"], ",", 
   SubscriptBox["\[Theta]", "18"], ",", 
   SubscriptBox["\[Theta]", "19"], ",", 
   SubscriptBox["\[Theta]", "20"], ",", 
   SubscriptBox["\[Theta]", "21"], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "21"}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["absentforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "2"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "3"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "4"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "5"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "6"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "3"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "4"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "5"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "6"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "4"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "5"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "6"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "5"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "6"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "6"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"7", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"8", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"9", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"10", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"11", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"12", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"13", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"14", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"14", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"14", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"14", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"14", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"14", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"14", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"15", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"15", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"15", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"15", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"15", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"15", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"16", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"16", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"16", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"16", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"16", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"17", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"17", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"17", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"17", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"18", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"18", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"18", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"19", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"19", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"20", ",", "21"}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["cauchys"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To check independence for any subspace, the following commands can be \
changed to some other subset of ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " and/or of solution vectors:"
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["forms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "1"], ",", 
   SubscriptBox["\[Theta]", "2"], ",", 
   SubscriptBox["\[Theta]", "3"], ",", 
   SubscriptBox["\[Theta]", "4"], ",", 
   SubscriptBox["\[Theta]", "5"], ",", 
   SubscriptBox["\[Theta]", "6"], ",", 
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"], ",", 
   SubscriptBox["\[Theta]", "11"], ",", 
   SubscriptBox["\[Theta]", "12"], ",", 
   SubscriptBox["\[Theta]", "13"], ",", 
   SubscriptBox["\[Theta]", "14"], ",", 
   SubscriptBox["\[Theta]", "15"], ",", 
   SubscriptBox["\[Theta]", "16"], ",", 
   SubscriptBox["\[Theta]", "17"], ",", 
   SubscriptBox["\[Theta]", "18"], ",", 
   SubscriptBox["\[Theta]", "19"], ",", 
   SubscriptBox["\[Theta]", "20"], ",", 
   SubscriptBox["\[Theta]", "21"], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "21"}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sub", "=", 
  RowBox[{
   RowBox[{"forms", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "\[Wedge]", 
   RowBox[{"forms", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "\[Wedge]", 
   RowBox[{"forms", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "\[Wedge]", 
   RowBox[{"forms", "[", 
    RowBox[{"[", "4", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Theta]", "1"], "\[Wedge]", 
  SubscriptBox["\[Theta]", "2"], "\[Wedge]", 
  SubscriptBox["\[Theta]", "3"], "\[Wedge]", 
  SubscriptBox["\[Theta]", "4"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"checkinvolution", "=", 
  RowBox[{
   RowBox[{"charv", "[", "4", "]"}], "\[SmallCircle]", 
   RowBox[{"charv", "[", "3", "]"}], "\[SmallCircle]", 
   RowBox[{"charv", "[", "2", "]"}], "\[SmallCircle]", 
   RowBox[{"charv", "[", "1", "]"}], "\[SmallCircle]", "sub"}]}]], "Input"],

Cell[BoxData[
 FractionBox["208853450847117", "3505824100"]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Changing the order of the basis 1-forms in the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list can be accomplished by executing the next cell to get the ",
 StyleBox["idealforms", "Input",
  FontWeight->"Plain"],
 " list and then re-ordering the output line. It will convert to input format \
with the first edit. Continue editing in this line. \n\nWhen finished (being \
careful not to omit or duplicate any forms and/or commas), type ",
 StyleBox["new=", "Input",
  FontWeight->"Plain"],
 " in front of the new list and enter. Then execute the ",
 StyleBox["makeforms[new]", "Input",
  FontWeight->"Plain"],
 " statement. To change ",
 StyleBox["maxrandom", "Input",
  FontWeight->"Plain"],
 " assign a new value in the next statement; if ",
 StyleBox["maxrandom", "Input",
  FontWeight->"Plain"],
 " is not re-set it will retain the previous value.\n\nFinally, select the ",
 StyleBox["characters", "Input",
  FontWeight->"Plain"],
 " cell and enter. Doing this last step alone will simply repeat a \
calculation with the same ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list and a randomly different set of integers selected from the same \
range.  \n\nRe-ordering the ",
 StyleBox["forms", "Input",
  FontWeight->"Plain"],
 " list can have a significant effect on the size of generated integers and \
so may have some effect on time and memory usage. As a general rule, placing \
the basis forms which appear more frequently in the ideal at the end of the \
list, gives smaller integers and a simpler solution. "
}], "Text",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData["idealforms"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Theta]", "1"], ",", 
   SubscriptBox["\[Theta]", "2"], ",", 
   SubscriptBox["\[Theta]", "3"], ",", 
   SubscriptBox["\[Theta]", "4"], ",", 
   SubscriptBox["\[Theta]", "5"], ",", 
   SubscriptBox["\[Theta]", "6"], ",", 
   SubscriptBox["\[Theta]", "7"], ",", 
   SubscriptBox["\[Theta]", "8"], ",", 
   SubscriptBox["\[Theta]", "9"], ",", 
   SubscriptBox["\[Theta]", "10"], ",", 
   SubscriptBox["\[Theta]", "11"], ",", 
   SubscriptBox["\[Theta]", "12"], ",", 
   SubscriptBox["\[Theta]", "13"], ",", 
   SubscriptBox["\[Theta]", "14"], ",", 
   SubscriptBox["\[Theta]", "15"], ",", 
   SubscriptBox["\[Theta]", "16"], ",", 
   SubscriptBox["\[Theta]", "17"], ",", 
   SubscriptBox["\[Theta]", "18"], ",", 
   SubscriptBox["\[Theta]", "19"], ",", 
   SubscriptBox["\[Theta]", "20"], ",", 
   SubscriptBox["\[Theta]", "21"], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "7"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "8"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "9"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "10"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "11"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "12"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "13"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "14"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "15"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "16"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "17"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "18"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "19"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "20"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"1", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"2", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"3", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"4", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"5", ",", "21"}]], ",", 
   SubscriptBox["\[Omega]", 
    RowBox[{"6", ",", "21"}]]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IV.d.10. Clean up", "Subsubsection"],

Cell[BoxData[
 RowBox[{"makeclear", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell["Cleaning up must be done by hand here, for these variables:", "Text"],

Cell[CellGroupData[{

Cell[BoxData["ModifiedGlobalVariables"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"cosub\"\>", ",", "\<\"sub\"\>", ",", "\<\"tosub\"\>", 
   ",", "\<\"maxrandom\"\>", ",", "\<\"embeddingforms\"\>", 
   ",", "\<\"solutionvectors\"\>", ",", "\<\"involutoryvectors\"\>", 
   ",", "\<\"allones\"\>", ",", "\<\"genvec\"\>", ",", "\<\"invset\"\>", 
   ",", "\<\"idealforms\"\>", ",", "\<\"absentforms\"\>", 
   ",", "\<\"cauchys\"\>", ",", "\<\"checkinvolution\"\>"}], "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1062, 769},
WindowMargins->{{103, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
ShowSelection->True,
MacintoshSystemPageSetup -> \
"00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001\n\
0000I00000400`<300000BL?00400@gZlT0000000000060801T1T00000000000\n\
00000000004000000000000000000000",
Magnification->1.5,
FrontEndVersion->"7.0 for Linux x86 (64-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "S5.52.1"->{
  Cell[503236, 18050, 101, 2, 157, "Input",
   CellTags->"S5.52.1"],
  Cell[503340, 18054, 617, 12, 157, "Message",
   CellTags->"S5.52.1"]},
 "reference"->{
  Cell[548043, 19479, 341, 10, 157, "Text",
   CellTags->"reference"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"S5.52.1", 2943946, 84417},
 {"reference", 2944104, 84422}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 108, 5, 125, "Title"],
Cell[678, 29, 94, 1, 78, "Subtitle"],
Cell[775, 32, 263, 7, 141, "Subsubtitle"],
Cell[1041, 41, 2410, 62, 677, "Text"],
Cell[3454, 105, 625, 13, 264, "Text"],
Cell[4082, 120, 744, 14, 264, "Text"],
Cell[CellGroupData[{
Cell[4851, 138, 65, 1, 108, "Section"],
Cell[4919, 141, 64, 0, 44, "Text"],
Cell[CellGroupData[{
Cell[5008, 145, 43, 0, 58, "Subsection"],
Cell[5054, 147, 613, 13, 313, "Text",
 PageBreakBelow->Automatic]
}, Closed]],
Cell[CellGroupData[{
Cell[5704, 165, 43, 0, 44, "Subsection"],
Cell[5750, 167, 327, 10, 190, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[6080, 179, 107, 3, 66, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[6190, 184, 666, 21, 108, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[6859, 207, 172, 5, 66, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[CellGroupData[{
Cell[7056, 216, 49, 0, 63, "Subsubsection"],
Cell[7108, 218, 474, 16, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[7585, 236, 378, 12, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[7966, 250, 754, 23, 157, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[8723, 275, 324, 9, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[9050, 286, 1796, 61, 157, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[10849, 349, 732, 23, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[11584, 374, 805, 27, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[12392, 403, 1008, 30, 157, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[13403, 435, 321, 12, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[13727, 449, 807, 23, 157, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[14537, 474, 921, 24, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[15461, 500, 383, 11, 157, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[15847, 513, 294, 9, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic]
}, Closed]],
Cell[CellGroupData[{
Cell[16178, 527, 39, 0, 46, "Subsubsection"],
Cell[16220, 529, 733, 22, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[16956, 553, 997, 33, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[17956, 588, 1560, 52, 157, "Text"],
Cell[19519, 642, 883, 23, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[20405, 667, 563, 18, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic]
}, Closed]],
Cell[CellGroupData[{
Cell[21005, 690, 40, 0, 46, "Subsubsection"],
Cell[21048, 692, 712, 18, 157, "Text"],
Cell[21763, 712, 1951, 67, 157, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[23717, 781, 800, 24, 157, "Text"],
Cell[24520, 807, 141, 3, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[24664, 812, 306, 8, 157, "Input",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[24973, 822, 687, 22, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[25663, 846, 1110, 32, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[26776, 880, 480, 13, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[27259, 895, 1030, 29, 157, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[28338, 930, 42, 0, 44, "Subsection"],
Cell[28383, 932, 158, 5, 157, "Text",
 PageBreakBelow->Automatic],
Cell[28544, 939, 1831, 55, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[30378, 996, 2225, 69, 157, "Text"],
Cell[CellGroupData[{
Cell[32628, 1069, 37, 0, 157, "Subsubsection"],
Cell[32668, 1071, 656, 16, 157, "Text"],
Cell[33327, 1089, 1743, 60, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[35073, 1151, 1094, 26, 157, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36204, 1182, 38, 0, 157, "Subsubsection"],
Cell[36245, 1184, 661, 19, 157, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[36955, 1209, 47, 0, 44, "Subsection"],
Cell[37005, 1211, 294, 8, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[CellGroupData[{
Cell[37324, 1223, 46, 0, 157, "Subsubsection"],
Cell[37373, 1225, 768, 19, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[38144, 1246, 322, 9, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[38469, 1257, 273, 5, 157, "Text"],
Cell[38745, 1264, 601, 13, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[39349, 1279, 483, 12, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[39835, 1293, 480, 14, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic]
}, Open  ]],
Cell[CellGroupData[{
Cell[40352, 1312, 41, 0, 157, "Subsubsection"],
Cell[40396, 1314, 1149, 42, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[41548, 1358, 327, 9, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[41878, 1369, 137, 4, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[42018, 1375, 937, 35, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[42958, 1412, 564, 16, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic]
}, Open  ]],
Cell[CellGroupData[{
Cell[43559, 1433, 50, 0, 157, "Subsubsection"],
Cell[43612, 1435, 1265, 39, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[44880, 1476, 759, 21, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[45642, 1499, 875, 28, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[46520, 1529, 1636, 49, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[48159, 1580, 970, 32, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[49132, 1614, 544, 17, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[49679, 1633, 341, 10, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[50023, 1645, 847, 25, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[50873, 1672, 717, 21, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[51593, 1695, 337, 8, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[51933, 1705, 151, 4, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[52087, 1711, 356, 9, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[52492, 1726, 70, 0, 44, "Subsection"],
Cell[52565, 1728, 960, 32, 157, "Text",
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[53528, 1762, 3085, 112, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[56616, 1876, 121, 2, 157, "Text",
 PageBreakBelow->Automatic],
Cell[56740, 1880, 439, 14, 157, "Input",
 Evaluatable->False,
 PageBreakBelow->Automatic],
Cell[57182, 1896, 710, 21, 157, "Text",
 PageBreakBelow->Automatic]
}, Closed]],
Cell[CellGroupData[{
Cell[57929, 1922, 44, 0, 44, "Subsection"],
Cell[57976, 1924, 784, 24, 157, "Text"],
Cell[58763, 1950, 965, 32, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[59731, 1984, 403, 13, 157, "Text"],
Cell[60137, 1999, 396, 12, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[60536, 2013, 147, 4, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[60686, 2019, 433, 14, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[61122, 2035, 203, 6, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[61328, 2043, 406, 13, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[61737, 2058, 206, 6, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[CellGroupData[{
Cell[61968, 2068, 49, 0, 157, "Subsubsection"],
Cell[62020, 2070, 530, 19, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[62553, 2091, 1090, 29, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[63646, 2122, 326, 10, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[63975, 2134, 907, 25, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[64885, 2161, 1593, 52, 157, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66515, 2218, 66, 0, 157, "Subsubsection"],
Cell[66584, 2220, 592, 22, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[67179, 2244, 2492, 71, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[69674, 2317, 560, 19, 157, "Text"],
Cell[70237, 2338, 4791, 145, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[75031, 2485, 407, 10, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[75441, 2497, 1303, 42, 157, "Text"],
Cell[76747, 2541, 2065, 64, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[78815, 2607, 337, 9, 157, "Text",
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[79155, 2618, 1175, 38, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[80333, 2658, 950, 31, 157, "Text"],
Cell[81286, 2691, 1059, 33, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[82348, 2726, 1129, 40, 157, "Text"],
Cell[83480, 2768, 1732, 54, 157, "Text"],
Cell[85215, 2824, 401, 13, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[85619, 2839, 264, 8, 157, "Text",
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[85886, 2849, 1686, 53, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[87575, 2904, 408, 10, 157, "Text",
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic],
Cell[87986, 2916, 1232, 35, 157, "Text"],
Cell[89221, 2953, 1049, 33, 157, "Input",
 Evaluatable->False,
 PageBreakAbove->Automatic,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[90319, 2992, 63, 0, 44, "Subsection"],
Cell[90385, 2994, 511, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[90921, 3012, 40, 0, 157, "Subsubsection"],
Cell[90964, 3014, 10775, 276, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[101776, 3295, 41, 0, 157, "Subsubsection"],
Cell[101820, 3297, 354, 9, 157, "Text"],
Cell[102177, 3308, 18094, 486, 157, "Text",
 PageBreakAbove->False,
 PageBreakWithin->False,
 PageBreakBelow->Automatic]
}, Closed]],
Cell[CellGroupData[{
Cell[120308, 3799, 82, 1, 157, "Subsubsection"],
Cell[120393, 3802, 2382, 97, 157, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[122836, 3906, 72, 1, 108, "Section"],
Cell[122911, 3909, 139, 3, 72, "Text"],
Cell[123053, 3914, 95, 5, 44, "Text"],
Cell[CellGroupData[{
Cell[123173, 3923, 53, 1, 46, "Input"],
Cell[CellGroupData[{
Cell[123251, 3928, 96, 1, 35, "Print"],
Cell[123350, 3931, 82, 1, 35, "Print"],
Cell[123435, 3934, 113, 1, 35, "Print"],
Cell[123551, 3937, 96, 1, 35, "Print"],
Cell[123650, 3940, 251, 3, 94, "Print"],
Cell[123904, 3945, 96, 1, 35, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124049, 3952, 42, 0, 58, "Subsection"],
Cell[CellGroupData[{
Cell[124116, 3956, 79, 0, 157, "Subsubsection"],
Cell[124198, 3958, 59, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[124282, 3962, 121, 3, 157, "Input"],
Cell[124406, 3967, 83, 2, 157, "Output"]
}, Open  ]],
Cell[124504, 3972, 62, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[124591, 3976, 33, 0, 157, "Input"],
Cell[124627, 3978, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124747, 3985, 31, 0, 157, "Input"],
Cell[124781, 3987, 28, 0, 157, "Output"]
}, Open  ]],
Cell[124824, 3990, 132, 4, 157, "Text"],
Cell[CellGroupData[{
Cell[124981, 3998, 34, 0, 157, "Input"],
Cell[125018, 4000, 86, 2, 157, "Output"]
}, Open  ]],
Cell[125119, 4005, 177, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[125321, 4016, 31, 0, 157, "Input"],
Cell[125355, 4018, 86, 2, 157, "Output"]
}, Open  ]],
Cell[125456, 4023, 337, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[125818, 4037, 134, 3, 157, "Input"],
Cell[125955, 4042, 137, 4, 157, "Output"]
}, Open  ]],
Cell[126107, 4049, 345, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[126477, 4065, 32, 0, 157, "Input"],
Cell[126512, 4067, 101, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126650, 4074, 32, 0, 157, "Input"],
Cell[126685, 4076, 191, 5, 157, "Output"]
}, Open  ]],
Cell[126891, 4084, 296, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[127212, 4101, 34, 0, 157, "Input"],
Cell[127249, 4103, 57, 1, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127343, 4109, 33, 0, 157, "Input"],
Cell[127379, 4111, 80, 2, 157, "Output"]
}, Open  ]],
Cell[127474, 4116, 337, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[127836, 4127, 228, 7, 157, "Input"],
Cell[128067, 4136, 185, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128289, 4147, 34, 0, 157, "Input"],
Cell[128326, 4149, 185, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128548, 4160, 31, 0, 157, "Input"],
Cell[128582, 4162, 28, 0, 157, "Output"]
}, Open  ]],
Cell[128625, 4165, 956, 30, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[129618, 4200, 131, 3, 157, "Subsubsection"],
Cell[129752, 4205, 312, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[130089, 4216, 791, 27, 157, "Input"],
Cell[130883, 4245, 857, 30, 157, "Output"]
}, Open  ]],
Cell[131755, 4278, 338, 14, 157, "Text"],
Cell[132096, 4294, 115, 3, 157, "Input"],
Cell[CellGroupData[{
Cell[132236, 4301, 33, 0, 157, "Input"],
Cell[132272, 4303, 857, 30, 157, "Output"]
}, Open  ]],
Cell[133144, 4336, 117, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[133286, 4342, 75, 2, 157, "Input",
 PageBreakAbove->False],
Cell[133364, 4346, 1167, 39, 157, "Output"]
}, Open  ]],
Cell[134546, 4388, 418, 16, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[135001, 4409, 123, 3, 157, "Subsubsection"],
Cell[135127, 4414, 479, 14, 157, "Text"],
Cell[135609, 4430, 1034, 40, 157, "Input"],
Cell[136646, 4472, 222, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[136893, 4484, 172, 6, 157, "Input"],
Cell[137068, 4492, 31, 0, 157, "Output"]
}, Open  ]],
Cell[137114, 4495, 430, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[137569, 4516, 34, 0, 157, "Input"],
Cell[137606, 4518, 185, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137828, 4529, 83, 2, 157, "Input"],
Cell[137914, 4533, 805, 30, 157, "Output"]
}, Open  ]],
Cell[138734, 4566, 161, 5, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[138932, 4576, 80, 1, 157, "Subsubsection",
 PageBreakAbove->True],
Cell[139015, 4579, 537, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[139577, 4600, 252, 7, 157, "Input"],
Cell[139832, 4609, 222, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140091, 4620, 257, 8, 157, "Input"],
Cell[140351, 4630, 226, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140614, 4642, 50, 0, 157, "Input"],
Cell[140667, 4644, 83, 2, 157, "Output"],
Cell[140753, 4648, 137, 4, 157, "Output"]
}, Open  ]],
Cell[140905, 4655, 438, 12, 157, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[141392, 4673, 48, 0, 44, "Subsection"],
Cell[CellGroupData[{
Cell[141465, 4677, 115, 3, 157, "Subsubsection"],
Cell[141583, 4682, 490, 13, 157, "Text"],
Cell[142076, 4697, 216, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[142317, 4708, 205, 7, 157, "Input"],
Cell[142525, 4717, 308, 9, 157, "Output"]
}, Open  ]],
Cell[142848, 4729, 199, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[143072, 4740, 56, 1, 157, "Input"],
Cell[143131, 4743, 181, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143349, 4752, 82, 2, 157, "Input"],
Cell[143434, 4756, 816, 20, 157, "Output"]
}, Open  ]],
Cell[144265, 4779, 163, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[144453, 4788, 230, 7, 157, "Input"],
Cell[144686, 4797, 31, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144754, 4802, 111, 3, 157, "Input"],
Cell[144868, 4807, 32, 0, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[144949, 4813, 120, 3, 157, "Subsubsection"],
Cell[145072, 4818, 212, 6, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[145309, 4828, 62, 1, 157, "Input"],
Cell[145374, 4831, 730, 19, 157, "Output"]
}, Open  ]],
Cell[146119, 4853, 116, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[146260, 4859, 63, 1, 157, "Input"],
Cell[146326, 4862, 925, 26, 157, "Output"]
}, Open  ]],
Cell[147266, 4891, 393, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[147684, 4909, 144, 4, 157, "Input"],
Cell[147831, 4915, 1611, 43, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149479, 4963, 62, 1, 157, "Input"],
Cell[149544, 4966, 2050, 52, 157, "Output"]
}, Open  ]],
Cell[151609, 5021, 276, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[151910, 5035, 113, 3, 157, "Input"],
Cell[152026, 5040, 526, 16, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152589, 5061, 139, 4, 157, "Input"],
Cell[152731, 5067, 378, 12, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[153158, 5085, 142, 4, 157, "Subsubsection",
 PageBreakAbove->True],
Cell[153303, 5091, 806, 25, 157, "Text"],
Cell[CellGroupData[{
Cell[154134, 5120, 30, 0, 157, "Input"],
Cell[154167, 5122, 257, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154461, 5135, 30, 0, 157, "Input"],
Cell[154494, 5137, 257, 8, 157, "Output"]
}, Open  ]],
Cell[154766, 5148, 327, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[155118, 5163, 31, 0, 157, "Input"],
Cell[155152, 5165, 137, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155326, 5174, 118, 3, 157, "Input"],
Cell[155447, 5179, 96, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155580, 5187, 30, 0, 157, "Input"],
Cell[155613, 5189, 226, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155876, 5201, 68, 1, 157, "Input"],
Cell[155947, 5204, 301, 10, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[156285, 5219, 65, 1, 157, "Input"],
Cell[156353, 5222, 28, 0, 157, "Output"]
}, Open  ]],
Cell[156396, 5225, 99, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[156520, 5231, 97, 2, 157, "Input"],
Cell[156620, 5235, 2682, 75, 157, "Output"]
}, Open  ]],
Cell[159317, 5313, 117, 3, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[159459, 5320, 157, 3, 157, "Input"],
Cell[159619, 5325, 3178, 88, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162834, 5418, 60, 1, 157, "Input"],
Cell[162897, 5421, 3000, 81, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165934, 5507, 65, 1, 157, "Input"],
Cell[166002, 5510, 83, 2, 157, "Output"]
}, Open  ]],
Cell[166100, 5515, 722, 19, 157, "Text"],
Cell[166825, 5536, 153, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[167003, 5545, 105, 3, 157, "Input"],
Cell[167111, 5550, 251, 8, 157, "Output"]
}, Open  ]],
Cell[167377, 5561, 151, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[167553, 5572, 112, 3, 157, "Input"],
Cell[167668, 5577, 287, 8, 157, "Output"]
}, Open  ]],
Cell[167970, 5588, 178, 7, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[168185, 5600, 117, 3, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[168327, 5607, 30, 0, 157, "Input"],
Cell[168360, 5609, 816, 20, 157, "Output"]
}, Open  ]],
Cell[169191, 5632, 264, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[169480, 5646, 117, 3, 157, "Input"],
Cell[169600, 5651, 345, 8, 157, "Output"]
}, Open  ]],
Cell[169960, 5662, 325, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[170310, 5677, 90, 2, 157, "Input"],
Cell[170403, 5681, 1227, 30, 157, "Output"]
}, Open  ]],
Cell[171645, 5714, 386, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[172056, 5731, 59, 1, 157, "Input"],
Cell[172118, 5734, 425, 12, 157, "Output"]
}, Open  ]],
Cell[172558, 5749, 387, 16, 157, "Text"],
Cell[172948, 5767, 168, 5, 157, "Text"],
Cell[173119, 5774, 1095, 29, 157, "Input"],
Cell[174217, 5805, 75, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[174317, 5811, 129, 3, 157, "Input"],
Cell[174449, 5816, 222, 6, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[174720, 5828, 187, 8, 157, "Subsubsection"],
Cell[174910, 5838, 535, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[175470, 5859, 62, 1, 157, "Input"],
Cell[175535, 5862, 521, 16, 157, "Output"]
}, Open  ]],
Cell[176071, 5881, 332, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[176428, 5894, 59, 1, 157, "Input"],
Cell[176490, 5897, 816, 20, 157, "Output"]
}, Open  ]],
Cell[177321, 5920, 621, 21, 157, "Text"],
Cell[177945, 5943, 456, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[178426, 5959, 83, 2, 157, "Input"],
Cell[178512, 5963, 727, 19, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179276, 5987, 59, 1, 157, "Input"],
Cell[179338, 5990, 425, 12, 157, "Output"]
}, Open  ]],
Cell[179778, 6005, 504, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[180307, 6022, 147, 3, 157, "Input"],
Cell[180457, 6027, 148, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180642, 6035, 59, 1, 157, "Input"],
Cell[180704, 6038, 104, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180845, 6046, 129, 3, 157, "Input"],
Cell[180977, 6051, 104, 3, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[181142, 6061, 56, 0, 44, "Subsection"],
Cell[CellGroupData[{
Cell[181223, 6065, 57, 0, 157, "Subsubsection"],
Cell[181283, 6067, 213, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[181521, 6079, 30, 0, 157, "Input"],
Cell[181554, 6081, 222, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181813, 6092, 57, 1, 157, "Input"],
Cell[181873, 6095, 387, 10, 157, "Output"]
}, Open  ]],
Cell[182275, 6108, 342, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[182642, 6124, 57, 1, 157, "Input"],
Cell[182702, 6127, 2024, 48, 157, "Output"]
}, Open  ]],
Cell[184741, 6178, 199, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[184965, 6190, 107, 3, 157, "Input"],
Cell[185075, 6195, 741, 21, 157, "Output"]
}, Open  ]],
Cell[185831, 6219, 116, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[185972, 6226, 60, 1, 157, "Input"],
Cell[186035, 6229, 3782, 85, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189854, 6319, 54, 1, 157, "Input"],
Cell[189911, 6322, 171, 6, 157, "Output"]
}, Open  ]],
Cell[190097, 6331, 522, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[190644, 6347, 254, 8, 157, "Input"],
Cell[190901, 6357, 31, 0, 157, "Output"]
}, Open  ]],
Cell[190947, 6360, 548, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[191520, 6381, 311, 10, 157, "Input"],
Cell[191834, 6393, 283, 9, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192154, 6407, 57, 1, 157, "Input"],
Cell[192214, 6410, 622, 19, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192873, 6434, 91, 2, 157, "Input"],
Cell[192967, 6438, 205, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193209, 6449, 54, 1, 157, "Input"],
Cell[193266, 6452, 586, 16, 157, "Output"]
}, Open  ]],
Cell[193867, 6471, 141, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[194033, 6478, 126, 3, 157, "Input"],
Cell[194162, 6483, 843, 28, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[195054, 6517, 178, 7, 157, "Subsubsection"],
Cell[195235, 6526, 1260, 35, 157, "Text"],
Cell[CellGroupData[{
Cell[196520, 6565, 33, 0, 157, "Input"],
Cell[196556, 6567, 191, 5, 157, "Output"]
}, Open  ]],
Cell[196762, 6575, 410, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[197197, 6593, 32, 0, 157, "Input"],
Cell[197232, 6595, 191, 5, 157, "Output"]
}, Open  ]],
Cell[197438, 6603, 161, 4, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[197624, 6611, 339, 9, 157, "Input"],
Cell[197966, 6622, 317, 8, 157, "Output"]
}, Open  ]],
Cell[198298, 6633, 307, 12, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[198630, 6649, 71, 1, 157, "Input"],
Cell[198704, 6652, 317, 8, 157, "Output"]
}, Open  ]],
Cell[199036, 6663, 455, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[199516, 6684, 57, 1, 157, "Input"],
Cell[199576, 6687, 299, 9, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[199912, 6701, 64, 1, 157, "Input"],
Cell[199979, 6704, 357, 10, 157, "Output"]
}, Open  ]],
Cell[200351, 6717, 669, 24, 157, "Text"],
Cell[CellGroupData[{
Cell[201045, 6745, 81, 2, 157, "Input"],
Cell[201129, 6749, 191, 5, 157, "Output"]
}, Open  ]],
Cell[201335, 6757, 97, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[201457, 6764, 95, 2, 157, "Input"],
Cell[201555, 6768, 157, 5, 157, "Output"]
}, Open  ]],
Cell[201727, 6776, 203, 9, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[201955, 6789, 71, 1, 157, "Input"],
Cell[202029, 6792, 317, 8, 157, "Output"]
}, Open  ]],
Cell[202361, 6803, 455, 15, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[202841, 6822, 86, 2, 157, "Input"],
Cell[202930, 6826, 61, 1, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[203028, 6832, 64, 1, 157, "Input"],
Cell[203095, 6835, 175, 5, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[203307, 6845, 87, 2, 157, "Input"],
Cell[203397, 6849, 175, 5, 157, "Output"]
}, Open  ]],
Cell[203587, 6857, 385, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[203997, 6873, 32, 0, 157, "Input"],
Cell[204032, 6875, 101, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204170, 6882, 59, 1, 157, "Input"],
Cell[204232, 6885, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204352, 6892, 60, 1, 157, "Input"],
Cell[204415, 6895, 83, 2, 157, "Output"]
}, Open  ]],
Cell[204513, 6900, 67, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[204605, 6906, 31, 0, 157, "Input"],
Cell[204639, 6908, 137, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204813, 6917, 58, 1, 157, "Input"],
Cell[204874, 6920, 137, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205048, 6929, 59, 1, 157, "Input"],
Cell[205110, 6932, 332, 10, 157, "Output"]
}, Open  ]],
Cell[205457, 6945, 311, 9, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[205793, 6958, 59, 1, 157, "Input"],
Cell[205855, 6961, 110, 3, 157, "Output"]
}, Open  ]],
Cell[205980, 6967, 206, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[206211, 6979, 54, 1, 157, "Input"],
Cell[206268, 6982, 134, 3, 157, "Output"]
}, Open  ]],
Cell[206417, 6988, 142, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[206584, 6995, 64, 1, 157, "Input"],
Cell[206651, 6998, 28, 0, 157, "Output"]
}, Open  ]],
Cell[206694, 7001, 105, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[206824, 7008, 264, 7, 157, "Input"],
Cell[207091, 7017, 31, 0, 157, "Output"]
}, Open  ]],
Cell[207137, 7020, 145, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[207307, 7027, 88, 2, 157, "Input"],
Cell[207398, 7031, 116, 3, 157, "Output"]
}, Open  ]],
Cell[207529, 7037, 241, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[207795, 7050, 85, 2, 157, "Input"],
Cell[207883, 7054, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207948, 7059, 87, 2, 157, "Input"],
Cell[208038, 7063, 28, 0, 157, "Output"]
}, Open  ]],
Cell[208081, 7066, 675, 18, 157, "Text"],
Cell[CellGroupData[{
Cell[208781, 7088, 70, 1, 157, "Input"],
Cell[208854, 7091, 512, 18, 157, "Output"]
}, Open  ]],
Cell[209381, 7112, 393, 14, 157, "Text"],
Cell[209777, 7128, 629, 16, 157, "Text",
 PageBreakAbove->True]
}, Closed]],
Cell[CellGroupData[{
Cell[210443, 7149, 63, 0, 157, "Subsubsection"],
Cell[210509, 7151, 265, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[210799, 7165, 63, 1, 157, "Input"],
Cell[210865, 7168, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210985, 7175, 131, 3, 157, "Input"],
Cell[211119, 7180, 100, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211256, 7187, 135, 3, 157, "Input"],
Cell[211394, 7192, 136, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211567, 7201, 34, 0, 157, "Input"],
Cell[211604, 7203, 143, 4, 157, "Output"]
}, Open  ]],
Cell[211762, 7210, 505, 18, 157, "Text"],
Cell[CellGroupData[{
Cell[212292, 7232, 492, 13, 157, "Input"],
Cell[212787, 7247, 474, 13, 157, "Output"]
}, Open  ]],
Cell[213276, 7263, 266, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[213567, 7278, 62, 1, 157, "Input"],
Cell[213632, 7281, 376, 10, 157, "Output"]
}, Open  ]],
Cell[214023, 7294, 290, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[214338, 7307, 246, 7, 157, "Input"],
Cell[214587, 7316, 1230, 30, 157, "Output"]
}, Open  ]],
Cell[215832, 7349, 195, 6, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[216052, 7359, 123, 3, 157, "Input"],
Cell[216178, 7364, 1651, 41, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217866, 7410, 171, 5, 157, "Input"],
Cell[218040, 7417, 136, 4, 157, "Output"]
}, Open  ]],
Cell[218191, 7424, 105, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[218321, 7431, 101, 2, 157, "Input"],
Cell[218425, 7435, 77, 1, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[218539, 7441, 62, 1, 157, "Input"],
Cell[218604, 7444, 1172, 29, 157, "Output"]
}, Open  ]],
Cell[219791, 7476, 320, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[220136, 7491, 59, 1, 157, "Input"],
Cell[220198, 7494, 1172, 29, 157, "Output"]
}, Open  ]],
Cell[221385, 7526, 223, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[221633, 7538, 59, 1, 157, "Input"],
Cell[221695, 7541, 1238, 32, 157, "Output"]
}, Open  ]],
Cell[222948, 7576, 198, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[223171, 7588, 61, 1, 157, "Input"],
Cell[223235, 7591, 191, 5, 157, "Output"]
}, Open  ]],
Cell[223441, 7599, 188, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[223654, 7611, 68, 1, 157, "Input"],
Cell[223725, 7614, 1230, 30, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[224992, 7649, 101, 2, 157, "Input"],
Cell[225096, 7653, 191, 5, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[225336, 7664, 41, 0, 157, "Subsubsection"],
Cell[225380, 7666, 587, 17, 157, "Text"],
Cell[225970, 7685, 113, 5, 157, "Text"],
Cell[226086, 7692, 106, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[226217, 7699, 49, 0, 157, "Input"],
Cell[226269, 7701, 531, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[226837, 7714, 69, 1, 157, "Input"],
Cell[226909, 7717, 1339, 64, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[228285, 7786, 58, 1, 157, "Input"],
Cell[228346, 7789, 8860, 260, 157, "Output"]
}, Open  ]],
Cell[237221, 8052, 164, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[237410, 8061, 95, 2, 157, "Input"],
Cell[237508, 8065, 57, 1, 157, "Output"]
}, Open  ]],
Cell[237580, 8069, 118, 3, 157, "Input"],
Cell[CellGroupData[{
Cell[237723, 8076, 80, 2, 157, "Input"],
Cell[237806, 8080, 143, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237986, 8089, 82, 2, 157, "Input"],
Cell[238071, 8093, 45, 1, 157, "Output"]
}, Open  ]],
Cell[238131, 8097, 20, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[238176, 8101, 49, 0, 157, "Input"],
Cell[238228, 8103, 45, 1, 157, "Output"]
}, Open  ]],
Cell[238288, 8107, 314, 9, 157, "Text"],
Cell[238605, 8118, 214, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[238844, 8130, 51, 1, 157, "Input"],
Cell[238898, 8133, 9357, 230, 157, "Print"]
}, Open  ]],
Cell[248270, 8366, 88, 2, 157, "Text"],
Cell[248361, 8370, 74, 1, 157, "Input"],
Cell[248438, 8373, 116, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[248579, 8382, 51, 1, 157, "Input"],
Cell[248633, 8385, 419, 8, 157, "Message"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[249113, 8400, 47, 0, 44, "Subsection"],
Cell[CellGroupData[{
Cell[249185, 8404, 90, 1, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[249300, 8409, 121, 3, 157, "Input"],
Cell[249424, 8414, 83, 2, 157, "Output"]
}, Open  ]],
Cell[249522, 8419, 136, 4, 157, "Text"],
Cell[249661, 8425, 323, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[250009, 8436, 51, 1, 157, "Input"],
Cell[250063, 8439, 570, 16, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[250682, 8461, 108, 2, 157, "Subsubsection"],
Cell[250793, 8465, 186, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[251004, 8476, 31, 0, 157, "Input"],
Cell[251038, 8478, 86, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[251161, 8485, 30, 0, 157, "Input"],
Cell[251194, 8487, 155, 5, 157, "Output"]
}, Open  ]],
Cell[251364, 8495, 592, 20, 157, "Text"],
Cell[CellGroupData[{
Cell[251981, 8519, 146, 4, 157, "Input"],
Cell[252130, 8525, 852, 31, 157, "Output"]
}, Open  ]],
Cell[252997, 8559, 137, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[253159, 8566, 57, 1, 157, "Input"],
Cell[253219, 8569, 83, 2, 157, "Output"]
}, Open  ]],
Cell[253317, 8574, 711, 20, 157, "Text"],
Cell[254031, 8596, 349, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[254405, 8613, 307, 9, 157, "Input"],
Cell[254715, 8624, 278, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255030, 8637, 439, 14, 157, "Input"],
Cell[255472, 8653, 420, 13, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255929, 8671, 79, 2, 157, "Input"],
Cell[256011, 8675, 7594, 255, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[263654, 8936, 202, 7, 157, "Subsubsection"],
Cell[263859, 8945, 917, 29, 157, "Text"],
Cell[264779, 8976, 438, 16, 157, "Text"],
Cell[CellGroupData[{
Cell[265242, 8996, 351, 11, 157, "Input"],
Cell[265596, 9009, 86, 2, 157, "Output"],
Cell[265685, 9013, 228, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265950, 9025, 196, 5, 157, "Input"],
Cell[266149, 9032, 153, 4, 157, "Output"]
}, Open  ]],
Cell[266317, 9039, 161, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[266503, 9050, 120, 3, 157, "Input"],
Cell[266626, 9055, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[266746, 9062, 33, 0, 157, "Input"],
Cell[266782, 9064, 153, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[266972, 9073, 32, 0, 157, "Input"],
Cell[267007, 9075, 1475, 50, 157, "Output"]
}, Open  ]],
Cell[268497, 9128, 149, 4, 157, "Text"],
Cell[CellGroupData[{
Cell[268671, 9136, 79, 2, 157, "Input"],
Cell[268753, 9140, 2149, 65, 157, "Output"]
}, Open  ]],
Cell[270917, 9208, 266, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[271208, 9218, 247, 7, 157, "Input"],
Cell[271458, 9227, 1660, 56, 157, "Output"]
}, Open  ]],
Cell[273133, 9286, 225, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[273383, 9297, 112, 3, 157, "Input"],
Cell[273498, 9302, 276, 6, 157, "Output"]
}, Open  ]],
Cell[273789, 9311, 166, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[273980, 9322, 113, 3, 157, "Input"],
Cell[274096, 9327, 803, 26, 157, "Output"]
}, Open  ]],
Cell[274914, 9356, 109, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[275048, 9362, 150, 4, 157, "Input"],
Cell[275201, 9368, 1418, 44, 157, "Output"]
}, Open  ]],
Cell[276634, 9415, 416, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[277075, 9433, 82, 2, 157, "Input"],
Cell[277160, 9437, 88, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277285, 9444, 54, 1, 157, "Input"],
Cell[277342, 9447, 201, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277580, 9459, 79, 2, 157, "Input"],
Cell[277662, 9463, 201, 7, 157, "Output"]
}, Open  ]],
Cell[277878, 9473, 261, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[278164, 9487, 217, 7, 157, "Input"],
Cell[278384, 9496, 1023, 34, 157, "Output"]
}, Open  ]],
Cell[279422, 9533, 359, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[279806, 9550, 64, 1, 157, "Input"],
Cell[279873, 9553, 28, 0, 157, "Output"]
}, Open  ]],
Cell[279916, 9556, 326, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[280267, 9573, 219, 7, 157, "Input"],
Cell[280489, 9582, 28, 0, 157, "Output"]
}, Open  ]],
Cell[280532, 9585, 697, 20, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[281266, 9610, 123, 3, 157, "Subsubsection"],
Cell[281392, 9615, 508, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[281925, 9636, 109, 3, 157, "Input"],
Cell[282037, 9641, 86, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282160, 9648, 125, 3, 157, "Input"],
Cell[282288, 9653, 186, 4, 157, "Output"]
}, Open  ]],
Cell[282489, 9660, 161, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[282675, 9671, 81, 2, 157, "Input"],
Cell[282759, 9675, 45, 1, 157, "Output"]
}, Open  ]],
Cell[282819, 9679, 156, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[283000, 9690, 120, 3, 157, "Input"],
Cell[283123, 9695, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[283243, 9702, 32, 0, 157, "Input"],
Cell[283278, 9704, 2192, 74, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[285507, 9783, 79, 2, 157, "Input"],
Cell[285589, 9787, 653, 23, 157, "Output"]
}, Open  ]],
Cell[286257, 9813, 117, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[286399, 9819, 185, 6, 157, "Input"],
Cell[286587, 9827, 1274, 44, 157, "Output"]
}, Open  ]],
Cell[287876, 9874, 105, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[288006, 9880, 436, 14, 157, "Input"],
Cell[288445, 9896, 28, 0, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[288522, 9902, 118, 3, 157, "Subsubsection"],
Cell[288643, 9907, 206, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[288874, 9916, 82, 2, 157, "Input"],
Cell[288959, 9920, 45, 1, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289041, 9926, 212, 6, 157, "Input"],
Cell[289256, 9934, 173, 5, 157, "Output"]
}, Open  ]],
Cell[289444, 9942, 116, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[289585, 9948, 52, 1, 157, "Input"],
Cell[289640, 9951, 155, 5, 157, "Output"]
}, Open  ]],
Cell[289810, 9959, 455, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[290290, 9980, 32, 0, 157, "Input"],
Cell[290325, 9982, 269, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290631, 9995, 54, 1, 157, "Input"],
Cell[290688, 9998, 83, 2, 157, "Output"]
}, Open  ]],
Cell[290786, 10003, 190, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[291001, 10014, 139, 4, 157, "Input"],
Cell[291143, 10020, 115, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291295, 10028, 79, 2, 157, "Input"],
Cell[291377, 10032, 28, 0, 157, "Output"]
}, Open  ]],
Cell[291420, 10035, 144, 4, 157, "Text"],
Cell[CellGroupData[{
Cell[291589, 10043, 656, 20, 157, "Input"],
Cell[292248, 10065, 609, 19, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292894, 10089, 70, 1, 157, "Input"],
Cell[292967, 10092, 609, 19, 157, "Output"]
}, Open  ]],
Cell[293591, 10114, 84, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[293700, 10120, 88, 2, 157, "Input"],
Cell[293791, 10124, 83, 2, 157, "Output"]
}, Open  ]],
Cell[293889, 10129, 261, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[294175, 10143, 64, 1, 157, "Input"],
Cell[294242, 10146, 155, 5, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294434, 10156, 31, 0, 157, "Input"],
Cell[294468, 10158, 278, 8, 157, "Output"]
}, Open  ]],
Cell[294761, 10169, 139, 4, 157, "Text"],
Cell[CellGroupData[{
Cell[294925, 10177, 79, 2, 157, "Input"],
Cell[295007, 10181, 520, 17, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[295564, 10203, 219, 7, 157, "Input"],
Cell[295786, 10212, 28, 0, 157, "Output"]
}, Open  ]],
Cell[295829, 10215, 274, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[296128, 10228, 30, 0, 157, "Input"],
Cell[296161, 10230, 257, 8, 157, "Output"]
}, Open  ]],
Cell[296433, 10241, 279, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[296737, 10253, 57, 1, 157, "Input"],
Cell[296797, 10256, 188, 5, 157, "Output"]
}, Open  ]],
Cell[297000, 10264, 393, 9, 157, "Text"],
Cell[297396, 10275, 310, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[297731, 10287, 121, 3, 157, "Input"],
Cell[297855, 10292, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297975, 10299, 31, 0, 157, "Input"],
Cell[298009, 10301, 209, 6, 157, "Output"]
}, Open  ]],
Cell[298233, 10310, 429, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[298687, 10328, 52, 1, 157, "Input"],
Cell[298742, 10331, 257, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[299036, 10344, 64, 1, 157, "Input"],
Cell[299103, 10347, 257, 8, 157, "Output"]
}, Open  ]],
Cell[299375, 10358, 237, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[299637, 10372, 120, 3, 157, "Input"],
Cell[299760, 10377, 83, 2, 157, "Output"]
}, Open  ]],
Cell[299858, 10382, 79, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[299962, 10388, 33, 0, 157, "Input"],
Cell[299998, 10390, 287, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300322, 10403, 31, 0, 157, "Input"],
Cell[300356, 10405, 416, 11, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300809, 10421, 32, 0, 157, "Input"],
Cell[300844, 10423, 2673, 91, 157, "Output"]
}, Open  ]],
Cell[303532, 10517, 117, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[303674, 10523, 104, 3, 157, "Input"],
Cell[303781, 10528, 1214, 42, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305032, 10575, 164, 5, 157, "Input"],
Cell[305199, 10582, 28, 0, 157, "Output"]
}, Open  ]],
Cell[305242, 10585, 108, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[305375, 10591, 80, 2, 157, "Input"],
Cell[305458, 10595, 13344, 444, 157, "Output"]
}, Open  ]],
Cell[318817, 11042, 117, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[318959, 11048, 271, 8, 157, "Input"],
Cell[319233, 11058, 243, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[319513, 11070, 104, 3, 157, "Input"],
Cell[319620, 11075, 2750, 95, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322407, 11175, 164, 5, 157, "Input"],
Cell[322574, 11182, 28, 0, 157, "Output"]
}, Open  ]],
Cell[322617, 11185, 164, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[322806, 11195, 332, 11, 157, "Input"],
Cell[323141, 11208, 301, 10, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323479, 11223, 79, 2, 157, "Input"],
Cell[323561, 11227, 3851, 122, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327449, 11354, 219, 7, 157, "Input"],
Cell[327671, 11363, 171, 6, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[327891, 11375, 154, 4, 157, "Subsubsection"],
Cell[328048, 11381, 432, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[328505, 11399, 82, 2, 157, "Input"],
Cell[328590, 11403, 45, 1, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328672, 11409, 31, 0, 157, "Input"],
Cell[328706, 11411, 173, 5, 157, "Output"]
}, Open  ]],
Cell[328894, 11419, 117, 3, 157, "Input"],
Cell[CellGroupData[{
Cell[329036, 11426, 56, 1, 157, "Input"],
Cell[329095, 11429, 617, 18, 157, "Output"]
}, Open  ]],
Cell[329727, 11450, 223, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[329975, 11461, 287, 9, 157, "Input"],
Cell[330265, 11472, 518, 17, 157, "Output"]
}, Open  ]],
Cell[330798, 11492, 324, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[331147, 11504, 649, 21, 157, "Input"],
Cell[331799, 11527, 606, 20, 157, "Output"]
}, Open  ]],
Cell[332420, 11550, 245, 8, 157, "Text"],
Cell[332668, 11560, 721, 25, 157, "Text"],
Cell[CellGroupData[{
Cell[333414, 11589, 58, 1, 157, "Input"],
Cell[333475, 11592, 420, 12, 157, "Print"],
Cell[333898, 11606, 620, 22, 157, "Output"]
}, Open  ]],
Cell[334533, 11631, 313, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[334871, 11644, 34, 0, 157, "Input"],
Cell[334908, 11646, 922, 31, 157, "Output"]
}, Open  ]],
Cell[335845, 11680, 65, 1, 157, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[335947, 11686, 191, 6, 157, "Subsubsection"],
Cell[336141, 11694, 156, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[336322, 11705, 121, 3, 157, "Input"],
Cell[336446, 11710, 83, 2, 157, "Output"]
}, Open  ]],
Cell[336544, 11715, 344, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[336913, 11732, 110, 3, 157, "Input"],
Cell[337026, 11737, 73, 2, 157, "Output"]
}, Open  ]],
Cell[337114, 11742, 349, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[337488, 11759, 33, 0, 157, "Input"],
Cell[337524, 11761, 103, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337664, 11768, 34, 0, 157, "Input"],
Cell[337701, 11770, 108, 2, 157, "Output"]
}, Open  ]],
Cell[337824, 11775, 524, 15, 157, "Text"],
Cell[CellGroupData[{
Cell[338373, 11794, 36, 0, 157, "Input"],
Cell[338412, 11796, 569, 20, 157, "Output"]
}, Open  ]],
Cell[338996, 11819, 250, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[339271, 11833, 66, 1, 157, "Input"],
Cell[339340, 11836, 483, 17, 157, "Output"]
}, Open  ]],
Cell[339838, 11856, 91, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[339954, 11862, 61, 1, 157, "Input"],
Cell[340018, 11865, 483, 17, 157, "Output"]
}, Open  ]],
Cell[340516, 11885, 113, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[340654, 11891, 55, 1, 157, "Input"],
Cell[340712, 11894, 103, 2, 157, "Output"]
}, Open  ]],
Cell[340830, 11899, 726, 22, 157, "Text"],
Cell[341559, 11923, 724, 22, 157, "Text"],
Cell[CellGroupData[{
Cell[342308, 11949, 185, 6, 157, "Input"],
Cell[342496, 11957, 237, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[342770, 11970, 76, 2, 157, "Input"],
Cell[342849, 11974, 494, 16, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343380, 11995, 76, 2, 157, "Input"],
Cell[343459, 11999, 1425, 46, 157, "Output"]
}, Open  ]],
Cell[344899, 12048, 235, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[345159, 12058, 149, 5, 157, "Input"],
Cell[345311, 12065, 28, 0, 157, "Output"]
}, Open  ]],
Cell[345354, 12068, 197, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[345576, 12077, 120, 3, 157, "Input"],
Cell[345699, 12082, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345819, 12089, 33, 0, 157, "Input"],
Cell[345855, 12091, 103, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345995, 12098, 34, 0, 157, "Input"],
Cell[346032, 12100, 108, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346177, 12107, 66, 1, 157, "Input"],
Cell[346246, 12110, 480, 16, 157, "Output"]
}, Open  ]],
Cell[346741, 12129, 349, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[347115, 12144, 59, 1, 157, "Input"],
Cell[347177, 12147, 88, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[347302, 12154, 54, 1, 157, "Input"],
Cell[347359, 12157, 201, 7, 157, "Output"]
}, Open  ]],
Cell[347575, 12167, 184, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[347784, 12178, 81, 2, 157, "Input"],
Cell[347868, 12182, 45, 1, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[347950, 12188, 116, 3, 157, "Input"],
Cell[348069, 12193, 783, 28, 157, "Output"]
}, Open  ]],
Cell[348867, 12224, 147, 4, 157, "Text"],
Cell[CellGroupData[{
Cell[349039, 12232, 1177, 38, 157, "Input"],
Cell[350219, 12272, 1116, 37, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351372, 12314, 122, 3, 157, "Input"],
Cell[351497, 12319, 85, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351619, 12326, 30, 0, 157, "Input"],
Cell[351652, 12328, 551, 16, 157, "Output"]
}, Open  ]],
Cell[352218, 12347, 253, 8, 157, "Text"],
Cell[352474, 12357, 133, 4, 157, "Text"],
Cell[CellGroupData[{
Cell[352632, 12365, 543, 17, 157, "Input"],
Cell[353178, 12384, 458, 15, 157, "Output"]
}, Open  ]],
Cell[353651, 12402, 207, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[353883, 12413, 160, 5, 157, "Input"],
Cell[354046, 12420, 133, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354216, 12429, 80, 2, 157, "Input"],
Cell[354299, 12433, 149, 4, 157, "Output"]
}, Open  ]],
Cell[354463, 12440, 236, 6, 157, "Input"],
Cell[CellGroupData[{
Cell[354724, 12450, 205, 5, 157, "Input"],
Cell[354932, 12457, 165, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355134, 12466, 122, 3, 157, "Input"],
Cell[355259, 12471, 85, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355381, 12478, 32, 0, 157, "Input"],
Cell[355416, 12480, 643, 20, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[356096, 12505, 155, 4, 157, "Input",
 PageBreakAbove->False],
Cell[356254, 12511, 3454, 106, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359745, 12622, 116, 3, 157, "Input"],
Cell[359864, 12627, 1229, 38, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361130, 12670, 100, 3, 157, "Input"],
Cell[361233, 12675, 497, 16, 157, "Output"]
}, Open  ]],
Cell[361745, 12694, 1167, 33, 157, "Text"],
Cell[362915, 12729, 272, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[363212, 12741, 128, 3, 157, "Input"],
Cell[363343, 12746, 97, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363477, 12753, 72, 1, 157, "Input"],
Cell[363552, 12756, 97, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363686, 12763, 34, 0, 157, "Input"],
Cell[363723, 12765, 101, 2, 157, "Output"]
}, Open  ]],
Cell[363839, 12770, 176, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[364040, 12779, 127, 4, 157, "Input"],
Cell[364170, 12785, 102, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[364309, 12793, 80, 2, 157, "Input"],
Cell[364392, 12797, 118, 3, 157, "Output"]
}, Open  ]],
Cell[364525, 12803, 84, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[364634, 12809, 30, 0, 157, "Input"],
Cell[364667, 12811, 189, 6, 157, "Output"]
}, Open  ]],
Cell[364871, 12820, 89, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[364985, 12826, 218, 7, 157, "Input"],
Cell[365206, 12835, 189, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[365432, 12846, 71, 1, 157, "Input"],
Cell[365506, 12849, 189, 6, 157, "Output"]
}, Open  ]],
Cell[365710, 12858, 158, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[365893, 12867, 162, 4, 157, "Input"],
Cell[366058, 12873, 243, 6, 157, "Output"]
}, Open  ]],
Cell[366316, 12882, 165, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[366506, 12893, 81, 2, 157, "Input"],
Cell[366590, 12897, 45, 1, 157, "Output"]
}, Open  ]],
Cell[366650, 12901, 155, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[366830, 12912, 71, 1, 157, "Input"],
Cell[366904, 12915, 97, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367038, 12922, 32, 0, 157, "Input"],
Cell[367073, 12924, 2131, 72, 157, "Output"]
}, Open  ]],
Cell[369219, 12999, 99, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[369343, 13005, 118, 3, 157, "Input"],
Cell[369464, 13010, 502, 17, 157, "Output"]
}, Open  ]],
Cell[369981, 13030, 101, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[370107, 13036, 157, 4, 157, "Input"],
Cell[370267, 13042, 569, 20, 157, "Output"]
}, Open  ]],
Cell[370851, 13065, 122, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[370998, 13071, 972, 31, 157, "Input"],
Cell[371973, 13104, 875, 28, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372885, 13137, 86, 2, 157, "Input"],
Cell[372974, 13141, 863, 29, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[373874, 13175, 226, 7, 157, "Input"],
Cell[374103, 13184, 697, 25, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[374837, 13214, 124, 3, 157, "Input"],
Cell[374964, 13219, 463, 15, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[375476, 13240, 41, 0, 157, "Subsubsection"],
Cell[375520, 13242, 57, 1, 157, "Input"],
Cell[375580, 13245, 74, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[375679, 13250, 49, 0, 157, "Input"],
Cell[375731, 13252, 45, 1, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[375849, 13261, 63, 1, 108, "Section"],
Cell[CellGroupData[{
Cell[375937, 13266, 115, 3, 58, "Subsection",
 PageBreakAbove->True],
Cell[376055, 13271, 56, 0, 157, "Text"],
Cell[376114, 13273, 347, 14, 157, "Text"],
Cell[376464, 13289, 882, 30, 157, "Text"],
Cell[377349, 13321, 217, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[377591, 13331, 123, 3, 157, "Input"],
Cell[377717, 13336, 85, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377839, 13343, 212, 6, 157, "Input"],
Cell[378054, 13351, 210, 6, 157, "Output"]
}, Open  ]],
Cell[378279, 13360, 252, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[378556, 13372, 275, 9, 157, "Input"],
Cell[378834, 13383, 87, 2, 157, "Output"],
Cell[378924, 13387, 133, 4, 157, "Output"]
}, Open  ]],
Cell[379072, 13394, 190, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[379287, 13404, 142, 4, 157, "Input"],
Cell[379432, 13410, 105, 2, 157, "Output"],
Cell[379540, 13414, 169, 5, 157, "Output"]
}, Open  ]],
Cell[379724, 13422, 331, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[380080, 13437, 437, 14, 157, "Input"],
Cell[380520, 13453, 402, 13, 157, "Output"]
}, Open  ]],
Cell[380937, 13469, 233, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[381195, 13484, 200, 6, 157, "Input"],
Cell[381398, 13492, 439, 14, 157, "Output"]
}, Open  ]],
Cell[381852, 13509, 1012, 31, 157, "Text"],
Cell[CellGroupData[{
Cell[382889, 13544, 535, 19, 157, "Input",
 PageBreakAbove->True],
Cell[383427, 13565, 463, 14, 157, "Output"]
}, Open  ]],
Cell[383905, 13582, 249, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[384179, 13593, 115, 3, 157, "Input"],
Cell[384297, 13598, 465, 14, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[384799, 13617, 157, 4, 157, "Input"],
Cell[384959, 13623, 500, 16, 157, "Output"]
}, Open  ]],
Cell[385474, 13642, 869, 31, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[386368, 13677, 420, 13, 157, "Input"],
Cell[386791, 13692, 389, 12, 157, "Output"]
}, Open  ]],
Cell[387195, 13707, 371, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[387591, 13723, 132, 3, 157, "Input"],
Cell[387726, 13728, 836, 26, 157, "Output"]
}, Open  ]],
Cell[388577, 13757, 507, 16, 157, "Text"],
Cell[CellGroupData[{
Cell[389109, 13777, 123, 3, 157, "Input"],
Cell[389235, 13782, 1056, 34, 157, "Output"]
}, Open  ]],
Cell[390306, 13819, 648, 23, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[390979, 13846, 203, 6, 157, "Input"],
Cell[391185, 13854, 595, 19, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[391817, 13878, 176, 5, 157, "Input"],
Cell[391996, 13885, 429, 15, 157, "Output"]
}, Open  ]],
Cell[392440, 13903, 173, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[392638, 13915, 123, 3, 157, "Input"],
Cell[392764, 13920, 1011, 32, 157, "Output"]
}, Open  ]],
Cell[393790, 13955, 329, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[394144, 13971, 71, 1, 157, "Input"],
Cell[394218, 13974, 1011, 32, 157, "Output"]
}, Open  ]],
Cell[395244, 14009, 444, 15, 157, "Text"],
Cell[395691, 14026, 110, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[395826, 14033, 90, 2, 157, "Input"],
Cell[395919, 14037, 73, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[396029, 14044, 88, 2, 157, "Input"],
Cell[396120, 14048, 103, 2, 157, "Output"]
}, Open  ]],
Cell[396238, 14053, 314, 10, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[396577, 14067, 136, 4, 157, "Input"],
Cell[396716, 14073, 323, 11, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397076, 14089, 146, 4, 157, "Input"],
Cell[397225, 14095, 1358, 46, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[398620, 14146, 121, 3, 157, "Input"],
Cell[398744, 14151, 519, 19, 157, "Output"]
}, Open  ]],
Cell[399278, 14173, 127, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[399430, 14180, 300, 8, 157, "Input"],
Cell[399733, 14190, 458, 15, 157, "Output"]
}, Open  ]],
Cell[400206, 14208, 255, 7, 157, "Text"],
Cell[400464, 14217, 98, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[400587, 14224, 118, 3, 157, "Input"],
Cell[400708, 14229, 284, 10, 157, "Output"]
}, Open  ]],
Cell[401007, 14242, 100, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[401132, 14249, 143, 4, 157, "Input"],
Cell[401278, 14255, 282, 10, 157, "Output"]
}, Open  ]],
Cell[401575, 14268, 102, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[401702, 14275, 111, 3, 157, "Input"],
Cell[401816, 14280, 162, 5, 157, "Output"]
}, Open  ]],
Cell[401993, 14288, 126, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[402144, 14295, 92, 2, 157, "Input"],
Cell[402239, 14299, 28, 0, 157, "Output"]
}, Open  ]],
Cell[402282, 14302, 414, 15, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[402721, 14321, 183, 5, 157, "Input"],
Cell[402907, 14328, 304, 9, 157, "Output"]
}, Open  ]],
Cell[403226, 14340, 419, 14, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[403670, 14358, 604, 18, 157, "Input",
 Evaluatable->False],
Cell[404277, 14378, 3863, 116, 157, "Output"]
}, Open  ]],
Cell[408155, 14497, 133, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[408313, 14504, 204, 6, 157, "Input",
 Evaluatable->False],
Cell[408520, 14512, 216, 7, 157, "Output"]
}, Open  ]],
Cell[408751, 14522, 128, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[408904, 14529, 168, 5, 157, "Input",
 Evaluatable->False],
Cell[409075, 14536, 593, 22, 157, "Output"]
}, Open  ]],
Cell[409683, 14561, 100, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[409808, 14568, 130, 4, 157, "Input",
 Evaluatable->False],
Cell[409941, 14574, 88, 2, 157, "Output"]
}, Open  ]],
Cell[410044, 14579, 103, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[410172, 14586, 130, 4, 157, "Input",
 Evaluatable->False],
Cell[410305, 14592, 88, 2, 157, "Output"]
}, Open  ]],
Cell[410408, 14597, 214, 7, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[410647, 14608, 304, 10, 157, "Input"],
Cell[410954, 14620, 278, 9, 157, "Output"]
}, Open  ]],
Cell[411247, 14632, 243, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[411515, 14644, 123, 3, 157, "Input"],
Cell[411641, 14649, 538, 19, 157, "Output"]
}, Open  ]],
Cell[412194, 14671, 218, 9, 157, "Text",
 PageBreakAbove->Automatic],
Cell[CellGroupData[{
Cell[412437, 14684, 159, 5, 157, "Input"],
Cell[412599, 14691, 888, 31, 157, "Output"]
}, Open  ]],
Cell[413502, 14725, 409, 15, 157, "Text"],
Cell[CellGroupData[{
Cell[413936, 14744, 90, 2, 157, "Input"],
Cell[414029, 14748, 1856, 62, 157, "Output"]
}, Open  ]],
Cell[415900, 14813, 133, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[416058, 14820, 74, 2, 157, "Input"],
Cell[416135, 14824, 1116, 37, 157, "Output"]
}, Open  ]],
Cell[417266, 14864, 25, 0, 157, "Text"],
Cell[417294, 14866, 57, 1, 157, "Input"],
Cell[417354, 14869, 74, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[417453, 14874, 49, 0, 157, "Input"],
Cell[417505, 14876, 45, 1, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[417599, 14883, 51, 0, 44, "Subsection"],
Cell[417653, 14885, 60, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[417738, 14889, 71, 0, 157, "Subsubsection"],
Cell[417812, 14891, 263, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[418100, 14904, 256, 7, 157, "Input"],
Cell[418359, 14913, 213, 6, 157, "Output"]
}, Open  ]],
Cell[418587, 14922, 132, 3, 157, "Text"],
Cell[418722, 14927, 1116, 34, 157, "Input"],
Cell[419841, 14963, 196, 8, 157, "Text"],
Cell[420040, 14973, 64, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[420129, 14978, 33, 0, 157, "Input"],
Cell[420165, 14980, 1013, 32, 157, "Output"]
}, Open  ]],
Cell[421193, 15015, 276, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[421494, 15030, 51, 1, 157, "Input"],
Cell[421548, 15033, 1325, 41, 157, "Output"]
}, Open  ]],
Cell[422888, 15077, 112, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[423025, 15084, 241, 8, 157, "Input"],
Cell[423269, 15094, 374, 13, 157, "Output"]
}, Open  ]],
Cell[423658, 15110, 113, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[423796, 15117, 209, 8, 157, "Input"],
Cell[424008, 15127, 374, 13, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[424431, 15146, 48, 0, 157, "Subsubsection"],
Cell[424482, 15148, 260, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[424767, 15162, 73, 2, 157, "Input"],
Cell[424843, 15166, 198, 5, 157, "Output"]
}, Open  ]],
Cell[425056, 15174, 245, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[425326, 15186, 105, 3, 157, "Input"],
Cell[425434, 15191, 402, 13, 157, "Output"]
}, Open  ]],
Cell[425851, 15207, 129, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[426005, 15214, 74, 2, 157, "Input"],
Cell[426082, 15218, 1886, 61, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[428005, 15284, 97, 3, 157, "Input"],
Cell[428105, 15289, 846, 25, 157, "Output"]
}, Open  ]],
Cell[428966, 15317, 131, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[429122, 15324, 84, 2, 157, "Input"],
Cell[429209, 15328, 4074, 121, 157, "Output"]
}, Open  ]],
Cell[433298, 15452, 293, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[433616, 15465, 247, 9, 157, "Input"],
Cell[433866, 15476, 28, 0, 157, "Output"]
}, Open  ]],
Cell[433909, 15479, 255, 7, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[434201, 15491, 49, 0, 157, "Subsubsection"],
Cell[434253, 15493, 251, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[434529, 15505, 60, 1, 157, "Input"],
Cell[434592, 15508, 1581, 54, 157, "Output"]
}, Open  ]],
Cell[436188, 15565, 139, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[436352, 15572, 61, 1, 157, "Input"],
Cell[436416, 15575, 1918, 65, 157, "Output"]
}, Open  ]],
Cell[438349, 15643, 298, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[438672, 15656, 206, 7, 157, "Input"],
Cell[438881, 15665, 1322, 47, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[440252, 15718, 49, 0, 157, "Subsubsection"],
Cell[440304, 15720, 424, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[440753, 15738, 55, 1, 157, "Input"],
Cell[440811, 15741, 28, 0, 157, "Output"]
}, Open  ]],
Cell[440854, 15744, 106, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[440985, 15751, 27, 0, 157, "Input"],
Cell[441015, 15753, 374, 13, 157, "Output"]
}, Open  ]],
Cell[441404, 15769, 131, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[441560, 15776, 97, 2, 157, "Input"],
Cell[441660, 15780, 185, 6, 157, "Output"]
}, Open  ]],
Cell[441860, 15789, 289, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[442174, 15804, 34, 0, 157, "Input"],
Cell[442211, 15806, 189, 6, 157, "Output"]
}, Open  ]],
Cell[442415, 15815, 294, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[442734, 15830, 54, 1, 157, "Input"],
Cell[442791, 15833, 324, 11, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[443152, 15849, 102, 3, 157, "Input"],
Cell[443257, 15854, 390, 13, 157, "Output"]
}, Open  ]],
Cell[443662, 15870, 222, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[443909, 15882, 95, 2, 157, "Input"],
Cell[444007, 15886, 349, 10, 157, "Output"]
}, Open  ]],
Cell[444371, 15899, 335, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[444731, 15914, 32, 0, 157, "Input"],
Cell[444766, 15916, 217, 6, 157, "Output"]
}, Open  ]],
Cell[444998, 15925, 234, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[445257, 15937, 54, 1, 157, "Input"],
Cell[445314, 15940, 352, 11, 157, "Output"]
}, Open  ]],
Cell[445681, 15954, 110, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[445816, 15961, 74, 2, 157, "Input"],
Cell[445893, 15965, 528, 16, 157, "Output"]
}, Open  ]],
Cell[446436, 15984, 237, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[446698, 15996, 89, 2, 157, "Input"],
Cell[446790, 16000, 3582, 113, 157, "Output"]
}, Open  ]],
Cell[450387, 16116, 207, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[450619, 16128, 163, 5, 157, "Input"],
Cell[450785, 16135, 856, 28, 157, "Output"]
}, Open  ]],
Cell[451656, 16166, 187, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[451868, 16176, 59, 1, 157, "Input"],
Cell[451930, 16179, 580, 18, 157, "Output"]
}, Open  ]],
Cell[452525, 16200, 223, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[452773, 16210, 233, 8, 157, "Input"],
Cell[453009, 16220, 28, 0, 157, "Output"]
}, Open  ]],
Cell[453052, 16223, 309, 7, 157, "Text"],
Cell[453364, 16232, 155, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[453544, 16241, 154, 5, 157, "Input"],
Cell[453701, 16248, 1548, 47, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[455298, 16301, 61, 0, 157, "Subsubsection"],
Cell[455362, 16303, 354, 10, 157, "Text"],
Cell[455719, 16315, 459, 16, 157, "Input"],
Cell[456181, 16333, 60, 1, 157, "Input"],
Cell[456244, 16336, 78, 2, 157, "Input"],
Cell[456325, 16340, 318, 11, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[456680, 16356, 165, 7, 157, "Subsubsection"],
Cell[456848, 16365, 363, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[457236, 16381, 141, 4, 157, "Input"],
Cell[457380, 16387, 28, 0, 157, "Output"]
}, Open  ]],
Cell[457423, 16390, 283, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[457731, 16405, 220, 7, 157, "Input"],
Cell[457954, 16414, 112, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[458103, 16422, 59, 1, 157, "Input"],
Cell[458165, 16425, 29, 0, 157, "Output"]
}, Open  ]],
Cell[458209, 16428, 626, 20, 157, "Text"],
Cell[CellGroupData[{
Cell[458860, 16452, 57, 1, 157, "Input"],
Cell[458920, 16455, 1035, 32, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[459992, 16492, 205, 7, 157, "Input"],
Cell[460200, 16501, 1272, 41, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[461509, 16547, 59, 1, 157, "Input"],
Cell[461571, 16550, 1412, 41, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[463032, 16597, 52, 0, 157, "Subsubsection"],
Cell[463087, 16599, 898, 30, 157, "Text"],
Cell[CellGroupData[{
Cell[464010, 16633, 31, 0, 157, "Input"],
Cell[464044, 16635, 349, 10, 157, "Output"]
}, Open  ]],
Cell[464408, 16648, 756, 24, 157, "Input"],
Cell[465167, 16674, 448, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[465640, 16689, 67, 1, 157, "Input"],
Cell[465710, 16692, 325, 10, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[466072, 16707, 141, 4, 157, "Input"],
Cell[466216, 16713, 1265, 38, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[467518, 16756, 88, 1, 157, "Input"],
Cell[467609, 16759, 816, 25, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[468462, 16789, 60, 1, 157, "Input"],
Cell[468525, 16792, 928, 32, 157, "Output"]
}, Open  ]],
Cell[469468, 16827, 112, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[469605, 16834, 55, 1, 157, "Input"],
Cell[469663, 16837, 139, 4, 157, "Output"]
}, Open  ]],
Cell[469817, 16844, 208, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[470050, 16856, 581, 19, 157, "Input"],
Cell[470634, 16877, 541, 18, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471212, 16900, 55, 1, 157, "Input"],
Cell[471270, 16903, 921, 31, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[472228, 16939, 64, 1, 157, "Input"],
Cell[472295, 16942, 1176, 37, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[473508, 16984, 88, 2, 157, "Input"],
Cell[473599, 16988, 3124, 98, 157, "Output"]
}, Open  ]],
Cell[476738, 17089, 254, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[477017, 17101, 126, 3, 157, "Input"],
Cell[477146, 17106, 457, 14, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477640, 17125, 31, 0, 157, "Input"],
Cell[477674, 17127, 629, 18, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[478340, 17150, 64, 1, 157, "Input"],
Cell[478407, 17153, 852, 25, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[479296, 17183, 88, 2, 157, "Input"],
Cell[479387, 17187, 1768, 56, 157, "Output"]
}, Open  ]],
Cell[481170, 17246, 436, 13, 157, "Text"],
Cell[481609, 17261, 785, 29, 157, "Text"],
Cell[CellGroupData[{
Cell[482419, 17294, 132, 3, 157, "Input"],
Cell[482554, 17299, 185, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[482776, 17310, 31, 0, 157, "Input"],
Cell[482810, 17312, 349, 10, 157, "Output"]
}, Open  ]],
Cell[483174, 17325, 122, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[483321, 17332, 28, 0, 157, "Input"],
Cell[483352, 17334, 325, 10, 157, "Output"]
}, Open  ]],
Cell[483692, 17347, 198, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[483915, 17359, 55, 1, 157, "Input"],
Cell[483973, 17362, 139, 4, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[484161, 17372, 71, 0, 157, "Subsubsection"],
Cell[484235, 17374, 348, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[484608, 17386, 51, 1, 157, "Input"],
Cell[484662, 17389, 1325, 41, 157, "Output"]
}, Open  ]],
Cell[486002, 17433, 98, 3, 157, "Text"],
Cell[486103, 17438, 1052, 37, 157, "Input"],
Cell[CellGroupData[{
Cell[487180, 17479, 421, 13, 157, "Input"],
Cell[487604, 17494, 31, 0, 157, "Output"],
Cell[487638, 17496, 31, 0, 157, "Output"]
}, Open  ]],
Cell[487684, 17499, 349, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[488058, 17513, 34, 0, 157, "Input"],
Cell[488095, 17515, 213, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[488345, 17526, 102, 2, 157, "Input"],
Cell[488450, 17530, 807, 28, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[489294, 17563, 27, 0, 157, "Input"],
Cell[489324, 17565, 374, 13, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[489735, 17583, 120, 3, 157, "Input"],
Cell[489858, 17588, 643, 22, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[490538, 17615, 56, 1, 157, "Input"],
Cell[490597, 17618, 1073, 33, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[491707, 17656, 28, 0, 157, "Input"],
Cell[491738, 17658, 528, 16, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[492303, 17679, 122, 3, 157, "Input"],
Cell[492428, 17684, 1140, 34, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[493605, 17723, 56, 1, 157, "Input"],
Cell[493664, 17726, 1582, 45, 157, "Output"]
}, Open  ]],
Cell[495261, 17774, 284, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[495570, 17787, 50, 1, 157, "Input"],
Cell[495623, 17790, 585, 17, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[496245, 17812, 154, 4, 157, "Input"],
Cell[496402, 17818, 1257, 36, 157, "Output"]
}, Open  ]],
Cell[497674, 17857, 242, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[497941, 17869, 84, 2, 157, "Input"],
Cell[498028, 17873, 1257, 36, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[499334, 17915, 46, 0, 157, "Subsubsection"],
Cell[499383, 17917, 592, 19, 157, "Text"],
Cell[CellGroupData[{
Cell[500000, 17940, 120, 3, 157, "Input"],
Cell[500123, 17945, 699, 22, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[500859, 17972, 94, 2, 157, "Input"],
Cell[500956, 17976, 1582, 45, 157, "Output"]
}, Open  ]],
Cell[502553, 18024, 658, 22, 157, "Text"],
Cell[CellGroupData[{
Cell[503236, 18050, 101, 2, 157, "Input",
 CellTags->"S5.52.1"],
Cell[503340, 18054, 617, 12, 157, "Message",
 CellTags->"S5.52.1"]
}, Open  ]],
Cell[503972, 18069, 156, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[504153, 18078, 560, 19, 157, "Input"],
Cell[504716, 18099, 2387, 73, 157, "Output"]
}, Open  ]],
Cell[507118, 18175, 253, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[507396, 18186, 94, 2, 157, "Input"],
Cell[507493, 18190, 6519, 177, 157, "Output"]
}, Open  ]],
Cell[514027, 18370, 215, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[514267, 18380, 482, 17, 157, "Input"],
Cell[514752, 18399, 1892, 58, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516681, 18462, 167, 4, 157, "Input"],
Cell[516851, 18468, 2387, 73, 157, "Output"]
}, Open  ]],
Cell[519253, 18544, 345, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[519623, 18557, 208, 6, 157, "Input"],
Cell[519834, 18565, 4530, 130, 157, "Output"]
}, Open  ]],
Cell[524379, 18698, 400, 12, 157, "Text"],
Cell[524782, 18712, 227, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[525034, 18724, 90, 2, 157, "Input"],
Cell[525127, 18728, 7662, 226, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532826, 18959, 54, 1, 157, "Input"],
Cell[532883, 18962, 171, 6, 157, "Output"]
}, Open  ]],
Cell[533069, 18971, 123, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[533217, 18978, 99, 2, 157, "Input"],
Cell[533319, 18982, 4424, 138, 157, "Output"]
}, Open  ]],
Cell[537758, 19123, 134, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[537917, 19130, 364, 13, 157, "Input"],
Cell[538284, 19145, 745, 25, 157, "Output"]
}, Open  ]],
Cell[539044, 19173, 216, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[539285, 19185, 64, 1, 157, "Input"],
Cell[539352, 19188, 1124, 33, 157, "Output"]
}, Open  ]],
Cell[540491, 19224, 154, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[540670, 19233, 137, 4, 157, "Input"],
Cell[540810, 19239, 1871, 59, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542718, 19303, 54, 1, 157, "Input"],
Cell[542775, 19306, 3962, 115, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[546774, 19426, 54, 1, 157, "Input"],
Cell[546831, 19429, 73, 2, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[546953, 19437, 43, 0, 157, "Subsubsection"],
Cell[546999, 19439, 57, 1, 157, "Input"],
Cell[547059, 19442, 74, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[547158, 19447, 49, 0, 157, "Input"],
Cell[547210, 19449, 45, 1, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[547316, 19457, 50, 0, 44, "Subsection"],
Cell[547369, 19459, 62, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[547456, 19463, 50, 0, 157, "Subsubsection"],
Cell[547509, 19465, 531, 12, 157, "Text"],
Cell[548043, 19479, 341, 10, 157, "Text",
 CellTags->"reference"]
}, Closed]],
Cell[CellGroupData[{
Cell[548421, 19494, 45, 0, 157, "Subsubsection"],
Cell[548469, 19496, 121, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[548615, 19503, 256, 7, 157, "Input"],
Cell[548874, 19512, 213, 6, 157, "Output"]
}, Open  ]],
Cell[549102, 19521, 1116, 34, 157, "Input"],
Cell[550221, 19557, 64, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[550310, 19562, 51, 1, 157, "Input"],
Cell[550364, 19565, 1325, 41, 157, "Output"]
}, Open  ]],
Cell[551704, 19609, 120, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[551849, 19616, 242, 8, 157, "Input"],
Cell[552094, 19626, 374, 13, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[552505, 19644, 100, 3, 157, "Input"],
Cell[552608, 19649, 374, 13, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[553019, 19667, 100, 3, 157, "Input"],
Cell[553122, 19672, 374, 13, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[553545, 19691, 70, 0, 157, "Subsubsection"],
Cell[553618, 19693, 205, 6, 157, "Text"],
Cell[553826, 19701, 1413, 51, 157, "Input"],
Cell[555242, 19754, 405, 15, 157, "Text"],
Cell[CellGroupData[{
Cell[555672, 19773, 692, 20, 157, "Input"],
Cell[556367, 19795, 31, 0, 157, "Output"]
}, Open  ]],
Cell[556413, 19798, 551, 20, 157, "Text"],
Cell[CellGroupData[{
Cell[556989, 19822, 315, 7, 157, "Input"],
Cell[557307, 19831, 192, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[557536, 19843, 60, 1, 157, "Input"],
Cell[557599, 19846, 257, 9, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[557893, 19860, 134, 3, 157, "Input"],
Cell[558030, 19865, 213, 8, 157, "Output"]
}, Open  ]],
Cell[558258, 19876, 261, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[558544, 19891, 191, 5, 157, "Input"],
Cell[558738, 19898, 317, 10, 157, "Output"]
}, Open  ]],
Cell[559070, 19911, 224, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[559319, 19923, 231, 7, 157, "Input"],
Cell[559553, 19932, 1397, 43, 157, "Output"]
}, Open  ]],
Cell[560965, 19978, 705, 24, 157, "Text"],
Cell[CellGroupData[{
Cell[561695, 20006, 130, 3, 157, "Input"],
Cell[561828, 20011, 93, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[561958, 20018, 33, 0, 157, "Input"],
Cell[561994, 20020, 357, 10, 157, "Output"]
}, Open  ]],
Cell[562366, 20033, 90, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[562481, 20040, 55, 1, 157, "Input"],
Cell[562539, 20043, 324, 11, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[562900, 20059, 98, 2, 157, "Input"],
Cell[563001, 20063, 1838, 65, 157, "Output"]
}, Open  ]],
Cell[564854, 20131, 228, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[565107, 20143, 90, 2, 157, "Input"],
Cell[565200, 20147, 1838, 65, 157, "Output"]
}, Open  ]],
Cell[567053, 20215, 277, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[567355, 20228, 77, 2, 157, "Input"],
Cell[567435, 20232, 985, 34, 157, "Output"]
}, Open  ]],
Cell[568435, 20269, 217, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[568677, 20281, 77, 2, 157, "Input"],
Cell[568757, 20285, 985, 34, 157, "Output"]
}, Open  ]],
Cell[569757, 20322, 177, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[569959, 20332, 517, 16, 157, "Input"],
Cell[570479, 20350, 4618, 139, 157, "Output"]
}, Open  ]],
Cell[575112, 20492, 204, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[575341, 20502, 528, 16, 157, "Input"],
Cell[575872, 20520, 4190, 127, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[580111, 20653, 50, 0, 157, "Subsubsection"],
Cell[580164, 20655, 988, 29, 157, "Text"],
Cell[581155, 20686, 93, 2, 157, "Input"],
Cell[581251, 20690, 347, 14, 157, "Text"],
Cell[581601, 20706, 866, 33, 157, "Text"],
Cell[CellGroupData[{
Cell[582492, 20743, 30, 0, 157, "Input"],
Cell[582525, 20745, 1709, 50, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[584271, 20800, 30, 0, 157, "Input"],
Cell[584304, 20802, 881, 26, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[585222, 20833, 51, 1, 157, "Input"],
Cell[585276, 20836, 9665, 287, 157, "Output"]
}, Open  ]],
Cell[594956, 21126, 282, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[595263, 21141, 295, 9, 157, "Input"],
Cell[595561, 21152, 518, 16, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[596116, 21173, 299, 9, 157, "Input"],
Cell[596418, 21184, 518, 16, 157, "Output"]
}, Open  ]],
Cell[596951, 21203, 126, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[597102, 21210, 431, 14, 157, "Input"],
Cell[597536, 21226, 3689, 111, 157, "Output"]
}, Open  ]],
Cell[601240, 21340, 314, 15, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[601579, 21359, 86, 2, 157, "Input"],
Cell[601668, 21363, 10794, 338, 157, "Output"]
}, Open  ]],
Cell[612477, 21704, 356, 12, 157, "Text"],
Cell[612836, 21718, 974, 27, 157, "Input"],
Cell[613813, 21747, 91, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[613929, 21754, 93, 2, 157, "Input"],
Cell[614025, 21758, 3769, 114, 157, "Output"]
}, Open  ]],
Cell[617809, 21875, 128, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[617962, 21882, 119, 3, 157, "Input"],
Cell[618084, 21887, 1806, 65, 157, "Output"]
}, Open  ]],
Cell[619905, 21955, 250, 8, 157, "Text"],
Cell[620158, 21965, 102, 2, 157, "Input"],
Cell[CellGroupData[{
Cell[620285, 21971, 51, 1, 157, "Input"],
Cell[620339, 21974, 1325, 41, 157, "Output"]
}, Open  ]],
Cell[621679, 22018, 343, 8, 157, "Text"],
Cell[622025, 22028, 87, 2, 157, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[622149, 22035, 50, 0, 157, "Subsubsection"],
Cell[622202, 22037, 554, 20, 157, "Text"],
Cell[622759, 22059, 141, 3, 157, "Text"],
Cell[622903, 22064, 307, 10, 157, "Input"],
Cell[CellGroupData[{
Cell[623235, 22078, 120, 3, 157, "Input"],
Cell[623358, 22083, 1246, 43, 157, "Output"]
}, Open  ]],
Cell[624619, 22129, 154, 5, 157, "Text"],
Cell[624776, 22136, 306, 10, 157, "Input"],
Cell[CellGroupData[{
Cell[625107, 22150, 119, 3, 157, "Input"],
Cell[625229, 22155, 894, 31, 157, "Output"]
}, Open  ]],
Cell[626138, 22189, 340, 11, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[626503, 22204, 544, 16, 157, "Input"],
Cell[627050, 22222, 28, 0, 157, "Output"]
}, Open  ]],
Cell[627093, 22225, 276, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[627394, 22238, 545, 18, 157, "Input"],
Cell[627942, 22258, 28, 0, 157, "Output"]
}, Open  ]],
Cell[627985, 22261, 220, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[628230, 22271, 546, 17, 157, "Input"],
Cell[628779, 22290, 28, 0, 157, "Output"]
}, Open  ]],
Cell[628822, 22293, 154, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[629001, 22302, 541, 16, 157, "Input"],
Cell[629545, 22320, 28, 0, 157, "Output"]
}, Open  ]],
Cell[629588, 22323, 238, 8, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[629863, 22336, 81, 1, 157, "Subsubsection",
 PageBreakAbove->True],
Cell[629947, 22339, 280, 8, 157, "Text"],
Cell[630230, 22349, 181, 6, 157, "Input"],
Cell[CellGroupData[{
Cell[630436, 22359, 34, 0, 157, "Input"],
Cell[630473, 22361, 703, 18, 157, "Output"]
}, Open  ]],
Cell[631191, 22382, 346, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[631562, 22397, 51, 1, 157, "Input"],
Cell[631616, 22400, 6448, 197, 157, "Output"]
}, Open  ]],
Cell[638079, 22600, 246, 9, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[638350, 22613, 266, 8, 157, "Input"],
Cell[638619, 22623, 3939, 116, 157, "Output"]
}, Open  ]],
Cell[642573, 22742, 252, 9, 157, "Text"],
Cell[642828, 22753, 2719, 76, 157, "Text"],
Cell[645550, 22831, 97, 3, 157, "Text"],
Cell[645650, 22836, 92, 2, 157, "Input"],
Cell[CellGroupData[{
Cell[645767, 22842, 51, 1, 157, "Input"],
Cell[645821, 22845, 4806, 140, 157, "Output"]
}, Open  ]],
Cell[650642, 22988, 133, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[650800, 22995, 34, 0, 157, "Input"],
Cell[650837, 22997, 713, 18, 157, "Output"]
}, Open  ]],
Cell[651565, 23018, 464, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[652054, 23036, 56, 1, 157, "Input"],
Cell[652113, 23039, 1316, 44, 157, "Output"]
}, Open  ]],
Cell[653444, 23086, 357, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[653826, 23104, 146, 4, 157, "Input"],
Cell[653975, 23110, 6960, 225, 157, "Output"]
}, Open  ]],
Cell[660950, 23338, 333, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[661308, 23352, 542, 17, 157, "Input"],
Cell[661853, 23371, 31, 0, 157, "Output"]
}, Open  ]],
Cell[661899, 23374, 378, 14, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[662302, 23392, 290, 9, 157, "Input"],
Cell[662595, 23403, 6743, 214, 157, "Output"]
}, Open  ]],
Cell[669353, 23620, 157, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[669535, 23629, 295, 10, 157, "Input"],
Cell[669833, 23641, 28, 0, 157, "Output"]
}, Open  ]],
Cell[669876, 23644, 342, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[670243, 23658, 279, 9, 157, "Input"],
Cell[670525, 23669, 31, 0, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[670605, 23675, 94, 1, 157, "Subsubsection",
 PageBreakAbove->True],
Cell[670702, 23678, 182, 8, 157, "Text"],
Cell[670887, 23688, 388, 12, 157, "Input"],
Cell[CellGroupData[{
Cell[671300, 23704, 77, 1, 157, "Input"],
Cell[671380, 23707, 317, 10, 157, "Output"]
}, Open  ]],
Cell[671712, 23720, 290, 11, 157, "Text"],
Cell[672005, 23733, 3702, 113, 157, "Input"],
Cell[675710, 23848, 76, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[675811, 23853, 51, 1, 157, "Input"],
Cell[675865, 23856, 3235, 115, 157, "Output"]
}, Open  ]],
Cell[679115, 23974, 589, 19, 157, "Text"],
Cell[CellGroupData[{
Cell[679729, 23997, 64, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[679818, 24002, 1000, 25, 157, "Print"],
Cell[680821, 24029, 977, 24, 157, "Print"],
Cell[681801, 24055, 977, 24, 157, "Print"],
Cell[682781, 24081, 1000, 25, 157, "Print"],
Cell[683784, 24108, 977, 24, 157, "Print"],
Cell[684764, 24134, 977, 24, 157, "Print"],
Cell[685744, 24160, 1000, 25, 157, "Print"],
Cell[686747, 24187, 1000, 25, 157, "Print"],
Cell[687750, 24214, 1000, 25, 157, "Print"],
Cell[688753, 24241, 160, 4, 157, "Print"]
}, Open  ]]
}, Open  ]],
Cell[688940, 24249, 380, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[689345, 24266, 343, 13, 157, "Input"],
Cell[689691, 24281, 28, 0, 157, "Output"]
}, Open  ]],
Cell[689734, 24284, 481, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[690240, 24305, 107, 3, 157, "Input"],
Cell[690350, 24310, 346, 13, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[690733, 24328, 107, 3, 157, "Input"],
Cell[690843, 24333, 346, 13, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[691226, 24351, 107, 3, 157, "Input"],
Cell[691336, 24356, 346, 13, 157, "Output"]
}, Open  ]],
Cell[691697, 24372, 193, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[691915, 24384, 107, 3, 157, "Input"],
Cell[692025, 24389, 374, 13, 157, "Output"]
}, Open  ]],
Cell[692414, 24405, 175, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[692614, 24417, 96, 2, 157, "Input"],
Cell[692713, 24421, 213, 6, 157, "Output"]
}, Open  ]],
Cell[692941, 24430, 190, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[693156, 24440, 203, 7, 157, "Input"],
Cell[693362, 24449, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[693427, 24454, 203, 7, 157, "Input"],
Cell[693633, 24463, 28, 0, 157, "Output"]
}, Open  ]],
Cell[693676, 24466, 140, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[693841, 24473, 243, 8, 157, "Input"],
Cell[694087, 24483, 879, 28, 157, "Output"]
}, Open  ]],
Cell[694981, 24514, 186, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[695192, 24524, 243, 8, 157, "Input"],
Cell[695438, 24534, 900, 29, 157, "Output"]
}, Open  ]],
Cell[696353, 24566, 247, 7, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[696625, 24577, 203, 7, 157, "Input"],
Cell[696831, 24586, 238, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[697106, 24598, 243, 8, 157, "Input"],
Cell[697352, 24608, 627, 20, 157, "Output"]
}, Open  ]],
Cell[697994, 24631, 123, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[698142, 24638, 203, 7, 157, "Input"],
Cell[698348, 24647, 28, 0, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[698425, 24653, 87, 1, 157, "Subsubsection",
 PageBreakAbove->True],
Cell[698515, 24656, 692, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[699232, 24677, 687, 26, 157, "Input"],
Cell[699922, 24705, 346, 13, 157, "Output"]
}, Open  ]],
Cell[700283, 24721, 236, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[700544, 24733, 605, 21, 157, "Input"],
Cell[701152, 24756, 2714, 95, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[703903, 24856, 56, 1, 157, "Input"],
Cell[703962, 24859, 3158, 105, 157, "Output"]
}, Open  ]],
Cell[707135, 24967, 136, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[707296, 24974, 337, 10, 157, "Input"],
Cell[707636, 24986, 3158, 105, 157, "Output"]
}, Open  ]],
Cell[710809, 25094, 184, 6, 157, "Text"],
Cell[710996, 25102, 335, 11, 157, "Input"],
Cell[711334, 25115, 120, 4, 157, "Text",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[711479, 25123, 122, 3, 157, "Input"],
Cell[711604, 25128, 20984, 672, 157, "Output"]
}, Open  ]],
Cell[732603, 25803, 278, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[732906, 25817, 382, 12, 157, "Input"],
Cell[733291, 25831, 260, 8, 157, "Output"]
}, Open  ]],
Cell[733566, 25842, 156, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[733747, 25851, 250, 8, 157, "Input"],
Cell[734000, 25861, 260, 8, 157, "Output"]
}, Open  ]],
Cell[734275, 25872, 190, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[734490, 25882, 295, 9, 157, "Input"],
Cell[734788, 25893, 161947, 4303, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[896784, 30202, 42, 0, 157, "Subsubsection"],
Cell[896829, 30204, 57, 1, 157, "Input"],
Cell[896889, 30207, 74, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[896988, 30212, 49, 0, 157, "Input"],
Cell[897040, 30214, 45, 1, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[897158, 30223, 75, 1, 108, "Section"],
Cell[CellGroupData[{
Cell[897258, 30228, 97, 1, 58, "Subsection"],
Cell[897358, 30231, 62, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[897445, 30235, 49, 0, 157, "Subsubsection"],
Cell[897497, 30237, 1292, 35, 157, "Text",
 PageBreakAbove->False]
}, Closed]],
Cell[CellGroupData[{
Cell[898826, 30277, 105, 2, 157, "Subsubsection"],
Cell[898934, 30281, 363, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[899322, 30294, 120, 3, 157, "Input"],
Cell[899445, 30299, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[899565, 30306, 34, 0, 157, "Input"],
Cell[899602, 30308, 86, 2, 157, "Output"]
}, Open  ]],
Cell[899703, 30313, 325, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[900053, 30329, 69, 1, 157, "Input"],
Cell[900125, 30332, 86, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[900248, 30339, 35, 0, 157, "Input"],
Cell[900286, 30341, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[900406, 30348, 33, 0, 157, "Input"],
Cell[900442, 30350, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[900562, 30357, 31, 0, 157, "Input"],
Cell[900596, 30359, 86, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[900719, 30366, 32, 0, 157, "Input"],
Cell[900754, 30368, 45, 1, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[900836, 30374, 32, 0, 157, "Input"],
Cell[900871, 30376, 45, 1, 157, "Output"]
}, Open  ]],
Cell[900931, 30380, 558, 21, 157, "Text"],
Cell[CellGroupData[{
Cell[901514, 30405, 123, 3, 157, "Input"],
Cell[901640, 30410, 77, 1, 157, "Output"],
Cell[901720, 30413, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[901785, 30418, 123, 3, 157, "Input"],
Cell[901911, 30423, 88, 2, 157, "Output"],
Cell[902002, 30427, 162, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[902201, 30436, 291, 9, 157, "Input"],
Cell[902495, 30447, 327, 10, 157, "Output"],
Cell[902825, 30459, 423, 13, 157, "Output"]
}, Open  ]],
Cell[903263, 30475, 538, 15, 157, "Text"],
Cell[CellGroupData[{
Cell[903826, 30494, 78, 2, 157, "Input"],
Cell[903907, 30498, 201, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904145, 30510, 95, 2, 157, "Input"],
Cell[904243, 30514, 153, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904433, 30523, 123, 3, 157, "Input"],
Cell[904559, 30528, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904624, 30533, 87, 2, 157, "Input"],
Cell[904714, 30537, 129, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904880, 30546, 177, 5, 157, "Input"],
Cell[905060, 30553, 479, 18, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[905576, 30576, 95, 2, 157, "Input"],
Cell[905674, 30580, 28, 0, 157, "Output"]
}, Open  ]],
Cell[905717, 30583, 423, 15, 157, "Text"],
Cell[CellGroupData[{
Cell[906165, 30602, 292, 8, 157, "Input"],
Cell[906460, 30612, 624, 19, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[907133, 30637, 111, 2, 157, "Subsubsection"],
Cell[907247, 30641, 1270, 34, 157, "Text"],
Cell[CellGroupData[{
Cell[908542, 30679, 132, 3, 157, "Input"],
Cell[908677, 30684, 95, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[908809, 30691, 206, 6, 157, "Input"],
Cell[909018, 30699, 167, 5, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[909222, 30709, 35, 0, 157, "Input"],
Cell[909260, 30711, 83, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[909380, 30718, 33, 0, 157, "Input"],
Cell[909416, 30720, 128, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[909581, 30728, 34, 0, 157, "Input"],
Cell[909618, 30730, 137, 4, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[909792, 30739, 31, 0, 157, "Input"],
Cell[909826, 30741, 249, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[910112, 30752, 32, 0, 157, "Input"],
Cell[910147, 30754, 170, 5, 157, "Output"]
}, Open  ]],
Cell[910332, 30762, 103, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[910460, 30768, 499, 16, 157, "Input"],
Cell[910962, 30786, 375, 11, 157, "Output"]
}, Open  ]],
Cell[911352, 30800, 88, 2, 157, "Text"],
Cell[CellGroupData[{
Cell[911465, 30806, 334, 9, 157, "Input"],
Cell[911802, 30817, 375, 11, 157, "Output"]
}, Open  ]],
Cell[912192, 30831, 459, 17, 157, "Text"],
Cell[CellGroupData[{
Cell[912676, 30852, 128, 3, 157, "Input"],
Cell[912807, 30857, 98, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[912942, 30864, 257, 8, 157, "Input"],
Cell[913202, 30874, 391, 12, 157, "Output"]
}, Open  ]],
Cell[913608, 30889, 270, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[913903, 30903, 190, 6, 157, "Input"],
Cell[914096, 30911, 527, 17, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[914660, 30933, 127, 3, 157, "Input"],
Cell[914790, 30938, 722, 23, 157, "Output"]
}, Open  ]],
Cell[915527, 30964, 171, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[915723, 30975, 134, 3, 157, "Input"],
Cell[915860, 30980, 1060, 33, 157, "Output"]
}, Open  ]],
Cell[916935, 31016, 521, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[917481, 31032, 158, 4, 157, "Input"],
Cell[917642, 31038, 155, 4, 157, "Output"],
Cell[917800, 31044, 183, 4, 157, "Output"]
}, Open  ]],
Cell[917998, 31051, 295, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[918318, 31063, 257, 8, 157, "Input"],
Cell[918578, 31073, 28, 0, 157, "Output"],
Cell[918609, 31075, 28, 0, 157, "Output"]
}, Open  ]],
Cell[918652, 31078, 134, 4, 157, "Text"],
Cell[CellGroupData[{
Cell[918811, 31086, 478, 14, 157, "Input"],
Cell[919292, 31102, 773, 23, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[920102, 31130, 123, 3, 157, "Input"],
Cell[920228, 31135, 100, 2, 157, "Output"],
Cell[920331, 31139, 255, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[920623, 31151, 78, 2, 157, "Input"],
Cell[920704, 31155, 225, 7, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[920966, 31167, 55, 1, 157, "Input"],
Cell[921024, 31170, 391, 13, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[921452, 31188, 89, 2, 157, "Input"],
Cell[921544, 31192, 591, 19, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[922172, 31216, 120, 3, 157, "Input"],
Cell[922295, 31221, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[922360, 31226, 390, 12, 157, "Input"],
Cell[922753, 31240, 444, 13, 157, "Output"],
Cell[923200, 31255, 627, 19, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[923864, 31279, 392, 11, 157, "Input"],
Cell[924259, 31292, 375, 10, 157, "Output"],
Cell[924637, 31304, 730, 22, 157, "Output"],
Cell[925370, 31328, 662, 17, 157, "Output"]
}, Open  ]],
Cell[926047, 31348, 188, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[926260, 31359, 206, 7, 157, "Input"],
Cell[926469, 31368, 2888, 85, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[929394, 31458, 87, 2, 157, "Input"],
Cell[929484, 31462, 556, 17, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[930077, 31484, 177, 5, 157, "Input"],
Cell[930257, 31491, 1226, 39, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[931520, 31535, 260, 8, 157, "Input"],
Cell[931783, 31545, 1038, 34, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[932858, 31584, 176, 4, 157, "Input"],
Cell[933037, 31590, 28, 0, 157, "Output"],
Cell[933068, 31592, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[933133, 31597, 287, 8, 157, "Input"],
Cell[933423, 31607, 4182, 125, 157, "Output"]
}, Open  ]],
Cell[937620, 31735, 221, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[937866, 31746, 79, 2, 157, "Input"],
Cell[937948, 31750, 554, 17, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[938539, 31772, 80, 2, 157, "Input"],
Cell[938622, 31776, 540, 16, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[939199, 31797, 80, 2, 157, "Input"],
Cell[939282, 31801, 540, 16, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[939871, 31823, 41, 0, 157, "Subsubsection"],
Cell[939915, 31825, 57, 1, 157, "Input"],
Cell[939975, 31828, 74, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[940074, 31833, 49, 0, 157, "Input"],
Cell[940126, 31835, 45, 1, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[940232, 31843, 58, 0, 44, "Subsection"],
Cell[940293, 31845, 56, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[940374, 31849, 58, 0, 157, "Subsubsection"],
Cell[940435, 31851, 386, 12, 157, "Text"],
Cell[940824, 31865, 152, 5, 157, "Input"],
Cell[940979, 31872, 336, 14, 157, "Text"],
Cell[CellGroupData[{
Cell[941340, 31890, 32, 0, 157, "Input"],
Cell[941375, 31892, 485, 14, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[941897, 31911, 31, 0, 157, "Input"],
Cell[941931, 31913, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[941996, 31918, 34, 0, 157, "Input"],
Cell[942033, 31920, 213, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[942283, 31931, 31, 0, 157, "Input"],
Cell[942317, 31933, 28, 0, 157, "Output"]
}, Open  ]],
Cell[942360, 31936, 909, 33, 157, "Text"],
Cell[CellGroupData[{
Cell[943294, 31973, 51, 1, 157, "Input"],
Cell[943348, 31976, 1325, 41, 157, "Output"]
}, Open  ]],
Cell[944688, 32020, 209, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[944922, 32030, 32, 0, 157, "Input"],
Cell[944957, 32032, 213, 6, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[945207, 32043, 32, 0, 157, "Input"],
Cell[945242, 32045, 265, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[945544, 32058, 32, 0, 157, "Input"],
Cell[945579, 32060, 265, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[945881, 32073, 31, 0, 157, "Input"],
Cell[945915, 32075, 477, 14, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[946429, 32094, 56, 1, 157, "Input"],
Cell[946488, 32097, 454, 15, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[946979, 32117, 56, 1, 157, "Input"],
Cell[947038, 32120, 454, 15, 157, "Output"]
}, Open  ]],
Cell[947507, 32138, 1384, 46, 157, "Text"],
Cell[CellGroupData[{
Cell[948916, 32188, 59, 1, 157, "Input"],
Cell[948978, 32191, 1467, 47, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[950482, 32243, 61, 1, 157, "Input"],
Cell[950546, 32246, 1026, 34, 157, "Output"]
}, Open  ]],
Cell[951587, 32283, 767, 24, 157, "Text"],
Cell[CellGroupData[{
Cell[952379, 32311, 65, 1, 157, "Input"],
Cell[952447, 32314, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[952512, 32319, 63, 1, 157, "Input"],
Cell[952578, 32322, 28, 0, 157, "Output"]
}, Open  ]],
Cell[952621, 32325, 167, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[952813, 32334, 159, 5, 157, "Input"],
Cell[952975, 32341, 426, 15, 157, "Output"]
}, Open  ]],
Cell[953416, 32359, 220, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[953661, 32371, 121, 3, 157, "Input"],
Cell[953785, 32376, 237, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[954059, 32389, 162, 5, 157, "Input"],
Cell[954224, 32396, 2286, 81, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[956547, 32482, 54, 1, 157, "Input"],
Cell[956604, 32485, 598, 20, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[957251, 32511, 72, 0, 157, "Subsubsection"],
Cell[957326, 32513, 122, 3, 157, "Text"],
Cell[957451, 32518, 152, 4, 157, "Input"],
Cell[CellGroupData[{
Cell[957628, 32526, 34, 0, 157, "Input"],
Cell[957665, 32528, 703, 18, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[958405, 32551, 31, 0, 157, "Input"],
Cell[958439, 32553, 2049, 62, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[960525, 32620, 51, 1, 157, "Input"],
Cell[960579, 32623, 13081, 397, 157, "Output"]
}, Open  ]],
Cell[973675, 33023, 417, 16, 157, "Text"],
Cell[CellGroupData[{
Cell[974117, 33043, 56, 1, 157, "Input"],
Cell[974176, 33046, 1886, 63, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[976099, 33114, 56, 1, 157, "Input"],
Cell[976158, 33117, 1886, 63, 157, "Output"]
}, Open  ]],
Cell[978059, 33183, 383, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[978467, 33200, 59, 1, 157, "Input"],
Cell[978529, 33203, 22009, 677, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1000575, 33885, 61, 1, 157, "Input"],
Cell[1000639, 33888, 12277, 385, 157, "Output"]
}, Open  ]],
Cell[1012931, 34276, 139, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1013095, 34283, 63, 1, 157, "Input"],
Cell[1013161, 34286, 28, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1013226, 34291, 65, 1, 157, "Input"],
Cell[1013294, 34294, 28, 0, 157, "Output"]
}, Open  ]],
Cell[1013337, 34297, 246, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[1013608, 34309, 83, 2, 157, "Input"],
Cell[1013694, 34313, 21688, 667, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1035419, 34985, 85, 2, 157, "Input"],
Cell[1035507, 34989, 11956, 375, 157, "Output"]
}, Open  ]],
Cell[1047478, 35367, 196, 8, 157, "Text"],
Cell[1047677, 35377, 140, 4, 157, "Input"],
Cell[CellGroupData[{
Cell[1047842, 35385, 189, 5, 157, "Input"],
Cell[1048034, 35392, 73, 2, 157, "Output"]
}, Open  ]],
Cell[1048122, 35397, 827, 25, 157, "Text"],
Cell[CellGroupData[{
Cell[1048974, 35426, 88, 2, 157, "Input"],
Cell[1049065, 35430, 392, 7, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1049506, 35443, 62, 0, 157, "Subsubsection"],
Cell[1049571, 35445, 355, 10, 157, "Text"],
Cell[1049929, 35457, 181, 6, 157, "Input"],
Cell[CellGroupData[{
Cell[1050135, 35467, 51, 1, 157, "Input"],
Cell[1050189, 35470, 6448, 197, 157, "Output"]
}, Open  ]],
Cell[1056652, 35670, 171, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[1056848, 35679, 320, 10, 157, "Input"],
Cell[1057171, 35691, 502, 17, 157, "Output"],
Cell[1057676, 35710, 750, 25, 157, "Output"]
}, Open  ]],
Cell[1058441, 35738, 137, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1058603, 35745, 146, 4, 157, "Input"],
Cell[1058752, 35751, 105, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1058894, 35758, 34, 0, 157, "Input"],
Cell[1058931, 35760, 112, 3, 157, "Output"]
}, Open  ]],
Cell[1059058, 35766, 242, 6, 157, "Text"],
Cell[1059303, 35774, 562, 19, 157, "Input"],
Cell[CellGroupData[{
Cell[1059890, 35797, 489, 15, 157, "Input"],
Cell[1060382, 35814, 669, 21, 157, "Output"]
}, Open  ]],
Cell[1061066, 35838, 223, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1061314, 35851, 141, 4, 157, "Input"],
Cell[1061458, 35857, 444, 12, 157, "Output"]
}, Open  ]],
Cell[1061917, 35872, 232, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[1062174, 35884, 363, 10, 157, "Input"],
Cell[1062540, 35896, 689, 21, 157, "Output"]
}, Open  ]],
Cell[1063244, 35920, 224, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1063493, 35933, 80, 2, 157, "Input"],
Cell[1063576, 35937, 310, 9, 157, "Output"]
}, Open  ]],
Cell[1063901, 35949, 286, 9, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1064224, 35963, 61, 0, 157, "Subsubsection"],
Cell[1064288, 35965, 230, 6, 157, "Text"],
Cell[1064521, 35973, 474, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[1065020, 35989, 268, 9, 157, "Input"],
Cell[1065291, 36000, 1697, 58, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1067025, 36063, 214, 6, 157, "Input"],
Cell[1067242, 36071, 2927, 98, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1070206, 36174, 140, 4, 157, "Input"],
Cell[1070349, 36180, 2844, 97, 157, "Output"]
}, Open  ]],
Cell[1073208, 36280, 219, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1073452, 36293, 84, 2, 157, "Input"],
Cell[1073539, 36297, 7046, 201, 157, "Output"]
}, Open  ]],
Cell[1080600, 36501, 121, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1080746, 36508, 383, 9, 157, "Input"],
Cell[1081132, 36519, 347, 8, 157, "Output"]
}, Open  ]],
Cell[1081494, 36530, 260, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[1081779, 36542, 241, 7, 157, "Input"],
Cell[1082023, 36551, 2573, 74, 157, "Output"]
}, Open  ]],
Cell[1084611, 36628, 140, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1084776, 36635, 121, 3, 157, "Input"],
Cell[1084900, 36640, 4734, 164, 157, "Output"]
}, Open  ]],
Cell[1089649, 36807, 296, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[1089970, 36822, 90, 2, 157, "Input"],
Cell[1090063, 36826, 5640, 188, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1095740, 37019, 182, 5, 157, "Input"],
Cell[1095925, 37026, 2618, 88, 157, "Output"]
}, Open  ]],
Cell[1098558, 37117, 215, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1098798, 37130, 137, 4, 157, "Input"],
Cell[1098938, 37136, 687, 21, 157, "Output"]
}, Open  ]],
Cell[1099640, 37160, 259, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1099924, 37173, 59, 1, 157, "Input"],
Cell[1099986, 37176, 28, 0, 157, "Output"]
}, Open  ]],
Cell[1100029, 37179, 237, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1100291, 37192, 61, 1, 157, "Input"],
Cell[1100355, 37195, 2451, 75, 157, "Output"]
}, Open  ]],
Cell[1102821, 37273, 252, 10, 157, "Text"],
Cell[1103076, 37285, 266, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1103367, 37298, 178, 5, 157, "Input"],
Cell[1103548, 37305, 4790, 129, 157, "Output"]
}, Open  ]],
Cell[1108353, 37437, 377, 15, 157, "Text"],
Cell[CellGroupData[{
Cell[1108755, 37456, 536, 18, 157, "Input"],
Cell[1109294, 37476, 490, 17, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1109821, 37498, 121, 3, 157, "Input"],
Cell[1109945, 37503, 28, 0, 157, "Output"]
}, Open  ]],
Cell[1109988, 37506, 494, 16, 157, "Text"],
Cell[CellGroupData[{
Cell[1110507, 37526, 206, 6, 157, "Input"],
Cell[1110716, 37534, 334, 11, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1111087, 37550, 62, 1, 157, "Input"],
Cell[1111152, 37553, 313, 10, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1111502, 37568, 35, 0, 157, "Input"],
Cell[1111540, 37570, 112, 3, 157, "Output"]
}, Open  ]],
Cell[1111667, 37576, 243, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[1111935, 37591, 31, 0, 157, "Input"],
Cell[1111969, 37593, 1507, 45, 157, "Output"]
}, Open  ]],
Cell[1113491, 37641, 201, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[1113717, 37653, 55, 1, 157, "Input"],
Cell[1113775, 37656, 303, 9, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1114115, 37670, 55, 1, 157, "Input"],
Cell[1114173, 37673, 45, 1, 157, "Output"]
}, Open  ]],
Cell[1114233, 37677, 267, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[1114525, 37690, 255, 8, 157, "Input"],
Cell[1114783, 37700, 688, 22, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1115508, 37727, 190, 6, 157, "Input"],
Cell[1115701, 37735, 1250, 41, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1116988, 37781, 156, 4, 157, "Input"],
Cell[1117147, 37787, 1644, 54, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1118828, 37846, 134, 3, 157, "Input"],
Cell[1118965, 37851, 2276, 73, 157, "Output"]
}, Open  ]],
Cell[1121256, 37927, 459, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[1121740, 37944, 462, 14, 157, "Input"],
Cell[1122205, 37960, 961, 29, 157, "Output"]
}, Open  ]],
Cell[1123181, 37992, 196, 6, 157, "Text"],
Cell[CellGroupData[{
Cell[1123402, 38002, 113, 3, 157, "Input"],
Cell[1123518, 38007, 4781, 152, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1128336, 38164, 97, 2, 157, "Input"],
Cell[1128436, 38168, 28, 0, 157, "Output"]
}, Open  ]],
Cell[1128479, 38171, 390, 12, 157, "Text"],
Cell[CellGroupData[{
Cell[1128894, 38187, 69, 1, 157, "Input"],
Cell[1128966, 38190, 105, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1129108, 38197, 94, 2, 157, "Input"],
Cell[1129205, 38201, 122, 2, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1129364, 38208, 54, 1, 157, "Input"],
Cell[1129421, 38211, 330, 9, 157, "Output"]
}, Open  ]],
Cell[1129766, 38223, 113, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1129904, 38230, 89, 2, 157, "Input"],
Cell[1129996, 38234, 1477, 47, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1131510, 38286, 62, 1, 157, "Input"],
Cell[1131575, 38289, 1163, 37, 157, "Output"]
}, Open  ]],
Cell[1132753, 38329, 108, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1132886, 38336, 74, 2, 157, "Input"],
Cell[1132963, 38340, 704, 20, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1133716, 38366, 77, 0, 157, "Subsubsection"],
Cell[1133796, 38368, 994, 31, 157, "Text"],
Cell[CellGroupData[{
Cell[1134815, 38403, 154, 3, 157, "Input"],
Cell[1134972, 38408, 369, 10, 157, "Output"],
Cell[1135344, 38420, 459, 12, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1135840, 38437, 628, 19, 157, "Input"],
Cell[1136471, 38458, 31, 0, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1136539, 38463, 63, 1, 157, "Input"],
Cell[1136605, 38466, 466, 14, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1137108, 38485, 125, 3, 157, "Input"],
Cell[1137236, 38490, 466, 14, 157, "Output"]
}, Open  ]],
Cell[1137717, 38507, 110, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1137852, 38514, 56, 1, 157, "Input"],
Cell[1137911, 38517, 687, 21, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1138635, 38543, 129, 3, 157, "Input"],
Cell[1138767, 38548, 2809, 78, 157, "Output"]
}, Open  ]],
Cell[1141591, 38629, 221, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[1141837, 38641, 82, 1, 157, "Input"],
Cell[1141922, 38644, 4835, 134, 157, "Output"]
}, Open  ]],
Cell[1146772, 38781, 120, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1146917, 38788, 181, 5, 157, "Input"],
Cell[1147101, 38795, 4835, 134, 157, "Output"]
}, Open  ]],
Cell[1151951, 38932, 737, 27, 157, "Text"],
Cell[CellGroupData[{
Cell[1152713, 38963, 444, 13, 157, "Input"],
Cell[1153160, 38978, 411, 12, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1153608, 38995, 60, 1, 157, "Input"],
Cell[1153671, 38998, 509, 16, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1154217, 39019, 159, 3, 157, "Input"],
Cell[1154379, 39024, 681, 23, 157, "Output"],
Cell[1155063, 39049, 678, 22, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1155778, 39076, 424, 13, 157, "Input"],
Cell[1156205, 39091, 453, 14, 157, "Output"],
Cell[1156661, 39107, 369, 10, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1157079, 39123, 60, 0, 157, "Subsubsection"],
Cell[1157142, 39125, 358, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[1157525, 39140, 35, 0, 157, "Input"],
Cell[1157563, 39142, 1017, 16, 157, "Output"]
}, Open  ]],
Cell[1158595, 39161, 2213, 52, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1160845, 39218, 41, 0, 157, "Subsubsection"],
Cell[1160889, 39220, 57, 1, 157, "Input"],
Cell[1160949, 39223, 74, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[1161048, 39228, 49, 0, 157, "Input"],
Cell[1161100, 39230, 45, 1, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1161206, 39238, 71, 0, 44, "Subsection"],
Cell[1161280, 39240, 55, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[1161360, 39244, 49, 0, 157, "Subsubsection"],
Cell[1161412, 39246, 516, 14, 157, "Text"],
Cell[1161931, 39262, 748, 23, 157, "Text"],
Cell[1162682, 39287, 1011, 31, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1163730, 39323, 53, 0, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[1163808, 39327, 1113, 35, 157, "Input"],
Cell[CellGroupData[{
Cell[1164946, 39366, 91, 1, 157, "Print"],
Cell[1165040, 39369, 940, 26, 157, "Print"],
Cell[1165983, 39397, 77, 0, 157, "Print"],
Cell[1166063, 39399, 1041, 31, 157, "Print"],
Cell[1167107, 39432, 92, 1, 157, "Print"],
Cell[1167202, 39435, 843, 24, 157, "Print"],
Cell[1168048, 39461, 94, 1, 157, "Print"],
Cell[1168145, 39464, 931, 26, 157, "Print"],
Cell[1169079, 39492, 84, 1, 157, "Print"],
Cell[1169166, 39495, 826, 25, 157, "Print"],
Cell[1169995, 39522, 95, 1, 157, "Print"],
Cell[1170093, 39525, 793, 25, 157, "Print"],
Cell[1170889, 39552, 91, 1, 157, "Print"],
Cell[1170983, 39555, 1532, 48, 157, "Print"],
Cell[1172518, 39605, 64, 0, 157, "Print"],
Cell[1172585, 39607, 868, 28, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1173514, 39642, 67, 0, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[1173606, 39646, 1112, 36, 157, "Input"],
Cell[CellGroupData[{
Cell[1174743, 39686, 91, 1, 157, "Print"],
Cell[1174837, 39689, 1011, 28, 157, "Print"],
Cell[1175851, 39719, 77, 0, 157, "Print"],
Cell[1175931, 39721, 1326, 37, 157, "Print"],
Cell[1177260, 39760, 92, 1, 157, "Print"],
Cell[1177355, 39763, 843, 24, 157, "Print"],
Cell[1178201, 39789, 94, 1, 157, "Print"],
Cell[1178298, 39792, 1186, 31, 157, "Print"],
Cell[1179487, 39825, 84, 1, 157, "Print"],
Cell[1179574, 39828, 1125, 33, 157, "Print"],
Cell[1180702, 39863, 95, 1, 157, "Print"],
Cell[1180800, 39866, 1067, 30, 157, "Print"],
Cell[1181870, 39898, 91, 1, 157, "Print"],
Cell[1181964, 39901, 2071, 57, 157, "Print"],
Cell[1184038, 39960, 64, 0, 157, "Print"],
Cell[1184105, 39962, 1044, 29, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1185210, 39998, 55, 0, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[1185290, 40002, 1380, 44, 157, "Input"],
Cell[1186673, 40048, 105, 2, 157, "Output"],
Cell[CellGroupData[{
Cell[1186803, 40054, 91, 1, 157, "Print"],
Cell[1186897, 40057, 1342, 38, 157, "Print"],
Cell[1188242, 40097, 77, 0, 157, "Print"],
Cell[1188322, 40099, 2440, 71, 157, "Print"],
Cell[1190765, 40172, 92, 1, 157, "Print"],
Cell[1190860, 40175, 7194, 187, 157, "Print"],
Cell[1198057, 40364, 94, 1, 157, "Print"],
Cell[1198154, 40367, 5303, 132, 157, "Print"],
Cell[1203460, 40501, 84, 1, 157, "Print"],
Cell[1203547, 40504, 2467, 73, 157, "Print"],
Cell[1206017, 40579, 95, 1, 157, "Print"],
Cell[1206115, 40582, 6631, 162, 157, "Print"],
Cell[1212749, 40746, 91, 1, 157, "Print"],
Cell[1212843, 40749, 1517, 42, 157, "Print"],
Cell[1214363, 40793, 64, 0, 157, "Print"],
Cell[1214430, 40795, 284, 7, 157, "Print"],
Cell[1214717, 40804, 89, 1, 157, "Print"],
Cell[1214809, 40807, 4618, 116, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1219488, 40930, 55, 0, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[1219568, 40934, 1732, 54, 157, "Input"],
Cell[1221303, 40990, 105, 2, 157, "Output"],
Cell[CellGroupData[{
Cell[1221433, 40996, 91, 1, 157, "Print"],
Cell[1221527, 40999, 1826, 51, 157, "Print"],
Cell[1223356, 41052, 77, 0, 157, "Print"],
Cell[1223436, 41054, 3055, 86, 157, "Print"],
Cell[1226494, 41142, 92, 1, 157, "Print"],
Cell[1226589, 41145, 7194, 187, 157, "Print"],
Cell[1233786, 41334, 94, 1, 157, "Print"],
Cell[1233883, 41337, 5837, 144, 157, "Print"],
Cell[1239723, 41483, 84, 1, 157, "Print"],
Cell[1239810, 41486, 2990, 86, 157, "Print"],
Cell[1242803, 41574, 95, 1, 157, "Print"],
Cell[1242901, 41577, 9501, 239, 157, "Print"],
Cell[1252405, 41818, 91, 1, 157, "Print"],
Cell[1252499, 41821, 6197, 168, 157, "Print"],
Cell[1258699, 41991, 64, 0, 157, "Print"],
Cell[1258766, 41993, 1833, 50, 157, "Print"],
Cell[1260602, 42045, 89, 1, 157, "Print"],
Cell[1260694, 42048, 3935, 96, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1264690, 42151, 58, 0, 157, "Subsubsection"],
Cell[1264751, 42153, 132, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[1264908, 42160, 1408, 42, 157, "Input"],
Cell[1266319, 42204, 653, 19, 157, "Output"],
Cell[CellGroupData[{
Cell[1266997, 42227, 91, 1, 157, "Print"],
Cell[1267091, 42230, 1325, 35, 157, "Print"],
Cell[1268419, 42267, 77, 0, 157, "Print"],
Cell[1268499, 42269, 3722, 100, 157, "Print"],
Cell[1272224, 42371, 92, 1, 157, "Print"],
Cell[1272319, 42374, 7194, 187, 157, "Print"],
Cell[1279516, 42563, 94, 1, 157, "Print"],
Cell[1279613, 42566, 6106, 148, 157, "Print"],
Cell[1285722, 42716, 84, 1, 157, "Print"],
Cell[1285809, 42719, 3635, 106, 157, "Print"],
Cell[1289447, 42827, 95, 1, 157, "Print"],
Cell[1289545, 42830, 9036, 223, 157, "Print"],
Cell[1298584, 43055, 91, 1, 157, "Print"],
Cell[1298678, 43058, 6027, 164, 157, "Print"],
Cell[1304708, 43224, 64, 0, 157, "Print"],
Cell[1304775, 43226, 1807, 49, 157, "Print"],
Cell[1306585, 43277, 89, 1, 157, "Print"],
Cell[1306677, 43280, 8900, 234, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1315638, 43521, 70, 0, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[1315733, 43525, 2676, 86, 157, "Input"],
Cell[CellGroupData[{
Cell[1318434, 43615, 91, 1, 157, "Print"],
Cell[1318528, 43618, 3918, 109, 157, "Print"],
Cell[1322449, 43729, 77, 0, 157, "Print"],
Cell[1322529, 43731, 17518, 436, 157, "Print"],
Cell[1340050, 44169, 92, 1, 157, "Print"],
Cell[1340145, 44172, 7194, 187, 157, "Print"],
Cell[1347342, 44361, 94, 1, 157, "Print"],
Cell[1347439, 44364, 20985, 556, 157, "Print"],
Cell[1368427, 44922, 84, 1, 157, "Print"],
Cell[1368514, 44925, 18116, 477, 157, "Print"],
Cell[1386633, 45404, 95, 1, 157, "Print"],
Cell[1386731, 45407, 96435, 2419, 157, "Print"],
Cell[1483169, 47828, 91, 1, 157, "Print"],
Cell[1483263, 47831, 49779, 1225, 157, "Print"],
Cell[1533045, 49058, 64, 0, 157, "Print"],
Cell[1533112, 49060, 10822, 269, 157, "Print"],
Cell[1543937, 49331, 89, 1, 157, "Print"],
Cell[1544029, 49334, 110450, 2694, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1654540, 52035, 75, 0, 157, "Subsubsection"],
Cell[1654618, 52037, 994, 28, 157, "Text"],
Cell[CellGroupData[{
Cell[1655637, 52069, 3704, 120, 157, "Input"],
Cell[CellGroupData[{
Cell[1659366, 52193, 91, 1, 157, "Print"],
Cell[1659460, 52196, 5529, 151, 157, "Print"],
Cell[1664992, 52349, 77, 0, 157, "Print"],
Cell[1665072, 52351, 26096, 620, 157, "Print"],
Cell[1691171, 52973, 92, 1, 157, "Print"],
Cell[1691266, 52976, 7194, 187, 157, "Print"],
Cell[1698463, 53165, 94, 1, 157, "Print"],
Cell[1698560, 53168, 30031, 770, 157, "Print"],
Cell[1728594, 53940, 84, 1, 157, "Print"],
Cell[1728681, 53943, 22609, 571, 157, "Print"],
Cell[1751293, 54516, 95, 1, 157, "Print"],
Cell[1751391, 54519, 159650, 3839, 157, "Print"],
Cell[1911044, 58360, 91, 1, 157, "Print"],
Cell[1911138, 58363, 52707, 1225, 157, "Print"],
Cell[1963848, 59590, 64, 0, 157, "Print"],
Cell[1963915, 59592, 9462, 229, 157, "Print"],
Cell[1973380, 59823, 89, 1, 157, "Print"],
Cell[1973472, 59826, 174008, 4051, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2147541, 63884, 49, 0, 157, "Subsubsection"],
Cell[2147593, 63886, 72, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[2147690, 63890, 1721, 53, 157, "Input"],
Cell[2149414, 63945, 112, 3, 157, "Output"],
Cell[2149529, 63950, 93, 2, 157, "Output"],
Cell[2149625, 63954, 824, 26, 157, "Output"],
Cell[2150452, 63982, 555, 18, 157, "Output"],
Cell[CellGroupData[{
Cell[2151032, 64004, 91, 1, 157, "Print"],
Cell[2151126, 64007, 1470, 38, 157, "Print"],
Cell[2152599, 64047, 77, 0, 157, "Print"],
Cell[2152679, 64049, 2862, 75, 157, "Print"],
Cell[2155544, 64126, 92, 1, 157, "Print"],
Cell[2155639, 64129, 7194, 187, 157, "Print"],
Cell[2162836, 64318, 94, 1, 157, "Print"],
Cell[2162933, 64321, 6186, 147, 157, "Print"],
Cell[2169122, 64470, 84, 1, 157, "Print"],
Cell[2169209, 64473, 3806, 105, 157, "Print"],
Cell[2173018, 64580, 95, 1, 157, "Print"],
Cell[2173116, 64583, 15765, 392, 157, "Print"],
Cell[2188884, 64977, 91, 1, 157, "Print"],
Cell[2188978, 64980, 3672, 101, 157, "Print"],
Cell[2192653, 65083, 64, 0, 157, "Print"],
Cell[2192720, 65085, 284, 7, 157, "Print"],
Cell[2193007, 65094, 89, 1, 157, "Print"],
Cell[2193099, 65097, 9559, 248, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2202719, 65352, 71, 0, 157, "Subsubsection"],
Cell[2202793, 65354, 442, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[2203260, 65367, 181, 5, 157, "Input"],
Cell[2203444, 65374, 3933, 110, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2207414, 65489, 181, 5, 157, "Input"],
Cell[2207598, 65496, 3933, 110, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2211568, 65611, 241, 7, 157, "Input"],
Cell[2211812, 65620, 3933, 110, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2215782, 65735, 180, 5, 157, "Input"],
Cell[2215965, 65742, 10592, 299, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2226594, 66046, 240, 7, 157, "Input"],
Cell[2226837, 66055, 10592, 299, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2237466, 66359, 177, 5, 157, "Input"],
Cell[2237646, 66366, 2447, 77, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2240130, 66448, 237, 7, 157, "Input"],
Cell[2240370, 66457, 2447, 77, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2242854, 66539, 178, 5, 157, "Input"],
Cell[2243035, 66546, 110, 3, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2243182, 66554, 176, 5, 157, "Input"],
Cell[2243361, 66561, 6478, 186, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2249876, 66752, 236, 7, 157, "Input"],
Cell[2250115, 66761, 6478, 186, 157, "Output"]
}, Open  ]],
Cell[2256608, 66950, 397, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[2257030, 66963, 170, 5, 157, "Input"],
Cell[2257203, 66970, 1918, 57, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2259158, 67032, 225, 6, 157, "Input"],
Cell[2259386, 67040, 1918, 57, 157, "Output"]
}, Open  ]],
Cell[2261319, 67100, 510, 13, 157, "Text"],
Cell[CellGroupData[{
Cell[2261854, 67117, 169, 5, 157, "Input"],
Cell[2262026, 67124, 4198, 127, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2266261, 67256, 224, 6, 157, "Input"],
Cell[2266488, 67264, 4198, 127, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2270723, 67396, 61, 1, 157, "Input"],
Cell[2270787, 67399, 4198, 127, 157, "Output"]
}, Open  ]],
Cell[2275000, 67529, 255, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[2275280, 67538, 165, 5, 157, "Input"],
Cell[2275448, 67545, 2591, 78, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2278076, 67628, 220, 6, 157, "Input"],
Cell[2278299, 67636, 2591, 78, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2280927, 67719, 163, 4, 157, "Input"],
Cell[2281093, 67725, 2306, 66, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2283436, 67796, 174, 4, 157, "Input"],
Cell[2283613, 67802, 83, 2, 157, "Output"]
}, Open  ]],
Cell[2283711, 67807, 118, 3, 157, "Text"],
Cell[CellGroupData[{
Cell[2283854, 67814, 3592, 117, 157, "Input"],
Cell[2287449, 67933, 83, 2, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2287581, 67941, 42, 0, 157, "Subsubsection"],
Cell[2287626, 67943, 57, 1, 157, "Input"],
Cell[2287686, 67946, 74, 1, 157, "Input"],
Cell[CellGroupData[{
Cell[2287785, 67951, 49, 0, 157, "Input"],
Cell[2287837, 67953, 45, 1, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2287943, 67961, 94, 2, 44, "Subsection"],
Cell[2288040, 67965, 64, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[2288129, 67969, 49, 0, 157, "Subsubsection"],
Cell[2288181, 67971, 1810, 40, 157, "Text"],
Cell[2289994, 68013, 2542, 74, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2292573, 68092, 77, 0, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[2292675, 68096, 1184, 37, 157, "Input"],
Cell[2293862, 68135, 571, 18, 157, "Output"],
Cell[CellGroupData[{
Cell[2294458, 68157, 49, 1, 157, "Print"],
Cell[2294510, 68160, 72, 2, 157, "Print"],
Cell[2294585, 68164, 72, 0, 157, "Print"],
Cell[2294660, 68166, 254, 5, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2294975, 68178, 83, 1, 157, "Subsubsection"],
Cell[2295061, 68181, 318, 10, 157, "Text"],
Cell[CellGroupData[{
Cell[2295404, 68195, 992, 30, 157, "Input"],
Cell[2296399, 68227, 133, 4, 157, "Output"],
Cell[2296535, 68233, 1173, 38, 157, "Output"],
Cell[CellGroupData[{
Cell[2297733, 68275, 49, 1, 157, "Print"],
Cell[2297785, 68278, 72, 2, 157, "Print"],
Cell[2297860, 68282, 72, 0, 157, "Print"],
Cell[2297935, 68284, 254, 5, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2298250, 68296, 103, 2, 157, "Subsubsection"],
Cell[CellGroupData[{
Cell[2298378, 68302, 2297, 70, 157, "Input"],
Cell[2300678, 68374, 1526, 48, 157, "Output"],
Cell[CellGroupData[{
Cell[2302229, 68426, 49, 1, 157, "Print"],
Cell[2302281, 68429, 72, 2, 157, "Print"],
Cell[2302356, 68433, 72, 0, 157, "Print"],
Cell[2302431, 68435, 254, 5, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2302746, 68447, 101, 2, 157, "Subsubsection"],
Cell[2302850, 68451, 751, 19, 157, "Text"],
Cell[CellGroupData[{
Cell[2303626, 68474, 905, 27, 157, "Input"],
Cell[2304534, 68503, 3333, 104, 157, "Output"],
Cell[CellGroupData[{
Cell[2307892, 68611, 49, 1, 157, "Print"],
Cell[2307944, 68614, 72, 2, 157, "Print"],
Cell[2308019, 68618, 82, 2, 157, "Print"],
Cell[2308104, 68622, 92, 2, 157, "Print"],
Cell[2308199, 68626, 102, 2, 157, "Print"],
Cell[2308304, 68630, 72, 0, 157, "Print"],
Cell[2308379, 68632, 256, 5, 157, "Print"]
}, Open  ]]
}, Open  ]],
Cell[2308662, 68641, 169, 6, 157, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2308868, 68652, 101, 2, 157, "Subsubsection"],
Cell[2308972, 68656, 340, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[2309337, 68671, 899, 26, 157, "Input"],
Cell[2310239, 68699, 294, 8, 157, "Output"],
Cell[2310536, 68709, 3333, 104, 157, "Output"],
Cell[2313872, 68815, 15297, 442, 157, "Output"],
Cell[CellGroupData[{
Cell[2329194, 69261, 49, 1, 157, "Print"],
Cell[2329246, 69264, 72, 2, 157, "Print"],
Cell[2329321, 69268, 83, 2, 157, "Print"],
Cell[2329407, 69272, 93, 2, 157, "Print"],
Cell[2329503, 69276, 72, 0, 157, "Print"],
Cell[2329578, 69278, 256, 5, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2329895, 69290, 100, 2, 157, "Subsubsection"],
Cell[2329998, 69294, 150, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[2330173, 69303, 950, 28, 157, "Input"],
Cell[2331126, 69333, 459, 12, 157, "Output"],
Cell[2331588, 69347, 7413, 232, 157, "Output"],
Cell[CellGroupData[{
Cell[2339026, 69583, 50, 1, 157, "Print"],
Cell[2339079, 69586, 74, 2, 157, "Print"],
Cell[2339156, 69590, 85, 2, 157, "Print"],
Cell[2339244, 69594, 96, 2, 157, "Print"],
Cell[2339343, 69598, 107, 2, 157, "Print"],
Cell[2339453, 69602, 121, 3, 157, "Print"],
Cell[2339577, 69607, 72, 0, 157, "Print"],
Cell[2339652, 69609, 256, 5, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2339969, 69621, 100, 2, 157, "Subsubsection"],
Cell[2340072, 69625, 362, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[2340459, 69637, 987, 28, 157, "Input"],
Cell[2341449, 69667, 665, 17, 157, "Output"],
Cell[2342117, 69686, 13115, 407, 157, "Output"],
Cell[CellGroupData[{
Cell[2355257, 70097, 50, 1, 157, "Print"],
Cell[2355310, 70100, 74, 2, 157, "Print"],
Cell[2355387, 70104, 85, 2, 157, "Print"],
Cell[2355475, 70108, 96, 2, 157, "Print"],
Cell[2355574, 70112, 107, 2, 157, "Print"],
Cell[2355684, 70116, 121, 3, 157, "Print"],
Cell[2355808, 70121, 133, 1, 157, "Print"],
Cell[2355944, 70124, 260, 5, 157, "Print"]
}, Open  ]]
}, Open  ]],
Cell[2356231, 70133, 149, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[2356405, 70142, 1117, 32, 157, "Input"],
Cell[2357525, 70176, 665, 17, 157, "Output"],
Cell[2358193, 70195, 13115, 407, 157, "Output"],
Cell[CellGroupData[{
Cell[2371333, 70606, 50, 1, 157, "Print"],
Cell[2371386, 70609, 74, 2, 157, "Print"],
Cell[2371463, 70613, 85, 2, 157, "Print"],
Cell[2371551, 70617, 96, 2, 157, "Print"],
Cell[2371650, 70621, 107, 2, 157, "Print"],
Cell[2371760, 70625, 121, 3, 157, "Print"],
Cell[2371884, 70630, 135, 4, 157, "Print"],
Cell[2372022, 70636, 72, 0, 157, "Print"],
Cell[2372097, 70638, 258, 5, 157, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2372416, 70650, 207, 5, 157, "Subsubsection"],
Cell[2372626, 70657, 280, 9, 157, "Text"],
Cell[CellGroupData[{
Cell[2372931, 70670, 41, 0, 157, "Input"],
Cell[2372975, 70672, 42959, 880, 157, "Output"]
}, Closed]],
Cell[2415949, 71555, 356, 8, 157, "Text"],
Cell[CellGroupData[{
Cell[2416330, 71567, 43, 0, 157, "Input"],
Cell[2416376, 71569, 152407, 3083, 157, "Output"]
}, Closed]],
Cell[2568798, 74655, 159, 5, 157, "Text"],
Cell[CellGroupData[{
Cell[2568982, 74664, 33, 0, 157, "Input"],
Cell[2569018, 74666, 147293, 4071, 157, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2716348, 78742, 65, 1, 157, "Input"],
Cell[2716416, 78745, 30, 0, 157, "Output"]
}, Open  ]],
Cell[2716461, 78748, 1267, 39, 157, "Text"],
Cell[CellGroupData[{
Cell[2717753, 78791, 31, 0, 157, "Input"],
Cell[2717787, 78793, 1161, 17, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2718985, 78815, 32, 0, 157, "Input"],
Cell[2719020, 78817, 189637, 4526, 157, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2908694, 83348, 32, 0, 157, "Input"],
Cell[2908729, 83350, 251, 8, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2909017, 83363, 36, 0, 157, "Input"],
Cell[2909056, 83365, 6827, 203, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2915920, 83573, 37, 0, 157, "Input"],
Cell[2915960, 83575, 8021, 242, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2924018, 83822, 33, 0, 157, "Input"],
Cell[2924054, 83824, 1222, 17, 157, "Output"]
}, Open  ]],
Cell[2925291, 83844, 242, 7, 157, "Text"],
Cell[CellGroupData[{
Cell[2925558, 83855, 31, 0, 157, "Input"],
Cell[2925592, 83857, 6827, 203, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2932456, 84065, 347, 10, 157, "Input"],
Cell[2932806, 84077, 207, 5, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2933050, 84087, 302, 6, 157, "Input"],
Cell[2933355, 84095, 71, 1, 157, "Output"]
}, Open  ]],
Cell[2933441, 84099, 1598, 37, 157, "Text"],
Cell[CellGroupData[{
Cell[2935064, 84140, 36, 0, 157, "Input"],
Cell[2935103, 84142, 6827, 203, 157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2941979, 84351, 42, 0, 157, "Subsubsection"],
Cell[2942024, 84353, 57, 1, 157, "Input"],
Cell[2942084, 84356, 74, 1, 157, "Input"],
Cell[2942161, 84359, 75, 0, 157, "Text"],
Cell[CellGroupData[{
Cell[2942261, 84363, 49, 0, 157, "Input"],
Cell[2942313, 84365, 441, 7, 157, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
